"""Per-prefix data, mapping each prefix to a dict of locale:name.

Auto-generated file, do not edit by hand.
"""
from ..util import u

# Copyright (C) 2011-2018 The Libphonenumber Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

data = {
 '498761':{'de': 'Moosburg an der Isar', 'en': 'Moosburg an der Isar'},
 '55114473':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114474':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114477':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '497551':{'de': u('\u00dcberlingen Bodensee'), 'en': u('\u00dcberlingen Bodensee')},
 '497552':{'de': 'Pfullendorf', 'en': 'Pfullendorf'},
 '497553':{'de': 'Salem Baden', 'en': 'Salem Baden'},
 '497554':{'de': 'Heiligenberg Baden', 'en': 'Heiligenberg Baden'},
 '497555':{'de': 'Deggenhausertal', 'en': 'Deggenhausertal'},
 '497556':{'de': u('Uhldingen-M\u00fchlhofen'), 'en': u('Uhldingen-M\u00fchlhofen')},
 '497557':{'de': u('Herdwangen-Sch\u00f6nach'), 'en': u('Herdwangen-Sch\u00f6nach')},
 '497558':{'de': 'Illmensee', 'en': 'Illmensee'},
 '55133461':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '494928':{'de': 'Ihlow-Riepe', 'en': 'Ihlow-Riepe'},
 '494929':{'de': 'Ihlow Kreis Aurich', 'en': 'Ihlow Kreis Aurich'},
 '441779':{'en': 'Peterhead'},
 '441778':{'en': 'Bourne'},
 '441777':{'en': 'Retford'},
 '441776':{'en': 'Stranraer'},
 '441775':{'en': 'Spalding'},
 '494923':{'de': u('Krummh\u00f6rn-Pewsum'), 'en': u('Krummh\u00f6rn-Pewsum')},
 '441773':{'en': 'Ripley'},
 '441772':{'en': 'Preston'},
 '441771':{'en': 'Maud'},
 '441770':{'en': 'Isle of Arran'},
 '52867':{'en': 'Nuevo Leon/Tamaulipas', 'es': u('Nuevo Le\u00f3n/Tamaulipas')},
 '55133278':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133279':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133271':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133272':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133273':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55114699':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '52862':{'en': 'Coahuila', 'es': 'Coahuila'},
 '55114044':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '52468':{'en': 'San Luis de la Paz, GTO', 'es': 'San Luis de la Paz, GTO'},
 '52469':{'en': 'Buenavista de Cortez/Penjamo, GTO', 'es': u('Buenavista de Cort\u00e9s/P\u00e9njamo, GTO')},
 '499142':{'de': 'Treuchtlingen', 'en': 'Treuchtlingen'},
 '499145':{'de': 'Solnhofen', 'en': 'Solnhofen'},
 '52462':{'en': 'Irapuato, GTO', 'es': 'Irapuato, GTO'},
 '52463':{'en': 'Jalpa/Tabasco, ZAC', 'es': 'Jalpa/Tabasco, ZAC'},
 '52464':{'en': 'Salamanca, GTO', 'es': 'Salamanca, GTO'},
 '52465':{'en': 'Aguascalientes', 'es': 'Aguascalientes'},
 '52466':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '499144':{'de': 'Pleinfeld', 'en': 'Pleinfeld'},
 '55112622':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112623':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112621':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115906':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499147':{'de': 'Nennslingen', 'en': 'Nennslingen'},
 '55115904':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112625':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112628':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499146':{'de': 'Markt Berolzheim', 'en': 'Markt Berolzheim'},
 '55123527':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '441368':{'en': 'Dunbar'},
 '441369':{'en': 'Dunoon'},
 '55123522':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '441364':{'en': 'Ashburton'},
 '441366':{'en': 'Downham Market'},
 '441367':{'en': 'Faringdon'},
 '441360':{'en': 'Killearn'},
 '441361':{'en': 'Duns'},
 '441362':{'en': 'Dereham'},
 '441363':{'en': 'Crediton'},
 '4414792':{'en': 'Grantown-on-Spey'},
 '4414793':{'en': 'Grantown-on-Spey'},
 '4414790':{'en': 'Grantown-on-Spey'},
 '4414791':{'en': 'Grantown-on-Spey'},
 '4414796':{'en': 'Grantown-on-Spey'},
 '4414797':{'en': 'Grantown-on-Spey'},
 '4414794':{'en': 'Grantown-on-Spey'},
 '4414795':{'en': 'Grantown-on-Spey'},
 '437619':{'de': 'Kirchham', 'en': 'Kirchham'},
 '4936454':{'de': 'Magdala', 'en': 'Magdala'},
 '4414799':{'en': 'Grantown-on-Spey'},
 '4936452':{'de': 'Berlstedt', 'en': 'Berlstedt'},
 '4936453':{'de': 'Mellingen', 'en': 'Mellingen'},
 '4936450':{'de': 'Kranichfeld', 'en': 'Kranichfeld'},
 '4936451':{'de': 'Buttelstedt', 'en': 'Buttelstedt'},
 '499264':{'de': u('K\u00fcps'), 'en': u('K\u00fcps')},
 '499265':{'de': 'Pressig', 'en': 'Pressig'},
 '499266':{'de': 'Mitwitz', 'en': 'Mitwitz'},
 '499267':{'de': 'Nordhalben', 'en': 'Nordhalben'},
 '499260':{'de': 'Wilhelmsthal Oberfranken', 'en': 'Wilhelmsthal Oberfranken'},
 '499261':{'de': 'Kronach', 'en': 'Kronach'},
 '499262':{'de': 'Wallenfels', 'en': 'Wallenfels'},
 '499263':{'de': 'Ludwigsstadt', 'en': 'Ludwigsstadt'},
 '44241':{'en': 'Coventry'},
 '44247':{'en': 'Coventry'},
 '499269':{'de': 'Tettau Kreis Kronach', 'en': 'Tettau Kreis Kronach'},
 '55112488':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112489':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '4934327':{'de': 'Waldheim Sachsen', 'en': 'Waldheim Sachsen'},
 '4934324':{'de': 'Ostrau Sachsen', 'en': 'Ostrau Sachsen'},
 '4934325':{'de': u('Mochau-L\u00fcttewitz'), 'en': u('Mochau-L\u00fcttewitz')},
 '4934322':{'de': 'Rosswein', 'en': 'Rosswein'},
 '4934321':{'de': 'Leisnig', 'en': 'Leisnig'},
 '437617':{'de': 'Traunkirchen', 'en': 'Traunkirchen'},
 '4934328':{'de': u('Hartha bei D\u00f6beln'), 'en': u('Hartha bei D\u00f6beln')},
 '55113689':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '437616':{'de': u('Gr\u00fcnau im Almtal'), 'en': u('Gr\u00fcnau im Almtal')},
 '55113683':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113682':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113681':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113687':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113686':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113685':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113684':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '437613':{'de': 'Laakirchen', 'en': 'Laakirchen'},
 '437612':{'de': 'Gmunden', 'en': 'Gmunden'},
 '441942':{'en': 'Wigan'},
 '441943':{'en': 'Guiseley'},
 '441944':{'en': 'West Heslerton'},
 '441945':{'en': 'Wisbech'},
 '441947':{'en': 'Whitby'},
 '441948':{'en': 'Whitchurch'},
 '441949':{'en': 'Whatton'},
 '4939226':{'de': 'Hohenziatz', 'en': 'Hohenziatz'},
 '498857':{'de': 'Benediktbeuern', 'en': 'Benediktbeuern'},
 '55113531':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499369':{'de': 'Uettingen', 'en': 'Uettingen'},
 '55113533':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113532':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113535':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113534':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113537':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113536':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113539':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113538':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543476':{'en': 'San Lorenzo, Santa Fe', 'es': 'San Lorenzo, Santa Fe'},
 '543471':{'en': u('Ca\u00f1ada de G\u00f3mez, Santa Fe'), 'es': u('Ca\u00f1ada de G\u00f3mez, Santa Fe')},
 '55123426':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '543472':{'en': u('Marcos Ju\u00e1rez, C\u00f3rdoba'), 'es': u('Marcos Ju\u00e1rez, C\u00f3rdoba')},
 '499935':{'de': 'Stephansposching', 'en': 'Stephansposching'},
 '4412291':{'en': 'Barrow-in-Furness/Millom'},
 '4412290':{'en': 'Barrow-in-Furness/Millom'},
 '4412293':{'en': 'Millom'},
 '4412292':{'en': 'Barrow-in-Furness'},
 '4412295':{'en': 'Barrow-in-Furness'},
 '4412294':{'en': 'Barrow-in-Furness'},
 '4412297':{'en': 'Millom'},
 '4412296':{'en': 'Barrow-in-Furness'},
 '4412299':{'en': 'Millom'},
 '4412298':{'en': 'Barrow-in-Furness'},
 '4938788':{'de': 'Gross Warnow', 'en': 'Gross Warnow'},
 '4938789':{'de': 'Wolfshagen bei Perleberg', 'en': 'Wolfshagen bei Perleberg'},
 '46960':{'en': 'Arvidsjaur'},
 '499936':{'de': 'Wallerfing', 'en': 'Wallerfing'},
 '4939395':{'de': 'Wanzer', 'en': 'Wanzer'},
 '4936870':{'de': 'Masserberg', 'en': 'Masserberg'},
 '4936871':{'de': 'Bad Colberg-Heldburg', 'en': 'Bad Colberg-Heldburg'},
 '4936873':{'de': 'Themar', 'en': 'Themar'},
 '4936874':{'de': u('Sch\u00f6nbrunn bei Hildburghaus'), 'en': u('Sch\u00f6nbrunn bei Hildburghaus')},
 '4936875':{'de': 'Straufhain-Streufdorf', 'en': 'Straufhain-Streufdorf'},
 '4936878':{'de': 'Oberland', 'en': 'Oberland'},
 '495724':{'de': 'Obernkirchen', 'en': 'Obernkirchen'},
 '495726':{'de': 'Wiedensahl', 'en': 'Wiedensahl'},
 '495721':{'de': 'Stadthagen', 'en': 'Stadthagen'},
 '495723':{'de': 'Bad Nenndorf', 'en': 'Bad Nenndorf'},
 '495722':{'de': u('B\u00fcckeburg'), 'en': u('B\u00fcckeburg')},
 '499937':{'de': u('Oberp\u00f6ring'), 'en': u('Oberp\u00f6ring')},
 '497959':{'de': 'Frankenhardt', 'en': 'Frankenhardt'},
 '511':{'en': 'Lima/Callao'},
 '497765':{'de': 'Rickenbach Hotzenwald', 'en': 'Rickenbach Hotzenwald'},
 '497764':{'de': 'Herrischried', 'en': 'Herrischried'},
 '497763':{'de': 'Murg', 'en': 'Murg'},
 '497762':{'de': 'Wehr Baden', 'en': 'Wehr Baden'},
 '497761':{'de': u('Bad S\u00e4ckingen'), 'en': u('Bad S\u00e4ckingen')},
 '499938':{'de': 'Moos Niederbayern', 'en': 'Moos Niederbayern'},
 '495541':{'de': u('Hann. M\u00fcnden'), 'en': u('Hann. M\u00fcnden')},
 '495543':{'de': 'Staufenberg Niedersachsen', 'en': 'Staufenberg Niedersachsen'},
 '495542':{'de': 'Witzenhausen', 'en': 'Witzenhausen'},
 '495545':{'de': u('Hedem\u00fcnden'), 'en': u('Hedem\u00fcnden')},
 '495544':{'de': 'Reinhardshagen', 'en': 'Reinhardshagen'},
 '495546':{'de': 'Scheden', 'en': 'Scheden'},
 '441562':{'en': 'Kidderminster'},
 '441563':{'en': 'Kilmarnock'},
 '441560':{'en': 'Moscow'},
 '441561':{'en': 'Laurencekirk'},
 '441566':{'en': 'Launceston'},
 '441567':{'en': 'Killin'},
 '441564':{'en': 'Lapworth'},
 '441565':{'en': 'Knutsford'},
 '441568':{'en': 'Leominster'},
 '441569':{'en': 'Stonehaven'},
 '55113916':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437945':{'de': 'Sankt Oswald bei Freistadt', 'en': 'St. Oswald bei Freistadt'},
 '437944':{'de': 'Sandl', 'en': 'Sandl'},
 '437947':{'de': 'Kefermarkt', 'en': 'Kefermarkt'},
 '437946':{'de': 'Gutau', 'en': 'Gutau'},
 '437941':{'de': u('Neumarkt im M\u00fchlkreis'), 'en': u('Neumarkt im M\u00fchlkreis')},
 '437943':{'de': 'Windhaag bei Freistadt', 'en': 'Windhaag bei Freistadt'},
 '437942':{'de': 'Freistadt', 'en': 'Freistadt'},
 '55115685':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115687':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115686':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437949':{'de': u('Rainbach im M\u00fchlkreis'), 'en': u('Rainbach im M\u00fchlkreis')},
 '437948':{'de': u('Hirschbach im M\u00fchlkreis'), 'en': u('Hirschbach im M\u00fchlkreis')},
 '55115683':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115682':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49391':{'de': 'Magdeburg', 'en': 'Magdeburg'},
 '55113915':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498281':{'de': 'Thannhausen Schwaben', 'en': 'Thannhausen Schwaben'},
 '499804':{'de': 'Aurach', 'en': 'Aurach'},
 '4844':{'en': u('Piotrk\u00f3w Trybunalski'), 'pl': u('Piotrk\u00f3w Trybunalski')},
 '498282':{'de': 'Krumbach Schwaben', 'en': 'Krumbach Schwaben'},
 '4934928':{'de': 'Seegrehna', 'en': 'Seegrehna'},
 '4934929':{'de': 'Straach', 'en': 'Straach'},
 '4934924':{'de': 'Zahna', 'en': 'Zahna'},
 '4934925':{'de': 'Bad Schmiedeberg', 'en': 'Bad Schmiedeberg'},
 '4934926':{'de': 'Pretzsch Elbe', 'en': 'Pretzsch Elbe'},
 '4934927':{'de': 'Globig-Bleddin', 'en': 'Globig-Bleddin'},
 '4934920':{'de': u('Kropst\u00e4dt'), 'en': u('Kropst\u00e4dt')},
 '4934921':{'de': 'Kemberg', 'en': 'Kemberg'},
 '4934922':{'de': u('M\u00fchlanger'), 'en': u('M\u00fchlanger')},
 '4934923':{'de': 'Cobbelsdorf', 'en': 'Cobbelsdorf'},
 '499805':{'de': 'Burgoberbach', 'en': 'Burgoberbach'},
 '4841':{'en': 'Kielce', 'pl': 'Kielce'},
 '494920':{'de': 'Wirdum', 'en': 'Wirdum'},
 '4842':{'en': u('L\u00f3d\u017a'), 'pl': u('\u0141\u00f3d\u017a')},
 '494921':{'de': 'Emden Stadt', 'en': 'Emden Stadt'},
 '4843':{'en': 'Sieradz', 'pl': 'Sieradz'},
 '494922':{'de': 'Borkum', 'en': 'Borkum'},
 '497943':{'de': u('Sch\u00f6ntal Jagst'), 'en': u('Sch\u00f6ntal Jagst')},
 '497942':{'de': u('Neuenstein W\u00fcrttemberg'), 'en': u('Neuenstein W\u00fcrttemberg')},
 '497941':{'de': u('\u00d6hringen'), 'en': u('\u00d6hringen')},
 '497576':{'de': 'Krauchenwies', 'en': 'Krauchenwies'},
 '4934692':{'de': 'Alsleben Saale', 'en': 'Alsleben Saale'},
 '497946':{'de': 'Bretzfeld', 'en': 'Bretzfeld'},
 '497945':{'de': u('W\u00fcstenrot'), 'en': u('W\u00fcstenrot')},
 '4934691':{'de': u('K\u00f6nnern'), 'en': u('K\u00f6nnern')},
 '494924':{'de': 'Moormerland-Oldersum', 'en': 'Moormerland-Oldersum'},
 '497949':{'de': 'Pfedelbach-Untersteinbach', 'en': 'Pfedelbach-Untersteinbach'},
 '497948':{'de': u('\u00d6hringen-Ohrnberg'), 'en': u('\u00d6hringen-Ohrnberg')},
 '494925':{'de': 'Hinte', 'en': 'Hinte'},
 '4936203':{'de': 'Vieselbach', 'en': 'Vieselbach'},
 '4936202':{'de': 'Neudietendorf', 'en': 'Neudietendorf'},
 '4936201':{'de': 'Walschleben', 'en': 'Walschleben'},
 '4936200':{'de': 'Elxleben bei Arnstadt', 'en': 'Elxleben bei Arnstadt'},
 '4936207':{'de': u('Plaue Th\u00fcringen'), 'en': u('Plaue Th\u00fcringen')},
 '4936206':{'de': 'Grossfahner', 'en': 'Grossfahner'},
 '4936205':{'de': u('Gr\u00e4fenroda'), 'en': u('Gr\u00e4fenroda')},
 '4936204':{'de': 'Stotternheim', 'en': 'Stotternheim'},
 '4936209':{'de': 'Klettbach', 'en': 'Klettbach'},
 '4936208':{'de': 'Ermstedt', 'en': 'Ermstedt'},
 '55113911':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497574':{'de': 'Gammertingen', 'en': 'Gammertingen'},
 '4621':{'en': u('V\u00e4ster\u00e5s'), 'sv': u('V\u00e4ster\u00e5s')},
 '55113054':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4623':{'en': 'Falun'},
 '55113052':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4626':{'en': u('G\u00e4vle-Sandviken'), 'sv': u('G\u00e4vle-Sandviken')},
 '55113051':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113059':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499721':{'de': 'Schweinfurt', 'en': 'Schweinfurt'},
 '499720':{'de': u('\u00dcchtelhausen'), 'en': u('\u00dcchtelhausen')},
 '499723':{'de': u('R\u00f6thlein'), 'en': u('R\u00f6thlein')},
 '499722':{'de': 'Werneck', 'en': 'Werneck'},
 '499725':{'de': 'Poppenhausen Unterfranken', 'en': 'Poppenhausen Unterfranken'},
 '499724':{'de': 'Stadtlauringen', 'en': 'Stadtlauringen'},
 '499727':{'de': 'Schonungen-Marktsteinach', 'en': 'Schonungen-Marktsteinach'},
 '499726':{'de': 'Euerbach', 'en': 'Euerbach'},
 '499729':{'de': 'Grettstadt', 'en': 'Grettstadt'},
 '499728':{'de': u('W\u00fclfershausen Unterfranken'), 'en': u('W\u00fclfershausen Unterfranken')},
 '55114228':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55114229':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '499802':{'de': 'Ansbach-Katterbach', 'en': 'Ansbach-Katterbach'},
 '55113948':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113949':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113941':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113942':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495065':{'de': 'Sibbesse', 'en': 'Sibbesse'},
 '55113237':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113234':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113235':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492845':{'de': 'Neukirchen-Vluyn', 'en': 'Neukirchen-Vluyn'},
 '492844':{'de': 'Rheinberg-Orsoy', 'en': 'Rheinberg-Orsoy'},
 '492841':{'de': 'Moers', 'en': 'Moers'},
 '492843':{'de': 'Rheinberg', 'en': 'Rheinberg'},
 '492842':{'de': 'Kamp-Lintfort', 'en': 'Kamp-Lintfort'},
 '46300':{'en': 'Kungsbacka', 'sv': 'Kungsbacka'},
 '46301':{'en': u('Hind\u00e5s'), 'sv': u('Hind\u00e5s')},
 '46302':{'en': 'Lerum'},
 '46303':{'en': u('Kung\u00e4lv'), 'sv': u('Kung\u00e4lv')},
 '46304':{'en': u('Orust-Tj\u00f6rn')},
 '46657':{'en': 'Los', 'sv': 'Los'},
 '4939202':{'de': 'Gross Ammensleben', 'en': 'Gross Ammensleben'},
 '4939203':{'de': 'Barleben', 'en': 'Barleben'},
 '4939200':{'de': 'Gommern', 'en': 'Gommern'},
 '4939201':{'de': 'Wolmirstedt', 'en': 'Wolmirstedt'},
 '4939206':{'de': 'Eichenbarleben', 'en': 'Eichenbarleben'},
 '4939207':{'de': 'Colbitz', 'en': 'Colbitz'},
 '4939204':{'de': 'Niederndodeleben', 'en': 'Niederndodeleben'},
 '4939205':{'de': 'Langenweddingen', 'en': 'Langenweddingen'},
 '55112682':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113062':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112683':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112549':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112019':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112018':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112015':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112011':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112010':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112013':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113068':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49791':{'de': u('Schw\u00e4bisch Hall'), 'en': u('Schw\u00e4bisch Hall')},
 '55113918':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437718':{'de': 'Waldkirchen am Wesen', 'en': 'Waldkirchen am Wesen'},
 '437719':{'de': 'Taufkirchen an der Pram', 'en': 'Taufkirchen an der Pram'},
 '493821':{'de': 'Ribnitz-Damgarten', 'en': 'Ribnitz-Damgarten'},
 '437711':{'de': 'Suben', 'en': 'Suben'},
 '437712':{'de': u('Sch\u00e4rding'), 'en': u('Sch\u00e4rding')},
 '437713':{'de': 'Schardenberg', 'en': 'Schardenberg'},
 '437714':{'de': 'Esternberg', 'en': 'Esternberg'},
 '437716':{'de': u('M\u00fcnzkirchen'), 'en': u('M\u00fcnzkirchen')},
 '437717':{'de': 'Sankt Aegidi', 'en': 'St. Aegidi'},
 '4938847':{'de': 'Boizenburg Elbe', 'en': 'Boizenburg Elbe'},
 '4938334':{'de': 'Grammendorf', 'en': 'Grammendorf'},
 '4938845':{'de': 'Kaarssen', 'en': 'Kaarssen'},
 '4938844':{'de': u('G\u00fclze'), 'en': u('G\u00fclze')},
 '4938331':{'de': 'Rakow Vorpom', 'en': 'Rakow Vorpom'},
 '4938842':{'de': u('L\u00fcttenmark'), 'en': u('L\u00fcttenmark')},
 '4938333':{'de': 'Horst bei Grimmen', 'en': 'Horst bei Grimmen'},
 '4938332':{'de': 'Gross Bisdorf', 'en': 'Gross Bisdorf'},
 '4938848':{'de': 'Vellahn', 'en': 'Vellahn'},
 '495971':{'de': 'Rheine', 'en': 'Rheine'},
 '495973':{'de': 'Neuenkirchen Kreis Steinfurt', 'en': 'Neuenkirchen Kreis Steinfurt'},
 '495975':{'de': 'Rheine-Mesum', 'en': 'Rheine-Mesum'},
 '495976':{'de': 'Salzbergen', 'en': 'Salzbergen'},
 '495977':{'de': 'Spelle', 'en': 'Spelle'},
 '495978':{'de': u('H\u00f6rstel-Dreierwalde'), 'en': u('H\u00f6rstel-Dreierwalde')},
 '55123848':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123849':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123845':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123842':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123843':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '499733':{'de': u('M\u00fcnnerstadt'), 'en': u('M\u00fcnnerstadt')},
 '496373':{'de': u('Sch\u00f6nenberg-K\u00fcbelberg'), 'en': u('Sch\u00f6nenberg-K\u00fcbelberg')},
 '496372':{'de': u('Bruchm\u00fchlbach-Miesau'), 'en': u('Bruchm\u00fchlbach-Miesau')},
 '496371':{'de': 'Landstuhl', 'en': 'Landstuhl'},
 '496375':{'de': 'Wallhalben', 'en': 'Wallhalben'},
 '496374':{'de': 'Weilerbach', 'en': 'Weilerbach'},
 '55114255':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55133424':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '55114256':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55123519':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '52461':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '55133422':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '492274':{'de': 'Elsdorf Rheinland', 'en': 'Elsdorf Rheinland'},
 '492275':{'de': 'Kerpen-Buir', 'en': 'Kerpen-Buir'},
 '492272':{'de': 'Bedburg Erft', 'en': 'Bedburg Erft'},
 '492273':{'de': 'Kerpen-Horrem', 'en': 'Kerpen-Horrem'},
 '492271':{'de': 'Bergheim Erft', 'en': 'Bergheim Erft'},
 '55115555':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52643':{'en': 'Sonora', 'es': 'Sonora'},
 '55114419':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55114418':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114417':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114416':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114415':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114414':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114413':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114412':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114411':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55115907':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112276':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497532':{'de': 'Meersburg', 'en': 'Meersburg'},
 '497021':{'de': 'Kirchheim unter Teck', 'en': 'Kirchheim unter Teck'},
 '497022':{'de': u('N\u00fcrtingen'), 'en': u('N\u00fcrtingen')},
 '497023':{'de': 'Weilheim an der Teck', 'en': 'Weilheim an der Teck'},
 '497024':{'de': 'Wendlingen am Neckar', 'en': 'Wendlingen am Neckar'},
 '497025':{'de': 'Neuffen', 'en': 'Neuffen'},
 '497026':{'de': 'Lenningen', 'en': 'Lenningen'},
 '493631':{'de': u('Nordhausen Th\u00fcringen'), 'en': u('Nordhausen Th\u00fcringen')},
 '493632':{'de': 'Sondershausen', 'en': 'Sondershausen'},
 '493635':{'de': u('K\u00f6lleda'), 'en': u('K\u00f6lleda')},
 '493634':{'de': u('S\u00f6mmerda'), 'en': u('S\u00f6mmerda')},
 '493636':{'de': 'Greussen', 'en': 'Greussen'},
 '494942':{'de': u('S\u00fcdbrookmerland'), 'en': u('S\u00fcdbrookmerland')},
 '494943':{'de': 'Grossefehn', 'en': 'Grossefehn'},
 '494941':{'de': 'Aurich', 'en': 'Aurich'},
 '494946':{'de': 'Grossefehn-Bagband', 'en': 'Grossefehn-Bagband'},
 '494947':{'de': 'Aurich-Ogenbargen', 'en': 'Aurich-Ogenbargen'},
 '494944':{'de': 'Wiesmoor', 'en': 'Wiesmoor'},
 '494945':{'de': 'Grossefehn-Timmel', 'en': 'Grossefehn-Timmel'},
 '494948':{'de': 'Wiesmoor-Marcardsmoor', 'en': 'Wiesmoor-Marcardsmoor'},
 '55113207':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498424':{'de': 'Nassenfels', 'en': 'Nassenfels'},
 '498427':{'de': 'Wellheim', 'en': 'Wellheim'},
 '498426':{'de': u('Walting Kreis Eichst\u00e4tt'), 'en': u('Walting Kreis Eichst\u00e4tt')},
 '55115090':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498421':{'de': u('Eichst\u00e4tt Bayern'), 'en': u('Eichst\u00e4tt Bayern')},
 '55115092':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115094':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115095':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113202':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492858':{'de': u('H\u00fcnxe'), 'en': u('H\u00fcnxe')},
 '492859':{'de': 'Wesel-Bislich', 'en': 'Wesel-Bislich'},
 '436548':{'de': 'Niedernsill', 'en': 'Niedernsill'},
 '436549':{'de': 'Piesendorf', 'en': 'Piesendorf'},
 '436546':{'de': u('Fusch an der Gro\u00dfglocknerstra\u00dfe'), 'en': 'Fusch an der Grossglocknerstrasse'},
 '436547':{'de': 'Kaprun', 'en': 'Kaprun'},
 '436544':{'de': 'Rauris', 'en': 'Rauris'},
 '436545':{'de': u('Bruck an der Gro\u00dfglocknerstra\u00dfe'), 'en': 'Bruck an der Grossglocknerstrasse'},
 '436542':{'de': 'Zell am See', 'en': 'Zell am See'},
 '436543':{'de': 'Taxenbach', 'en': 'Taxenbach'},
 '436541':{'de': 'Saalbach', 'en': 'Saalbach'},
 '4934771':{'de': 'Querfurt', 'en': 'Querfurt'},
 '4934773':{'de': 'Schwittersdorf', 'en': 'Schwittersdorf'},
 '4934772':{'de': 'Helbra', 'en': 'Helbra'},
 '4934775':{'de': 'Wippra', 'en': 'Wippra'},
 '4934774':{'de': u('R\u00f6blingen am See'), 'en': u('R\u00f6blingen am See')},
 '4934776':{'de': 'Rothenschirmbach', 'en': 'Rothenschirmbach'},
 '4934779':{'de': 'Abberode', 'en': 'Abberode'},
 '49561':{'de': 'Kassel', 'en': 'Kassel'},
 '498624':{'de': 'Obing', 'en': 'Obing'},
 '498623':{'de': 'Kirchweidach', 'en': 'Kirchweidach'},
 '498622':{'de': 'Tacherting-Peterskirchen', 'en': 'Tacherting-Peterskirchen'},
 '498621':{'de': 'Trostberg', 'en': 'Trostberg'},
 '492851':{'de': 'Rees', 'en': 'Rees'},
 '498629':{'de': 'Palling', 'en': 'Palling'},
 '498628':{'de': 'Kienberg Oberbayern', 'en': 'Kienberg Oberbayern'},
 '494366':{'de': u('Gr\u00f6mitz-Cismar'), 'en': u('Gr\u00f6mitz-Cismar')},
 '494367':{'de': 'Grossenbrode', 'en': 'Grossenbrode'},
 '494364':{'de': 'Dahme Kreis Ostholstein', 'en': 'Dahme Kreis Ostholstein'},
 '494365':{'de': 'Heringsdorf Holstein', 'en': 'Heringsdorf Holstein'},
 '494362':{'de': 'Heiligenhafen', 'en': 'Heiligenhafen'},
 '494363':{'de': 'Lensahn', 'en': 'Lensahn'},
 '494361':{'de': 'Oldenburg in Holstein', 'en': 'Oldenburg in Holstein'},
 '49541':{'de': u('Osnabr\u00fcck'), 'en': u('Osnabr\u00fcck')},
 '55115855':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '46515':{'en': u('Falk\u00f6ping'), 'sv': u('Falk\u00f6ping')},
 '46514':{'en': u('Gr\u00e4storp'), 'sv': u('Gr\u00e4storp')},
 '46511':{'en': u('Skara-G\u00f6tene'), 'sv': u('Skara-G\u00f6tene')},
 '46510':{'en': u('Lidk\u00f6ping'), 'sv': u('Lidk\u00f6ping')},
 '46513':{'en': 'Herrljunga'},
 '46512':{'en': 'Vara-Nossebro', 'sv': 'Vara-Nossebro'},
 '499286':{'de': 'Oberkotzau', 'en': 'Oberkotzau'},
 '499287':{'de': 'Selb', 'en': 'Selb'},
 '499284':{'de': 'Schwarzenbach an der Saale', 'en': 'Schwarzenbach an der Saale'},
 '499285':{'de': 'Kirchenlamitz', 'en': 'Kirchenlamitz'},
 '499282':{'de': 'Naila', 'en': 'Naila'},
 '499283':{'de': 'Rehau', 'en': 'Rehau'},
 '499280':{'de': 'Selbitz Oberfranken', 'en': 'Selbitz Oberfranken'},
 '499281':{'de': 'Hof Saale', 'en': 'Hof Saale'},
 '4934341':{'de': 'Geithain', 'en': 'Geithain'},
 '4934342':{'de': 'Neukieritzsch', 'en': 'Neukieritzsch'},
 '4934343':{'de': 'Regis-Breitingen', 'en': 'Regis-Breitingen'},
 '4934344':{'de': 'Kohren-Sahlis', 'en': 'Kohren-Sahlis'},
 '4934345':{'de': 'Bad Lausick', 'en': 'Bad Lausick'},
 '4934346':{'de': 'Narsdorf', 'en': 'Narsdorf'},
 '4934347':{'de': 'Oelzschau bei Borna', 'en': 'Oelzschau bei Borna'},
 '4934348':{'de': 'Frohburg', 'en': 'Frohburg'},
 '55113834':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112396':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '494702':{'de': 'Sandstedt', 'en': 'Sandstedt'},
 '494703':{'de': 'Loxstedt-Donnern', 'en': 'Loxstedt-Donnern'},
 '542622':{'en': u('Tunuy\u00e1n, Mendoza'), 'es': u('Tunuy\u00e1n, Mendoza')},
 '494704':{'de': 'Drangstedt', 'en': 'Drangstedt'},
 '55113835':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494705':{'de': 'Wremen', 'en': 'Wremen'},
 '441928':{'en': 'Runcorn'},
 '441929':{'en': 'Wareham'},
 '4936458':{'de': 'Bad Berka', 'en': 'Bad Berka'},
 '441922':{'en': 'Walsall'},
 '441923':{'en': 'Watford'},
 '441920':{'en': 'Ware'},
 '4936459':{'de': u('Blankenhain Th\u00fcringen'), 'en': u('Blankenhain Th\u00fcringen')},
 '441926':{'en': 'Warwick'},
 '494409':{'de': 'Westerstede-Ocholt', 'en': 'Westerstede-Ocholt'},
 '441924':{'en': 'Wakefield'},
 '441925':{'en': 'Warrington'},
 '499084':{'de': 'Bissingen Schwaben', 'en': 'Bissingen Schwaben'},
 '441583':{'en': 'Carradale'},
 '55113836':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113556':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113555':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113554':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113552':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113559':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494403':{'de': 'Bad Zwischenahn', 'en': 'Bad Zwischenahn'},
 '55112978':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112979':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113837':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112972':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112973':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112970':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55112971':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112976':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112977':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112974':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112975':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112486':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55114789':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '543458':{'en': u('San Jos\u00e9 de Feliciano, Entre R\u00edos'), 'es': u('San Jos\u00e9 de Feliciano, Entre R\u00edos')},
 '55114787':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '543456':{'en': u('Chajar\u00ed, Entre R\u00edos'), 'es': u('Chajar\u00ed, Entre R\u00edos')},
 '543455':{'en': u('Villaguay, Entre R\u00edos'), 'es': u('Villaguay, Entre R\u00edos')},
 '543454':{'en': u('Federal, Entre R\u00edos'), 'es': u('Federal, Entre R\u00edos')},
 '55114783':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '55112484':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112954':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112485':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112482':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55115853':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112483':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '495707':{'de': 'Petershagen Weser', 'en': 'Petershagen Weser'},
 '495706':{'de': 'Porta Westfalica', 'en': 'Porta Westfalica'},
 '495705':{'de': 'Petershagen-Windheim', 'en': 'Petershagen-Windheim'},
 '495704':{'de': 'Petershagen-Friedewalde', 'en': 'Petershagen-Friedewalde'},
 '495703':{'de': 'Hille', 'en': 'Hille'},
 '495702':{'de': 'Petershagen-Lahde', 'en': 'Petershagen-Lahde'},
 '55112481':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112955':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113831':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499268':{'de': 'Teuschnitz', 'en': 'Teuschnitz'},
 '55112956':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112959':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4938458':{'de': 'Zehna', 'en': 'Zehna'},
 '4938459':{'de': 'Laage', 'en': 'Laage'},
 '497703':{'de': 'Bonndorf im Schwarzwald', 'en': 'Bonndorf im Schwarzwald'},
 '497702':{'de': 'Blumberg Baden', 'en': 'Blumberg Baden'},
 '497705':{'de': 'Wolterdingen Schwarzw', 'en': 'Wolterdingen Schwarzw'},
 '497704':{'de': 'Geisingen Baden', 'en': 'Geisingen Baden'},
 '497707':{'de': u('Br\u00e4unlingen'), 'en': u('Br\u00e4unlingen')},
 '497706':{'de': 'Oberbaldingen', 'en': 'Oberbaldingen'},
 '4938450':{'de': u('Tarnow bei B\u00fctzow'), 'en': u('Tarnow bei B\u00fctzow')},
 '4938451':{'de': u('Hoppenrade bei G\u00fcstrow'), 'en': u('Hoppenrade bei G\u00fcstrow')},
 '4938452':{'de': 'Lalendorf', 'en': 'Lalendorf'},
 '4938453':{'de': 'Mistorf', 'en': 'Mistorf'},
 '4938454':{'de': 'Kritzkow', 'en': 'Kritzkow'},
 '4938455':{'de': 'Plaaz', 'en': 'Plaaz'},
 '4938456':{'de': u('Langhagen bei G\u00fcstrow'), 'en': u('Langhagen bei G\u00fcstrow')},
 '4938457':{'de': 'Krakow am See', 'en': 'Krakow am See'},
 '495563':{'de': 'Kreiensen', 'en': 'Kreiensen'},
 '495562':{'de': 'Dassel-Markoldendorf', 'en': 'Dassel-Markoldendorf'},
 '495561':{'de': 'Einbeck', 'en': 'Einbeck'},
 '495565':{'de': 'Einbeck-Wenzen', 'en': 'Einbeck-Wenzen'},
 '495564':{'de': 'Dassel', 'en': 'Dassel'},
 '55112957':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112201':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115522':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112203':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112204':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112205':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112206':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112207':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123108':{'en': 'Aparecida - SP', 'pt': 'Aparecida - SP'},
 '55123103':{'en': 'Cachoeira Paulista - SP', 'pt': 'Cachoeira Paulista - SP'},
 '55123102':{'en': 'Silveiras - SP', 'pt': 'Silveiras - SP'},
 '55123101':{'en': 'Cachoeira Paulista - SP', 'pt': 'Cachoeira Paulista - SP'},
 '55123107':{'en': 'Areias - SP', 'pt': 'Areias - SP'},
 '55123106':{'en': 'Silveiras - SP', 'pt': 'Silveiras - SP'},
 '55123105':{'en': 'Aparecida - SP', 'pt': 'Aparecida - SP'},
 '55123104':{'en': 'Aparecida - SP', 'pt': 'Aparecida - SP'},
 '441548':{'en': 'Kingsbridge'},
 '441549':{'en': 'Lairg'},
 '55112950':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441544':{'en': 'Kington'},
 '441545':{'en': 'Llanarth'},
 '441546':{'en': 'Lochgilphead'},
 '441547':{'en': 'Knighton'},
 '441540':{'en': 'Kingussie'},
 '441542':{'en': 'Keith'},
 '441543':{'en': 'Cannock'},
 '55115663':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115661':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115660':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112951':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115666':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115665':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115669':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115668':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492485':{'de': 'Schleiden-Dreiborn', 'en': 'Schleiden-Dreiborn'},
 '492484':{'de': 'Mechernich-Eiserfey', 'en': 'Mechernich-Eiserfey'},
 '4934904':{'de': 'Oranienbaum', 'en': 'Oranienbaum'},
 '4934905':{'de': u('W\u00f6rlitz'), 'en': u('W\u00f6rlitz')},
 '4934903':{'de': 'Coswig Anhalt', 'en': 'Coswig Anhalt'},
 '543877':{'en': u('Joaqu\u00edn V\u00edctor Gonz\u00e1lez, Salta'), 'es': u('Joaqu\u00edn V\u00edctor Gonz\u00e1lez, Salta')},
 '492482':{'de': 'Hellenthal', 'en': 'Hellenthal'},
 '543878':{'en': u('Or\u00e1n, Salta'), 'es': u('Or\u00e1n, Salta')},
 '4934909':{'de': 'Aken Elbe', 'en': 'Aken Elbe'},
 '55113688':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113971':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113934':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52836':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '435523':{'de': u('G\u00f6tzis'), 'en': u('G\u00f6tzis')},
 '435522':{'de': 'Feldkirch', 'en': 'Feldkirch'},
 '435525':{'de': 'Nenzing', 'en': 'Nenzing'},
 '435524':{'de': 'Satteins', 'en': 'Satteins'},
 '52831':{'en': 'Ciudad Mante/Los Aztecas, TAMPS', 'es': 'Ciudad Mante/Los Aztecas, TAMPS'},
 '435526':{'de': 'Laterns', 'en': 'Laterns'},
 '55112953':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499824':{'de': 'Dietenhofen', 'en': 'Dietenhofen'},
 '496031':{'de': 'Friedberg Hessen', 'en': 'Friedberg Hessen'},
 '496032':{'de': 'Bad Nauheim', 'en': 'Bad Nauheim'},
 '496033':{'de': 'Butzbach', 'en': 'Butzbach'},
 '496034':{'de': u('W\u00f6llstadt'), 'en': u('W\u00f6llstadt')},
 '496035':{'de': 'Reichelsheim Wetterau', 'en': 'Reichelsheim Wetterau'},
 '496036':{'de': u('W\u00f6lfersheim'), 'en': u('W\u00f6lfersheim')},
 '496039':{'de': 'Karben', 'en': 'Karben'},
 '55133284':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55113838':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492739':{'de': 'Wilnsdorf', 'en': 'Wilnsdorf'},
 '492738':{'de': 'Netphen', 'en': 'Netphen'},
 '492737':{'de': 'Netphen-Deuz', 'en': 'Netphen-Deuz'},
 '492736':{'de': 'Burbach Siegerl', 'en': 'Burbach Siegerl'},
 '492735':{'de': 'Neunkirchen Siegerl', 'en': 'Neunkirchen Siegerl'},
 '492734':{'de': 'Freudenberg Westfalen', 'en': 'Freudenberg Westfalen'},
 '492733':{'de': 'Hilchenbach', 'en': 'Hilchenbach'},
 '492732':{'de': 'Kreuztal', 'en': 'Kreuztal'},
 '55113973':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133288':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '542477':{'en': 'Pergamino, Buenos Aires', 'es': 'Pergamino, Buenos Aires'},
 '542474':{'en': 'Salto, Buenos Aires', 'es': 'Salto, Buenos Aires'},
 '542475':{'en': 'Rojas, Buenos Aires', 'es': 'Rojas, Buenos Aires'},
 '542473':{'en': u('Col\u00f3n, Buenos Aires'), 'es': u('Col\u00f3n, Buenos Aires')},
 '542478':{'en': 'Arrecifes, Buenos Aires', 'es': 'Arrecifes, Buenos Aires'},
 '52349':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52348':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52345':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52344':{'en': 'Mexticacan/Yahualica, JAL', 'es': 'Mexticacan/Yahualica, JAL'},
 '52347':{'en': 'Jalisco', 'es': 'Jalisco'},
 '498841':{'de': 'Murnau am Staffelsee', 'en': 'Murnau am Staffelsee'},
 '52341':{'en': 'Ciudad Guzman, JAL', 'es': u('Ciudad Guzm\u00e1n, JAL')},
 '55113031':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52343':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52342':{'en': 'Gomez Farias/Sayula, JAL', 'es': u('G\u00f3mez Far\u00edas/Sayula, JAL')},
 '4414349':{'en': 'Bellingham'},
 '4414348':{'en': 'Hexham'},
 '4414345':{'en': 'Haltwhistle'},
 '4414344':{'en': 'Bellingham'},
 '4414347':{'en': 'Hexham'},
 '4414346':{'en': 'Hexham'},
 '4414341':{'en': 'Bellingham/Haltwhistle/Hexham'},
 '4414340':{'en': 'Bellingham/Haltwhistle/Hexham'},
 '4414343':{'en': 'Haltwhistle'},
 '4414342':{'en': 'Bellingham'},
 '55114209':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114202':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55114201':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114206':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '55114204':{'en': u('Ara\u00e7ariguama - SP'), 'pt': u('Ara\u00e7ariguama - SP')},
 '55114205':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '499708':{'de': 'Bad Bocklet', 'en': 'Bad Bocklet'},
 '494559':{'de': 'Wensin', 'en': 'Wensin'},
 '494558':{'de': 'Todesfelde', 'en': 'Todesfelde'},
 '55112958':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494555':{'de': 'Seedorf bei Bad Segeberg', 'en': 'Seedorf bei Bad Segeberg'},
 '494554':{'de': 'Wahlstedt', 'en': 'Wahlstedt'},
 '494557':{'de': 'Blunk', 'en': 'Blunk'},
 '494556':{'de': u('Ahrensb\u00f6k-Gnissau'), 'en': u('Ahrensb\u00f6k-Gnissau')},
 '494551':{'de': 'Bad Segeberg', 'en': 'Bad Segeberg'},
 '494550':{'de': u('B\u00fchnsdorf'), 'en': u('B\u00fchnsdorf')},
 '494881':{'de': 'Friedrichstadt', 'en': 'Friedrichstadt'},
 '494552':{'de': 'Leezen', 'en': 'Leezen'},
 '492867':{'de': 'Heiden Kreis Borken', 'en': 'Heiden Kreis Borken'},
 '492866':{'de': 'Dorsten-Rhade', 'en': 'Dorsten-Rhade'},
 '492865':{'de': 'Raesfeld', 'en': 'Raesfeld'},
 '492864':{'de': 'Reken', 'en': 'Reken'},
 '492863':{'de': 'Velen', 'en': 'Velen'},
 '492862':{'de': u('S\u00fcdlohn'), 'en': u('S\u00fcdlohn')},
 '492861':{'de': 'Borken Westfalen', 'en': 'Borken Westfalen'},
 '55113785':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113966':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113788':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113965':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52697':{'en': 'Sinoloa', 'es': 'Sinoloa'},
 '52696':{'en': 'Sinoloa', 'es': 'Sinoloa'},
 '52695':{'en': 'Sinoloa', 'es': 'Sinoloa'},
 '52694':{'en': 'Sinoloa', 'es': 'Sinoloa'},
 '4935754':{'de': 'Klettwitz', 'en': 'Klettwitz'},
 '4935755':{'de': 'Ortrand', 'en': 'Ortrand'},
 '4935756':{'de': 'Hosena', 'en': 'Hosena'},
 '4935751':{'de': 'Welzow', 'en': 'Welzow'},
 '4935752':{'de': 'Ruhland', 'en': 'Ruhland'},
 '4935753':{'de': u('Gro\u00dfr\u00e4schen'), 'en': u('Grossr\u00e4schen')},
 '4939888':{'de': 'Lychen', 'en': 'Lychen'},
 '4939889':{'de': 'Boitzenburg', 'en': 'Boitzenburg'},
 '46670':{'en': u('Str\u00f6msund'), 'sv': u('Str\u00f6msund')},
 '46671':{'en': 'Hoting', 'sv': 'Hoting'},
 '494773':{'de': 'Lamstedt', 'en': 'Lamstedt'},
 '4939883':{'de': u('Gro\u00df D\u00f6lln'), 'en': u('Gross D\u00f6lln')},
 '4939884':{'de': 'Hassleben bei Prenzlau', 'en': 'Hassleben bei Prenzlau'},
 '4939885':{'de': 'Jakobshagen', 'en': 'Jakobshagen'},
 '4939886':{'de': 'Milmersdorf', 'en': 'Milmersdorf'},
 '4939887':{'de': 'Gerswalde', 'en': 'Gerswalde'},
 '496307':{'de': 'Schopp', 'en': 'Schopp'},
 '55112785':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112784':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112787':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112781':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112783':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4939080':{'de': 'Kalbe Milde', 'en': 'Kalbe Milde'},
 '4939081':{'de': 'Kakerbeck Sachsen-Anhalt', 'en': 'Kakerbeck Sachsen-Anhalt'},
 '4939082':{'de': 'Mieste', 'en': 'Mieste'},
 '4939083':{'de': 'Messdorf', 'en': 'Messdorf'},
 '4939084':{'de': 'Lindstedt', 'en': 'Lindstedt'},
 '4939085':{'de': 'Zichtau', 'en': 'Zichtau'},
 '4939086':{'de': u('J\u00e4venitz'), 'en': u('J\u00e4venitz')},
 '4939087':{'de': 'Jerchel Altmark', 'en': 'Jerchel Altmark'},
 '4939088':{'de': 'Letzlingen', 'en': 'Letzlingen'},
 '4939089':{'de': 'Bismark Altmark', 'en': 'Bismark Altmark'},
 '55114606':{'en': u('V\u00e1rzea Paulista - SP'), 'pt': u('V\u00e1rzea Paulista - SP')},
 '55114607':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114604':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55114586':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114605':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '55114602':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55112561':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112562':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112565':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112567':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112566':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112569':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112568':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114601':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55112553':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498367':{'de': u('Ro\u00dfhaupten Forggensee'), 'en': 'Rosshaupten Forggensee'},
 '49751':{'de': 'Ravensburg', 'en': 'Ravensburg'},
 '55124104':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55124109':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '542648':{'en': 'Calingasta, San Juan', 'es': 'Calingasta, San Juan'},
 '542647':{'en': u('San Jos\u00e9 de J\u00e1chal, San Juan'), 'es': u('San Jos\u00e9 de J\u00e1chal, San Juan')},
 '542646':{'en': u('Villa San Agust\u00edn, San Juan'), 'es': u('Villa San Agust\u00edn, San Juan')},
 '492251':{'de': 'Euskirchen', 'en': 'Euskirchen'},
 '492252':{'de': u('Z\u00fclpich'), 'en': u('Z\u00fclpich')},
 '492253':{'de': u('Bad M\u00fcnstereifel'), 'en': u('Bad M\u00fcnstereifel')},
 '492254':{'de': 'Weilerswist', 'en': 'Weilerswist'},
 '492255':{'de': 'Euskirchen-Flamersheim', 'en': 'Euskirchen-Flamersheim'},
 '492256':{'de': 'Mechernich-Satzvey', 'en': 'Mechernich-Satzvey'},
 '492257':{'de': 'Reckerscheid', 'en': 'Reckerscheid'},
 '55114435':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114434':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114437':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114436':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114431':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114433':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114432':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114439':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114438':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '441489':{'en': 'Bishops Waltham'},
 '441488':{'en': 'Hungerford'},
 '497041':{'de': u('M\u00fchlacker'), 'en': u('M\u00fchlacker')},
 '497046':{'de': 'Zaberfeld', 'en': 'Zaberfeld'},
 '497044':{'de': u('M\u00f6nsheim'), 'en': u('M\u00f6nsheim')},
 '497045':{'de': 'Oberderdingen', 'en': 'Oberderdingen'},
 '441481':{'en': 'Guernsey'},
 '441480':{'en': 'Huntingdon'},
 '441483':{'en': 'Guildford'},
 '441482':{'en': 'Kingston-upon-Hull'},
 '441485':{'en': 'Hunstanton'},
 '441484':{'en': 'Huddersfield'},
 '441487':{'en': 'Warboys'},
 '55114177':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '441733':{'en': 'Peterborough'},
 '441732':{'en': 'Sevenoaks'},
 '441730':{'en': 'Petersfield'},
 '441737':{'en': 'Redhill'},
 '441736':{'en': 'Penzance'},
 '494964':{'de': 'Rhede Ems', 'en': 'Rhede Ems'},
 '494965':{'de': 'Surwold', 'en': 'Surwold'},
 '494966':{'de': u('Neub\u00f6rger'), 'en': u('Neub\u00f6rger')},
 '441738':{'en': 'Perth'},
 '494961':{'de': 'Papenburg', 'en': 'Papenburg'},
 '494962':{'de': 'Papenburg-Aschendorf', 'en': 'Papenburg-Aschendorf'},
 '494963':{'de': u('D\u00f6rpen'), 'en': u('D\u00f6rpen')},
 '4938784':{'de': 'Kleinow Kreis Prignitz', 'en': 'Kleinow Kreis Prignitz'},
 '4938785':{'de': 'Berge bei Perleberg', 'en': 'Berge bei Perleberg'},
 '55133506':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '55133507':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '4938787':{'de': u('Gl\u00f6wen'), 'en': u('Gl\u00f6wen')},
 '55133500':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '4938780':{'de': 'Lanz Brandenburg', 'en': 'Lanz Brandenburg'},
 '4938781':{'de': 'Mellen', 'en': 'Mellen'},
 '499503':{'de': 'Oberhaid Oberfranken', 'en': 'Oberhaid Oberfranken'},
 '4938782':{'de': 'Reetz bei Perleberg', 'en': 'Reetz bei Perleberg'},
 '4938783':{'de': 'Dallmin', 'en': 'Dallmin'},
 '436562':{'de': 'Mittersill', 'en': 'Mittersill'},
 '436563':{'de': 'Uttendorf', 'en': 'Uttendorf'},
 '436564':{'de': 'Krimml', 'en': 'Krimml'},
 '436565':{'de': u('Neukirchen am Gro\u00dfvenediger'), 'en': 'Neukirchen am Grossvenediger'},
 '436566':{'de': 'Bramberg am Wildkogel', 'en': 'Bramberg am Wildkogel'},
 '498641':{'de': 'Grassau Kreis Traunstein', 'en': 'Grassau Kreis Traunstein'},
 '493344':{'de': 'Bad Freienwalde', 'en': 'Bad Freienwalde'},
 '498867':{'de': 'Rottenbuch Oberbayern', 'en': 'Rottenbuch Oberbayern'},
 '493346':{'de': 'Seelow', 'en': 'Seelow'},
 '493341':{'de': 'Strausberg', 'en': 'Strausberg'},
 '498860':{'de': 'Bernbeuren', 'en': 'Bernbeuren'},
 '493342':{'de': 'Neuenhagen bei Berlin', 'en': 'Neuenhagen bei Berlin'},
 '498649':{'de': 'Schleching', 'en': 'Schleching'},
 '55112182':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498869':{'de': 'Kinsau', 'en': 'Kinsau'},
 '498868':{'de': 'Schwabsoien', 'en': 'Schwabsoien'},
 '494340':{'de': 'Achterwehr', 'en': 'Achterwehr'},
 '494342':{'de': u('Preetz Kreis Pl\u00f6n'), 'en': u('Preetz Kreis Pl\u00f6n')},
 '494343':{'de': 'Laboe', 'en': 'Laboe'},
 '494344':{'de': u('Sch\u00f6nberg Holstein'), 'en': u('Sch\u00f6nberg Holstein')},
 '494346':{'de': 'Gettorf', 'en': 'Gettorf'},
 '494347':{'de': 'Flintbek', 'en': 'Flintbek'},
 '494348':{'de': u('Sch\u00f6nkirchen'), 'en': u('Sch\u00f6nkirchen')},
 '494349':{'de': u('D\u00e4nischenhagen'), 'en': u('D\u00e4nischenhagen')},
 '55113345':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112068':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55132101':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55132105':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '46533':{'en': u('S\u00e4ffle'), 'sv': u('S\u00e4ffle')},
 '46532':{'en': u('\u00c5m\u00e5l'), 'sv': u('\u00c5m\u00e5l')},
 '46531':{'en': 'Bengtsfors', 'sv': 'Bengtsfors'},
 '46530':{'en': 'Mellerud', 'sv': 'Mellerud'},
 '46534':{'en': 'Ed', 'sv': 'Ed'},
 '55112187':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4934362':{'de': u('M\u00fcgeln bei Oschatz'), 'en': u('M\u00fcgeln bei Oschatz')},
 '4934363':{'de': 'Cavertitz', 'en': 'Cavertitz'},
 '4934361':{'de': 'Dahlen Sachsen', 'en': 'Dahlen Sachsen'},
 '4934364':{'de': 'Wermsdorf', 'en': 'Wermsdorf'},
 '55114047':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55112186':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495725':{'de': 'Lindhorst bei Stadthagen', 'en': 'Lindhorst bei Stadthagen'},
 '55113578':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113576':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113571':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113572':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112184':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112990':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112991':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112992':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112993':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112994':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112995':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112996':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '44208':{'en': 'London'},
 '44207':{'en': 'London'},
 '44203':{'en': 'London'},
 '44201':{'en': 'London'},
 '44200':{'en': 'London'},
 '543438':{'en': u('Bovril, Entre R\u00edos'), 'es': u('Bovril, Entre R\u00edos')},
 '543435':{'en': u('Nogoy\u00e1, Entre R\u00edos'), 'es': u('Nogoy\u00e1, Entre R\u00edos')},
 '543437':{'en': u('La Paz, Entre R\u00edos'), 'es': u('La Paz, Entre R\u00edos')},
 '543436':{'en': u('Victoria, Entre R\u00edos'), 'es': u('Victoria, Entre R\u00edos')},
 '4937439':{'de': 'Jocketa', 'en': 'Jocketa'},
 '4937438':{'de': 'Bad Brambach', 'en': 'Bad Brambach'},
 '4937433':{'de': u('Gutenf\u00fcrst'), 'en': u('Gutenf\u00fcrst')},
 '4937432':{'de': 'Pausa Vogtland', 'en': 'Pausa Vogtland'},
 '4937431':{'de': 'Mehltheuer Vogtland', 'en': 'Mehltheuer Vogtland'},
 '4937430':{'de': 'Eichigt', 'en': 'Eichigt'},
 '4937437':{'de': 'Bad Elster', 'en': 'Bad Elster'},
 '4937436':{'de': 'Weischlitz', 'en': 'Weischlitz'},
 '4937435':{'de': 'Reuth bei Plauen', 'en': 'Reuth bei Plauen'},
 '4937434':{'de': 'Bobenneukirchen', 'en': 'Bobenneukirchen'},
 '4419755':{'en': 'Alford (Aberdeen)'},
 '4419754':{'en': 'Alford (Aberdeen)'},
 '4419757':{'en': 'Strathdon'},
 '4419756':{'en': 'Strathdon'},
 '4419751':{'en': 'Alford (Aberdeen)/Strathdon'},
 '4419750':{'en': 'Alford (Aberdeen)/Strathdon'},
 '4419753':{'en': 'Strathdon'},
 '4419752':{'en': 'Alford (Aberdeen)'},
 '495769':{'de': 'Steyerberg-Voigtei', 'en': 'Steyerberg-Voigtei'},
 '495768':{'de': 'Petershagen-Heimsen', 'en': 'Petershagen-Heimsen'},
 '55112192':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112193':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4419759':{'en': 'Alford (Aberdeen)'},
 '4419758':{'en': 'Strathdon'},
 '55112196':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112197':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441904':{'en': 'York'},
 '441905':{'en': 'Worcester'},
 '441900':{'en': 'Workington'},
 '441902':{'en': 'Wolverhampton'},
 '441903':{'en': 'Worthing'},
 '441908':{'en': 'Milton Keynes'},
 '441909':{'en': 'Worksop'},
 '499929':{'de': 'Ruhmannsfelden', 'en': 'Ruhmannsfelden'},
 '498802':{'de': 'Huglfing', 'en': 'Huglfing'},
 '499928':{'de': 'Kirchdorf im Wald', 'en': 'Kirchdorf im Wald'},
 '498801':{'de': 'Seeshaupt', 'en': 'Seeshaupt'},
 '4939996':{'de': u('T\u00f6rpin'), 'en': u('T\u00f6rpin')},
 '497729':{'de': 'Tennenbronn', 'en': 'Tennenbronn'},
 '497728':{'de': 'Niedereschach', 'en': 'Niedereschach'},
 '499461':{'de': 'Roding', 'en': 'Roding'},
 '4939997':{'de': 'Jarmen', 'en': 'Jarmen'},
 '497723':{'de': 'Furtwangen im Schwarzwald', 'en': 'Furtwangen im Schwarzwald'},
 '497722':{'de': 'Triberg im Schwarzwald', 'en': 'Triberg im Schwarzwald'},
 '497721':{'de': 'Villingen im Schwarzwald', 'en': 'Villingen im Schwarzwald'},
 '497720':{'de': 'Schwenningen am Neckar', 'en': 'Schwenningen am Neckar'},
 '497727':{'de': u('V\u00f6hrenbach'), 'en': u('V\u00f6hrenbach')},
 '497726':{'de': u('Bad D\u00fcrrheim'), 'en': u('Bad D\u00fcrrheim')},
 '497725':{'de': u('K\u00f6nigsfeld im Schwarzwald'), 'en': u('K\u00f6nigsfeld im Schwarzwald')},
 '497724':{'de': 'St Georgen im Schwarzwald', 'en': 'St Georgen im Schwarzwald'},
 '499924':{'de': 'Bodenmais', 'en': 'Bodenmais'},
 '55112228':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55112229':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '495585':{'de': 'Herzberg-Sieber', 'en': 'Herzberg-Sieber'},
 '495584':{'de': 'Hattorf am Harz', 'en': 'Hattorf am Harz'},
 '55112224':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495586':{'de': 'Wieda', 'en': 'Wieda'},
 '55115502':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112223':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495583':{'de': 'Braunlage-Hohegeiss', 'en': 'Braunlage-Hohegeiss'},
 '495582':{'de': 'Sankt Andreasberg', 'en': 'Sankt Andreasberg'},
 '55123123':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55123122':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '499466':{'de': 'Stamsried', 'en': 'Stamsried'},
 '499921':{'de': 'Regen', 'en': 'Regen'},
 '55123127':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55123126':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55123128':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55115839':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4939991':{'de': 'Daberkow', 'en': 'Daberkow'},
 '498809':{'de': 'Wessobrunn', 'en': 'Wessobrunn'},
 '498808':{'de': u('P\u00e4hl'), 'en': u('P\u00e4hl')},
 '55133036':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '499467':{'de': 'Michelsneukirchen', 'en': 'Michelsneukirchen'},
 '55115641':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115643':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115642':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115645':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115646':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933731':{'de': 'Trebbin', 'en': 'Trebbin'},
 '4933732':{'de': 'Hennickendorf bei Luckenwalde', 'en': 'Hennickendorf bei Luckenwalde'},
 '4933733':{'de': u('St\u00fclpe'), 'en': u('St\u00fclpe')},
 '4933734':{'de': 'Felgentreu', 'en': 'Felgentreu'},
 '55113935':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496580':{'de': 'Zemmer', 'en': 'Zemmer'},
 '496581':{'de': 'Saarburg', 'en': 'Saarburg'},
 '496582':{'de': 'Freudenburg', 'en': 'Freudenburg'},
 '496583':{'de': 'Palzem', 'en': 'Palzem'},
 '496584':{'de': 'Wellen Mosel', 'en': 'Wellen Mosel'},
 '496585':{'de': 'Ralingen', 'en': 'Ralingen'},
 '496238':{'de': 'Dirmstein', 'en': 'Dirmstein'},
 '496587':{'de': 'Zerf', 'en': 'Zerf'},
 '496236':{'de': 'Neuhofen Pfalz', 'en': 'Neuhofen Pfalz'},
 '496237':{'de': 'Maxdorf', 'en': 'Maxdorf'},
 '496234':{'de': 'Mutterstadt', 'en': 'Mutterstadt'},
 '496235':{'de': 'Schifferstadt', 'en': 'Schifferstadt'},
 '496232':{'de': 'Speyer', 'en': 'Speyer'},
 '496233':{'de': 'Frankenthal Pfalz', 'en': 'Frankenthal Pfalz'},
 '496231':{'de': 'Hochdorf-Assenheim', 'en': 'Hochdorf-Assenheim'},
 '543858':{'en': u('Termas de R\u00edo Hondo, Santiago del Estero'), 'es': u('Termas de R\u00edo Hondo, Santiago del Estero')},
 '55133034':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '497184':{'de': 'Kaisersbach', 'en': 'Kaisersbach'},
 '497183':{'de': u('Rudersberg W\u00fcrttemberg'), 'en': u('Rudersberg W\u00fcrttemberg')},
 '497182':{'de': 'Welzheim', 'en': 'Welzheim'},
 '497181':{'de': u('Schorndorf W\u00fcrttemberg'), 'en': u('Schorndorf W\u00fcrttemberg')},
 '543854':{'en': u('Fr\u00edas, Santiago del Estero'), 'es': u('Fr\u00edas, Santiago del Estero')},
 '55114893':{'en': 'Campo Limpo Paulista - SP', 'pt': 'Campo Limpo Paulista - SP'},
 '496058':{'de': u('Gr\u00fcndau'), 'en': u('Gr\u00fcndau')},
 '496059':{'de': 'Jossgrund', 'en': 'Jossgrund'},
 '496052':{'de': 'Bad Orb', 'en': 'Bad Orb'},
 '496053':{'de': u('W\u00e4chtersbach'), 'en': u('W\u00e4chtersbach')},
 '496050':{'de': u('Biebergem\u00fcnd'), 'en': u('Biebergem\u00fcnd')},
 '496051':{'de': 'Gelnhausen', 'en': 'Gelnhausen'},
 '496056':{'de': u('Bad Soden-Salm\u00fcnster'), 'en': u('Bad Soden-Salm\u00fcnster')},
 '496057':{'de': u('Fl\u00f6rsbachtal'), 'en': u('Fl\u00f6rsbachtal')},
 '496054':{'de': 'Birstein', 'en': 'Birstein'},
 '496055':{'de': 'Freigericht', 'en': 'Freigericht'},
 '492759':{'de': 'Bad Berleburg-Aue', 'en': 'Bad Berleburg-Aue'},
 '492758':{'de': 'Bad Berleburg-Girkhausen', 'en': 'Bad Berleburg-Girkhausen'},
 '492751':{'de': 'Bad Berleburg', 'en': 'Bad Berleburg'},
 '492750':{'de': 'Diedenshausen', 'en': 'Diedenshausen'},
 '492753':{'de': u('Erndtebr\u00fcck'), 'en': u('Erndtebr\u00fcck')},
 '492752':{'de': 'Bad Laasphe', 'en': 'Bad Laasphe'},
 '492755':{'de': 'Bad Berleburg-Schwarzenau', 'en': 'Bad Berleburg-Schwarzenau'},
 '492754':{'de': 'Bad Laasphe-Feudingen', 'en': 'Bad Laasphe-Feudingen'},
 '543876':{'en': u('San Jos\u00e9 de Met\u00e1n, Salta'), 'es': u('San Jos\u00e9 de Met\u00e1n, Salta')},
 '4761':{'en': 'Oppland'},
 '4760':{'en': 'Oppland'},
 '4763':{'en': 'Akershus'},
 '4762':{'en': 'Hedmark'},
 '4764':{'en': 'Akershus'},
 '4767':{'en': 'Akershus'},
 '4766':{'en': 'Akershus'},
 '4769':{'en': u('\u00d8stfold')},
 '55114894':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114598':{'en': 'Vargem - SP', 'pt': 'Vargem - SP'},
 '55114599':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55113931':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114592':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '55114593':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '55114591':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '55114596':{'en': u('V\u00e1rzea Paulista - SP'), 'pt': u('V\u00e1rzea Paulista - SP')},
 '55114597':{'en': u('Nazar\u00e9 Paulista - SP'), 'pt': u('Nazar\u00e9 Paulista - SP')},
 '55114594':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114595':{'en': u('V\u00e1rzea Paulista - SP'), 'pt': u('V\u00e1rzea Paulista - SP')},
 '55115908':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112697':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113855':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113011':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113016':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113014':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113015':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112695':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112694':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112693':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112692':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499857':{'de': 'Schopfloch Mittelfranken', 'en': 'Schopfloch Mittelfranken'},
 '499856':{'de': u('D\u00fcrrwangen'), 'en': u('D\u00fcrrwangen')},
 '499855':{'de': 'Dentlein am Forst', 'en': 'Dentlein am Forst'},
 '499854':{'de': 'Wittelshofen', 'en': 'Wittelshofen'},
 '498303':{'de': 'Waltenhofen', 'en': 'Waltenhofen'},
 '499852':{'de': 'Feuchtwangen', 'en': 'Feuchtwangen'},
 '499851':{'de': u('Dinkelsb\u00fchl'), 'en': u('Dinkelsb\u00fchl')},
 '55123431':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '492801':{'de': 'Xanten', 'en': 'Xanten'},
 '498327':{'de': 'Rettenberg', 'en': 'Rettenberg'},
 '492803':{'de': u('Wesel-B\u00fcderich'), 'en': u('Wesel-B\u00fcderich')},
 '492802':{'de': 'Alpen', 'en': 'Alpen'},
 '498322':{'de': 'Oberstdorf', 'en': 'Oberstdorf'},
 '492804':{'de': 'Xanten-Marienbaum', 'en': 'Xanten-Marienbaum'},
 '498320':{'de': 'Missen-Wilhams', 'en': 'Missen-Wilhams'},
 '498321':{'de': 'Sonthofen', 'en': 'Sonthofen'},
 '498458':{'de': 'Gaimersheim', 'en': 'Gaimersheim'},
 '498459':{'de': 'Manching', 'en': 'Manching'},
 '498328':{'de': 'Balderschwang', 'en': 'Balderschwang'},
 '55123021':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '434826':{'de': u('M\u00f6rtschach'), 'en': u('M\u00f6rtschach')},
 '4935774':{'de': 'Boxberg Sachsen', 'en': 'Boxberg Sachsen'},
 '4935775':{'de': 'Pechern', 'en': 'Pechern'},
 '4935772':{'de': 'Rietschen', 'en': 'Rietschen'},
 '4935773':{'de': 'Schleife', 'en': 'Schleife'},
 '4935771':{'de': 'Bad Muskau', 'en': 'Bad Muskau'},
 '55112698':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494753':{'de': 'Balje', 'en': 'Balje'},
 '494752':{'de': 'Neuhaus Oste', 'en': 'Neuhaus Oste'},
 '494751':{'de': 'Otterndorf', 'en': 'Otterndorf'},
 '494757':{'de': 'Wanna', 'en': 'Wanna'},
 '494756':{'de': 'Odisheim', 'en': 'Odisheim'},
 '494755':{'de': 'Ihlienworth', 'en': 'Ihlienworth'},
 '494754':{'de': u('B\u00fclkau'), 'en': u('B\u00fclkau')},
 '494758':{'de': 'Nordleda', 'en': 'Nordleda'},
 '4889':{'en': 'Olsztyn', 'pl': 'Olsztyn'},
 '4881':{'en': 'Lublin', 'pl': 'Lublin'},
 '4882':{'en': 'Chelm', 'pl': u('Che\u0142m')},
 '4883':{'en': 'Biala Podlaska', 'pl': u('Bia\u0142a Podlaska')},
 '4884':{'en': u('Zamo\u015b\u0107'), 'pl': u('Zamo\u015b\u0107')},
 '4885':{'en': 'Bialystok', 'pl': u('Bia\u0142ystok')},
 '4886':{'en': u('Lom\u017ca'), 'pl': u('\u0141om\u017ca')},
 '4887':{'en': 'Suwalki', 'pl': u('Suwa\u0142ki')},
 '441228':{'en': 'Carlisle'},
 '441225':{'en': 'Bath'},
 '441224':{'en': 'Aberdeen'},
 '441227':{'en': 'Canterbury'},
 '441226':{'en': 'Barnsley'},
 '441223':{'en': 'Cambridge'},
 '499325':{'de': 'Kleinlangheim', 'en': 'Kleinlangheim'},
 '499324':{'de': 'Dettelbach', 'en': 'Dettelbach'},
 '499326':{'de': 'Markt Einersheim', 'en': 'Markt Einersheim'},
 '499321':{'de': 'Kitzingen', 'en': 'Kitzingen'},
 '499323':{'de': 'Iphofen', 'en': 'Iphofen'},
 '55113953':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55122131':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '4936607':{'de': u('Niederp\u00f6llnitz'), 'en': u('Niederp\u00f6llnitz')},
 '4936606':{'de': 'Kraftsdorf', 'en': 'Kraftsdorf'},
 '4937602':{'de': 'Kirchberg Sachsen', 'en': 'Kirchberg Sachsen'},
 '4937603':{'de': 'Wildenfels', 'en': 'Wildenfels'},
 '4937604':{'de': 'Mosel', 'en': 'Mosel'},
 '4937605':{'de': 'Hartenstein Sachsen', 'en': 'Hartenstein Sachsen'},
 '4937606':{'de': 'Lengenfeld Vogtland', 'en': 'Lengenfeld Vogtland'},
 '4937607':{'de': 'Ebersbrunn Sachsen', 'en': 'Ebersbrunn Sachsen'},
 '4937608':{'de': 'Waldenburg Sachsen', 'en': 'Waldenburg Sachsen'},
 '4937609':{'de': 'Wolkenburg Mulde', 'en': 'Wolkenburg Mulde'},
 '4936608':{'de': u('Seelingst\u00e4dt bei Gera'), 'en': u('Seelingst\u00e4dt bei Gera')},
 '437758':{'de': 'Obernberg am Inn', 'en': 'Obernberg am Inn'},
 '437759':{'de': 'Antiesenhofen', 'en': 'Antiesenhofen'},
 '437754':{'de': 'Waldzell', 'en': 'Waldzell'},
 '437755':{'de': 'Mettmach', 'en': 'Mettmach'},
 '542935':{'en': 'Rivera, Buenos Aires', 'es': 'Rivera, Buenos Aires'},
 '437757':{'de': 'Gurten', 'en': 'Gurten'},
 '437750':{'de': 'Andrichsfurt', 'en': 'Andrichsfurt'},
 '437751':{'de': 'Sankt Martin im Innkreis', 'en': 'St. Martin im Innkreis'},
 '437752':{'de': 'Ried im Innkreis', 'en': 'Ried im Innkreis'},
 '437753':{'de': 'Eberschwang', 'en': 'Eberschwang'},
 '4939608':{'de': 'Staven', 'en': 'Staven'},
 '4939606':{'de': 'Glienke', 'en': 'Glienke'},
 '4939607':{'de': 'Kotelow', 'en': 'Kotelow'},
 '4939604':{'de': 'Wildberg bei Altentreptow', 'en': 'Wildberg bei Altentreptow'},
 '4939605':{'de': 'Gross Nemerow', 'en': 'Gross Nemerow'},
 '4939602':{'de': 'Kleeth', 'en': 'Kleeth'},
 '4939603':{'de': 'Burg Stargard', 'en': 'Burg Stargard'},
 '4939600':{'de': 'Zwiedorf', 'en': 'Zwiedorf'},
 '4939601':{'de': 'Friedland', 'en': 'Friedland'},
 '494926':{'de': u('Krummh\u00f6rn-Greetsiel'), 'en': u('Krummh\u00f6rn-Greetsiel')},
 '55114222':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55115681':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494927':{'de': u('Krummh\u00f6rn-Loquard'), 'en': u('Krummh\u00f6rn-Loquard')},
 '55112431':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112437':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112867':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112436':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '4935974':{'de': 'Hinterhermsdorf', 'en': 'Hinterhermsdorf'},
 '4935975':{'de': 'Hohnstein', 'en': 'Hohnstein'},
 '4935971':{'de': 'Sebnitz', 'en': 'Sebnitz'},
 '4935973':{'de': 'Stolpen', 'en': 'Stolpen'},
 '492232':{'de': u('Br\u00fchl Rheinland'), 'en': u('Br\u00fchl Rheinland')},
 '492233':{'de': u('H\u00fcrth Rheinland'), 'en': u('H\u00fcrth Rheinland')},
 '492236':{'de': 'Wesseling Rheinland', 'en': 'Wesseling Rheinland'},
 '492237':{'de': u('Kerpen Rheinland-T\u00fcrnich'), 'en': u('Kerpen Rheinland-T\u00fcrnich')},
 '492234':{'de': 'Frechen', 'en': 'Frechen'},
 '492235':{'de': 'Erftstadt', 'en': 'Erftstadt'},
 '492238':{'de': 'Pulheim', 'en': 'Pulheim'},
 '49841':{'de': 'Ingolstadt Donau', 'en': 'Ingolstadt Donau'},
 '495246':{'de': 'Verl', 'en': 'Verl'},
 '495247':{'de': 'Harsewinkel', 'en': 'Harsewinkel'},
 '495244':{'de': 'Rietberg', 'en': 'Rietberg'},
 '495937':{'de': 'Geeste-Gross Hesepe', 'en': 'Geeste-Gross Hesepe'},
 '495242':{'de': u('Rheda-Wiedenbr\u00fcck'), 'en': u('Rheda-Wiedenbr\u00fcck')},
 '495931':{'de': 'Meppen', 'en': 'Meppen'},
 '495932':{'de': 'Haren Ems', 'en': 'Haren Ems'},
 '495241':{'de': u('G\u00fctersloh'), 'en': u('G\u00fctersloh')},
 '495939':{'de': 'Sustrum', 'en': 'Sustrum'},
 '495248':{'de': u('Langenberg Kreis G\u00fctersloh'), 'en': u('Langenberg Kreis G\u00fctersloh')},
 '55114784':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '499682':{'de': 'Erbendorf', 'en': 'Erbendorf'},
 '499683':{'de': 'Friedenfels', 'en': 'Friedenfels'},
 '499681':{'de': 'Windischeschenbach', 'en': 'Windischeschenbach'},
 '492588':{'de': 'Harsewinkel-Greffen', 'en': 'Harsewinkel-Greffen'},
 '492584':{'de': 'Warendorf-Milte', 'en': 'Warendorf-Milte'},
 '492585':{'de': 'Warendorf-Hoetmar', 'en': 'Warendorf-Hoetmar'},
 '492586':{'de': 'Beelen', 'en': 'Beelen'},
 '492587':{'de': 'Ennigerloh-Westkirchen', 'en': 'Ennigerloh-Westkirchen'},
 '492581':{'de': 'Warendorf', 'en': 'Warendorf'},
 '497062':{'de': u('Beilstein W\u00fcrttemberg'), 'en': u('Beilstein W\u00fcrttemberg')},
 '497063':{'de': 'Bad Wimpfen', 'en': 'Bad Wimpfen'},
 '543533':{'en': u('Las Varillas, C\u00f3rdoba'), 'es': u('Las Varillas, C\u00f3rdoba')},
 '55133568':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133569':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133564':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133565':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133566':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133567':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133561':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133563':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '498221':{'de': u('G\u00fcnzburg'), 'en': u('G\u00fcnzburg')},
 '499841':{'de': 'Bad Windsheim', 'en': 'Bad Windsheim'},
 '55114104':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '499842':{'de': 'Uffenheim', 'en': 'Uffenheim'},
 '55114056':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114055':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '498669':{'de': 'Traunreut', 'en': 'Traunreut'},
 '55114054':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '498663':{'de': 'Ruhpolding', 'en': 'Ruhpolding'},
 '493366':{'de': 'Beeskow', 'en': 'Beeskow'},
 '498661':{'de': u('Grabenst\u00e4tt Chiemsee'), 'en': u('Grabenst\u00e4tt Chiemsee')},
 '493364':{'de': u('Eisenh\u00fcttenstadt'), 'en': u('Eisenh\u00fcttenstadt')},
 '498667':{'de': 'Seeon-Seebruck', 'en': 'Seeon-Seebruck'},
 '493362':{'de': 'Erkner', 'en': 'Erkner'},
 '493361':{'de': u('F\u00fcrstenwalde Spree'), 'en': u('F\u00fcrstenwalde Spree')},
 '498664':{'de': 'Chieming', 'en': 'Chieming'},
 '494328':{'de': 'Rickling', 'en': 'Rickling'},
 '494329':{'de': 'Langwedel Holstein', 'en': 'Langwedel Holstein'},
 '494322':{'de': 'Bordesholm', 'en': 'Bordesholm'},
 '494323':{'de': u('Bornh\u00f6ved'), 'en': u('Bornh\u00f6ved')},
 '494320':{'de': u('Heidm\u00fchlen'), 'en': u('Heidm\u00fchlen')},
 '494321':{'de': u('Neum\u00fcnster'), 'en': u('Neum\u00fcnster')},
 '494326':{'de': 'Wankendorf', 'en': 'Wankendorf'},
 '494327':{'de': 'Grossenaspe', 'en': 'Grossenaspe'},
 '494324':{'de': 'Brokstedt', 'en': 'Brokstedt'},
 '499175':{'de': 'Spalt', 'en': 'Spalt'},
 '55133382':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133383':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133384':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133386':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133387':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55114059':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '499354':{'de': 'Rieneck', 'en': 'Rieneck'},
 '5012':{'en': 'Belize District'},
 '5013':{'en': 'Orange Walk District'},
 '5014':{'en': 'Corozal District'},
 '5015':{'en': 'Stann Creek District'},
 '499401':{'de': 'Neutraubling', 'en': 'Neutraubling'},
 '499355':{'de': 'Frammersbach', 'en': 'Frammersbach'},
 '46551':{'en': u('Gullsp\u00e5ng'), 'sv': u('Gullsp\u00e5ng')},
 '46550':{'en': 'Kristinehamn', 'sv': 'Kristinehamn'},
 '46553':{'en': 'Molkom', 'sv': 'Molkom'},
 '46552':{'en': 'Deje', 'sv': 'Deje'},
 '46555':{'en': 'Grums'},
 '46554':{'en': 'Kil', 'sv': 'Kil'},
 '498224':{'de': 'Offingen Donau', 'en': 'Offingen Donau'},
 '499357':{'de': u('Gr\u00e4fendorf Bayern'), 'en': u('Gr\u00e4fendorf Bayern')},
 '499350':{'de': 'Eussenheim-Hundsbach', 'en': 'Eussenheim-Hundsbach'},
 '499351':{'de': u('Gem\u00fcnden am Main'), 'en': u('Gem\u00fcnden am Main')},
 '46247':{'en': u('Leksand-Insj\u00f6n'), 'sv': u('Leksand-Insj\u00f6n')},
 '499420':{'de': 'Feldkirchen Niederbayern', 'en': 'Feldkirchen Niederbayern'},
 '499353':{'de': 'Karlstadt', 'en': 'Karlstadt'},
 '52966':{'en': 'Arriaga/Tonala, CHIS', 'es': u('Arriaga/Tonal\u00e1, CHIS')},
 '55114019':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114018':{'en': 'Pinhalzinho - SP', 'pt': 'Pinhalzinho - SP'},
 '55114013':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114012':{'en': u('Bom Jesus dos Perd\u00f5es - SP'), 'pt': u('Bom Jesus dos Perd\u00f5es - SP')},
 '55114011':{'en': 'Piracaia - SP', 'pt': 'Piracaia - SP'},
 '55114017':{'en': 'Jarinu - SP', 'pt': 'Jarinu - SP'},
 '55114016':{'en': 'Jarinu - SP', 'pt': 'Jarinu - SP'},
 '55114015':{'en': 'Tuiuti - SP', 'pt': 'Tuiuti - SP'},
 '55114014':{'en': 'Morungaba - SP', 'pt': 'Morungaba - SP'},
 '46246':{'en': u('Sv\u00e4rdsj\u00f6-Enviken'), 'sv': u('Sv\u00e4rdsj\u00f6-Enviken')},
 '499505':{'de': 'Litzendorf', 'en': 'Litzendorf'},
 '55113812':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499428':{'de': 'Kirchroth', 'en': 'Kirchroth'},
 '55113595':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497546':{'de': 'Oberteuringen', 'en': 'Oberteuringen'},
 '55113599':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '499429':{'de': 'Rain Niederbayern', 'en': 'Rain Niederbayern'},
 '497545':{'de': 'Immenstaad am Bodensee', 'en': 'Immenstaad am Bodensee'},
 '46241':{'en': 'Gagnef-Floda', 'sv': 'Gagnef-Floda'},
 '497544':{'de': 'Markdorf', 'en': 'Markdorf'},
 '496136':{'de': 'Nieder-Olm', 'en': 'Nieder-Olm'},
 '4939453':{'de': 'Derenburg', 'en': 'Derenburg'},
 '4939452':{'de': 'Ilsenburg', 'en': 'Ilsenburg'},
 '4939451':{'de': 'Wasserleben', 'en': 'Wasserleben'},
 '4939457':{'de': 'Benneckenstein Harz', 'en': 'Benneckenstein Harz'},
 '4939456':{'de': 'Altenbrak', 'en': 'Altenbrak'},
 '4939455':{'de': 'Schierke', 'en': 'Schierke'},
 '4939454':{'de': 'Elbingerode Harz', 'en': 'Elbingerode Harz'},
 '4939459':{'de': 'Hasselfelde', 'en': 'Hasselfelde'},
 '4939458':{'de': 'Heudeber', 'en': 'Heudeber'},
 '46240':{'en': 'Ludvika-Smedjebacken', 'sv': 'Ludvika-Smedjebacken'},
 '46911':{'en': u('Pite\u00e5'), 'sv': u('Pite\u00e5')},
 '497940':{'de': u('K\u00fcnzelsau'), 'en': u('K\u00fcnzelsau')},
 '497947':{'de': 'Forchtenberg', 'en': 'Forchtenberg'},
 '46243':{'en': u('Borl\u00e4nge'), 'sv': u('Borl\u00e4nge')},
 '46913':{'en': u('L\u00f6v\u00e5nger'), 'sv': u('L\u00f6v\u00e5nger')},
 '495035':{'de': 'Gross Munzel', 'en': 'Gross Munzel'},
 '495742':{'de': 'Preussisch Oldendorf', 'en': 'Preussisch Oldendorf'},
 '495037':{'de': 'Bad Rehburg', 'en': 'Bad Rehburg'},
 '495036':{'de': 'Neustadt-Schneeren', 'en': 'Neustadt-Schneeren'},
 '495031':{'de': 'Wunstorf', 'en': 'Wunstorf'},
 '495746':{'de': u('R\u00f6dinghausen'), 'en': u('R\u00f6dinghausen')},
 '495033':{'de': 'Wunstorf-Grossenheidorn', 'en': 'Wunstorf-Grossenheidorn'},
 '495744':{'de': u('H\u00fcllhorst'), 'en': u('H\u00fcllhorst')},
 '498630':{'de': 'Oberneukirchen', 'en': 'Oberneukirchen'},
 '55123321':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '54220':{'en': 'Merlo, Buenos Aires', 'es': 'Merlo, Buenos Aires'},
 '54221':{'en': 'La Plata, Buenos Aires', 'es': 'La Plata, Buenos Aires'},
 '498631':{'de': u('M\u00fchldorf am Inn'), 'en': u('M\u00fchldorf am Inn')},
 '499407':{'de': 'Wenzenbach', 'en': 'Wenzenbach'},
 '498633':{'de': u('T\u00fc\u00dfling'), 'en': u('T\u00fcssling')},
 '52969':{'en': 'Flamboyanes/Yucalpeten, YUC', 'es': 'Flamboyanes/Yucalpeten, YUC'},
 '498636':{'de': 'Ampfing', 'en': 'Ampfing'},
 '495621':{'de': 'Bad Wildungen', 'en': 'Bad Wildungen'},
 '499408':{'de': 'Altenthann', 'en': 'Altenthann'},
 '493965':{'de': 'Burow bei Altentreptow', 'en': 'Burow bei Altentreptow'},
 '493964':{'de': 'Bredenfelde bei Strasburg', 'en': 'Bredenfelde bei Strasburg'},
 '493967':{'de': 'Oertzenhof bei Strasburg', 'en': 'Oertzenhof bei Strasburg'},
 '495331':{'de': u('Wolfenb\u00fcttel'), 'en': u('Wolfenb\u00fcttel')},
 '493961':{'de': 'Altentreptow', 'en': 'Altentreptow'},
 '55112241':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493963':{'de': 'Woldegk', 'en': 'Woldegk'},
 '493962':{'de': 'Penzlin bei Waren', 'en': 'Penzlin bei Waren'},
 '495624':{'de': 'Bad Emstal', 'en': 'Bad Emstal'},
 '493969':{'de': 'Siedenbollentin', 'en': 'Siedenbollentin'},
 '493968':{'de': u('Sch\u00f6nbeck'), 'en': u('Sch\u00f6nbeck')},
 '495625':{'de': 'Naumburg Hessen', 'en': 'Naumburg Hessen'},
 '55123147':{'en': 'Queluz - SP', 'pt': 'Queluz - SP'},
 '55123146':{'en': 'Lavrinhas - SP', 'pt': 'Lavrinhas - SP'},
 '55123145':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '55123144':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '55123143':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '495626':{'de': 'Bad Zwesten', 'en': 'Bad Zwesten'},
 '499409':{'de': 'Pielenhofen', 'en': 'Pielenhofen'},
 '437255':{'de': 'Losenstein', 'en': 'Losenstein'},
 '437254':{'de': u('Gro\u00dframing'), 'en': 'Grossraming'},
 '437257':{'de': u('Gr\u00fcnburg'), 'en': u('Gr\u00fcnburg')},
 '437256':{'de': 'Ternberg', 'en': 'Ternberg'},
 '437251':{'de': 'Schiedlberg', 'en': 'Schiedlberg'},
 '437250':{'de': 'Maria Neustift', 'en': 'Maria Neustift'},
 '437253':{'de': 'Wolfern', 'en': 'Wolfern'},
 '437252':{'de': 'Steyr', 'en': 'Steyr'},
 '55115626':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115625':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115624':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437259':{'de': 'Sierning', 'en': 'Sierning'},
 '437258':{'de': 'Bad Hall', 'en': 'Bad Hall'},
 '55115621':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115620':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498241':{'de': 'Buchloe', 'en': 'Buchloe'},
 '55113383':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4418518':{'en': 'Stornoway'},
 '4418519':{'en': 'Great Bernera'},
 '4936651':{'de': 'Lobenstein', 'en': 'Lobenstein'},
 '4418510':{'en': 'Great Bernera/Stornoway'},
 '4418511':{'en': 'Great Bernera/Stornoway'},
 '4418512':{'en': 'Stornoway'},
 '4418513':{'en': 'Stornoway'},
 '4418514':{'en': 'Great Bernera'},
 '4418515':{'en': 'Stornoway'},
 '4418516':{'en': 'Great Bernera'},
 '4418517':{'en': 'Stornoway'},
 '496074':{'de': u('R\u00f6dermark'), 'en': u('R\u00f6dermark')},
 '4854':{'en': 'Wloclawek', 'pl': u('W\u0142oc\u0142awek')},
 '496071':{'de': 'Dieburg', 'en': 'Dieburg'},
 '496073':{'de': 'Babenhausen Hessen', 'en': 'Babenhausen Hessen'},
 '496078':{'de': 'Gross-Umstadt', 'en': 'Gross-Umstadt'},
 '46120':{'en': u('\u00c5tvidaberg'), 'sv': u('\u00c5tvidaberg')},
 '46122':{'en': u('Finsp\u00e5ng'), 'sv': u('Finsp\u00e5ng')},
 '441707':{'en': 'Welwyn Garden City'},
 '494827':{'de': 'Wacken', 'en': 'Wacken'},
 '55114571':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114573':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114576':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114577':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114578':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55133268':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '441676':{'en': 'Meriden'},
 '441677':{'en': 'Bedale'},
 '441674':{'en': 'Montrose'},
 '441675':{'en': 'Coleshill'},
 '441672':{'en': 'Marlborough'},
 '441673':{'en': 'Market Rasen'},
 '441670':{'en': 'Morpeth'},
 '441671':{'en': 'Newton Stewart'},
 '497082':{'de': u('Neuenb\u00fcrg W\u00fcrttemberg'), 'en': u('Neuenb\u00fcrg W\u00fcrttemberg')},
 '441678':{'en': 'Bala'},
 '492773':{'de': 'Haiger', 'en': 'Haiger'},
 '492772':{'de': 'Herborn Hessen', 'en': 'Herborn Hessen'},
 '492771':{'de': 'Dillenburg', 'en': 'Dillenburg'},
 '492770':{'de': 'Eschenburg', 'en': 'Eschenburg'},
 '492777':{'de': 'Breitscheid Hessen', 'en': 'Breitscheid Hessen'},
 '492776':{'de': 'Bad Endbach-Hartenrod', 'en': 'Bad Endbach-Hartenrod'},
 '492775':{'de': 'Driedorf', 'en': 'Driedorf'},
 '492774':{'de': u('Dietzh\u00f6lztal'), 'en': u('Dietzh\u00f6lztal')},
 '492779':{'de': 'Greifenstein-Beilstein', 'en': 'Greifenstein-Beilstein'},
 '492778':{'de': 'Siegbach', 'en': 'Siegbach'},
 '497309':{'de': 'Weissenhorn', 'en': 'Weissenhorn'},
 '497308':{'de': 'Nersingen', 'en': 'Nersingen'},
 '493421':{'de': 'Torgau', 'en': 'Torgau'},
 '498302':{'de': u('G\u00f6risried'), 'en': u('G\u00f6risried')},
 '493423':{'de': 'Eilenburg', 'en': 'Eilenburg'},
 '498304':{'de': 'Wildpoldsried', 'en': 'Wildpoldsried'},
 '493425':{'de': 'Wurzen', 'en': 'Wurzen'},
 '498306':{'de': 'Ronsberg', 'en': 'Ronsberg'},
 '492823':{'de': 'Goch', 'en': 'Goch'},
 '492822':{'de': 'Emmerich', 'en': 'Emmerich'},
 '492821':{'de': 'Kleve Niederrhein', 'en': 'Kleve Niederrhein'},
 '492827':{'de': 'Goch-Hassum', 'en': 'Goch-Hassum'},
 '492826':{'de': 'Kranenburg Niederrhein', 'en': 'Kranenburg Niederrhein'},
 '492825':{'de': 'Uedem', 'en': 'Uedem'},
 '492824':{'de': 'Kalkar', 'en': 'Kalkar'},
 '434843':{'de': u('Au\u00dfervillgraten'), 'en': 'Ausservillgraten'},
 '434842':{'de': 'Sillian', 'en': 'Sillian'},
 '434847':{'de': 'Obertilliach', 'en': 'Obertilliach'},
 '434846':{'de': 'Abfaltersbach', 'en': 'Abfaltersbach'},
 '434848':{'de': 'Kartitsch', 'en': 'Kartitsch'},
 '498324':{'de': 'Hindelang', 'en': 'Hindelang'},
 '499522':{'de': 'Eltmann', 'en': 'Eltmann'},
 '55112749':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112748':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115817':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112741':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112743':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112742':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112745':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112747':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112746':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441207':{'en': 'Consett'},
 '441206':{'en': 'Colchester'},
 '441205':{'en': 'Boston'},
 '441204':{'en': 'Bolton'},
 '55112911':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441202':{'en': 'Bournemouth'},
 '441200':{'en': 'Clitheroe'},
 '55113875':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441209':{'en': 'Redruth'},
 '441208':{'en': 'Bodmin'},
 '55113057':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113929':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113299':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113294':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113295':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113296':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113297':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113926':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113291':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113292':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113293':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112528':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112524':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112521':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112523':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499527':{'de': 'Knetzgau', 'en': 'Knetzgau'},
 '46942':{'en': 'Dorotea', 'sv': 'Dorotea'},
 '46943':{'en': 'Fredrika'},
 '46940':{'en': 'Vilhelmina', 'sv': 'Vilhelmina'},
 '49261':{'de': 'Koblenz am Rhein', 'en': 'Koblenz am Rhein'},
 '499307':{'de': 'Altertheim', 'en': 'Altertheim'},
 '499306':{'de': 'Kist', 'en': 'Kist'},
 '499305':{'de': 'Estenfeld', 'en': 'Estenfeld'},
 '499303':{'de': 'Eibelstadt', 'en': 'Eibelstadt'},
 '499302':{'de': 'Rottendorf Unterfranken', 'en': 'Rottendorf Unterfranken'},
 '4934446':{'de': 'Grosskorbetha', 'en': 'Grosskorbetha'},
 '4934445':{'de': u('St\u00f6\u00dfen'), 'en': u('St\u00f6ssen')},
 '4934444':{'de': u('L\u00fctzen'), 'en': u('L\u00fctzen')},
 '4934443':{'de': 'Teuchern', 'en': 'Teuchern'},
 '4934441':{'de': u('Hohenm\u00f6lsen'), 'en': u('Hohenm\u00f6lsen')},
 '4936621':{'de': 'Elsterberg bei Plauen', 'en': 'Elsterberg bei Plauen'},
 '4936623':{'de': 'Berga Elster', 'en': 'Berga Elster'},
 '4936622':{'de': 'Triebes', 'en': 'Triebes'},
 '4936625':{'de': 'Langenwetzendorf', 'en': 'Langenwetzendorf'},
 '4936624':{'de': 'Teichwolframsdorf', 'en': 'Teichwolframsdorf'},
 '4936626':{'de': 'Auma', 'en': 'Auma'},
 '4936628':{'de': 'Zeulenroda', 'en': 'Zeulenroda'},
 '493883':{'de': 'Hagenow', 'en': 'Hagenow'},
 '493881':{'de': u('Grevesm\u00fchlen'), 'en': u('Grevesm\u00fchlen')},
 '493886':{'de': 'Gadebusch', 'en': 'Gadebusch'},
 '542953':{'en': u('Macach\u00edn, La Pampa'), 'es': u('Macach\u00edn, La Pampa')},
 '542952':{'en': 'General Acha, La Pampa', 'es': 'General Acha, La Pampa'},
 '542954':{'en': 'Santa Rosa, La Pampa', 'es': 'Santa Rosa, La Pampa'},
 '499525':{'de': u('K\u00f6nigsberg in Bayern'), 'en': u('K\u00f6nigsberg in Bayern')},
 '4938825':{'de': u('Kl\u00fctz'), 'en': u('Kl\u00fctz')},
 '4938824':{'de': 'Mallentin', 'en': 'Mallentin'},
 '4938827':{'de': 'Kalkhorst', 'en': 'Kalkhorst'},
 '4938826':{'de': 'Dassow', 'en': 'Dassow'},
 '4938821':{'de': u('L\u00fcdersdorf'), 'en': u('L\u00fcdersdorf')},
 '4938823':{'de': 'Selmsdorf', 'en': 'Selmsdorf'},
 '4938822':{'de': u('Diedrichshagen bei Grevesm\u00fchlen'), 'en': u('Diedrichshagen bei Grevesm\u00fchlen')},
 '55113431':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55113432':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55113433':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '55113434':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4938828':{'de': u('Sch\u00f6nberg'), 'en': u('Sch\u00f6nberg')},
 '542942':{'en': u('Zapala, Neuqu\u00e9n'), 'es': u('Zapala, Neuqu\u00e9n')},
 '55113437':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '542962':{'en': u('Puerto San Juli\u00e1n, Santa Cruz'), 'es': u('Puerto San Juli\u00e1n, Santa Cruz')},
 '55114805':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114806':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '496683':{'de': u('Ehrenberg Rh\u00f6n'), 'en': u('Ehrenberg Rh\u00f6n')},
 '496682':{'de': u('Tann Rh\u00f6n'), 'en': u('Tann Rh\u00f6n')},
 '496681':{'de': 'Hilders', 'en': 'Hilders'},
 '496684':{'de': 'Hofbieber-Schwarzbach', 'en': 'Hofbieber-Schwarzbach'},
 '55114224':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55114225':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '542940':{'en': u('Ingeniero Jacobacci, R\u00edo Negro'), 'es': u('Ingeniero Jacobacci, R\u00edo Negro')},
 '55114226':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '495484':{'de': 'Lienen-Kattenvenne', 'en': 'Lienen-Kattenvenne'},
 '495485':{'de': 'Ladbergen', 'en': 'Ladbergen'},
 '55114227':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '495481':{'de': 'Lengerich Westfalen', 'en': 'Lengerich Westfalen'},
 '495482':{'de': 'Tecklenburg', 'en': 'Tecklenburg'},
 '495483':{'de': 'Lienen', 'en': 'Lienen'},
 '55114220':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '4935954':{'de': 'Grossharthau', 'en': 'Grossharthau'},
 '4935955':{'de': 'Pulsnitz', 'en': 'Pulsnitz'},
 '4935952':{'de': u('Gro\u00dfr\u00f6hrsdorf OL'), 'en': u('Grossr\u00f6hrsdorf OL')},
 '4935953':{'de': 'Burkau', 'en': 'Burkau'},
 '4935951':{'de': 'Neukirch Lausitz', 'en': 'Neukirch Lausitz'},
 '55114223':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '499528':{'de': 'Donnersdorf', 'en': 'Donnersdorf'},
 '542946':{'en': u('Choele Choel, R\u00edo Negro'), 'es': u('Choele Choel, R\u00edo Negro')},
 '55112281':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495261':{'de': 'Lemgo', 'en': 'Lemgo'},
 '495262':{'de': 'Extertal', 'en': 'Extertal'},
 '495263':{'de': 'Barntrup', 'en': 'Barntrup'},
 '495264':{'de': 'Kalletal', 'en': 'Kalletal'},
 '495265':{'de': u('D\u00f6rentrup'), 'en': u('D\u00f6rentrup')},
 '495266':{'de': 'Lemgo-Kirchheide', 'en': 'Lemgo-Kirchheide'},
 '55112284':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55112285':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113451':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542963':{'en': 'Perito Moreno, Santa Cruz', 'es': 'Perito Moreno, Santa Cruz'},
 '55112287':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441304':{'en': 'Dover'},
 '55112288':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441449':{'en': 'Stowmarket'},
 '55112289':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441445':{'en': 'Gairloch'},
 '441444':{'en': 'Haywards Heath'},
 '441446':{'en': 'Barry'},
 '441440':{'en': 'Haverhill'},
 '441443':{'en': 'Pontypridd'},
 '441442':{'en': 'Hemel Hempstead'},
 '55112487':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '499447':{'de': 'Essing', 'en': 'Essing'},
 '542945':{'en': 'Esquel, Chubut', 'es': 'Esquel, Chubut'},
 '55113231':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113946':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113947':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123186':{'en': 'Cachoeira Paulista - SP', 'pt': 'Cachoeira Paulista - SP'},
 '4936027':{'de': 'Lengenfeld Unterm Stein', 'en': 'Lengenfeld Unterm Stein'},
 '4936026':{'de': u('Struth bei M\u00fchlhausen'), 'en': u('Struth bei M\u00fchlhausen')},
 '4936025':{'de': u('K\u00f6rner'), 'en': u('K\u00f6rner')},
 '4936024':{'de': u('Diedorf bei M\u00fchlhausen'), 'en': u('Diedorf bei M\u00fchlhausen')},
 '4936023':{'de': 'Horsmar', 'en': 'Horsmar'},
 '4936022':{'de': 'Grossengottern', 'en': 'Grossengottern'},
 '4936021':{'de': 'Schlotheim', 'en': 'Schlotheim'},
 '4936020':{'de': 'Ebeleben', 'en': 'Ebeleben'},
 '4936029':{'de': 'Menteroda', 'en': 'Menteroda'},
 '4936028':{'de': u('Kammerforst Th\u00fcringen'), 'en': u('Kammerforst Th\u00fcringen')},
 '497084':{'de': u('Sch\u00f6mberg bei Neuenb\u00fcrg'), 'en': u('Sch\u00f6mberg bei Neuenb\u00fcrg')},
 '435331':{'de': 'Brandenberg', 'en': 'Brandenberg'},
 '435332':{'de': u('W\u00f6rgl'), 'en': u('W\u00f6rgl')},
 '497085':{'de': u('Enzkl\u00f6sterle'), 'en': u('Enzkl\u00f6sterle')},
 '435334':{'de': 'Westendorf', 'en': 'Westendorf'},
 '435335':{'de': 'Hopfgarten im Brixental', 'en': 'Hopfgarten im Brixental'},
 '435336':{'de': 'Alpbach', 'en': 'Alpbach'},
 '435337':{'de': 'Brixlegg', 'en': 'Brixlegg'},
 '435338':{'de': 'Kundl', 'en': 'Kundl'},
 '435339':{'de': u('Wildsch\u00f6nau'), 'en': u('Wildsch\u00f6nau')},
 '497083':{'de': 'Bad Herrenalb', 'en': 'Bad Herrenalb'},
 '499443':{'de': 'Abensberg', 'en': 'Abensberg'},
 '497081':{'de': 'Bad Wildbad', 'en': 'Bad Wildbad'},
 '493301':{'de': 'Oranienburg', 'en': 'Oranienburg'},
 '493303':{'de': 'Birkenwerder', 'en': 'Birkenwerder'},
 '493302':{'de': 'Hennigsdorf', 'en': 'Hennigsdorf'},
 '498825':{'de': u('Kr\u00fcn'), 'en': u('Kr\u00fcn')},
 '493304':{'de': 'Velten', 'en': 'Velten'},
 '493307':{'de': 'Zehdenick', 'en': 'Zehdenick'},
 '493306':{'de': 'Gransee', 'en': 'Gransee'},
 '55112480':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55114241':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '542982':{'en': u('Claromec\u00f3, Buenos Aires'), 'es': u('Claromec\u00f3, Buenos Aires')},
 '55113603':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113602':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113601':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113607':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55114346':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113608':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '46652':{'en': u('Bergsj\u00f6'), 'sv': u('Bergsj\u00f6')},
 '55114344':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '46653':{'en': 'Delsbo', 'sv': 'Delsbo'},
 '55114343':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '46650':{'en': 'Hudiksvall', 'sv': 'Hudiksvall'},
 '55114342':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '499152':{'de': 'Hartenstein Mittelfranken', 'en': 'Hartenstein Mittelfranken'},
 '494305':{'de': 'Westensee', 'en': 'Westensee'},
 '55114033':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '494307':{'de': 'Raisdorf', 'en': 'Raisdorf'},
 '499156':{'de': 'Neuhaus an der Pegnitz', 'en': 'Neuhaus an der Pegnitz'},
 '499157':{'de': 'Alfeld Mittelfranken', 'en': 'Alfeld Mittelfranken'},
 '494302':{'de': 'Kirchbarkau', 'en': 'Kirchbarkau'},
 '494303':{'de': 'Schlesen', 'en': 'Schlesen'},
 '55114039':{'en': 'Campo Limpo Paulista - SP', 'pt': 'Campo Limpo Paulista - SP'},
 '55114038':{'en': 'Campo Limpo Paulista - SP', 'pt': 'Campo Limpo Paulista - SP'},
 '499158':{'de': 'Offenhausen Mittelfranken', 'en': 'Offenhausen Mittelfranken'},
 '494308':{'de': 'Schwedeneck', 'en': 'Schwedeneck'},
 '55123921':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '499426':{'de': 'Oberschneiding', 'en': 'Oberschneiding'},
 '499093':{'de': 'Polsingen', 'en': 'Polsingen'},
 '499092':{'de': 'Wemding', 'en': 'Wemding'},
 '499091':{'de': 'Monheim Schwaben', 'en': 'Monheim Schwaben'},
 '437219':{'de': u('Vorderwei\u00dfenbach'), 'en': 'Vorderweissenbach'},
 '499427':{'de': 'Leiblfing', 'en': 'Leiblfing'},
 '499090':{'de': 'Rain Lech', 'en': 'Rain Lech'},
 '437218':{'de': u('Gro\u00dftraberg'), 'en': 'Grosstraberg'},
 '499097':{'de': 'Marxheim', 'en': 'Marxheim'},
 '49381':{'de': 'Rostock', 'en': 'Rostock'},
 '46573':{'en': u('\u00c5rj\u00e4ng'), 'sv': u('\u00c5rj\u00e4ng')},
 '46571':{'en': u('Charlottenberg-\u00c5motfors'), 'sv': u('Charlottenberg-\u00c5motfors')},
 '46570':{'en': 'Arvika', 'sv': 'Arvika'},
 '55115531':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499094':{'de': 'Tagmersheim', 'en': 'Tagmersheim'},
 '499424':{'de': 'Strasskirchen', 'en': 'Strasskirchen'},
 '55112947':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112946':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112945':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437211':{'de': u('Reichenau im M\u00fchlkreis'), 'en': u('Reichenau im M\u00fchlkreis')},
 '55112944':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112943':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437213':{'de': 'Bad Leonfelden', 'en': 'Bad Leonfelden'},
 '499276':{'de': u('Bischofsgr\u00fcn'), 'en': u('Bischofsgr\u00fcn')},
 '437212':{'de': 'Zwettl an der Rodl', 'en': 'Zwettl an der Rodl'},
 '55112941':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123301':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '437215':{'de': u('Hellmons\u00f6dt'), 'en': u('Hellmons\u00f6dt')},
 '55112940':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437214':{'de': 'Reichenthal', 'en': 'Reichenthal'},
 '543382':{'en': 'Rufino, Santa Fe', 'es': 'Rufino, Santa Fe'},
 '543387':{'en': u('Buchardo, C\u00f3rdoba'), 'es': u('Buchardo, C\u00f3rdoba')},
 '437217':{'de': u('Sankt Veit im M\u00fchlkreis'), 'en': u('St. Veit im M\u00fchlkreis')},
 '543385':{'en': u('Laboulaye, C\u00f3rdoba'), 'es': u('Laboulaye, C\u00f3rdoba')},
 '437216':{'de': 'Helfenberg', 'en': 'Helfenberg'},
 '499422':{'de': 'Bogen Niederbayern', 'en': 'Bogen Niederbayern'},
 '499278':{'de': 'Weidenberg', 'en': 'Weidenberg'},
 '4933082':{'de': 'Menz Kreis Oberhavel', 'en': 'Menz Kreis Oberhavel'},
 '4933083':{'de': 'Schulzendorf Kreis Oberhavel', 'en': 'Schulzendorf Kreis Oberhavel'},
 '4933080':{'de': 'Marienthal Kreis Oberhavel', 'en': 'Marienthal Kreis Oberhavel'},
 '55115549':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933086':{'de': 'Grieben Kreis Oberhavel', 'en': 'Grieben Kreis Oberhavel'},
 '4933087':{'de': 'Bredereiche', 'en': 'Bredereiche'},
 '4933084':{'de': 'Gutengermendorf', 'en': 'Gutengermendorf'},
 '492691':{'de': 'Adenau', 'en': 'Adenau'},
 '55112262':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112263':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933088':{'de': 'Falkenthal', 'en': 'Falkenthal'},
 '4933089':{'de': 'Himmelpfort', 'en': 'Himmelpfort'},
 '55115546':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112267':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112264':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112265':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492693':{'de': 'Antweiler', 'en': 'Antweiler'},
 '49921':{'de': 'Bayreuth', 'en': 'Bayreuth'},
 '493949':{'de': 'Oschersleben Bode', 'en': 'Oschersleben Bode'},
 '493947':{'de': 'Thale', 'en': 'Thale'},
 '492694':{'de': 'Wershofen', 'en': 'Wershofen'},
 '493944':{'de': 'Blankenburg Harz', 'en': 'Blankenburg Harz'},
 '493943':{'de': 'Wernigerode', 'en': 'Wernigerode'},
 '493941':{'de': 'Halberstadt', 'en': 'Halberstadt'},
 '496254':{'de': 'Lautertal Odenwald', 'en': 'Lautertal Odenwald'},
 '492164':{'de': u('J\u00fcchen-Otzenrath'), 'en': u('J\u00fcchen-Otzenrath')},
 '496255':{'de': 'Lindenfels', 'en': 'Lindenfels'},
 '492697':{'de': u('Blankenheim-Ahrh\u00fctte'), 'en': u('Blankenheim-Ahrh\u00fctte')},
 '496524':{'de': 'Rodershausen', 'en': 'Rodershausen'},
 '496257':{'de': 'Seeheim-Jugenheim', 'en': 'Seeheim-Jugenheim'},
 '496251':{'de': 'Bensheim', 'en': 'Bensheim'},
 '437279':{'de': 'Haibach ob der Donau', 'en': 'Haibach ob der Donau'},
 '437278':{'de': 'Neukirchen am Walde', 'en': 'Neukirchen am Walde'},
 '437277':{'de': 'Waizenkirchen', 'en': 'Waizenkirchen'},
 '437276':{'de': 'Peuerbach', 'en': 'Peuerbach'},
 '437274':{'de': 'Alkoven', 'en': 'Alkoven'},
 '437273':{'de': 'Aschach an der Donau', 'en': 'Aschach an der Donau'},
 '437272':{'de': 'Eferding', 'en': 'Eferding'},
 '496272':{'de': 'Hirschhorn Neckar', 'en': 'Hirschhorn Neckar'},
 '496271':{'de': 'Eberbach Baden', 'en': 'Eberbach Baden'},
 '496276':{'de': 'Hesseneck', 'en': 'Hesseneck'},
 '496274':{'de': 'Waldbrunn Odenwald', 'en': 'Waldbrunn Odenwald'},
 '496275':{'de': 'Rothenberg Odenwald', 'en': 'Rothenberg Odenwald'},
 '498203':{'de': 'Grossaitingen', 'en': 'Grossaitingen'},
 '498202':{'de': 'Althegnenberg', 'en': 'Althegnenberg'},
 '55112183':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498204':{'de': 'Mickhausen', 'en': 'Mickhausen'},
 '55114639':{'en': u('Po\u00e1 - SP'), 'pt': u('Po\u00e1 - SP')},
 '55114638':{'en': u('Po\u00e1 - SP'), 'pt': u('Po\u00e1 - SP')},
 '55114684':{'en': 'Juquitiba - SP', 'pt': 'Juquitiba - SP'},
 '496096':{'de': 'Wiesen Unterfranken', 'en': 'Wiesen Unterfranken'},
 '496094':{'de': 'Weibersbrunn', 'en': 'Weibersbrunn'},
 '496095':{'de': 'Bessenbach', 'en': 'Bessenbach'},
 '496092':{'de': 'Heimbuchenthal', 'en': 'Heimbuchenthal'},
 '496093':{'de': 'Laufach', 'en': 'Laufach'},
 '55114634':{'en': u('Po\u00e1 - SP'), 'pt': u('Po\u00e1 - SP')},
 '55133481':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '496897':{'de': 'Sulzbach Saar', 'en': 'Sulzbach Saar'},
 '496894':{'de': 'St Ingbert', 'en': 'St Ingbert'},
 '496893':{'de': u('Saarbr\u00fccken-Ensheim'), 'en': u('Saarbr\u00fccken-Ensheim')},
 '496898':{'de': u('V\u00f6lklingen'), 'en': u('V\u00f6lklingen')},
 '55114555':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '498146':{'de': 'Moorenweis', 'en': 'Moorenweis'},
 '498144':{'de': 'Grafrath', 'en': 'Grafrath'},
 '498145':{'de': 'Mammendorf', 'en': 'Mammendorf'},
 '498142':{'de': 'Olching', 'en': 'Olching'},
 '498143':{'de': 'Inning am Ammersee', 'en': 'Inning am Ammersee'},
 '498141':{'de': u('F\u00fcrstenfeldbruck'), 'en': u('F\u00fcrstenfeldbruck')},
 '441650':{'en': 'Cemmaes Road'},
 '441651':{'en': 'Oldmeldrum'},
 '494539':{'de': 'Westerau', 'en': 'Westerau'},
 '441653':{'en': 'Malton'},
 '494829':{'de': 'Wewelsfleth', 'en': 'Wewelsfleth'},
 '494828':{'de': u('L\u00e4gerdorf'), 'en': u('L\u00e4gerdorf')},
 '441656':{'en': 'Bridgend'},
 '494533':{'de': 'Reinfeld Holstein', 'en': 'Reinfeld Holstein'},
 '494824':{'de': 'Krempe', 'en': 'Krempe'},
 '494531':{'de': 'Bad Oldesloe', 'en': 'Bad Oldesloe'},
 '494826':{'de': 'Hohenlockstedt', 'en': 'Hohenlockstedt'},
 '494821':{'de': 'Itzehoe', 'en': 'Itzehoe'},
 '494536':{'de': 'Steinhorst Lauenburg', 'en': 'Steinhorst Lauenburg'},
 '494823':{'de': 'Wilster', 'en': 'Wilster'},
 '494822':{'de': 'Kellinghusen', 'en': 'Kellinghusen'},
 '497329':{'de': 'Steinheim am Albuch', 'en': 'Steinheim am Albuch'},
 '497328':{'de': u('K\u00f6nigsbronn'), 'en': u('K\u00f6nigsbronn')},
 '497327':{'de': 'Dischingen', 'en': 'Dischingen'},
 '497326':{'de': 'Neresheim', 'en': 'Neresheim'},
 '497325':{'de': 'Sontheim an der Brenz', 'en': 'Sontheim an der Brenz'},
 '497324':{'de': 'Herbrechtingen', 'en': 'Herbrechtingen'},
 '497323':{'de': 'Gerstetten', 'en': 'Gerstetten'},
 '497322':{'de': 'Giengen an der Brenz', 'en': 'Giengen an der Brenz'},
 '497321':{'de': 'Heidenheim an der Brenz', 'en': 'Heidenheim an der Brenz'},
 '493448':{'de': u('Meuselwitz Th\u00fcringen'), 'en': u('Meuselwitz Th\u00fcringen')},
 '498369':{'de': u('R\u00fcckholz'), 'en': u('R\u00fcckholz')},
 '498362':{'de': u('F\u00fcssen'), 'en': u('F\u00fcssen')},
 '493443':{'de': 'Weissenfels Sachsen-Anhalt', 'en': 'Weissenfels Sachsen-Anhalt'},
 '493441':{'de': 'Zeitz', 'en': 'Zeitz'},
 '498366':{'de': 'Oy-Mittelberg', 'en': 'Oy-Mittelberg'},
 '493447':{'de': u('Altenburg Th\u00fcringen'), 'en': u('Altenburg Th\u00fcringen')},
 '498364':{'de': 'Seeg', 'en': 'Seeg'},
 '493445':{'de': 'Naumburg Saale', 'en': 'Naumburg Saale'},
 '494796':{'de': 'Teufelsmoor', 'en': 'Teufelsmoor'},
 '494795':{'de': 'Garlstedt', 'en': 'Garlstedt'},
 '494794':{'de': 'Worpswede-Ostersode', 'en': 'Worpswede-Ostersode'},
 '494793':{'de': 'Hambergen', 'en': 'Hambergen'},
 '4939863':{'de': 'Seehausen bei Prenzlau', 'en': 'Seehausen bei Prenzlau'},
 '494791':{'de': 'Osterholz-Scharmbeck', 'en': 'Osterholz-Scharmbeck'},
 '4939861':{'de': 'Gramzow bei Prenzlau', 'en': 'Gramzow bei Prenzlau'},
 '46380':{'en': u('N\u00e4ssj\u00f6'), 'sv': u('N\u00e4ssj\u00f6')},
 '46381':{'en': u('Eksj\u00f6'), 'sv': u('Eksj\u00f6')},
 '46382':{'en': u('S\u00e4vsj\u00f6'), 'sv': u('S\u00e4vsj\u00f6')},
 '46383':{'en': 'Vetlanda', 'sv': 'Vetlanda'},
 '52983':{'en': 'Quintana Roo', 'es': 'Quintana Roo'},
 '52982':{'en': 'Campeche', 'es': 'Campeche'},
 '4415392':{'en': 'Kendal'},
 '52987':{'en': 'Cozumel, QRO', 'es': 'Cozumel, QRO'},
 '52986':{'en': 'Yucatan', 'es': u('Yucat\u00e1n')},
 '52329':{'en': 'Nayarit', 'es': 'Nayarit'},
 '52328':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52327':{'en': 'Nayarit', 'es': 'Nayarit'},
 '52326':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52325':{'en': 'Acaponeta, NAY', 'es': 'Acaponeta, NAY'},
 '52324':{'en': 'Nayarit', 'es': 'Nayarit'},
 '52323':{'en': 'Nayarit', 'es': 'Nayarit'},
 '52322':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52321':{'en': 'El Grullo/El Limon, JAL', 'es': 'El Grullo/El Limon, JAL'},
 '55112728':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112727':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112726':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112725':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112724':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112891':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55112722':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112721':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112892':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441261':{'en': 'Banff'},
 '441260':{'en': 'Congleton'},
 '441263':{'en': 'Cromer'},
 '441262':{'en': 'Bridlington'},
 '49711':{'de': 'Stuttgart', 'en': 'Stuttgart'},
 '441264':{'en': 'Andover'},
 '441267':{'en': 'Carmarthen'},
 '441269':{'en': 'Ammanford'},
 '441268':{'en': 'Basildon'},
 '55112095':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112094':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112097':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112091':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112090':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112093':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112092':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112099':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112098':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4939398':{'de': 'Gross Garz', 'en': 'Gross Garz'},
 '4939399':{'de': 'Kleinau', 'en': 'Kleinau'},
 '542922':{'en': 'Coronel Pringles, Buenos Aires', 'es': 'Coronel Pringles, Buenos Aires'},
 '4939390':{'de': 'Iden', 'en': 'Iden'},
 '4939391':{'de': u('L\u00fcckstedt'), 'en': u('L\u00fcckstedt')},
 '4939392':{'de': u('R\u00f6nnebeck Sachsen-Anhalt'), 'en': u('R\u00f6nnebeck Sachsen-Anhalt')},
 '4939393':{'de': 'Werben Elbe', 'en': 'Werben Elbe'},
 '4939394':{'de': 'Hohenberg-Krusemark', 'en': 'Hohenberg-Krusemark'},
 '49241':{'de': 'Aachen', 'en': 'Aachen'},
 '4939396':{'de': 'Neukirchen Altmark', 'en': 'Neukirchen Altmark'},
 '4939397':{'de': 'Geestgottberg', 'en': 'Geestgottberg'},
 '4934461':{'de': 'Nebra Unstrut', 'en': 'Nebra Unstrut'},
 '55112547':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4934463':{'de': u('Bad K\u00f6sen'), 'en': u('Bad K\u00f6sen')},
 '4934462':{'de': 'Laucha Unstrut', 'en': 'Laucha Unstrut'},
 '4934465':{'de': 'Bad Bibra', 'en': 'Bad Bibra'},
 '4934464':{'de': 'Freyburg Unstrut', 'en': 'Freyburg Unstrut'},
 '4934467':{'de': 'Eckartsberga', 'en': 'Eckartsberga'},
 '4934466':{'de': 'Janisroda', 'en': 'Janisroda'},
 '4936649':{'de': 'Gefell bei Schleiz', 'en': 'Gefell bei Schleiz'},
 '4936648':{'de': 'Dittersdorf bei Schleiz', 'en': 'Dittersdorf bei Schleiz'},
 '4848':{'en': 'Radom', 'pl': 'Radom'},
 '4936643':{'de': 'Thimmendorf', 'en': 'Thimmendorf'},
 '4936642':{'de': 'Harra', 'en': 'Harra'},
 '4846':{'en': 'Skierniewice', 'pl': 'Skierniewice'},
 '4936640':{'de': 'Remptendorf', 'en': 'Remptendorf'},
 '4936647':{'de': u('Saalburg Th\u00fcringen'), 'en': u('Saalburg Th\u00fcringen')},
 '4936646':{'de': 'Tanna bei Schleiz', 'en': 'Tanna bei Schleiz'},
 '4936645':{'de': u('M\u00fchltroff'), 'en': u('M\u00fchltroff')},
 '4936644':{'de': 'Hirschberg Saale', 'en': 'Hirschberg Saale'},
 '441885':{'en': 'Pencombe'},
 '441884':{'en': 'Tiverton'},
 '441887':{'en': 'Aberfeldy'},
 '441886':{'en': 'Bromyard (Knightwick/Leigh Sinton)'},
 '441880':{'en': 'Tarbert'},
 '441883':{'en': 'Caterham'},
 '441882':{'en': 'Kinloch Rannoch'},
 '441889':{'en': 'Rugeley'},
 '441888':{'en': 'Turriff'},
 '542924':{'en': 'Darregueira, Buenos Aires', 'es': 'Darregueira, Buenos Aires'},
 '55113418':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '55113416':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '55113414':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55113412':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113413':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55113411':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542925':{'en': 'Villa Iris, Buenos Aires', 'es': 'Villa Iris, Buenos Aires'},
 '542926':{'en': u('Coronel Su\u00e1rez, Buenos Aires'), 'es': u('Coronel Su\u00e1rez, Buenos Aires')},
 '55114826':{'en': 'Rio Grande da Serra - SP', 'pt': 'Rio Grande da Serra - SP'},
 '55114827':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '55114824':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '55114825':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '55114823':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '55114820':{'en': 'Rio Grande da Serra - SP', 'pt': 'Rio Grande da Serra - SP'},
 '55114821':{'en': 'Rio Grande da Serra - SP', 'pt': 'Rio Grande da Serra - SP'},
 '55114828':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '55114829':{'en': u('Ribeir\u00e3o Pires - SP'), 'pt': u('Ribeir\u00e3o Pires - SP')},
 '436213':{'de': 'Oberhofen am Irrsee', 'en': 'Oberhofen am Irrsee'},
 '542972':{'en': u('San Mart\u00edn de los Andes, Neuqu\u00e9n'), 'es': u('San Mart\u00edn de los Andes, Neuqu\u00e9n')},
 '495468':{'de': 'Bramsche-Engter', 'en': 'Bramsche-Engter'},
 '495466':{'de': 'Merzen', 'en': 'Merzen'},
 '495467':{'de': 'Voltlage', 'en': 'Voltlage'},
 '495464':{'de': 'Alfhausen', 'en': 'Alfhausen'},
 '495465':{'de': 'Neuenkirchen bei Bramsche', 'en': 'Neuenkirchen bei Bramsche'},
 '495462':{'de': 'Ankum', 'en': 'Ankum'},
 '495461':{'de': 'Bramsche Hase', 'en': 'Bramsche Hase'},
 '4935930':{'de': 'Seitschen', 'en': 'Seitschen'},
 '4935931':{'de': u('K\u00f6nigswartha'), 'en': u('K\u00f6nigswartha')},
 '4935932':{'de': 'Guttau', 'en': 'Guttau'},
 '4935933':{'de': 'Neschwitz', 'en': 'Neschwitz'},
 '4935934':{'de': 'Grossdubrau', 'en': 'Grossdubrau'},
 '4935935':{'de': 'Kleinwelka', 'en': 'Kleinwelka'},
 '4935936':{'de': 'Sohland Spree', 'en': 'Sohland Spree'},
 '4935937':{'de': 'Prischwitz', 'en': 'Prischwitz'},
 '4935938':{'de': u('Gro\u00dfpostwitz OL'), 'en': 'Grosspostwitz OL'},
 '4935939':{'de': 'Hochkirch', 'en': 'Hochkirch'},
 '542626':{'en': 'La Paz, Mendoza', 'es': 'La Paz, Mendoza'},
 '542625':{'en': 'General Alvear, Mendoza', 'es': 'General Alvear, Mendoza'},
 '542624':{'en': 'Uspallata, Mendoza', 'es': 'Uspallata, Mendoza'},
 '4937204':{'de': 'Lichtenstein Sachsen', 'en': 'Lichtenstein Sachsen'},
 '4937206':{'de': 'Frankenberg Sachsen', 'en': 'Frankenberg Sachsen'},
 '4937207':{'de': 'Hainichen Sachsen', 'en': 'Hainichen Sachsen'},
 '4937200':{'de': 'Wittgensdorf bei Chemnitz', 'en': 'Wittgensdorf bei Chemnitz'},
 '4937202':{'de': 'Claussnitz bei Chemnitz', 'en': 'Claussnitz bei Chemnitz'},
 '4937203':{'de': 'Gersdorf bei Chemnitz', 'en': 'Gersdorf bei Chemnitz'},
 '4937208':{'de': 'Auerswalde', 'en': 'Auerswalde'},
 '4937209':{'de': 'Einsiedel bei Chemnitz', 'en': 'Einsiedel bei Chemnitz'},
 '495208':{'de': u('Leopoldsh\u00f6he'), 'en': u('Leopoldsh\u00f6he')},
 '495209':{'de': u('G\u00fctersloh-Friedrichsdorf'), 'en': u('G\u00fctersloh-Friedrichsdorf')},
 '495202':{'de': 'Oerlinghausen', 'en': 'Oerlinghausen'},
 '495203':{'de': 'Werther Westfalen', 'en': 'Werther Westfalen'},
 '495201':{'de': 'Halle Westfalen', 'en': 'Halle Westfalen'},
 '495206':{'de': u('Bielefeld-J\u00f6llenbeck'), 'en': u('Bielefeld-J\u00f6llenbeck')},
 '495207':{'de': 'Schloss Holte-Stukenbrock', 'en': 'Schloss Holte-Stukenbrock'},
 '495204':{'de': 'Steinhagen Westfalen', 'en': 'Steinhagen Westfalen'},
 '495205':{'de': 'Bielefeld-Sennestadt', 'en': 'Bielefeld-Sennestadt'},
 '441467':{'en': 'Inverurie'},
 '441466':{'en': 'Huntly'},
 '441465':{'en': 'Girvan'},
 '441464':{'en': 'Insch'},
 '441463':{'en': 'Inverness'},
 '441462':{'en': 'Hitchin'},
 '441461':{'en': 'Gretna'},
 '441460':{'en': 'Chard'},
 '441469':{'en': 'Killingholme'},
 '55114798':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '499391':{'de': 'Marktheidenfeld', 'en': 'Marktheidenfeld'},
 '55114799':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '437684':{'de': 'Frankenmarkt', 'en': 'Frankenmarkt'},
 '437682':{'de': u('V\u00f6cklamarkt'), 'en': u('V\u00f6cklamarkt')},
 '437683':{'de': 'Frankenburg am Hausruck', 'en': 'Frankenburg am Hausruck'},
 '537':{'en': 'Havana City'},
 '55114795':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '499392':{'de': 'Faulbach Unterfranken', 'en': 'Faulbach Unterfranken'},
 '55114163':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114533':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '441790':{'en': 'Spilsby'},
 '441793':{'en': 'Swindon'},
 '441792':{'en': 'Swansea'},
 '441795':{'en': 'Sittingbourne'},
 '441794':{'en': 'Romsey'},
 '441797':{'en': 'Rye'},
 '441796':{'en': 'Pitlochry'},
 '441799':{'en': 'Saffron Walden'},
 '441798':{'en': 'Pulborough'},
 '55114791':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '499393':{'de': 'Rothenfels Unterfranken', 'en': 'Rothenfels Unterfranken'},
 '55115010':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115011':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115012':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115013':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115014':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115015':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115016':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115017':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115018':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543838':{'en': u('Santa Mar\u00eda, Catamarca'), 'es': u('Santa Mar\u00eda, Catamarca')},
 '46416':{'en': u('Sj\u00f6bo'), 'sv': u('Sj\u00f6bo')},
 '499394':{'de': 'Esselbach', 'en': 'Esselbach'},
 '55114169':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '492636':{'de': 'Burgbrohl', 'en': 'Burgbrohl'},
 '492637':{'de': 'Weissenthurm', 'en': 'Weissenthurm'},
 '492634':{'de': 'Rengsdorf', 'en': 'Rengsdorf'},
 '492635':{'de': 'Rheinbrohl', 'en': 'Rheinbrohl'},
 '492632':{'de': 'Andernach', 'en': 'Andernach'},
 '492633':{'de': u('Brohl-L\u00fctzing'), 'en': u('Brohl-L\u00fctzing')},
 '492630':{'de': u('M\u00fclheim-K\u00e4rlich'), 'en': u('M\u00fclheim-K\u00e4rlich')},
 '492631':{'de': 'Neuwied', 'en': 'Neuwied'},
 '499554':{'de': 'Untersteinbach Unterfranken', 'en': 'Untersteinbach Unterfranken'},
 '492638':{'de': 'Waldbreitbach', 'en': 'Waldbreitbach'},
 '492639':{'de': 'Anhausen Kreis Neuwied', 'en': 'Anhausen Kreis Neuwied'},
 '435358':{'de': 'Ellmau', 'en': 'Ellmau'},
 '435359':{'de': 'Hochfilzen', 'en': 'Hochfilzen'},
 '435352':{'de': 'Sankt Johann in Tirol', 'en': 'St. Johann in Tirol'},
 '435353':{'de': 'Waidring', 'en': 'Waidring'},
 '435356':{'de': u('Kitzb\u00fchel'), 'en': u('Kitzb\u00fchel')},
 '435357':{'de': 'Kirchberg in Tirol', 'en': 'Kirchberg in Tirol'},
 '435354':{'de': 'Fieberbrunn', 'en': 'Fieberbrunn'},
 '435355':{'de': 'Jochberg', 'en': 'Jochberg'},
 '498803':{'de': 'Peissenberg', 'en': 'Peissenberg'},
 '493322':{'de': 'Falkensee', 'en': 'Falkensee'},
 '493321':{'de': 'Nauen Brandenburg', 'en': 'Nauen Brandenburg'},
 '493327':{'de': 'Werder Havel', 'en': 'Werder Havel'},
 '498806':{'de': 'Utting am Ammersee', 'en': 'Utting am Ammersee'},
 '498805':{'de': 'Hohenpeissenberg', 'en': 'Hohenpeissenberg'},
 '55113832':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493329':{'de': 'Stahnsdorf', 'en': 'Stahnsdorf'},
 '493328':{'de': 'Teltow', 'en': 'Teltow'},
 '499396':{'de': 'Urspringen bei Lohr', 'en': 'Urspringen bei Lohr'},
 '55112903':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492409':{'de': 'Stolberg-Gressenich', 'en': 'Stolberg-Gressenich'},
 '492408':{'de': u('Aachen-Kornelim\u00fcnster'), 'en': u('Aachen-Kornelim\u00fcnster')},
 '492405':{'de': u('W\u00fcrselen'), 'en': u('W\u00fcrselen')},
 '492404':{'de': 'Alsdorf Rheinland', 'en': 'Alsdorf Rheinland'},
 '55123926':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '492407':{'de': 'Herzogenrath-Kohlscheid', 'en': 'Herzogenrath-Kohlscheid'},
 '492406':{'de': 'Herzogenrath', 'en': 'Herzogenrath'},
 '497121':{'de': 'Reutlingen', 'en': 'Reutlingen'},
 '494494':{'de': u('B\u00f6sel Oldenburg'), 'en': u('B\u00f6sel Oldenburg')},
 '494495':{'de': u('Friesoythe-Th\u00fcle'), 'en': u('Friesoythe-Th\u00fcle')},
 '494496':{'de': 'Friesoythe-Markhausen', 'en': 'Friesoythe-Markhausen'},
 '494497':{'de': u('Bar\u00dfel-Harkebr\u00fcgge'), 'en': u('Barssel-Harkebr\u00fcgge')},
 '494491':{'de': 'Friesoythe', 'en': 'Friesoythe'},
 '494492':{'de': 'Saterland', 'en': 'Saterland'},
 '494493':{'de': 'Friesoythe-Gehlenberg', 'en': 'Friesoythe-Gehlenberg'},
 '492402':{'de': 'Stolberg Rheinland', 'en': 'Stolberg Rheinland'},
 '494498':{'de': 'Saterland-Ramsloh', 'en': 'Saterland-Ramsloh'},
 '494499':{'de': 'Barssel', 'en': 'Barssel'},
 '55113628':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113621':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113623':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113622':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113625':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113624':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498774':{'de': 'Bayerbach bei Ergoldsbach', 'en': 'Bayerbach bei Ergoldsbach'},
 '498771':{'de': 'Ergoldsbach', 'en': 'Ergoldsbach'},
 '498773':{'de': 'Neufahrn in Niederbayern', 'en': 'Neufahrn in Niederbayern'},
 '498772':{'de': 'Mallersdorf-Pfaffenberg', 'en': 'Mallersdorf-Pfaffenberg'},
 '498535':{'de': 'Haarbach', 'en': 'Haarbach'},
 '4935695':{'de': 'Simmersdorf', 'en': 'Simmersdorf'},
 '4935694':{'de': 'Gosda bei Klinge', 'en': 'Gosda bei Klinge'},
 '4935697':{'de': 'Bagenz', 'en': 'Bagenz'},
 '4935696':{'de': 'Briesnig', 'en': 'Briesnig'},
 '4935691':{'de': u('B\u00e4renklau NL'), 'en': u('B\u00e4renklau NL')},
 '4935693':{'de': u('Lausch\u00fctz'), 'en': u('Lausch\u00fctz')},
 '4935692':{'de': 'Kerkwitz', 'en': 'Kerkwitz'},
 '498533':{'de': u('Rotthalm\u00fcnster'), 'en': u('Rotthalm\u00fcnster')},
 '4935698':{'de': 'Hornow', 'en': 'Hornow'},
 '498532':{'de': 'Griesbach im Rottal', 'en': 'Griesbach im Rottal'},
 '55114057':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '494671':{'de': 'Bredstedt', 'en': 'Bredstedt'},
 '494672':{'de': 'Langenhorn', 'en': 'Langenhorn'},
 '494673':{'de': 'Joldelund', 'en': 'Joldelund'},
 '494674':{'de': 'Ockholm', 'en': 'Ockholm'},
 '499179':{'de': 'Freystadt', 'en': 'Freystadt'},
 '55114051':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '499174':{'de': 'Hilpoltstein', 'en': 'Hilpoltstein'},
 '4938843':{'de': 'Bennin', 'en': 'Bennin'},
 '499176':{'de': 'Allersberg', 'en': 'Allersberg'},
 '499177':{'de': 'Heideck', 'en': 'Heideck'},
 '499170':{'de': 'Schwanstetten', 'en': 'Schwanstetten'},
 '499171':{'de': 'Roth Mittelfranken', 'en': 'Roth Mittelfranken'},
 '499172':{'de': u('Georgensgm\u00fcnd'), 'en': u('Georgensgm\u00fcnd')},
 '499173':{'de': u('Thalm\u00e4ssing'), 'en': u('Thalm\u00e4ssing')},
 '4938841':{'de': 'Neuhaus Elbe', 'en': 'Neuhaus Elbe'},
 '55113201':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114280':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '499099':{'de': 'Kaisheim', 'en': 'Kaisheim'},
 '46591':{'en': u('H\u00e4llefors-Grythyttan'), 'sv': u('H\u00e4llefors-Grythyttan')},
 '46590':{'en': 'Filipstad', 'sv': 'Filipstad'},
 '55115536':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495071':{'de': 'Schwarmstedt', 'en': 'Schwarmstedt'},
 '495073':{'de': 'Neustadt-Esperke', 'en': 'Neustadt-Esperke'},
 '495072':{'de': 'Neustadt-Mandelsloh', 'en': 'Neustadt-Mandelsloh'},
 '495074':{'de': 'Rodewald', 'en': 'Rodewald'},
 '46651':{'en': 'Ljusdal', 'sv': 'Ljusdal'},
 '54260':{'en': 'San Rafael, Mendoza', 'es': 'San Rafael, Mendoza'},
 '54261':{'en': 'Mendoza, Mendoza', 'es': 'Mendoza, Mendoza'},
 '54263':{'en': u('San Mart\u00edn, Mendoza'), 'es': u('San Mart\u00edn, Mendoza')},
 '54264':{'en': 'San Juan, San Juan', 'es': 'San Juan, San Juan'},
 '54266':{'en': 'San Luis, San Luis', 'es': 'San Luis, San Luis'},
 '55112280':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499952':{'de': 'Eichendorf', 'en': 'Eichendorf'},
 '55112282':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112283':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437479':{'de': 'Ardagger', 'en': 'Ardagger'},
 '437478':{'de': 'Oed-Oehling', 'en': 'Oed-Oehling'},
 '55112286':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499953':{'de': 'Pilsting', 'en': 'Pilsting'},
 '437475':{'de': 'Hausmening, Neuhofen an der Ybbs', 'en': 'Hausmening, Neuhofen an der Ybbs'},
 '437474':{'de': 'Euratsfeld', 'en': 'Euratsfeld'},
 '437477':{'de': 'Sankt Peter in der Au', 'en': 'St. Peter in der Au'},
 '437476':{'de': 'Aschbach-Markt', 'en': 'Aschbach-Markt'},
 '437471':{'de': 'Neustadtl an der Donau', 'en': 'Neustadtl an der Donau'},
 '55115833':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437473':{'de': 'Blindenmarkt', 'en': 'Blindenmarkt'},
 '437472':{'de': 'Amstetten', 'en': 'Amstetten'},
 '493928':{'de': u('Sch\u00f6nebeck Elbe'), 'en': u('Sch\u00f6nebeck Elbe')},
 '49906':{'de': u('Donauw\u00f6rth'), 'en': u('Donauw\u00f6rth')},
 '55123185':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '55123184':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '493921':{'de': 'Burg bei Magdeburg', 'en': 'Burg bei Magdeburg'},
 '499956':{'de': 'Eichendorf-Aufhausen', 'en': 'Eichendorf-Aufhausen'},
 '493923':{'de': 'Zerbst', 'en': 'Zerbst'},
 '493925':{'de': 'Stassfurt', 'en': 'Stassfurt'},
 '4938726':{'de': 'Spornitz', 'en': 'Spornitz'},
 '4938727':{'de': 'Mestlin', 'en': 'Mestlin'},
 '4938724':{'de': 'Siggelkow', 'en': 'Siggelkow'},
 '4938725':{'de': 'Gross Godems', 'en': 'Gross Godems'},
 '4938722':{'de': 'Raduhn', 'en': 'Raduhn'},
 '4938723':{'de': 'Kladrum', 'en': 'Kladrum'},
 '4938720':{'de': 'Grebbin', 'en': 'Grebbin'},
 '4938721':{'de': 'Ziegendorf', 'en': 'Ziegendorf'},
 '4938728':{'de': u('Doms\u00fchl'), 'en': u('Doms\u00fchl')},
 '4938729':{'de': 'Marnitz', 'en': 'Marnitz'},
 '495695':{'de': 'Twistetal', 'en': 'Twistetal'},
 '495694':{'de': 'Diemelstadt', 'en': 'Diemelstadt'},
 '495696':{'de': 'Bad Arolsen-Landau', 'en': 'Bad Arolsen-Landau'},
 '495691':{'de': 'Bad Arolsen', 'en': 'Bad Arolsen'},
 '495693':{'de': 'Volkmarsen', 'en': 'Volkmarsen'},
 '495692':{'de': 'Wolfhagen', 'en': 'Wolfhagen'},
 '4933208':{'de': 'Fahrland', 'en': 'Fahrland'},
 '4933209':{'de': 'Caputh', 'en': 'Caputh'},
 '4933200':{'de': u('Bergholz-Rehbr\u00fccke'), 'en': u('Bergholz-Rehbr\u00fccke')},
 '4933201':{'de': 'Gross Glienicke', 'en': 'Gross Glienicke'},
 '4933202':{'de': u('T\u00f6plitz'), 'en': u('T\u00f6plitz')},
 '4933203':{'de': 'Kleinmachnow', 'en': 'Kleinmachnow'},
 '4933204':{'de': 'Beelitz Mark', 'en': 'Beelitz Mark'},
 '4933205':{'de': 'Michendorf', 'en': 'Michendorf'},
 '4933206':{'de': 'Fichtenwalde', 'en': 'Fichtenwalde'},
 '4933207':{'de': 'Gross Kreutz', 'en': 'Gross Kreutz'},
 '496258':{'de': 'Gernsheim', 'en': 'Gernsheim'},
 '5411':{'en': 'Buenos Aires', 'es': 'Buenos Aires'},
 '496526':{'de': 'Bollendorf', 'en': 'Bollendorf'},
 '496527':{'de': 'Oberweis', 'en': 'Oberweis'},
 '496256':{'de': u('Lampertheim-H\u00fcttenfeld'), 'en': u('Lampertheim-H\u00fcttenfeld')},
 '496525':{'de': 'Irrel', 'en': 'Irrel'},
 '496522':{'de': 'Mettendorf', 'en': 'Mettendorf'},
 '496523':{'de': 'Holsthum', 'en': 'Holsthum'},
 '496252':{'de': u('Heppenheim Bergstra\u00dfe'), 'en': 'Heppenheim Bergstrasse'},
 '496253':{'de': u('F\u00fcrth Odenwald'), 'en': u('F\u00fcrth Odenwald')},
 '542964':{'en': u('R\u00edo Grande, Tierra del Fuego'), 'es': u('R\u00edo Grande, Tierra del Fuego')},
 '55114611':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55113904':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114612':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114615':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114614':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114617':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114616':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114619':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '55114618':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '542966':{'en': u('R\u00edo Gallegos, Santa Cruz'), 'es': u('R\u00edo Gallegos, Santa Cruz')},
 '499131':{'de': 'Erlangen', 'en': 'Erlangen'},
 '55114538':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114539':{'en': u('Joan\u00f3polis - SP'), 'pt': u('Joan\u00f3polis - SP')},
 '55114534':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114535':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114537':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114531':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114532':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55113488':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123119':{'en': 'Campos de Cunha - SP', 'pt': 'Campos de Cunha - SP'},
 '497129':{'de': u('Lichtenstein W\u00fcrttemberg'), 'en': u('Lichtenstein W\u00fcrttemberg')},
 '497128':{'de': u('Sonnenb\u00fchl'), 'en': u('Sonnenb\u00fchl')},
 '497125':{'de': 'Bad Urach', 'en': 'Bad Urach'},
 '497124':{'de': 'Trochtelfingen Hohenz', 'en': 'Trochtelfingen Hohenz'},
 '497127':{'de': 'Neckartenzlingen', 'en': 'Neckartenzlingen'},
 '497126':{'de': 'Burladingen-Melchingen', 'en': 'Burladingen-Melchingen'},
 '492401':{'de': 'Baesweiler', 'en': 'Baesweiler'},
 '497123':{'de': u('Metzingen W\u00fcrttemberg'), 'en': u('Metzingen W\u00fcrttemberg')},
 '497122':{'de': u('St Johann W\u00fcrttemberg'), 'en': u('St Johann W\u00fcrttemberg')},
 '498168':{'de': 'Attenkirchen', 'en': 'Attenkirchen'},
 '498161':{'de': 'Freising', 'en': 'Freising'},
 '498165':{'de': 'Neufahrn bei Freising', 'en': 'Neufahrn bei Freising'},
 '498166':{'de': 'Allershausen Oberbayern', 'en': 'Allershausen Oberbayern'},
 '498167':{'de': 'Zolling', 'en': 'Zolling'},
 '55114282':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494806':{'de': u('Sarzb\u00fcttel'), 'en': u('Sarzb\u00fcttel')},
 '494805':{'de': 'Schafstedt', 'en': 'Schafstedt'},
 '494804':{'de': 'Nordhastedt', 'en': 'Nordhastedt'},
 '494803':{'de': 'Pahlen', 'en': 'Pahlen'},
 '494802':{'de': 'Wrohm', 'en': 'Wrohm'},
 '55114284':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '441638':{'en': 'Newmarket'},
 '441639':{'en': 'Neath'},
 '441633':{'en': 'Newport'},
 '441630':{'en': 'Market Drayton'},
 '441631':{'en': 'Oban'},
 '441636':{'en': 'Newark-on-Trent'},
 '441637':{'en': 'Newquay'},
 '441634':{'en': 'Medway'},
 '441635':{'en': 'Newbury'},
 '497348':{'de': 'Beimerstetten', 'en': 'Beimerstetten'},
 '497340':{'de': 'Neenstetten', 'en': 'Neenstetten'},
 '497343':{'de': 'Buch bei Illertissen', 'en': 'Buch bei Illertissen'},
 '497345':{'de': u('Langenau W\u00fcrttemberg'), 'en': u('Langenau W\u00fcrttemberg')},
 '497344':{'de': 'Blaubeuren', 'en': 'Blaubeuren'},
 '497347':{'de': 'Dietenheim', 'en': 'Dietenheim'},
 '497346':{'de': 'Illerkirchberg', 'en': 'Illerkirchberg'},
 '55123034':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '436483':{'de': u('G\u00f6riach'), 'en': u('G\u00f6riach')},
 '436484':{'de': 'Lessach', 'en': 'Lessach'},
 '55112705':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112704':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112707':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112876':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55112703':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441249':{'en': 'Chippenham'},
 '441248':{'en': 'Bangor (Gwynedd)'},
 '441243':{'en': 'Chichester'},
 '441242':{'en': 'Cheltenham'},
 '441241':{'en': 'Arbroath'},
 '441246':{'en': 'Chesterfield'},
 '441245':{'en': 'Chelmsford'},
 '441244':{'en': 'Chester'},
 '493464':{'de': 'Sangerhausen', 'en': 'Sangerhausen'},
 '498345':{'de': u('St\u00f6ttwang'), 'en': u('St\u00f6ttwang')},
 '493466':{'de': 'Artern Unstrut', 'en': 'Artern Unstrut'},
 '498347':{'de': 'Friesenried', 'en': 'Friesenried'},
 '498340':{'de': 'Baisweil', 'en': 'Baisweil'},
 '493461':{'de': 'Merseburg Saale', 'en': 'Merseburg Saale'},
 '493462':{'de': u('Bad D\u00fcrrenberg'), 'en': u('Bad D\u00fcrrenberg')},
 '498343':{'de': 'Aitrang', 'en': 'Aitrang'},
 '498348':{'de': 'Bidingen', 'en': 'Bidingen'},
 '498349':{'de': u('St\u00f6tten am Auerberg'), 'en': u('St\u00f6tten am Auerberg')},
 '499343':{'de': u('Lauda-K\u00f6nigshofen'), 'en': u('Lauda-K\u00f6nigshofen')},
 '499342':{'de': 'Wertheim', 'en': 'Wertheim'},
 '499341':{'de': 'Tauberbischofsheim', 'en': 'Tauberbischofsheim'},
 '499340':{'de': u('K\u00f6nigheim-Brehmen'), 'en': u('K\u00f6nigheim-Brehmen')},
 '499347':{'de': 'Wittighausen', 'en': 'Wittighausen'},
 '49731':{'de': 'Ulm Donau', 'en': 'Ulm Donau'},
 '499345':{'de': u('K\u00fclsheim Baden'), 'en': u('K\u00fclsheim Baden')},
 '499344':{'de': 'Gerchsheim', 'en': 'Gerchsheim'},
 '499349':{'de': 'Werbach-Wenkheim', 'en': 'Werbach-Wenkheim'},
 '499348':{'de': 'Werbach-Gamburg', 'en': 'Werbach-Gamburg'},
 '499439':{'de': 'Neunburg-Kemnath', 'en': 'Neunburg-Kemnath'},
 '499438':{'de': 'Fensterbach', 'en': 'Fensterbach'},
 '49228':{'de': 'Bonn', 'en': 'Bonn'},
 '49221':{'de': u('K\u00f6ln'), 'en': 'Cologne'},
 '4868':{'en': u('Zielona G\u00f3ra'), 'pl': u('Zielona G\u00f3ra')},
 '4862':{'en': 'Kalisz', 'pl': 'Kalisz'},
 '4863':{'en': 'Konin', 'pl': 'Konin'},
 '4861':{'en': u('Pozna\u0144'), 'pl': u('Pozna\u0144')},
 '4867':{'en': 'Pila', 'pl': u('Pi\u0142a')},
 '4865':{'en': 'Leszno', 'pl': 'Leszno'},
 '499378':{'de': u('Eichenb\u00fchl-Riedern'), 'en': u('Eichenb\u00fchl-Riedern')},
 '55115674':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115675':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113474':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113475':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113476':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113477':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113471':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113472':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113473':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113478':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113479':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115679':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495448':{'de': 'Barver', 'en': 'Barver'},
 '495198':{'de': 'Schneverdingen-Wintermoor', 'en': 'Schneverdingen-Wintermoor'},
 '495199':{'de': 'Schneverdingen-Heber', 'en': 'Schneverdingen-Heber'},
 '495192':{'de': 'Munster', 'en': 'Munster'},
 '495193':{'de': 'Schneverdingen', 'en': 'Schneverdingen'},
 '495442':{'de': 'Barnstorf Kreis Diepholz', 'en': 'Barnstorf Kreis Diepholz'},
 '495191':{'de': 'Soltau', 'en': 'Soltau'},
 '495444':{'de': 'Wagenfeld', 'en': 'Wagenfeld'},
 '495197':{'de': 'Soltau-Frielingen', 'en': 'Soltau-Frielingen'},
 '495194':{'de': 'Bispingen', 'en': 'Bispingen'},
 '495447':{'de': 'Lembruch', 'en': 'Lembruch'},
 '543525':{'en': u('Jes\u00fas Mar\u00eda, C\u00f3rdoba'), 'es': u('Jes\u00fas Mar\u00eda, C\u00f3rdoba')},
 '55113651':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113876':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113877':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495224':{'de': 'Enger Westfalen', 'en': 'Enger Westfalen'},
 '495225':{'de': 'Spenge', 'en': 'Spenge'},
 '495226':{'de': u('Bruchm\u00fchlen Westfalen'), 'en': u('Bruchm\u00fchlen Westfalen')},
 '495221':{'de': 'Herford', 'en': 'Herford'},
 '495222':{'de': 'Bad Salzuflen', 'en': 'Bad Salzuflen'},
 '495223':{'de': u('B\u00fcnde'), 'en': u('B\u00fcnde')},
 '495228':{'de': 'Vlotho-Exter', 'en': 'Vlotho-Exter'},
 '55123648':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '498743':{'de': 'Geisenhausen', 'en': 'Geisenhausen'},
 '55123641':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123642':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123643':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123644':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123645':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55123646':{'en': 'Roseira - SP', 'pt': 'Roseira - SP'},
 '55123647':{'en': 'Lagoinha - SP', 'pt': 'Lagoinha - SP'},
 '441400':{'en': 'Honington'},
 '441403':{'en': 'Horsham'},
 '441405':{'en': 'Goole'},
 '441404':{'en': 'Honiton'},
 '441407':{'en': 'Holyhead'},
 '441406':{'en': 'Holbeach'},
 '441409':{'en': 'Holsworthy'},
 '441408':{'en': 'Golspie'},
 '46930':{'en': 'Nordmaling', 'sv': 'Nordmaling'},
 '4418477':{'en': 'Tongue'},
 '4418476':{'en': 'Tongue'},
 '4418475':{'en': 'Thurso'},
 '4418474':{'en': 'Thurso'},
 '4418473':{'en': 'Thurso'},
 '4418472':{'en': 'Thurso'},
 '4418471':{'en': 'Thurso/Tongue'},
 '4418470':{'en': 'Thurso/Tongue'},
 '4418479':{'en': 'Tongue'},
 '4418478':{'en': 'Thurso'},
 '55115034':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115032':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115031':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496755':{'de': 'Odernheim am Glan', 'en': 'Odernheim am Glan'},
 '496754':{'de': 'Martinstein', 'en': 'Martinstein'},
 '496757':{'de': 'Becherbach bei Kirn', 'en': 'Becherbach bei Kirn'},
 '496756':{'de': 'Winterbach Soonwald', 'en': 'Winterbach Soonwald'},
 '496751':{'de': 'Bad Sobernheim', 'en': 'Bad Sobernheim'},
 '496753':{'de': 'Meisenheim', 'en': 'Meisenheim'},
 '496752':{'de': 'Kirn Nahe', 'en': 'Kirn Nahe'},
 '496758':{'de': u('Waldb\u00f6ckelheim'), 'en': u('Waldb\u00f6ckelheim')},
 '435374':{'de': 'Walchsee', 'en': 'Walchsee'},
 '435375':{'de': u('K\u00f6ssen'), 'en': u('K\u00f6ssen')},
 '435376':{'de': 'Thiersee', 'en': 'Thiersee'},
 '435372':{'de': 'Kufstein', 'en': 'Kufstein'},
 '435373':{'de': 'Ebbs', 'en': 'Ebbs'},
 '492451':{'de': 'Geilenkirchen', 'en': 'Geilenkirchen'},
 '498344':{'de': 'Westendorf bei Kaufbeuren', 'en': 'Westendorf bei Kaufbeuren'},
 '493693':{'de': 'Meiningen', 'en': 'Meiningen'},
 '493691':{'de': u('Eisenach Th\u00fcringen'), 'en': u('Eisenach Th\u00fcringen')},
 '498346':{'de': 'Pforzen', 'en': 'Pforzen'},
 '493695':{'de': 'Bad Salzungen', 'en': 'Bad Salzungen'},
 '498341':{'de': 'Kaufbeuren', 'en': 'Kaufbeuren'},
 '52281':{'en': 'Loma Bonita, OAX', 'es': 'Loma Bonita, OAX'},
 '52282':{'en': 'Puebla/Veracruz', 'es': 'Puebla/Veracruz'},
 '52283':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52284':{'en': 'Angel Rosario Cabada/Lerdo de Tejada, VER', 'es': u('\u00c1ngel Rosario Cabada/Lerdo de Tejada, VER')},
 '498342':{'de': 'Marktoberdorf', 'en': 'Marktoberdorf'},
 '52287':{'en': 'Oaxaca', 'es': 'Oaxaca'},
 '52288':{'en': 'Veracruz', 'es': 'Veracruz'},
 '499163':{'de': 'Dachsbach', 'en': 'Dachsbach'},
 '499162':{'de': 'Scheinfeld', 'en': 'Scheinfeld'},
 '499178':{'de': 'Abenberg Mittelfranken', 'en': 'Abenberg Mittelfranken'},
 '499161':{'de': 'Neustadt an der Aisch', 'en': 'Neustadt an der Aisch'},
 '542202':{'en': u('Gonz\u00e1lez Cat\u00e1n/Virrey del Pino, Buenos Aires'), 'es': u('Gonz\u00e1lez Cat\u00e1n/Virrey del Pino, Buenos Aires')},
 '499167':{'de': 'Oberscheinfeld', 'en': 'Oberscheinfeld'},
 '499166':{'de': u('M\u00fcnchsteinach'), 'en': u('M\u00fcnchsteinach')},
 '499165':{'de': 'Sugenheim', 'en': 'Sugenheim'},
 '494478':{'de': 'Cappeln Oldenburg', 'en': 'Cappeln Oldenburg'},
 '494479':{'de': 'Molbergen-Peheim', 'en': 'Molbergen-Peheim'},
 '494477':{'de': 'Lastrup-Hemmelte', 'en': 'Lastrup-Hemmelte'},
 '494474':{'de': 'Garrel', 'en': 'Garrel'},
 '494475':{'de': 'Molbergen', 'en': 'Molbergen'},
 '494472':{'de': 'Lastrup', 'en': 'Lastrup'},
 '494473':{'de': 'Emstek', 'en': 'Emstek'},
 '494471':{'de': 'Cloppenburg', 'en': 'Cloppenburg'},
 '499435':{'de': 'Schwarzenfeld', 'en': 'Schwarzenfeld'},
 '55113869':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113868':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113649':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499434':{'de': u('Bodenw\u00f6hr'), 'en': u('Bodenw\u00f6hr')},
 '55113647':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113646':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113645':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113644':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113643':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113642':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113641':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113864':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499436':{'de': 'Nittenau', 'en': 'Nittenau'},
 '498756':{'de': 'Nandlstadt', 'en': 'Nandlstadt'},
 '498754':{'de': 'Volkenschwand', 'en': 'Volkenschwand'},
 '498753':{'de': 'Elsendorf Niederbayern', 'en': 'Elsendorf Niederbayern'},
 '498752':{'de': 'Au in der Hallertau', 'en': 'Au in der Hallertau'},
 '498751':{'de': 'Mainburg', 'en': 'Mainburg'},
 '499346':{'de': u('Gr\u00fcnsfeld'), 'en': u('Gr\u00fcnsfeld')},
 '55114079':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '499433':{'de': 'Nabburg', 'en': 'Nabburg'},
 '496004':{'de': 'Lich-Eberstadt', 'en': 'Lich-Eberstadt'},
 '55114075':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '542342':{'en': 'Bragado, Buenos Aires', 'es': 'Bragado, Buenos Aires'},
 '542343':{'en': 'Norberto de La Riestra, Buenos Aires', 'es': 'Norberto de La Riestra, Buenos Aires'},
 '542344':{'en': 'Saladillo, Buenos Aires', 'es': 'Saladillo, Buenos Aires'},
 '542345':{'en': '25 de Mayo, Buenos Aires', 'es': '25 de Mayo, Buenos Aires'},
 '542346':{'en': 'Chivilcoy, Buenos Aires', 'es': 'Chivilcoy, Buenos Aires'},
 '55114072':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '499658':{'de': 'Georgenberg', 'en': 'Georgenberg'},
 '55115541':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497533':{'de': 'Allensbach', 'en': 'Allensbach'},
 '5341':{'en': u('Sancti Sp\u00edritus Province')},
 '497531':{'de': 'Konstanz', 'en': 'Konstanz'},
 '5342':{'en': 'Villa Clara Province'},
 '498454':{'de': 'Karlshuld', 'en': 'Karlshuld'},
 '496008':{'de': 'Echzell', 'en': 'Echzell'},
 '496456':{'de': 'Haina Kloster', 'en': 'Haina Kloster'},
 '497534':{'de': 'Reichenau Baden', 'en': 'Reichenau Baden'},
 '496105':{'de': u('M\u00f6rfelden-Walldorf'), 'en': u('M\u00f6rfelden-Walldorf')},
 '496454':{'de': 'Lichtenfels-Sachsenberg', 'en': 'Lichtenfels-Sachsenberg'},
 '496107':{'de': 'Kelsterbach', 'en': 'Kelsterbach'},
 '5348':{'en': u('Pinar del R\u00edo Province')},
 '496101':{'de': 'Bad Vilbel', 'en': 'Bad Vilbel'},
 '55112111':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112112':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112113':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112114':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112115':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112117':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495053':{'de': u('Fa\u00dfberg-M\u00fcden'), 'en': u('Fassberg-M\u00fcden')},
 '495052':{'de': 'Hermannsburg', 'en': 'Hermannsburg'},
 '495051':{'de': 'Bergen Kreis Celle', 'en': 'Bergen Kreis Celle'},
 '496103':{'de': 'Langen Hessen', 'en': 'Langen Hessen'},
 '495056':{'de': 'Winsen-Meissendorf', 'en': 'Winsen-Meissendorf'},
 '495055':{'de': 'Fassberg', 'en': 'Fassberg'},
 '495054':{'de': u('Bergen-S\u00fclze'), 'en': u('Bergen-S\u00fclze')},
 '55123432':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '498456':{'de': 'Lenting', 'en': 'Lenting'},
 '441988':{'en': 'Wigtown'},
 '441989':{'en': 'Ross-on-Wye'},
 '4934221':{'de': 'Schildau Gneisenaustadt', 'en': 'Schildau Gneisenaustadt'},
 '441984':{'en': 'Watchet (Williton)'},
 '441985':{'en': 'Warminster'},
 '441986':{'en': 'Bungay'},
 '441987':{'en': 'Ebbsfleet'},
 '441980':{'en': 'Amesbury'},
 '441981':{'en': 'Wormbridge'},
 '441982':{'en': 'Builth Wells'},
 '441983':{'en': 'Isle of Wight'},
 '498457':{'de': 'Vohburg an der Donau', 'en': 'Vohburg an der Donau'},
 '55115854':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4419643':{'en': 'Patrington'},
 '493901':{'de': 'Salzwedel', 'en': 'Salzwedel'},
 '55115585':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493907':{'de': 'Gardelegen', 'en': 'Gardelegen'},
 '55115583':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115852':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495320':{'de': 'Torfhaus', 'en': 'Torfhaus'},
 '493909':{'de': u('Kl\u00f6tze Altmark'), 'en': u('Kl\u00f6tze Altmark')},
 '495323':{'de': 'Clausthal-Zellerfeld', 'en': 'Clausthal-Zellerfeld'},
 '55115588':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115589':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495322':{'de': 'Bad Harzburg', 'en': 'Bad Harzburg'},
 '49961':{'de': 'Weiden in der Oberpfalz', 'en': 'Weiden in der Oberpfalz'},
 '495325':{'de': 'Goslar-Hahnenklee', 'en': 'Goslar-Hahnenklee'},
 '495324':{'de': 'Vienenburg', 'en': 'Vienenburg'},
 '495327':{'de': 'Bad Grund Harz', 'en': 'Bad Grund Harz'},
 '4419644':{'en': 'Patrington'},
 '55113903':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437233':{'de': 'Feldkirchen an der Donau', 'en': 'Feldkirchen an der Donau'},
 '437232':{'de': u('Sankt Martin im M\u00fchlkreis'), 'en': u('St. Martin im M\u00fchlkreis')},
 '437231':{'de': 'Herzogsdorf', 'en': 'Herzogsdorf'},
 '437230':{'de': 'Altenberg bei Linz', 'en': 'Altenberg bei Linz'},
 '437237':{'de': 'Sankt Georgen an der Gusen', 'en': 'St. Georgen an der Gusen'},
 '437236':{'de': 'Pregarten', 'en': 'Pregarten'},
 '437235':{'de': 'Gallneukirchen', 'en': 'Gallneukirchen'},
 '437234':{'de': 'Ottensheim', 'en': 'Ottensheim'},
 '437239':{'de': 'Lichtenberg', 'en': 'Lichtenberg'},
 '437238':{'de': 'Mauthausen', 'en': 'Mauthausen'},
 '496508':{'de': 'Hetzerath Mosel', 'en': 'Hetzerath Mosel'},
 '496509':{'de': u('B\u00fcdlich'), 'en': u('B\u00fcdlich')},
 '496500':{'de': 'Waldrach', 'en': 'Waldrach'},
 '496501':{'de': 'Konz', 'en': 'Konz'},
 '496502':{'de': 'Schweich', 'en': 'Schweich'},
 '496503':{'de': 'Hermeskeil', 'en': 'Hermeskeil'},
 '496504':{'de': 'Thalfang', 'en': 'Thalfang'},
 '496505':{'de': 'Kordel', 'en': 'Kordel'},
 '496506':{'de': 'Welschbillig', 'en': 'Welschbillig'},
 '496507':{'de': 'Neumagen-Dhron', 'en': 'Neumagen-Dhron'},
 '46589':{'en': 'Arboga', 'sv': 'Arboga'},
 '55114677':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55114676':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55114675':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55114674':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55114679':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55114678':{'en': 'Ferraz de Vasconcelos - SP', 'pt': 'Ferraz de Vasconcelos - SP'},
 '55114513':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114511':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114518':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114519':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '492427':{'de': 'Nideggen', 'en': 'Nideggen'},
 '492426':{'de': u('N\u00f6rvenich'), 'en': u('N\u00f6rvenich')},
 '492425':{'de': 'Nideggen-Embken', 'en': 'Nideggen-Embken'},
 '492424':{'de': 'Vettweiss', 'en': 'Vettweiss'},
 '492423':{'de': 'Langerwehe', 'en': 'Langerwehe'},
 '492422':{'de': 'Kreuzau', 'en': 'Kreuzau'},
 '492421':{'de': u('D\u00fcren'), 'en': u('D\u00fcren')},
 '492429':{'de': u('H\u00fcrtgenwald'), 'en': u('H\u00fcrtgenwald')},
 '492428':{'de': 'Niederzier', 'en': 'Niederzier'},
 '55133251':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '435583':{'de': 'Lech', 'en': 'Lech'},
 '435582':{'de': u('Kl\u00f6sterle'), 'en': u('Kl\u00f6sterle')},
 '435585':{'de': 'Dalaas', 'en': 'Dalaas'},
 '494861':{'de': u('T\u00f6nning'), 'en': u('T\u00f6nning')},
 '494863':{'de': 'Sankt Peter-Ording', 'en': 'Sankt Peter-Ording'},
 '494862':{'de': 'Garding', 'en': 'Garding'},
 '494865':{'de': 'Osterhever', 'en': 'Osterhever'},
 '494864':{'de': 'Oldenswort', 'en': 'Oldenswort'},
 '55133258':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '497363':{'de': 'Lauchheim', 'en': 'Lauchheim'},
 '497362':{'de': 'Bopfingen', 'en': 'Bopfingen'},
 '497361':{'de': 'Aalen', 'en': 'Aalen'},
 '497367':{'de': 'Aalen-Ebnat', 'en': 'Aalen-Ebnat'},
 '497366':{'de': u('Abtsgm\u00fcnd'), 'en': u('Abtsgm\u00fcnd')},
 '497365':{'de': u('Essingen W\u00fcrttemberg'), 'en': u('Essingen W\u00fcrttemberg')},
 '497364':{'de': 'Oberkochen', 'en': 'Oberkochen'},
 '499463':{'de': 'Wald Oberpfalz', 'en': 'Wald Oberpfalz'},
 '55133446':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '55133445':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '55115097':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4855':{'en': u('Elbl\u0105g'), 'pl': u('Elbl\u0105g')},
 '4939828':{'de': 'Wustrow Kreis Mecklenburg-Strelitz', 'en': 'Wustrow Kreis Mecklenburg-Strelitz'},
 '4939829':{'de': u('Blankenf\u00f6rde'), 'en': u('Blankenf\u00f6rde')},
 '436468':{'de': 'Werfen', 'en': 'Werfen'},
 '4939822':{'de': 'Kratzeburg', 'en': 'Kratzeburg'},
 '4939823':{'de': 'Rechlin', 'en': 'Rechlin'},
 '4939820':{'de': 'Triepkendorf', 'en': 'Triepkendorf'},
 '4939821':{'de': 'Carpin', 'en': 'Carpin'},
 '4939826':{'de': 'Blankensee bei Neustrelitz', 'en': 'Blankensee bei Neustrelitz'},
 '4939827':{'de': 'Schwarz bei Neustrelitz', 'en': 'Schwarz bei Neustrelitz'},
 '4939824':{'de': 'Hohenzieritz', 'en': 'Hohenzieritz'},
 '4939825':{'de': 'Wokuhl', 'en': 'Wokuhl'},
 '498102':{'de': u('H\u00f6henkirchen-Siegertsbrunn'), 'en': u('H\u00f6henkirchen-Siegertsbrunn')},
 '498106':{'de': 'Vaterstetten', 'en': 'Vaterstetten'},
 '498104':{'de': 'Sauerlach', 'en': 'Sauerlach'},
 '498105':{'de': 'Gilching', 'en': 'Gilching'},
 '494285':{'de': 'Rhade bei Zeven', 'en': 'Rhade bei Zeven'},
 '494284':{'de': 'Selsingen', 'en': 'Selsingen'},
 '494287':{'de': 'Heeslingen-Boitzen', 'en': 'Heeslingen-Boitzen'},
 '494286':{'de': 'Gyhum', 'en': 'Gyhum'},
 '494281':{'de': 'Zeven', 'en': 'Zeven'},
 '494283':{'de': 'Tarmstedt', 'en': 'Tarmstedt'},
 '494282':{'de': 'Sittensen', 'en': 'Sittensen'},
 '494289':{'de': 'Kirchtimke', 'en': 'Kirchtimke'},
 '494288':{'de': 'Horstedt Kreis Rotenburg', 'en': 'Horstedt Kreis Rotenburg'},
 '4414370':{'en': 'Haverfordwest/Clynderwen (Clunderwen)'},
 '55113988':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55113989':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113985':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113986':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113987':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4631':{'en': 'Gothenburg', 'sv': u('G\u00f6teborg')},
 '55113982':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4636':{'en': u('J\u00f6nk\u00f6ping-Huskvarna'), 'sv': u('J\u00f6nk\u00f6ping-Huskvarna')},
 '46920':{'en': u('Lule\u00e5'), 'sv': u('Lule\u00e5')},
 '49201':{'de': 'Essen', 'en': 'Essen'},
 '49202':{'de': 'Wuppertal', 'en': 'Wuppertal'},
 '49203':{'de': 'Duisburg', 'en': 'Duisburg'},
 '46924':{'en': u('R\u00e5ne\u00e5'), 'sv': u('R\u00e5ne\u00e5')},
 '46925':{'en': u('Lakatr\u00e4sk'), 'sv': u('Lakatr\u00e4sk')},
 '494139':{'de': 'Hohnstorf Elbe', 'en': 'Hohnstorf Elbe'},
 '494138':{'de': u('Betzendorf Kreis L\u00fcneburg'), 'en': u('Betzendorf Kreis L\u00fcneburg')},
 '494137':{'de': 'Barendorf', 'en': 'Barendorf'},
 '494136':{'de': 'Scharnebeck', 'en': 'Scharnebeck'},
 '494135':{'de': 'Kirchgellersen', 'en': 'Kirchgellersen'},
 '494134':{'de': u('Embsen Kreis L\u00fcneburg'), 'en': u('Embsen Kreis L\u00fcneburg')},
 '494133':{'de': u('Wittorf Kreis L\u00fcneburg'), 'en': u('Wittorf Kreis L\u00fcneburg')},
 '494132':{'de': 'Amelinghausen', 'en': 'Amelinghausen'},
 '494131':{'de': u('L\u00fcneburg'), 'en': u('L\u00fcneburg')},
 '52495':{'en': 'Aguascalientes/Jalisco', 'es': 'Aguascalientes/Jalisco'},
 '52494':{'en': 'Jerez de Garcia Salinas, ZAC', 'es': u('Jerez de Garc\u00eda Salinas, ZAC')},
 '52496':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '52493':{'en': 'Fresnillo, ZAC', 'es': 'Fresnillo, ZAC'},
 '52492':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '4934425':{'de': 'Droyssig', 'en': 'Droyssig'},
 '4934424':{'de': 'Reuden bei Zeitz', 'en': 'Reuden bei Zeitz'},
 '4934426':{'de': 'Kayna', 'en': 'Kayna'},
 '52499':{'en': 'Jalisco/Zacatecas', 'es': 'Jalisco/Zacatecas'},
 '52498':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '4934423':{'de': 'Heuckewalde', 'en': 'Heuckewalde'},
 '4934422':{'de': 'Osterfeld', 'en': 'Osterfeld'},
 '55113184':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113180':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113183':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55113205':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113188':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112858':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112851':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112852':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112855':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112854':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112856':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52723':{'en': 'Coatepec Harinas, MEX', 'es': 'Coatepec Harinas, MEX'},
 '52722':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52721':{'en': 'Ixtapan de la Sal, MEX', 'es': 'Ixtapan de la Sal, MEX'},
 '55113459':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52727':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52726':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52725':{'en': 'Almoloya de Juarez/Santa Maria Del Monte, MEX', 'es': u('Almoloya de Ju\u00e1rez/Santa Mar\u00eda del Monte, MEX')},
 '52724':{'en': 'Luvianos/Tejupilco de Hidalgo, MEX', 'es': 'Luvianos/Tejupilco de Hidalgo, MEX'},
 '55113452':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499876':{'de': 'Rohr Mittelfranken', 'en': 'Rohr Mittelfranken'},
 '52729':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52728':{'en': 'Lerma/Santa Maria Atarasquillo, MEX', 'es': u('Lerma/Santa Mar\u00eda Atarasquillo, MEX')},
 '55113325':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113326':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113327':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494706':{'de': 'Schiffdorf', 'en': 'Schiffdorf'},
 '55113203':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55122134':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '492994':{'de': 'Marsberg-Westheim', 'en': 'Marsberg-Westheim'},
 '492993':{'de': 'Marsberg-Canstein', 'en': 'Marsberg-Canstein'},
 '492992':{'de': 'Marsberg', 'en': 'Marsberg'},
 '492991':{'de': 'Marsberg-Bredelar', 'en': 'Marsberg-Bredelar'},
 '55112589':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112588':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112586':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112583':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112582':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112581':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495422':{'de': 'Melle', 'en': 'Melle'},
 '495423':{'de': 'Versmold', 'en': 'Versmold'},
 '495421':{'de': 'Dissen am Teutoburger Wald', 'en': 'Dissen am Teutoburger Wald'},
 '495426':{'de': 'Glandorf', 'en': 'Glandorf'},
 '495427':{'de': 'Melle-Buer', 'en': 'Melle-Buer'},
 '495424':{'de': 'Bad Rothenfelde', 'en': 'Bad Rothenfelde'},
 '495425':{'de': 'Borgholzhausen', 'en': 'Borgholzhausen'},
 '495428':{'de': 'Melle-Neuenkirchen', 'en': 'Melle-Neuenkirchen'},
 '495429':{'de': 'Melle-Wellingholzhausen', 'en': 'Melle-Wellingholzhausen'},
 '55114234':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '4938227':{'de': u('L\u00fcdershagen bei Barth'), 'en': u('L\u00fcdershagen bei Barth')},
 '4938226':{'de': 'Dierhagen Ostseebad', 'en': 'Dierhagen Ostseebad'},
 '4938225':{'de': 'Trinwillershagen', 'en': 'Trinwillershagen'},
 '4938224':{'de': 'Gresenhorst', 'en': 'Gresenhorst'},
 '4938223':{'de': 'Saal Vorpom', 'en': 'Saal Vorpom'},
 '4938222':{'de': 'Semlow', 'en': 'Semlow'},
 '4938221':{'de': 'Marlow', 'en': 'Marlow'},
 '4938220':{'de': 'Wustrow Ostseebad', 'en': 'Wustrow Ostseebad'},
 '55114230':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '4938229':{'de': u('Bad S\u00fclze'), 'en': u('Bad S\u00fclze')},
 '4938228':{'de': u('Dettmannsdorf-K\u00f6lzow'), 'en': u('Dettmannsdorf-K\u00f6lzow')},
 '499867':{'de': 'Geslau', 'en': 'Geslau'},
 '5042516':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '499865':{'de': 'Adelshofen Mittelfranken', 'en': 'Adelshofen Mittelfranken'},
 '55112321':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123882':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123883':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123881':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123886':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123668':{'en': u('Campos do Jord\u00e3o - SP'), 'pt': u('Campos do Jord\u00e3o - SP')},
 '55123669':{'en': u('Campos do Jord\u00e3o - SP'), 'pt': u('Campos do Jord\u00e3o - SP')},
 '55123666':{'en': u('Santo Ant\u00f4nio do Pinhal - SP'), 'pt': u('Santo Ant\u00f4nio do Pinhal - SP')},
 '55123664':{'en': u('Campos do Jord\u00e3o - SP'), 'pt': u('Campos do Jord\u00e3o - SP')},
 '499861':{'de': 'Rothenburg ob der Tauber', 'en': 'Rothenburg ob der Tauber'},
 '55123662':{'en': u('Campos do Jord\u00e3o - SP'), 'pt': u('Campos do Jord\u00e3o - SP')},
 '55123663':{'en': u('Campos do Jord\u00e3o - SP'), 'pt': u('Campos do Jord\u00e3o - SP')},
 '55112296':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499356':{'de': 'Burgsinn', 'en': 'Burgsinn'},
 '441429':{'en': 'Hartlepool'},
 '441428':{'en': 'Haslemere'},
 '441422':{'en': 'Halifax'},
 '441420':{'en': 'Alton'},
 '441427':{'en': 'Gainsborough'},
 '441425':{'en': 'Ringwood'},
 '441424':{'en': 'Hastings'},
 '4933053':{'de': 'Zehlendorf Kreis Oberhavel', 'en': 'Zehlendorf Kreis Oberhavel'},
 '496852':{'de': 'Nohfelden', 'en': 'Nohfelden'},
 '4933052':{'de': 'Leegebruch', 'en': 'Leegebruch'},
 '496853':{'de': 'Marpingen', 'en': 'Marpingen'},
 '4933055':{'de': 'Kremmen', 'en': 'Kremmen'},
 '4933054':{'de': 'Liebenwalde', 'en': 'Liebenwalde'},
 '496192':{'de': 'Hofheim am Taunus', 'en': 'Hofheim am Taunus'},
 '496851':{'de': 'St Wendel', 'en': 'St Wendel'},
 '496196':{'de': 'Bad Soden am Taunus', 'en': 'Bad Soden am Taunus'},
 '496195':{'de': 'Kelkheim Taunus', 'en': 'Kelkheim Taunus'},
 '496856':{'de': 'St Wendel-Niederkirchen', 'en': 'St Wendel-Niederkirchen'},
 '496198':{'de': 'Eppstein', 'en': 'Eppstein'},
 '55113951':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496857':{'de': 'Namborn', 'en': 'Namborn'},
 '55113365':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496670':{'de': 'Ludwigsau Hessen', 'en': 'Ludwigsau Hessen'},
 '497275':{'de': 'Kandel', 'en': 'Kandel'},
 '4936041':{'de': 'Bad Tennstedt', 'en': 'Bad Tennstedt'},
 '55113955':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4936043':{'de': 'Kirchheilingen', 'en': 'Kirchheilingen'},
 '4936042':{'de': 'Tonna', 'en': 'Tonna'},
 '55115054':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115055':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115056':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497277':{'de': u('W\u00f6rth-B\u00fcchelberg'), 'en': u('W\u00f6rth-B\u00fcchelberg')},
 '55115052':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115053':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497271':{'de': u('W\u00f6rth am Rhein'), 'en': u('W\u00f6rth am Rhein')},
 '472':{'en': 'Oslo'},
 '497273':{'de': 'Hagenbach Pfalz', 'en': 'Hagenbach Pfalz'},
 '496776':{'de': 'Dachsenhausen', 'en': 'Dachsenhausen'},
 '496775':{'de': u('Str\u00fcth Taunus'), 'en': u('Str\u00fcth Taunus')},
 '496774':{'de': 'Kaub', 'en': 'Kaub'},
 '496773':{'de': 'Kamp-Bornhofen', 'en': 'Kamp-Bornhofen'},
 '496772':{'de': u('Nast\u00e4tten'), 'en': u('Nast\u00e4tten')},
 '496771':{'de': 'St Goarshausen', 'en': 'St Goarshausen'},
 '492678':{'de': u('B\u00fcchel bei Cochem'), 'en': u('B\u00fcchel bei Cochem')},
 '492672':{'de': 'Treis-Karden', 'en': 'Treis-Karden'},
 '492673':{'de': 'Ellenz-Poltersdorf', 'en': 'Ellenz-Poltersdorf'},
 '492671':{'de': 'Cochem', 'en': 'Cochem'},
 '492676':{'de': 'Ulmen', 'en': 'Ulmen'},
 '492677':{'de': 'Lutzerath', 'en': 'Lutzerath'},
 '492674':{'de': 'Bad Bertrich', 'en': 'Bad Bertrich'},
 '492675':{'de': 'Ediger-Eller', 'en': 'Ediger-Eller'},
 '55113209':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498406':{'de': u('B\u00f6hmfeld'), 'en': u('B\u00f6hmfeld')},
 '498405':{'de': 'Stammham bei Ingolstadt', 'en': 'Stammham bei Ingolstadt'},
 '4418907':{'en': 'Ayton'},
 '498404':{'de': 'Oberdolling', 'en': 'Oberdolling'},
 '4418906':{'en': 'Ayton'},
 '498403':{'de': u('Pf\u00f6rring'), 'en': u('Pf\u00f6rring')},
 '4418905':{'en': 'Ayton'},
 '55113208':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4418904':{'en': 'Coldstream'},
 '498051':{'de': 'Prien am Chiemsee', 'en': 'Prien am Chiemsee'},
 '4418903':{'en': 'Coldstream'},
 '4418902':{'en': 'Coldstream'},
 '55133302':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '4418901':{'en': 'Coldstream/Ayton'},
 '4938754':{'de': 'Leussow bei Ludwigslust', 'en': 'Leussow bei Ludwigslust'},
 '495441':{'de': 'Diepholz', 'en': 'Diepholz'},
 '498057':{'de': 'Aschau-Sachrang', 'en': 'Aschau-Sachrang'},
 '495190':{'de': 'Soltau-Emmingen', 'en': 'Soltau-Emmingen'},
 '495443':{'de': u('Lemf\u00f6rde'), 'en': u('Lemf\u00f6rde')},
 '542229':{'en': u('Juan Mar\u00eda Guti\u00e9rrez/El Pato, Buenos Aires'), 'es': u('Juan Mar\u00eda Guti\u00e9rrez/El Pato, Buenos Aires')},
 '435418':{'de': u('Sch\u00f6nwies'), 'en': u('Sch\u00f6nwies')},
 '542227':{'en': 'Lobos, Buenos Aires', 'es': 'Lobos, Buenos Aires'},
 '495196':{'de': 'Wietzendorf', 'en': 'Wietzendorf'},
 '542225':{'en': 'Alejandro Korn, Buenos Aires', 'es': 'Alejandro Korn, Buenos Aires'},
 '542224':{'en': 'Glew/Guernica, Buenos Aires', 'es': 'Glew/Guernica, Buenos Aires'},
 '542223':{'en': 'Brandsen, Buenos Aires', 'es': 'Brandsen, Buenos Aires'},
 '542221':{'en': u('Magdalena/Ver\u00f3nica, Buenos Aires'), 'es': u('Magdalena/Ver\u00f3nica, Buenos Aires')},
 '495445':{'de': 'Drebber', 'en': 'Drebber'},
 '494458':{'de': 'Wiefelstede-Spohle', 'en': 'Wiefelstede-Spohle'},
 '495446':{'de': 'Rehden', 'en': 'Rehden'},
 '494451':{'de': 'Varel Jadebusen', 'en': 'Varel Jadebusen'},
 '494452':{'de': 'Zetel-Neuenburg', 'en': 'Zetel-Neuenburg'},
 '494453':{'de': 'Zetel', 'en': 'Zetel'},
 '494454':{'de': 'Jade', 'en': 'Jade'},
 '494455':{'de': 'Jade-Schweiburg', 'en': 'Jade-Schweiburg'},
 '494456':{'de': u('Varel-Altj\u00fchrden'), 'en': u('Varel-Altj\u00fchrden')},
 '55113665':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437224':{'de': 'Sankt Florian', 'en': 'St. Florian'},
 '55113667':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113666':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113661':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113844':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113663':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437225':{'de': 'Hargelsberg', 'en': 'Hargelsberg'},
 '55113849':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113848':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437226':{'de': 'Wilhering', 'en': 'Wilhering'},
 '542323':{'en': u('Luj\u00e1n, Buenos Aires'), 'es': u('Luj\u00e1n, Buenos Aires')},
 '542320':{'en': u('Jos\u00e9 C. Paz, Buenos Aires'), 'es': u('Jos\u00e9 C. Paz, Buenos Aires')},
 '542326':{'en': 'San Antonio de Areco, Buenos Aires', 'es': 'San Antonio de Areco, Buenos Aires'},
 '542324':{'en': 'Mercedes, Buenos Aires', 'es': 'Mercedes, Buenos Aires'},
 '542325':{'en': u('San Andr\u00e9s de Giles, Buenos Aires'), 'es': u('San Andr\u00e9s de Giles, Buenos Aires')},
 '498731':{'de': 'Dingolfing', 'en': 'Dingolfing'},
 '498733':{'de': 'Mengkofen', 'en': 'Mengkofen'},
 '498732':{'de': 'Frontenhausen', 'en': 'Frontenhausen'},
 '498735':{'de': 'Gangkofen-Kollbach', 'en': 'Gangkofen-Kollbach'},
 '435413':{'de': 'Sankt Leonhard im Pitztal', 'en': 'St. Leonhard im Pitztal'},
 '437221':{'de': u('H\u00f6rsching'), 'en': u('H\u00f6rsching')},
 '494634':{'de': 'Husby', 'en': 'Husby'},
 '494635':{'de': u('S\u00f6rup'), 'en': u('S\u00f6rup')},
 '494636':{'de': 'Langballig', 'en': 'Langballig'},
 '435412':{'de': 'Imst', 'en': 'Imst'},
 '494630':{'de': 'Barderup', 'en': 'Barderup'},
 '494631':{'de': u('Gl\u00fccksburg Ostsee'), 'en': u('Gl\u00fccksburg Ostsee')},
 '494632':{'de': 'Steinbergkirche', 'en': 'Steinbergkirche'},
 '494633':{'de': 'Satrup', 'en': 'Satrup'},
 '55114099':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '492378':{'de': u('Fr\u00f6ndenberg-Langschede'), 'en': u('Fr\u00f6ndenberg-Langschede')},
 '494638':{'de': 'Tarp', 'en': 'Tarp'},
 '494639':{'de': 'Schafflund', 'en': 'Schafflund'},
 '437228':{'de': 'Kematen an der Krems', 'en': 'Kematen an der Krems'},
 '437229':{'de': 'Traun', 'en': 'Traun'},
 '494766':{'de': 'Basdahl', 'en': 'Basdahl'},
 '494767':{'de': u('Bremerv\u00f6rde-Bevern'), 'en': u('Bremerv\u00f6rde-Bevern')},
 '494764':{'de': 'Gnarrenburg-Klenkendorf', 'en': 'Gnarrenburg-Klenkendorf'},
 '494765':{'de': u('Ebersdorf bei Bremerv\u00f6rde'), 'en': u('Ebersdorf bei Bremerv\u00f6rde')},
 '55112136':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '499155':{'de': 'Simmelsdorf', 'en': 'Simmelsdorf'},
 '55112134':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112135':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112132':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112133':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112131':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123411':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123413':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55112138':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112139':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499288':{'de': 'Bad Steben', 'en': 'Bad Steben'},
 '543327':{'en': u('Benav\u00eddez, Buenos Aires'), 'es': u('Benav\u00eddez, Buenos Aires')},
 '543329':{'en': 'San Pedro, Buenos Aires', 'es': 'San Pedro, Buenos Aires'},
 '499289':{'de': 'Schwarzenbach am Wald', 'en': 'Schwarzenbach am Wald'},
 '437433':{'de': 'Wallsee', 'en': 'Wallsee'},
 '437432':{'de': 'Strengberg', 'en': 'Strengberg'},
 '437435':{'de': 'Sankt Valentin', 'en': 'St. Valentin'},
 '437434':{'de': 'Haag', 'en': 'Haag'},
 '55115872':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115873':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112507':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115871':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123115':{'en': u('Arape\u00ed - SP'), 'pt': u('Arape\u00ed - SP')},
 '55115874':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115875':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49941':{'de': 'Regensburg', 'en': 'Regensburg'},
 '5042540':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '5182':{'en': 'Madre de Dios'},
 '5183':{'en': u('Apur\u00edmac')},
 '543498':{'en': 'San Justo, Santa Fe', 'es': 'San Justo, Santa Fe'},
 '5184':{'en': 'Cusco'},
 '543493':{'en': 'Sunchales, Santa Fe', 'es': 'Sunchales, Santa Fe'},
 '543492':{'en': 'Rafaela, Santa Fe', 'es': 'Rafaela, Santa Fe'},
 '543491':{'en': 'Ceres, Santa Fe', 'es': 'Ceres, Santa Fe'},
 '543497':{'en': 'Llambi Campbell, Santa Fe', 'es': 'Llambi Campbell, Santa Fe'},
 '543496':{'en': 'Esperanza, Santa Fe', 'es': 'Esperanza, Santa Fe'},
 '496535':{'de': 'Osann-Monzel', 'en': 'Osann-Monzel'},
 '496242':{'de': 'Osthofen', 'en': 'Osthofen'},
 '55114994':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114995':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '4933978':{'de': 'Segeletz', 'en': 'Segeletz'},
 '4933979':{'de': 'Wusterhausen Dosse', 'en': 'Wusterhausen Dosse'},
 '4933976':{'de': 'Wutike', 'en': 'Wutike'},
 '4933977':{'de': 'Gumtow', 'en': 'Gumtow'},
 '4933974':{'de': 'Dessow', 'en': 'Dessow'},
 '4933975':{'de': 'Dannenwalde Kreis Prignitz', 'en': 'Dannenwalde Kreis Prignitz'},
 '4933972':{'de': 'Breddin', 'en': 'Breddin'},
 '4933973':{'de': 'Zernitz bei Neustadt Dosse', 'en': 'Zernitz bei Neustadt Dosse'},
 '4933970':{'de': 'Neustadt Dosse', 'en': 'Neustadt Dosse'},
 '4933971':{'de': 'Kyritz Brandenburg', 'en': 'Kyritz Brandenburg'},
 '496562':{'de': 'Speicher', 'en': 'Speicher'},
 '496563':{'de': 'Kyllburg', 'en': 'Kyllburg'},
 '496561':{'de': 'Bitburg', 'en': 'Bitburg'},
 '496566':{'de': u('K\u00f6rperich'), 'en': u('K\u00f6rperich')},
 '496567':{'de': 'Oberkail', 'en': 'Oberkail'},
 '496564':{'de': 'Neuerburg Eifel', 'en': 'Neuerburg Eifel'},
 '496565':{'de': 'Dudeldorf', 'en': 'Dudeldorf'},
 '496568':{'de': 'Wolsfeld', 'en': 'Wolsfeld'},
 '496532':{'de': 'Zeltingen-Rachtig', 'en': 'Zeltingen-Rachtig'},
 '54379':{'en': 'Corrientes, Corrientes', 'es': 'Corrientes, Corrientes'},
 '55115564':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123022':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55114658':{'en': u('Igarat\u00e1 - SP'), 'pt': u('Igarat\u00e1 - SP')},
 '55114655':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55114654':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55114657':{'en': 'Santa Isabel - SP', 'pt': 'Santa Isabel - SP'},
 '55114656':{'en': 'Santa Isabel - SP', 'pt': 'Santa Isabel - SP'},
 '55114651':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55114653':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55114652':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55123023':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55115566':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496386':{'de': 'Altenkirchen Pfalz', 'en': 'Altenkirchen Pfalz'},
 '496387':{'de': 'Sankt Julian', 'en': 'Sankt Julian'},
 '496384':{'de': 'Konken', 'en': 'Konken'},
 '496385':{'de': 'Reichenbach-Steegen', 'en': 'Reichenbach-Steegen'},
 '496382':{'de': 'Lauterecken', 'en': 'Lauterecken'},
 '496383':{'de': u('Glan-M\u00fcnchweiler'), 'en': u('Glan-M\u00fcnchweiler')},
 '496381':{'de': 'Kusel', 'en': 'Kusel'},
 '492441':{'de': 'Kall', 'en': 'Kall'},
 '492440':{'de': 'Nettersheim-Tondorf', 'en': 'Nettersheim-Tondorf'},
 '492443':{'de': 'Mechernich', 'en': 'Mechernich'},
 '497162':{'de': u('S\u00fc\u00dfen'), 'en': u('S\u00fcssen')},
 '492445':{'de': 'Schleiden Eifel', 'en': 'Schleiden Eifel'},
 '492444':{'de': u('Schleiden-Gem\u00fcnd'), 'en': u('Schleiden-Gem\u00fcnd')},
 '492447':{'de': 'Dahlem bei Kall', 'en': 'Dahlem bei Kall'},
 '497166':{'de': 'Adelberg', 'en': 'Adelberg'},
 '492449':{'de': 'Blankenheim Ahr', 'en': 'Blankenheim Ahr'},
 '492448':{'de': 'Hellenthal-Rescheid', 'en': 'Hellenthal-Rescheid'},
 '4417689':{'en': 'Penrith'},
 '4417688':{'en': 'Penrith'},
 '4417685':{'en': 'Penrith'},
 '4417684':{'en': 'Pooley Bridge'},
 '4417687':{'en': 'Keswick'},
 '4417686':{'en': 'Penrith'},
 '4417681':{'en': 'Penrith'},
 '4417680':{'en': 'Penrith'},
 '4417683':{'en': 'Appleby'},
 '4417682':{'en': 'Penrith'},
 '494849':{'de': 'Hooge', 'en': 'Hooge'},
 '494848':{'de': 'Rantrum', 'en': 'Rantrum'},
 '494843':{'de': u('Vi\u00f6l'), 'en': u('Vi\u00f6l')},
 '494842':{'de': 'Nordstrand', 'en': 'Nordstrand'},
 '494841':{'de': 'Husum Nordsee', 'en': 'Husum Nordsee'},
 '494847':{'de': 'Oster-Ohrstedt', 'en': 'Oster-Ohrstedt'},
 '494846':{'de': 'Hattstedt', 'en': 'Hattstedt'},
 '494845':{'de': 'Ostenfeld Husum', 'en': 'Ostenfeld Husum'},
 '494844':{'de': 'Pellworm', 'en': 'Pellworm'},
 '55133469':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133468':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '497389':{'de': 'Heroldstatt', 'en': 'Heroldstatt'},
 '497388':{'de': 'Pfronstetten', 'en': 'Pfronstetten'},
 '497385':{'de': 'Gomadingen', 'en': 'Gomadingen'},
 '497384':{'de': u('Schelklingen-H\u00fctten'), 'en': u('Schelklingen-H\u00fctten')},
 '497387':{'de': u('Hohenstein W\u00fcrttemberg'), 'en': u('Hohenstein W\u00fcrttemberg')},
 '497386':{'de': 'Hayingen', 'en': 'Hayingen'},
 '497381':{'de': u('M\u00fcnsingen'), 'en': u('M\u00fcnsingen')},
 '55133464':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '497383':{'de': u('M\u00fcnsingen-Buttenhausen'), 'en': u('M\u00fcnsingen-Buttenhausen')},
 '497382':{'de': u('R\u00f6merstein'), 'en': u('R\u00f6merstein')},
 '55115562':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112464':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55115563':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112465':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55133375':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '52924':{'en': 'Veracruz', 'es': 'Veracruz'},
 '46914':{'en': u('Burtr\u00e4sk')},
 '52921':{'en': 'Coatzacoalcos/Ixhuatlan Del Sureste, VER', 'es': u('Coatzacoalcos/Ixhuatl\u00e1n del Sureste, VER')},
 '55123302':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '52923':{'en': 'Tabasco/Veracruz', 'es': 'Tabasco/Veracruz'},
 '52922':{'en': 'Veracruz', 'es': 'Veracruz'},
 '55114487':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '498124':{'de': 'Forstern Oberbayern', 'en': 'Forstern Oberbayern'},
 '498121':{'de': 'Markt Schwaben', 'en': 'Markt Schwaben'},
 '498122':{'de': 'Erding', 'en': 'Erding'},
 '498123':{'de': 'Moosinning', 'en': 'Moosinning'},
 '46490':{'en': u('V\u00e4stervik'), 'sv': u('V\u00e4stervik')},
 '46491':{'en': u('Oskarshamn-H\u00f6gsby'), 'sv': u('Oskarshamn-H\u00f6gsby')},
 '46492':{'en': 'Vimmerby', 'sv': 'Vimmerby'},
 '46493':{'en': 'Gamleby', 'sv': 'Gamleby'},
 '46494':{'en': 'Kisa', 'sv': 'Kisa'},
 '46495':{'en': 'Hultsfred-Virserum'},
 '46496':{'en': 'Mariannelund', 'sv': 'Mariannelund'},
 '46498':{'en': 'Gotland', 'sv': 'Gotland'},
 '46499':{'en': u('M\u00f6nster\u00e5s'), 'sv': u('M\u00f6nster\u00e5s')},
 '499657':{'de': 'Waldthurn', 'en': 'Waldthurn'},
 '499656':{'de': u('Moosbach bei Vohenstrau\u00df'), 'en': 'Moosbach bei Vohenstrauss'},
 '499651':{'de': 'Vohenstrauss', 'en': 'Vohenstrauss'},
 '499653':{'de': 'Eslarn', 'en': 'Eslarn'},
 '499652':{'de': 'Waidhaus', 'en': 'Waidhaus'},
 '497839':{'de': 'Schapbach', 'en': 'Schapbach'},
 '497838':{'de': 'Nordrach', 'en': 'Nordrach'},
 '497837':{'de': 'Oberharmersbach', 'en': 'Oberharmersbach'},
 '497836':{'de': 'Schiltach', 'en': 'Schiltach'},
 '497835':{'de': 'Zell am Harmersbach', 'en': 'Zell am Harmersbach'},
 '497834':{'de': 'Wolfach', 'en': 'Wolfach'},
 '497833':{'de': 'Hornberg Schwarzwaldbahn', 'en': 'Hornberg Schwarzwaldbahn'},
 '497832':{'de': 'Haslach im Kinzigtal', 'en': 'Haslach im Kinzigtal'},
 '497831':{'de': 'Hausach', 'en': 'Hausach'},
 '52894':{'en': 'Santa Apolonia/Valle Hermoso, TAMPS', 'es': 'Santa Apolonia/Valle Hermoso, TAMPS'},
 '498388':{'de': 'Hergensweiler', 'en': 'Hergensweiler'},
 '498389':{'de': 'Weissensberg', 'en': 'Weissensberg'},
 '498380':{'de': 'Achberg', 'en': 'Achberg'},
 '498381':{'de': u('Lindenberg im Allg\u00e4u'), 'en': u('Lindenberg im Allg\u00e4u')},
 '498382':{'de': 'Lindau Bodensee', 'en': 'Lindau Bodensee'},
 '498383':{'de': u('Gr\u00fcnenbach Allg\u00e4u'), 'en': u('Gr\u00fcnenbach Allg\u00e4u')},
 '43512':{'de': 'Innsbruck', 'en': 'Innsbruck'},
 '498385':{'de': 'Hergatz', 'en': 'Hergatz'},
 '498386':{'de': 'Oberstaufen', 'en': 'Oberstaufen'},
 '498387':{'de': 'Weiler-Simmerberg', 'en': 'Weiler-Simmerberg'},
 '494159':{'de': 'Basthorst', 'en': 'Basthorst'},
 '494158':{'de': 'Roseburg', 'en': 'Roseburg'},
 '46278':{'en': u('Bolln\u00e4s'), 'sv': u('Bolln\u00e4s')},
 '494151':{'de': 'Schwarzenbek', 'en': 'Schwarzenbek'},
 '49771':{'de': 'Donaueschingen', 'en': 'Donaueschingen'},
 '494153':{'de': 'Lauenburg Elbe', 'en': 'Lauenburg Elbe'},
 '494152':{'de': 'Geesthacht', 'en': 'Geesthacht'},
 '46270':{'en': u('S\u00f6derhamn'), 'sv': u('S\u00f6derhamn')},
 '46271':{'en': 'Alfta-Edsbyn', 'sv': 'Alfta-Edsbyn'},
 '494156':{'de': 'Talkau', 'en': 'Talkau'},
 '55112577':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112574':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113109':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '4829':{'en': u('Ostrol\u0119ka'), 'pl': u('Ostro\u0142\u0119ka')},
 '4824':{'en': 'Plock', 'pl': u('P\u0142ock')},
 '4825':{'en': 'Siedlce', 'pl': 'Siedlce'},
 '4822':{'en': 'Warsaw', 'pl': 'Warszawa'},
 '4823':{'en': u('Ciechan\u00f3w'), 'pl': u('Ciechan\u00f3w')},
 '55114138':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '55113104':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112839':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112838':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112837':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112836':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112835':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55112571':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114134':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55113106':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112831':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114137':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '55113100':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52749':{'en': 'Calpulalpan, TLAX', 'es': 'Calpulalpan, TLAX'},
 '52748':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '55113308':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '52741':{'en': 'Guerrero', 'es': 'Guerrero'},
 '55113307':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52743':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '52742':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52745':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52744':{'en': 'Acapulco/Xaltianguis, GRO', 'es': 'Acapulco/Xaltianguis, GRO'},
 '52747':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52746':{'en': 'Puebla/Veracruz', 'es': 'Puebla/Veracruz'},
 '499386':{'de': 'Prosselsheim', 'en': 'Prosselsheim'},
 '499385':{'de': 'Kolitzheim', 'en': 'Kolitzheim'},
 '499384':{'de': 'Schwanfeld', 'en': 'Schwanfeld'},
 '499383':{'de': 'Wiesentheid', 'en': 'Wiesentheid'},
 '499382':{'de': 'Gerolzhofen', 'en': 'Gerolzhofen'},
 '499381':{'de': 'Volkach', 'en': 'Volkach'},
 '55114706':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '495409':{'de': 'Hilter am Teutoburger Wald', 'en': 'Hilter am Teutoburger Wald'},
 '495158':{'de': 'Hemeringen', 'en': 'Hemeringen'},
 '495159':{'de': u('Coppenbr\u00fcgge-Bisperode'), 'en': u('Coppenbr\u00fcgge-Bisperode')},
 '495156':{'de': u('Coppenbr\u00fcgge'), 'en': u('Coppenbr\u00fcgge')},
 '495157':{'de': u('Emmerthal-B\u00f6rry'), 'en': u('Emmerthal-B\u00f6rry')},
 '495154':{'de': 'Aerzen', 'en': 'Aerzen'},
 '495155':{'de': 'Emmerthal', 'en': 'Emmerthal'},
 '495152':{'de': 'Hessisch Oldendorf', 'en': 'Hessisch Oldendorf'},
 '495153':{'de': 'Salzhemmendorf', 'en': 'Salzhemmendorf'},
 '495402':{'de': u('Bissendorf Kreis Osnabr\u00fcck'), 'en': u('Bissendorf Kreis Osnabr\u00fcck')},
 '495151':{'de': 'Hameln', 'en': 'Hameln'},
 '441395':{'en': 'Budleigh Salterton'},
 '441394':{'en': 'Felixstowe'},
 '441397':{'en': 'Fort William'},
 '441392':{'en': 'Exeter'},
 '441398':{'en': 'Dulverton'},
 '4938201':{'de': 'Gelbensande', 'en': 'Gelbensande'},
 '55114704':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '4938203':{'de': 'Bad Doberan', 'en': 'Bad Doberan'},
 '4938202':{'de': 'Volkenshagen', 'en': 'Volkenshagen'},
 '4938205':{'de': 'Tessin bei Rostock', 'en': 'Tessin bei Rostock'},
 '4938204':{'de': 'Broderstorf', 'en': 'Broderstorf'},
 '4938207':{'de': u('St\u00e4below'), 'en': u('St\u00e4below')},
 '4938206':{'de': u('Graal-M\u00fcritz Seeheilbad'), 'en': u('Graal-M\u00fcritz Seeheilbad')},
 '4938209':{'de': 'Sanitz bei Rostock', 'en': 'Sanitz bei Rostock'},
 '4938208':{'de': 'Kavelstorf', 'en': 'Kavelstorf'},
 '55112301':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112303':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112304':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55123924':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123604':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '4939992':{'de': u('G\u00f6rmin'), 'en': u('G\u00f6rmin')},
 '55123607':{'en': u('Trememb\u00e9 - SP'), 'pt': u('Trememb\u00e9 - SP')},
 '55123600':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123601':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123602':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123608':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123609':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '499639':{'de': u('M\u00e4hring'), 'en': u('M\u00e4hring')},
 '499638':{'de': 'Neualbenreuth', 'en': 'Neualbenreuth'},
 '55114786':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '496175':{'de': 'Friedrichsdorf Taunus', 'en': 'Friedrichsdorf Taunus'},
 '496174':{'de': u('K\u00f6nigstein im Taunus'), 'en': u('K\u00f6nigstein im Taunus')},
 '496171':{'de': 'Oberursel Taunus', 'en': 'Oberursel Taunus'},
 '55114785':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '496173':{'de': 'Kronberg im Taunus', 'en': 'Kronberg im Taunus'},
 '496172':{'de': u('Bad Homburg von der H\u00f6he'), 'en': u('Bad Homburg von der H\u00f6he')},
 '492388':{'de': 'Hamm-Uentrop', 'en': 'Hamm-Uentrop'},
 '492389':{'de': 'Werne', 'en': 'Werne'},
 '492382':{'de': 'Ahlen Westfalen', 'en': 'Ahlen Westfalen'},
 '492383':{'de': u('B\u00f6nen'), 'en': u('B\u00f6nen')},
 '492381':{'de': 'Hamm Westfalen', 'en': 'Hamm Westfalen'},
 '492387':{'de': 'Drensteinfurt-Walstedde', 'en': 'Drensteinfurt-Walstedde'},
 '492384':{'de': 'Welver', 'en': 'Welver'},
 '492385':{'de': 'Hamm-Rhynern', 'en': 'Hamm-Rhynern'},
 '55115072':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499633':{'de': 'Mitterteich', 'en': 'Mitterteich'},
 '55115071':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114781':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '55115074':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499632':{'de': 'Waldsassen', 'en': 'Waldsassen'},
 '55115078':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499631':{'de': 'Tirschenreuth', 'en': 'Tirschenreuth'},
 '499089':{'de': 'Bissingen-Unterringingen', 'en': 'Bissingen-Unterringingen'},
 '499635':{'de': u('B\u00e4rnau'), 'en': u('B\u00e4rnau')},
 '499634':{'de': 'Wiesau', 'en': 'Wiesau'},
 '493381':{'de': 'Brandenburg an der Havel', 'en': 'Brandenburg an der Havel'},
 '493382':{'de': 'Lehnin', 'en': 'Lehnin'},
 '493385':{'de': 'Rathenow', 'en': 'Rathenow'},
 '493386':{'de': 'Premnitz', 'en': 'Premnitz'},
 '55114196':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55133324':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133323':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133321':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '494432':{'de': u('D\u00f6tlingen-Brettorf'), 'en': u('D\u00f6tlingen-Brettorf')},
 '494433':{'de': u('D\u00f6tlingen'), 'en': u('D\u00f6tlingen')},
 '494431':{'de': 'Wildeshausen', 'en': 'Wildeshausen'},
 '494434':{'de': 'Colnrade', 'en': 'Colnrade'},
 '494435':{'de': 'Grossenkneten', 'en': 'Grossenkneten'},
 '542241':{'en': u('Chascom\u00fas, Buenos Aires'), 'es': u('Chascom\u00fas, Buenos Aires')},
 '542243':{'en': 'General Belgrano, Buenos Aires', 'es': 'General Belgrano, Buenos Aires'},
 '542242':{'en': 'Lezama, Buenos Aires', 'es': 'Lezama, Buenos Aires'},
 '542245':{'en': 'Dolores, Buenos Aires', 'es': 'Dolores, Buenos Aires'},
 '542244':{'en': 'Las Flores, Buenos Aires', 'es': 'Las Flores, Buenos Aires'},
 '542246':{'en': 'Santa Teresita, Buenos Aires', 'es': 'Santa Teresita, Buenos Aires'},
 '492654':{'de': 'Polch', 'en': 'Polch'},
 '492655':{'de': 'Weibern', 'en': 'Weibern'},
 '492656':{'de': 'Virneburg', 'en': 'Virneburg'},
 '492657':{'de': 'Uersfeld', 'en': 'Uersfeld'},
 '497442':{'de': 'Baiersbronn', 'en': 'Baiersbronn'},
 '492651':{'de': 'Mayen', 'en': 'Mayen'},
 '492652':{'de': 'Mendig', 'en': 'Mendig'},
 '492653':{'de': 'Kaisersesch', 'en': 'Kaisersesch'},
 '497448':{'de': 'Seewald', 'en': 'Seewald'},
 '492129':{'de': 'Haan Rheinland', 'en': 'Haan Rheinland'},
 '493525':{'de': 'Riesa', 'en': 'Riesa'},
 '55113826':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498247':{'de': u('Bad W\u00f6rishofen'), 'en': u('Bad W\u00f6rishofen')},
 '498246':{'de': 'Waal', 'en': 'Waal'},
 '493521':{'de': 'Meissen', 'en': 'Meissen'},
 '55113822':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493523':{'de': 'Coswig bei Dresden', 'en': 'Coswig bei Dresden'},
 '493522':{'de': 'Grossenhain Sachsen', 'en': 'Grossenhain Sachsen'},
 '493529':{'de': 'Heidenau Sachsen', 'en': 'Heidenau Sachsen'},
 '493528':{'de': 'Radeberg', 'en': 'Radeberg'},
 '55113829':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113828':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542302':{'en': 'General Pico, La Pampa', 'es': 'General Pico, La Pampa'},
 '4938322':{'de': 'Richtenberg', 'en': 'Richtenberg'},
 '4938855':{'de': u('L\u00fcbtheen'), 'en': u('L\u00fcbtheen')},
 '494384':{'de': 'Selent', 'en': 'Selent'},
 '494385':{'de': 'Hohenfelde bei Kiel', 'en': 'Hohenfelde bei Kiel'},
 '4938320':{'de': 'Tribsees', 'en': 'Tribsees'},
 '494382':{'de': 'Wangels', 'en': 'Wangels'},
 '494383':{'de': 'Grebin', 'en': 'Grebin'},
 '52244':{'en': 'Puebla', 'es': 'Puebla'},
 '52245':{'en': 'Puebla', 'es': 'Puebla'},
 '52246':{'en': 'Tlaxcala', 'es': 'Tlaxcala'},
 '52247':{'en': 'Huamantla/San Cosme Xalostoc, TLAX', 'es': 'Huamantla/San Cosme Xalostoc, TLAX'},
 '52241':{'en': 'Tlaxcala', 'es': 'Tlaxcala'},
 '52243':{'en': 'Puebla', 'es': 'Puebla'},
 '4938326':{'de': 'Grimmen', 'en': 'Grimmen'},
 '52248':{'en': 'Puebla', 'es': 'Puebla'},
 '52249':{'en': 'Puebla', 'es': 'Puebla'},
 '4938327':{'de': 'Elmenhorst Vorpom', 'en': 'Elmenhorst Vorpom'},
 '55123151':{'en': 'Canas - SP', 'pt': 'Canas - SP'},
 '4938324':{'de': 'Velgast', 'en': 'Velgast'},
 '4938325':{'de': 'Rolofshagen', 'en': 'Rolofshagen'},
 '55114295':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55112158':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112159':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112154':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112155':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112156':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112157':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112151':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112152':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '46684':{'en': u('Hede-Fun\u00e4sdalen'), 'sv': u('Hede-Fun\u00e4sdalen')},
 '46687':{'en': 'Svenstavik', 'sv': 'Svenstavik'},
 '46680':{'en': 'Sveg', 'sv': 'Sveg'},
 '46682':{'en': u('R\u00e4tan'), 'sv': u('R\u00e4tan')},
 '498534':{'de': 'Tettenweis', 'en': 'Tettenweis'},
 '497374':{'de': 'Uttenweiler', 'en': 'Uttenweiler'},
 '55115892':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115581':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115895':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115896':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497375':{'de': 'Obermarchtal', 'en': 'Obermarchtal'},
 '437413':{'de': 'Marbach an der Donau', 'en': 'Marbach an der Donau'},
 '437412':{'de': 'Ybbs an der Donau', 'en': 'Ybbs an der Donau'},
 '55113305':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '44131':{'en': 'Edinburgh'},
 '437416':{'de': 'Wieselburg', 'en': 'Wieselburg'},
 '437415':{'de': 'Altenmarkt, Yspertal', 'en': 'Altenmarkt, Yspertal'},
 '437414':{'de': 'Weins-Isperdorf', 'en': 'Weins-Isperdorf'},
 '49431':{'de': 'Kiel', 'en': 'Kiel'},
 '55113303':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55123019':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '497709':{'de': 'Wutach', 'en': 'Wutach'},
 '54358':{'en': u('R\u00edo Cuarto, C\u00f3rdoba'), 'es': u('R\u00edo Cuarto, C\u00f3rdoba')},
 '497708':{'de': 'Geisingen-Leipferdingen', 'en': 'Geisingen-Leipferdingen'},
 '496544':{'de': 'Rhaunen', 'en': 'Rhaunen'},
 '496545':{'de': 'Blankenrath', 'en': 'Blankenrath'},
 '496541':{'de': 'Traben-Trarbach', 'en': 'Traben-Trarbach'},
 '496542':{'de': 'Bullay', 'en': 'Bullay'},
 '496543':{'de': u('B\u00fcchenbeuren'), 'en': u('B\u00fcchenbeuren')},
 '55133453':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '492358':{'de': 'Meinerzhagen-Valbert', 'en': 'Meinerzhagen-Valbert'},
 '46971':{'en': 'Jokkmokk', 'sv': 'Jokkmokk'},
 '55115528':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113301':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '5511':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '5513':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '5512':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '52634':{'en': 'Sonora', 'es': 'Sonora'},
 '495365':{'de': 'Wolfsburg-Neindorf', 'en': 'Wolfsburg-Neindorf'},
 '495364':{'de': 'Velpke', 'en': 'Velpke'},
 '495367':{'de': u('R\u00fchen'), 'en': u('R\u00fchen')},
 '495366':{'de': 'Jembke', 'en': 'Jembke'},
 '495361':{'de': 'Wolfsburg', 'en': 'Wolfsburg'},
 '495363':{'de': 'Wolfsburg-Vorsfelde', 'en': 'Wolfsburg-Vorsfelde'},
 '495362':{'de': 'Wolfsburg-Fallersleben', 'en': 'Wolfsburg-Fallersleben'},
 '495368':{'de': 'Parsau', 'en': 'Parsau'},
 '55115523':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115524':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52632':{'en': 'Imuris/Magdalena, SON', 'es': u('\u00cdmuris/Magdalena, SON')},
 '55115525':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115526':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52285':{'en': 'Veracruz', 'es': 'Veracruz'},
 '497148':{'de': 'Grossbottwar', 'en': 'Grossbottwar'},
 '492463':{'de': 'Titz', 'en': 'Titz'},
 '492462':{'de': 'Linnich', 'en': 'Linnich'},
 '492461':{'de': u('J\u00fclich'), 'en': u('J\u00fclich')},
 '497636':{'de': u('M\u00fcnstertal Schwarzwald'), 'en': u('M\u00fcnstertal Schwarzwald')},
 '497147':{'de': u('Sachsenheim W\u00fcrttemberg'), 'en': u('Sachsenheim W\u00fcrttemberg')},
 '497146':{'de': 'Remseck am Neckar', 'en': 'Remseck am Neckar'},
 '492465':{'de': 'Inden', 'en': 'Inden'},
 '492464':{'de': u('Aldenhoven bei J\u00fclich'), 'en': u('Aldenhoven bei J\u00fclich')},
 '492354':{'de': 'Meinerzhagen', 'en': 'Meinerzhagen'},
 '4414376':{'en': 'Haverfordwest'},
 '55123003':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55113727':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133406':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '499372':{'de': 'Klingenberg am Main', 'en': 'Klingenberg am Main'},
 '499373':{'de': 'Amorbach', 'en': 'Amorbach'},
 '55113729':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '436472':{'de': 'Mauterndorf', 'en': 'Mauterndorf'},
 '436470':{'de': 'Atzmannsdorf', 'en': 'Atzmannsdorf'},
 '493731':{'de': 'Freiberg Sachsen', 'en': 'Freiberg Sachsen'},
 '493733':{'de': 'Annaberg-Buchholz', 'en': 'Annaberg-Buchholz'},
 '493735':{'de': 'Marienberg Sachsen', 'en': 'Marienberg Sachsen'},
 '493737':{'de': 'Rochlitz', 'en': 'Rochlitz'},
 '46478':{'en': 'Lessebo', 'sv': 'Lessebo'},
 '46479':{'en': 'Osby', 'sv': 'Osby'},
 '46476':{'en': u('\u00c4lmhult'), 'sv': u('\u00c4lmhult')},
 '46477':{'en': 'Tingsryd', 'sv': 'Tingsryd'},
 '46474':{'en': u('\u00c5seda-Lenhovda'), 'sv': u('\u00c5seda-Lenhovda')},
 '46472':{'en': 'Alvesta-Rydaholm', 'sv': 'Alvesta-Rydaholm'},
 '46470':{'en': u('V\u00e4xj\u00f6'), 'sv': u('V\u00e4xj\u00f6')},
 '46471':{'en': 'Emmaboda', 'sv': 'Emmaboda'},
 '497851':{'de': 'Kehl', 'en': 'Kehl'},
 '497853':{'de': 'Kehl-Bodersweier', 'en': 'Kehl-Bodersweier'},
 '497852':{'de': u('Willst\u00e4tt'), 'en': u('Willst\u00e4tt')},
 '497854':{'de': 'Kehl-Goldscheuer', 'en': 'Kehl-Goldscheuer'},
 '497272':{'de': u('R\u00fclzheim'), 'en': u('R\u00fclzheim')},
 '55115506':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113141':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113142':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113144':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113145':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113146':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113147':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113148':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113149':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114193':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55113384':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115507':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499677':{'de': 'Oberviechtach-Pullenried', 'en': 'Oberviechtach-Pullenried'},
 '499676':{'de': 'Winklarn', 'en': 'Winklarn'},
 '499675':{'de': 'Altendorf am Nabburg', 'en': 'Altendorf am Nabburg'},
 '499674':{'de': u('Sch\u00f6nsee'), 'en': u('Sch\u00f6nsee')},
 '499673':{'de': 'Tiefenbach Oberpfalz', 'en': 'Tiefenbach Oberpfalz'},
 '499672':{'de': 'Neunburg vorm Wald', 'en': 'Neunburg vorm Wald'},
 '499671':{'de': 'Oberviechtach', 'en': 'Oberviechtach'},
 '55112812':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112819':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55112818':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '52767':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52766':{'en': 'Gutierrez Zamora/Tecolutla, VER', 'es': u('Guti\u00e9rrez Zamora/Tecolutla, VER')},
 '52765':{'en': 'Alamo Temapache/Alazan/Potrero Del Llano, VER', 'es': u('\u00c1lamo Temapache/Alaz\u00e1n/Potrero del Llano, VER')},
 '52764':{'en': 'Puebla', 'es': 'Puebla'},
 '52763':{'en': 'Tezontepec de Aldama/Tlahuelilpan, HGO', 'es': 'Tezontepec de Aldama/Tlahuelilpan, HGO'},
 '52762':{'en': 'Taxco, GRO', 'es': 'Taxco, GRO'},
 '52761':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '5281':{'en': 'Monterrey, NL', 'es': 'Monterrey, NL'},
 '52769':{'en': 'Morelos', 'es': 'Morelos'},
 '52768':{'en': 'Veracruz', 'es': 'Veracruz'},
 '498506':{'de': u('Bad H\u00f6henstadt'), 'en': u('Bad H\u00f6henstadt')},
 '498507':{'de': 'Neuburg am Inn', 'en': 'Neuburg am Inn'},
 '498504':{'de': 'Tittling', 'en': 'Tittling'},
 '498505':{'de': 'Hutthurm', 'en': 'Hutthurm'},
 '498502':{'de': u('F\u00fcrstenzell'), 'en': u('F\u00fcrstenzell')},
 '498503':{'de': 'Neuhaus am Inn', 'en': 'Neuhaus am Inn'},
 '55113362':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498501':{'de': 'Thyrnau', 'en': 'Thyrnau'},
 '55115667':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113368':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113498':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498509':{'de': 'Ruderting', 'en': 'Ruderting'},
 '55115505':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494173':{'de': 'Wulfsen', 'en': 'Wulfsen'},
 '494172':{'de': 'Salzhausen', 'en': 'Salzhausen'},
 '494171':{'de': 'Winsen Luhe', 'en': 'Winsen Luhe'},
 '499906':{'de': 'Mariaposching', 'en': 'Mariaposching'},
 '494177':{'de': 'Drage Elbe', 'en': 'Drage Elbe'},
 '494176':{'de': 'Marschacht', 'en': 'Marschacht'},
 '494175':{'de': 'Egestorf Nordheide', 'en': 'Egestorf Nordheide'},
 '494174':{'de': 'Stelle Kreis Harburg', 'en': 'Stelle Kreis Harburg'},
 '494179':{'de': u('Winsen-T\u00f6nnhausen'), 'en': u('Winsen-T\u00f6nnhausen')},
 '494178':{'de': 'Radbruch', 'en': 'Radbruch'},
 '499908':{'de': u('Sch\u00f6fweg'), 'en': u('Sch\u00f6fweg')},
 '441503':{'en': 'Looe'},
 '55112843':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492368':{'de': 'Oer-Erkenschwick', 'en': 'Oer-Erkenschwick'},
 '495171':{'de': 'Peine', 'en': 'Peine'},
 '495172':{'de': 'Ilsede', 'en': 'Ilsede'},
 '495173':{'de': 'Uetze', 'en': 'Uetze'},
 '495174':{'de': 'Lahstedt', 'en': 'Lahstedt'},
 '495175':{'de': 'Lehrte-Arpke', 'en': 'Lehrte-Arpke'},
 '495176':{'de': 'Edemissen', 'en': 'Edemissen'},
 '495177':{'de': 'Edemissen-Abbensen', 'en': 'Edemissen-Abbensen'},
 '55113863':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441809':{'en': 'Tomdoun'},
 '441808':{'en': 'Tomatin'},
 '55113862':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441805':{'en': 'Torrington'},
 '441807':{'en': 'Ballindalloch'},
 '441806':{'en': 'Shetland'},
 '55113861':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441803':{'en': 'Torquay'},
 '55113867':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113866':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495282':{'de': 'Schieder-Schwalenberg', 'en': 'Schieder-Schwalenberg'},
 '495283':{'de': u('L\u00fcgde-Rischenau'), 'en': u('L\u00fcgde-Rischenau')},
 '495281':{'de': 'Bad Pyrmont', 'en': 'Bad Pyrmont'},
 '495286':{'de': 'Ottenstein Niedersachsen', 'en': 'Ottenstein Niedersachsen'},
 '55112848':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495284':{'de': 'Schwalenberg', 'en': 'Schwalenberg'},
 '495285':{'de': 'Bad Pyrmont-Kleinenberg', 'en': 'Bad Pyrmont-Kleinenberg'},
 '55115501':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123629':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123622':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123623':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123621':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123626':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123627':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123624':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123625':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '4934906':{'de': 'Raguhn', 'en': 'Raguhn'},
 '4934907':{'de': 'Jeber-Bergfrieden', 'en': 'Jeber-Bergfrieden'},
 '543873':{'en': 'Tartagal, Salta', 'es': 'Tartagal, Salta'},
 '492486':{'de': 'Nettersheim', 'en': 'Nettersheim'},
 '437355':{'de': 'Weyer', 'en': 'Weyer'},
 '437357':{'de': 'Kleinreifling', 'en': 'Kleinreifling'},
 '496157':{'de': 'Pfungstadt', 'en': 'Pfungstadt'},
 '496155':{'de': 'Griesheim Hessen', 'en': 'Griesheim Hessen'},
 '496154':{'de': 'Ober-Ramstadt', 'en': 'Ober-Ramstadt'},
 '496152':{'de': 'Gross-Gerau', 'en': 'Gross-Gerau'},
 '496151':{'de': 'Darmstadt', 'en': 'Darmstadt'},
 '496150':{'de': 'Weiterstadt', 'en': 'Weiterstadt'},
 '4934901':{'de': u('Ro\u00dflau Elbe'), 'en': 'Rosslau Elbe'},
 '496159':{'de': 'Messel', 'en': 'Messel'},
 '496158':{'de': 'Riedstadt', 'en': 'Riedstadt'},
 '496483':{'de': 'Selters Taunus', 'en': 'Selters Taunus'},
 '496482':{'de': 'Runkel', 'en': 'Runkel'},
 '496485':{'de': 'Nentershausen Westerwald', 'en': 'Nentershausen Westerwald'},
 '496484':{'de': 'Beselich', 'en': 'Beselich'},
 '496486':{'de': 'Katzenelnbogen', 'en': 'Katzenelnbogen'},
 '495826':{'de': 'Suderburg', 'en': 'Suderburg'},
 '495827':{'de': u('Unterl\u00fc\u00df'), 'en': u('Unterl\u00fcss')},
 '495824':{'de': 'Bad Bodenteich', 'en': 'Bad Bodenteich'},
 '495825':{'de': 'Wieren', 'en': 'Wieren'},
 '495822':{'de': 'Ebstorf', 'en': 'Ebstorf'},
 '495823':{'de': u('Bienenb\u00fcttel'), 'en': u('Bienenb\u00fcttel')},
 '495820':{'de': 'Suhlendorf', 'en': 'Suhlendorf'},
 '495821':{'de': 'Bad Bevensen', 'en': 'Bad Bevensen'},
 '495828':{'de': 'Himbergen', 'en': 'Himbergen'},
 '495829':{'de': 'Wriedel', 'en': 'Wriedel'},
 '4936081':{'de': 'Arenshausen', 'en': 'Arenshausen'},
 '4936083':{'de': 'Uder', 'en': 'Uder'},
 '4936082':{'de': 'Ershausen', 'en': 'Ershausen'},
 '4936085':{'de': 'Reinholterode', 'en': 'Reinholterode'},
 '4936084':{'de': 'Heuthen', 'en': 'Heuthen'},
 '4936087':{'de': u('W\u00fcstheuterode'), 'en': u('W\u00fcstheuterode')},
 '496733':{'de': 'Gau-Odernheim', 'en': 'Gau-Odernheim'},
 '496732':{'de': u('W\u00f6rrstadt'), 'en': u('W\u00f6rrstadt')},
 '496731':{'de': 'Alzey', 'en': 'Alzey'},
 '496737':{'de': u('K\u00f6ngernheim'), 'en': u('K\u00f6ngernheim')},
 '496736':{'de': 'Bechenheim', 'en': 'Bechenheim'},
 '496735':{'de': 'Eppelsheim', 'en': 'Eppelsheim'},
 '496734':{'de': 'Flonheim', 'en': 'Flonheim'},
 '55114751':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55114755':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55114077':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '4933653':{'de': 'Ziltendorf', 'en': 'Ziltendorf'},
 '55114076':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '4933876':{'de': 'Buschow', 'en': 'Buschow'},
 '55114071':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '4933657':{'de': 'Steinsdorf Brandenburg', 'en': 'Steinsdorf Brandenburg'},
 '52835':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '4933656':{'de': 'Bahro', 'en': 'Bahro'},
 '52834':{'en': 'Ciudad Victoria, TAMPS', 'es': 'Ciudad Victoria, TAMPS'},
 '52833':{'en': 'Tampico, TAMPS', 'es': 'Tampico, TAMPS'},
 '4933870':{'de': 'Zollchow bei Rathenow', 'en': 'Zollchow bei Rathenow'},
 '52832':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '498083':{'de': 'Isen', 'en': 'Isen'},
 '498082':{'de': 'Schwindegg', 'en': 'Schwindegg'},
 '498081':{'de': 'Dorfen Stadt', 'en': 'Dorfen Stadt'},
 '498086':{'de': 'Buchbach Oberbayern', 'en': 'Buchbach Oberbayern'},
 '498085':{'de': 'Sankt Wolfgang', 'en': 'Sankt Wolfgang'},
 '498084':{'de': 'Taufkirchen Vils', 'en': 'Taufkirchen Vils'},
 '542262':{'en': 'Necochea, Buenos Aires', 'es': 'Necochea, Buenos Aires'},
 '542261':{'en': u('Lober\u00eda, Buenos Aires'), 'es': u('Lober\u00eda, Buenos Aires')},
 '497034':{'de': 'Ehningen', 'en': 'Ehningen'},
 '542267':{'en': 'General Juan Madariaga, Buenos Aires', 'es': 'General Juan Madariaga, Buenos Aires'},
 '542266':{'en': 'Balcarce, Buenos Aires', 'es': 'Balcarce, Buenos Aires'},
 '542265':{'en': 'Coronel Vidal, Buenos Aires', 'es': 'Coronel Vidal, Buenos Aires'},
 '542264':{'en': 'La Dulce (Nicanor Olivera), Buenos Aires', 'es': 'La Dulce (Nicanor Olivera), Buenos Aires'},
 '542268':{'en': u('Maip\u00fa, Buenos Aires'), 'es': u('Maip\u00fa, Buenos Aires')},
 '497461':{'de': 'Tuttlingen', 'en': 'Tuttlingen'},
 '492102':{'de': 'Ratingen', 'en': 'Ratingen'},
 '492103':{'de': 'Hilden', 'en': 'Hilden'},
 '492104':{'de': 'Mettmann', 'en': 'Mettmann'},
 '497465':{'de': 'Emmingen-Liptingen', 'en': 'Emmingen-Liptingen'},
 '497466':{'de': 'Beuron', 'en': 'Beuron'},
 '497467':{'de': 'Neuhausen ob Eck', 'en': 'Neuhausen ob Eck'},
 '49741':{'de': 'Rottweil', 'en': 'Rottweil'},
 '498269':{'de': 'Unteregg bei Mindelheim', 'en': 'Unteregg bei Mindelheim'},
 '498268':{'de': 'Tussenhausen', 'en': 'Tussenhausen'},
 '498267':{'de': 'Dirlewang', 'en': 'Dirlewang'},
 '498266':{'de': 'Kirchheim in Schwaben', 'en': 'Kirchheim in Schwaben'},
 '498265':{'de': 'Pfaffenhausen Schwaben', 'en': 'Pfaffenhausen Schwaben'},
 '493504':{'de': 'Dippoldiswalde', 'en': 'Dippoldiswalde'},
 '498263':{'de': 'Breitenbrunn Schwaben', 'en': 'Breitenbrunn Schwaben'},
 '494122':{'de': 'Uetersen', 'en': 'Uetersen'},
 '493501':{'de': 'Pirna', 'en': 'Pirna'},
 '494123':{'de': 'Barmstedt', 'en': 'Barmstedt'},
 '494124':{'de': u('Gl\u00fcckstadt'), 'en': u('Gl\u00fcckstadt')},
 '46932':{'en': 'Bjurholm', 'sv': 'Bjurholm'},
 '494126':{'de': 'Horst Holstein', 'en': 'Horst Holstein'},
 '494127':{'de': 'Westerhorn', 'en': 'Westerhorn'},
 '52222':{'en': 'Puebla', 'es': 'Puebla'},
 '4939347':{'de': 'Kade', 'en': 'Kade'},
 '52221':{'en': 'Puebla', 'es': 'Puebla'},
 '52226':{'en': 'Altotonga/Jalacingo, VER', 'es': 'Altotonga/Jalacingo, VER'},
 '52227':{'en': 'Huejotzingo/San Buenaventura Nealtican, PUE', 'es': 'Huejotzingo/San Buenaventura Nealtican, PUE'},
 '52224':{'en': 'Puebla', 'es': 'Puebla'},
 '4939346':{'de': 'Tucheim', 'en': 'Tucheim'},
 '52228':{'en': 'Jalapa/Tuzamapan, VER', 'es': 'Jalapa/Tuzamapan, VER'},
 '52229':{'en': 'Veracruz, VER', 'es': 'Veracruz, VER'},
 '55133341':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133342':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133343':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '4939342':{'de': 'Gladau', 'en': 'Gladau'},
 '52599':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55113809':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113808':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113805':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52591':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52592':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52593':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52594':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52595':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52596':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55112172':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112173':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112171':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112176':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112177':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112174':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112175':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112178':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112179':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49631':{'de': 'Kaiserslautern', 'en': 'Kaiserslautern'},
 '4989':{'de': u('M\u00fcnchen'), 'en': 'Munich'},
 '4936704':{'de': 'Steinheid', 'en': 'Steinheid'},
 '4936705':{'de': u('Oberwei\u00dfbach Th\u00fcringer Wald'), 'en': u('Oberweissbach Th\u00fcringer Wald')},
 '4936702':{'de': 'Lauscha', 'en': 'Lauscha'},
 '4936703':{'de': u('Gr\u00e4fenthal'), 'en': u('Gr\u00e4fenthal')},
 '4936701':{'de': 'Lichte', 'en': 'Lichte'},
 '4415391':{'en': 'Kendal'},
 '4415390':{'en': 'Kendal'},
 '4415393':{'en': 'Kendal'},
 '44118':{'en': 'Reading'},
 '4415395':{'en': 'Grange-over-Sands'},
 '4415394':{'en': 'Hawkshead'},
 '4415397':{'en': 'Kendal'},
 '4415396':{'en': 'Sedbergh'},
 '44113':{'en': 'Leeds'},
 '4415398':{'en': 'Kendal'},
 '44117':{'en': 'Bristol'},
 '44116':{'en': 'Leicester'},
 '44115':{'en': 'Nottingham'},
 '44114':{'en': 'Sheffield'},
 '49451':{'de': u('L\u00fcbeck'), 'en': u('L\u00fcbeck')},
 '49981':{'de': 'Ansbach', 'en': 'Ansbach'},
 '441724':{'en': 'Scunthorpe'},
 '55113779':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494950':{'de': 'Holtland', 'en': 'Holtland'},
 '55113773':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113772':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113771':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494953':{'de': 'Bunde', 'en': 'Bunde'},
 '55113775':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113774':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '442837':{'en': 'Armagh'},
 '494952':{'de': 'Rhauderfehn', 'en': 'Rhauderfehn'},
 '442830':{'en': 'Newry'},
 '494955':{'de': 'Westoverledingen', 'en': 'Westoverledingen'},
 '442838':{'en': 'Portadown'},
 '441721':{'en': 'Peebles'},
 '55123903':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123902':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123907':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '494957':{'de': 'Detern', 'en': 'Detern'},
 '55123905':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123904':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '494956':{'de': 'Uplengen', 'en': 'Uplengen'},
 '54336':{'en': u('San Nicol\u00e1s, Buenos Aires'), 'es': u('San Nicol\u00e1s, Buenos Aires')},
 '543725':{'en': u('General Jos\u00e9 de San Mart\u00edn, Chaco'), 'es': u('General Jos\u00e9 de San Mart\u00edn, Chaco')},
 '543721':{'en': 'Charadai, Chaco', 'es': 'Charadai, Chaco'},
 '55114693':{'en': 'Guararema - SP', 'pt': 'Guararema - SP'},
 '55114692':{'en': 'Biritiba-Mirim - SP', 'pt': 'Biritiba-Mirim - SP'},
 '55114695':{'en': 'Guararema - SP', 'pt': 'Guararema - SP'},
 '55114694':{'en': 'Biritiba-Mirim - SP', 'pt': 'Biritiba-Mirim - SP'},
 '55114696':{'en': u('Sales\u00f3polis - SP'), 'pt': u('Sales\u00f3polis - SP')},
 '4933932':{'de': 'Fehrbellin', 'en': 'Fehrbellin'},
 '4933933':{'de': 'Lindow Mark', 'en': 'Lindow Mark'},
 '4933931':{'de': 'Rheinsberg Mark', 'en': 'Rheinsberg Mark'},
 '495347':{'de': 'Burgdorf bei Salzgitter', 'en': 'Burgdorf bei Salzgitter'},
 '495346':{'de': 'Liebenburg', 'en': 'Liebenburg'},
 '495345':{'de': 'Baddeckenstedt', 'en': 'Baddeckenstedt'},
 '495344':{'de': 'Lengede', 'en': 'Lengede'},
 '495341':{'de': 'Salzgitter', 'en': 'Salzgitter'},
 '496838':{'de': 'Saarwellingen', 'en': 'Saarwellingen'},
 '496831':{'de': 'Saarlouis', 'en': 'Saarlouis'},
 '496832':{'de': 'Beckingen-Reimsbach', 'en': 'Beckingen-Reimsbach'},
 '496833':{'de': 'Rehlingen-Siersburg', 'en': 'Rehlingen-Siersburg'},
 '496834':{'de': 'Bous', 'en': 'Bous'},
 '496835':{'de': 'Beckingen', 'en': 'Beckingen'},
 '496836':{'de': u('\u00dcberherrn'), 'en': u('\u00dcberherrn')},
 '496837':{'de': 'Wallerfangen', 'en': 'Wallerfangen'},
 '55114717':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '55133425':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '52716':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55133427':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '55133426':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '55133421':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '52717':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '55133429':{'en': u('Itanha\u00e9m - SP'), 'pt': u('Itanha\u00e9m - SP')},
 '52714':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52715':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52712':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52713':{'en': 'Santiago Tianguistenco, MEX', 'es': 'Santiago Tianguistenco, MEX'},
 '52711':{'en': 'Mexico/Michoacan', 'es': u('M\u00e9xico/Michoac\u00e1n')},
 '52961':{'en': 'Chiapas', 'es': 'Chiapas'},
 '55112118':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '52963':{'en': 'Chiapas', 'es': 'Chiapas'},
 '52962':{'en': 'Chiapas', 'es': 'Chiapas'},
 '52965':{'en': 'Chiapas', 'es': 'Chiapas'},
 '52964':{'en': 'Chiapas', 'es': 'Chiapas'},
 '52967':{'en': 'San Cristobal de las Casas, CHIS', 'es': u('San Crist\u00f3bal de las Casas, CHIS')},
 '4416979':{'en': 'Brampton'},
 '435477':{'de': u('T\u00f6sens'), 'en': u('T\u00f6sens')},
 '435476':{'de': 'Serfaus', 'en': 'Serfaus'},
 '435475':{'de': 'Feichten', 'en': 'Feichten'},
 '435474':{'de': 'Pfunds', 'en': 'Pfunds'},
 '435473':{'de': 'Nauders', 'en': 'Nauders'},
 '435472':{'de': 'Prutz', 'en': 'Prutz'},
 '55113039':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113034':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113035':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52719':{'en': 'San Francisco Xonacatlan/Temoaya, MEX', 'es': u('San Francisco Xonacatl\u00e1n/Temoaya, MEX')},
 '55113497':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52346':{'en': 'Jalisco/Zacatecas', 'es': 'Jalisco/Zacatecas'},
 '55113466':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113030':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113465':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133281':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55113464':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133285':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55113032':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133286':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133289':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55113463':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113462':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55122123':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55113495':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113167':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113164':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113165':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113163':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113161':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55122125':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55113168':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113169':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '46454':{'en': u('Karlshamn-Olofstr\u00f6m'), 'sv': u('Karlshamn-Olofstr\u00f6m')},
 '46455':{'en': 'Karlskrona', 'sv': 'Karlskrona'},
 '46456':{'en': u('S\u00f6lvesborg-Brom\u00f6lla'), 'sv': u('S\u00f6lvesborg-Brom\u00f6lla')},
 '46457':{'en': 'Ronneby', 'sv': 'Ronneby'},
 '46451':{'en': u('H\u00e4ssleholm'), 'sv': u('H\u00e4ssleholm')},
 '55114173':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113493':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114178':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '46459':{'en': 'Ryd', 'sv': 'Ryd'},
 '55113348':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113349':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52789':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52785':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52784':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52786':{'en': 'Ciudad Hidalgo/Tuxpan, MICH', 'es': 'Ciudad Hidalgo/Tuxpan, MICH'},
 '52781':{'en': 'Coyuca de Benitez/San Jeronimo de Juarez, GRO', 'es': u('Coyuca de Ben\u00edtez/San Jer\u00f3nimo de Ju\u00e1rez, GRO')},
 '52783':{'en': 'Tuxpan, VER', 'es': 'Tuxpan, VER'},
 '52782':{'en': 'Poza Rica, VER', 'es': 'Poza Rica, VER'},
 '492938':{'de': 'Ense', 'en': 'Ense'},
 '492935':{'de': 'Sundern-Hachen', 'en': 'Sundern-Hachen'},
 '492934':{'de': 'Sundern-Altenhellefeld', 'en': 'Sundern-Altenhellefeld'},
 '492937':{'de': 'Arnsberg-Oeventrop', 'en': 'Arnsberg-Oeventrop'},
 '492931':{'de': 'Arnsberg', 'en': 'Arnsberg'},
 '492933':{'de': 'Sundern Sauerland', 'en': 'Sundern Sauerland'},
 '492932':{'de': u('Neheim-H\u00fcsten'), 'en': u('Neheim-H\u00fcsten')},
 '55112597':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112591':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '46980':{'en': 'Kiruna', 'sv': 'Kiruna'},
 '46981':{'en': 'Vittangi', 'sv': 'Vittangi'},
 '4939998':{'de': 'Loitz bei Demmin', 'en': 'Loitz bei Demmin'},
 '4939999':{'de': 'Tutow', 'en': 'Tutow'},
 '494195':{'de': 'Hartenholm', 'en': 'Hartenholm'},
 '494194':{'de': u('Sieversh\u00fctten'), 'en': u('Sieversh\u00fctten')},
 '4939994':{'de': 'Metschow', 'en': 'Metschow'},
 '4939995':{'de': 'Nossendorf', 'en': 'Nossendorf'},
 '494191':{'de': 'Kaltenkirchen Holstein', 'en': 'Kaltenkirchen Holstein'},
 '4939993':{'de': 'Hohenmocker', 'en': 'Hohenmocker'},
 '494193':{'de': 'Henstedt-Ulzburg', 'en': 'Henstedt-Ulzburg'},
 '494192':{'de': 'Bad Bramstedt', 'en': 'Bad Bramstedt'},
 '55115521':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441827':{'en': 'Tamworth'},
 '55112696':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441825':{'en': 'Uckfield'},
 '441824':{'en': 'Ruthin'},
 '441823':{'en': 'Taunton'},
 '441822':{'en': 'Tavistock'},
 '441821':{'en': 'Kinrossie'},
 '55123025':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123026':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123027':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '498650':{'de': 'Marktschellenberg', 'en': 'Marktschellenberg'},
 '441829':{'en': 'Tarporley'},
 '441828':{'en': 'Coupar Angus'},
 '498657':{'de': 'Ramsau bei Berchtesgaden', 'en': 'Ramsau bei Berchtesgaden'},
 '499875':{'de': 'Wolframs-Eschenbach', 'en': 'Wolframs-Eschenbach'},
 '55112439':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112438':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '499874':{'de': 'Neuendettelsau', 'en': 'Neuendettelsau'},
 '55112433':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112432':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112347':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112346':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112341':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494885':{'de': 'Bergenhusen', 'en': 'Bergenhusen'},
 '55112342':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494884':{'de': 'Schwabstedt', 'en': 'Schwabstedt'},
 '493902':{'de': 'Diesdorf Altm', 'en': 'Diesdorf Altm'},
 '494883':{'de': u('S\u00fcderstapel'), 'en': u('S\u00fcderstapel')},
 '55115584':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494882':{'de': 'Lunden', 'en': 'Lunden'},
 '494553':{'de': 'Geschendorf', 'en': 'Geschendorf'},
 '55115582':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543532':{'en': u('Oliva, C\u00f3rdoba'), 'es': u('Oliva, C\u00f3rdoba')},
 '499704':{'de': 'Euerdorf', 'en': 'Euerdorf'},
 '543537':{'en': u('Bell Ville, C\u00f3rdoba'), 'es': u('Bell Ville, C\u00f3rdoba')},
 '55113782':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113783':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493904':{'de': 'Haldensleben', 'en': 'Haldensleben'},
 '4933638':{'de': u('R\u00fcdersdorf bei Berlin'), 'en': u('R\u00fcdersdorf bei Berlin')},
 '52698':{'en': 'Sinoloa', 'es': 'Sinoloa'},
 '4933631':{'de': 'Bad Saarow-Pieskow', 'en': 'Bad Saarow-Pieskow'},
 '4933633':{'de': 'Spreenhagen', 'en': 'Spreenhagen'},
 '4933632':{'de': 'Hangelsberg', 'en': 'Hangelsberg'},
 '4933635':{'de': 'Arensdorf Kreis Oder-Spree', 'en': 'Arensdorf Kreis Oder-Spree'},
 '4933634':{'de': u('Berkenbr\u00fcck Kreis Oder-Spree'), 'en': u('Berkenbr\u00fcck Kreis Oder-Spree')},
 '4933637':{'de': 'Beerfelde', 'en': 'Beerfelde'},
 '4933636':{'de': u('Steinh\u00f6fel Kreis Oder-Spree'), 'en': u('Steinh\u00f6fel Kreis Oder-Spree')},
 '496131':{'de': 'Mainz', 'en': 'Mainz'},
 '496130':{'de': 'Schwabenheim an der Selz', 'en': 'Schwabenheim an der Selz'},
 '496133':{'de': 'Oppenheim', 'en': 'Oppenheim'},
 '496132':{'de': 'Ingelheim am Rhein', 'en': 'Ingelheim am Rhein'},
 '496135':{'de': 'Bodenheim Rhein', 'en': 'Bodenheim Rhein'},
 '496134':{'de': 'Mainz-Kastel', 'en': 'Mainz-Kastel'},
 '497249':{'de': 'Stutensee', 'en': 'Stutensee'},
 '496139':{'de': 'Budenheim', 'en': 'Budenheim'},
 '496138':{'de': 'Mommenheim', 'en': 'Mommenheim'},
 '55113969':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496667':{'de': 'Steinau-Ulmbach', 'en': 'Steinau-Ulmbach'},
 '496666':{'de': 'Freiensteinau', 'en': 'Freiensteinau'},
 '55113964':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '496660':{'de': 'Steinau-Marjoss', 'en': 'Steinau-Marjoss'},
 '495802':{'de': 'Wrestedt', 'en': 'Wrestedt'},
 '495803':{'de': 'Rosche', 'en': 'Rosche'},
 '495804':{'de': u('R\u00e4tzlingen Kreis Uelzen'), 'en': u('R\u00e4tzlingen Kreis Uelzen')},
 '495805':{'de': 'Oetzen', 'en': 'Oetzen'},
 '495806':{'de': 'Barum bei Bad Bevensen', 'en': 'Barum bei Bad Bevensen'},
 '495807':{'de': 'Altenmedingen', 'en': 'Altenmedingen'},
 '495808':{'de': 'Gerdau', 'en': 'Gerdau'},
 '55113962':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492360':{'de': 'Haltern-Lippramsdorf', 'en': 'Haltern-Lippramsdorf'},
 '55113961':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492362':{'de': 'Dorsten', 'en': 'Dorsten'},
 '497243':{'de': 'Ettlingen', 'en': 'Ettlingen'},
 '55112422':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55114779':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '492364':{'de': 'Haltern Westfalen', 'en': 'Haltern Westfalen'},
 '55114774':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55114775':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114772':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '55114773':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '497245':{'de': 'Durmersheim', 'en': 'Durmersheim'},
 '497246':{'de': 'Malsch Kreis Karlsruhe', 'en': 'Malsch Kreis Karlsruhe'},
 '497247':{'de': 'Linkenheim-Hochstetten', 'en': 'Linkenheim-Hochstetten'},
 '55114031':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '4935323':{'de': 'Sonnewalde', 'en': 'Sonnewalde'},
 '4935322':{'de': 'Doberlug-Kirchhain', 'en': 'Doberlug-Kirchhain'},
 '497268':{'de': 'Bad Rappenau-Obergimpern', 'en': 'Bad Rappenau-Obergimpern'},
 '497269':{'de': 'Sulzfeld Baden', 'en': 'Sulzfeld Baden'},
 '497266':{'de': 'Kirchardt', 'en': 'Kirchardt'},
 '497267':{'de': 'Gemmingen', 'en': 'Gemmingen'},
 '497264':{'de': 'Bad Rappenau', 'en': 'Bad Rappenau'},
 '497265':{'de': 'Angelbachtal', 'en': 'Angelbachtal'},
 '497262':{'de': 'Eppingen', 'en': 'Eppingen'},
 '497263':{'de': 'Waibstadt', 'en': 'Waibstadt'},
 '497260':{'de': 'Sinsheim-Hilsbach', 'en': 'Sinsheim-Hilsbach'},
 '497261':{'de': 'Sinsheim', 'en': 'Sinsheim'},
 '498065':{'de': u('Tuntenhausen-Sch\u00f6nau'), 'en': u('Tuntenhausen-Sch\u00f6nau')},
 '498064':{'de': 'Au bei Bad Aibling', 'en': 'Au bei Bad Aibling'},
 '498067':{'de': 'Tuntenhausen', 'en': 'Tuntenhausen'},
 '498066':{'de': 'Bad Feilnbach', 'en': 'Bad Feilnbach'},
 '498061':{'de': 'Bad Aibling', 'en': 'Bad Aibling'},
 '498063':{'de': 'Feldkirchen-Westerham', 'en': 'Feldkirchen-Westerham'},
 '498062':{'de': u('Bruckm\u00fchl Mangfall'), 'en': u('Bruckm\u00fchl Mangfall')},
 '495181':{'de': 'Alfeld Leine', 'en': 'Alfeld Leine'},
 '55114349':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114348':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '542285':{'en': 'Laprida, Buenos Aires', 'es': 'Laprida, Buenos Aires'},
 '542284':{'en': u('Olavarr\u00eda, Buenos Aires'), 'es': u('Olavarr\u00eda, Buenos Aires')},
 '55114345':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '542286':{'en': 'General La Madrid, Buenos Aires', 'es': 'General La Madrid, Buenos Aires'},
 '542281':{'en': 'Azul, Buenos Aires', 'es': 'Azul, Buenos Aires'},
 '4936920':{'de': 'Grossenlupnitz', 'en': 'Grossenlupnitz'},
 '542283':{'en': u('Tapalqu\u00e9, Buenos Aires'), 'es': u('Tapalqu\u00e9, Buenos Aires')},
 '4936921':{'de': 'Wutha-Farnroda', 'en': 'Wutha-Farnroda'},
 '441599':{'en': 'Kyle'},
 '441598':{'en': 'Lynton'},
 '441597':{'en': 'Llandrindod Wells'},
 '4936926':{'de': 'Creuzburg', 'en': 'Creuzburg'},
 '441595':{'en': 'Lerwick, Foula & Fair Isle'},
 '441594':{'en': 'Lydney'},
 '441593':{'en': 'Lybster'},
 '441592':{'en': 'Kirkcaldy'},
 '441591':{'en': 'Llanwrtyd Wells'},
 '441590':{'en': 'Lymington'},
 '4936924':{'de': 'Mihla', 'en': 'Mihla'},
 '492162':{'de': 'Viersen', 'en': 'Viersen'},
 '492163':{'de': 'Schwalmtal Niederrhein', 'en': 'Schwalmtal Niederrhein'},
 '492692':{'de': 'Kelberg', 'en': 'Kelberg'},
 '492161':{'de': u('M\u00f6nchengladbach'), 'en': u('M\u00f6nchengladbach')},
 '492166':{'de': u('M\u00f6nchengladbach-Rheydt'), 'en': u('M\u00f6nchengladbach-Rheydt')},
 '492695':{'de': 'Insul', 'en': 'Insul'},
 '492696':{'de': 'Nohn Eifel', 'en': 'Nohn Eifel'},
 '492165':{'de': u('J\u00fcchen'), 'en': u('J\u00fcchen')},
 '498208':{'de': 'Eurasburg bei Augsburg', 'en': 'Eurasburg bei Augsburg'},
 '55114363':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '493561':{'de': 'Guben', 'en': 'Guben'},
 '493563':{'de': 'Spremberg', 'en': 'Spremberg'},
 '493562':{'de': 'Forst Lausitz', 'en': 'Forst Lausitz'},
 '498205':{'de': 'Dasing', 'en': 'Dasing'},
 '493564':{'de': 'Schwarze Pumpe', 'en': 'Schwarze Pumpe'},
 '498207':{'de': 'Affing', 'en': 'Affing'},
 '498206':{'de': 'Egling an der Paar', 'en': 'Egling an der Paar'},
 '494779':{'de': 'Freiburg Elbe', 'en': 'Freiburg Elbe'},
 '543885':{'en': 'La Quiaca, Jujuy', 'es': 'La Quiaca, Jujuy'},
 '543886':{'en': u('Libertador General San Mart\u00edn, Jujuy'), 'es': u('Libertador General San Mart\u00edn, Jujuy')},
 '494778':{'de': 'Wingst', 'en': 'Wingst'},
 '543888':{'en': 'San Pedro de Jujuy, Jujuy', 'es': 'San Pedro de Jujuy, Jujuy'},
 '55114368':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55133362':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133363':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133361':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133367':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133364':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133365':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55133369':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '494771':{'de': 'Hemmoor', 'en': 'Hemmoor'},
 '436219':{'de': 'Obertrum am See', 'en': 'Obertrum am See'},
 '436216':{'de': 'Neumarkt am Wallersee', 'en': 'Neumarkt am Wallersee'},
 '436217':{'de': 'Mattsee', 'en': 'Mattsee'},
 '436214':{'de': 'Henndorf am Wallersee', 'en': 'Henndorf am Wallersee'},
 '436215':{'de': u('Stra\u00dfwalchen'), 'en': 'Strasswalchen'},
 '436212':{'de': 'Seekirchen am Wallersee', 'en': 'Seekirchen am Wallersee'},
 '46672':{'en': u('G\u00e4ddede'), 'sv': u('G\u00e4ddede')},
 '4934601':{'de': 'Teutschenthal', 'en': 'Teutschenthal'},
 '4934600':{'de': 'Ostrau Saalkreis', 'en': 'Ostrau Saalkreis'},
 '4934603':{'de': 'Nauendorf Sachsen-Anhalt', 'en': 'Nauendorf Sachsen-Anhalt'},
 '4934602':{'de': 'Landsberg Sachsen-Anhalt', 'en': 'Landsberg Sachsen-Anhalt'},
 '4934605':{'de': u('Gr\u00f6bers'), 'en': u('Gr\u00f6bers')},
 '4934604':{'de': 'Niemberg', 'en': 'Niemberg'},
 '4934607':{'de': 'Wettin', 'en': 'Wettin'},
 '4934606':{'de': 'Teicha Sachsen-Anhalt', 'en': 'Teicha Sachsen-Anhalt'},
 '4934609':{'de': u('Salzm\u00fcnde'), 'en': u('Salzm\u00fcnde')},
 '494775':{'de': u('Grossenw\u00f6rden'), 'en': u('Grossenw\u00f6rden')},
 '494774':{'de': 'Hechthausen', 'en': 'Hechthausen'},
 '494777':{'de': 'Cadenberge', 'en': 'Cadenberge'},
 '494776':{'de': 'Osten-Altendorf', 'en': 'Osten-Altendorf'},
 '4939295':{'de': 'Zuchau', 'en': 'Zuchau'},
 '4939294':{'de': 'Gross Rosenburg', 'en': 'Gross Rosenburg'},
 '4939297':{'de': u('Eickendorf Kreis Sch\u00f6nebeck'), 'en': u('Eickendorf Kreis Sch\u00f6nebeck')},
 '4939296':{'de': 'Welsleben', 'en': 'Welsleben'},
 '4939291':{'de': 'Calbe Saale', 'en': 'Calbe Saale'},
 '499553':{'de': 'Ebrach Oberfranken', 'en': 'Ebrach Oberfranken'},
 '4939293':{'de': 'Dreileben', 'en': 'Dreileben'},
 '4939292':{'de': 'Biederitz', 'en': 'Biederitz'},
 '4939298':{'de': 'Barby Elbe', 'en': 'Barby Elbe'},
 '49881':{'de': 'Weilheim in Oberbayern', 'en': 'Weilheim in Oberbayern'},
 '55114292':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '4939408':{'de': 'Hadmersleben', 'en': 'Hadmersleben'},
 '49611':{'de': 'Wiesbaden', 'en': 'Wiesbaden'},
 '49335':{'de': 'Frankfurt (Oder)', 'en': 'Frankfurt (Oder)'},
 '55114746':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '499295':{'de': u('T\u00f6pen'), 'en': u('T\u00f6pen')},
 '4969':{'de': 'Frankfurt am Main', 'en': 'Frankfurt am Main'},
 '499294':{'de': 'Regnitzlosau', 'en': 'Regnitzlosau'},
 '4936761':{'de': 'Heubisch', 'en': 'Heubisch'},
 '4936762':{'de': u('Steinach Th\u00fcringen'), 'en': u('Steinach Th\u00fcringen')},
 '4936764':{'de': 'Neuhaus-Schierschnitz', 'en': 'Neuhaus-Schierschnitz'},
 '4936766':{'de': 'Schalkau', 'en': 'Schalkau'},
 '49471':{'de': 'Bremerhaven', 'en': 'Bremerhaven'},
 '493981':{'de': 'Neustrelitz', 'en': 'Neustrelitz'},
 '493987':{'de': 'Templin', 'en': 'Templin'},
 '493984':{'de': 'Prenzlau', 'en': 'Prenzlau'},
 '4416866':{'en': 'Newtown'},
 '4416867':{'en': 'Llanidloes'},
 '4416864':{'en': 'Llanidloes'},
 '4416865':{'en': 'Newtown'},
 '4416862':{'en': 'Llanidloes'},
 '4416863':{'en': 'Llanidloes'},
 '4416860':{'en': 'Newtown/Llanidloes'},
 '4416861':{'en': 'Newtown/Llanidloes'},
 '499292':{'de': 'Konradsreuth', 'en': 'Konradsreuth'},
 '4416868':{'en': 'Newtown'},
 '4416869':{'en': 'Newtown'},
 '55113751':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113750':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113753':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113752':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113755':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113754':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55113757':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113756':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113759':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113758':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497742':{'de': 'Klettgau', 'en': 'Klettgau'},
 '55114317':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '4937384':{'de': 'Wechselburg', 'en': 'Wechselburg'},
 '4937381':{'de': 'Penig', 'en': 'Penig'},
 '4937383':{'de': 'Lunzenau', 'en': 'Lunzenau'},
 '4937382':{'de': 'Geringswalde', 'en': 'Geringswalde'},
 '55115077':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497626':{'de': 'Kandern', 'en': 'Kandern'},
 '495636':{'de': 'Lichtenfels-Goddelsheim', 'en': 'Lichtenfels-Goddelsheim'},
 '495635':{'de': u('V\u00f6hl'), 'en': u('V\u00f6hl')},
 '495634':{'de': 'Waldeck-Sachsenhausen', 'en': 'Waldeck-Sachsenhausen'},
 '495633':{'de': 'Diemelsee', 'en': 'Diemelsee'},
 '495632':{'de': 'Willingen Upland', 'en': 'Willingen Upland'},
 '495631':{'de': 'Korbach', 'en': 'Korbach'},
 '495329':{'de': 'Schulenberg im Oberharz', 'en': 'Schulenberg im Oberharz'},
 '495328':{'de': 'Altenau Harz', 'en': 'Altenau Harz'},
 '4419649':{'en': 'Hornsea'},
 '4419648':{'en': 'Hornsea'},
 '55123981':{'en': 'Cedro - SP', 'pt': 'Cedro - SP'},
 '495321':{'de': 'Goslar', 'en': 'Goslar'},
 '4419642':{'en': 'Hornsea'},
 '4419641':{'en': 'Hornsea/Patrington'},
 '4419640':{'en': 'Hornsea/Patrington'},
 '4419647':{'en': 'Patrington'},
 '4419646':{'en': 'Patrington'},
 '4419645':{'en': 'Hornsea'},
 '495326':{'de': 'Langelsheim', 'en': 'Langelsheim'},
 '497671':{'de': 'Todtnau', 'en': 'Todtnau'},
 '497673':{'de': u('Sch\u00f6nau im Schwarzwald'), 'en': u('Sch\u00f6nau im Schwarzwald')},
 '497672':{'de': 'St Blasien', 'en': 'St Blasien'},
 '497675':{'de': 'Bernau Baden', 'en': 'Bernau Baden'},
 '497674':{'de': 'Todtmoos', 'en': 'Todtmoos'},
 '497676':{'de': 'Feldberg Schwarzwald', 'en': 'Feldberg Schwarzwald'},
 '441439':{'en': 'Helmsley'},
 '497503':{'de': u('Wilhelmsdorf W\u00fcrttemberg'), 'en': u('Wilhelmsdorf W\u00fcrttemberg')},
 '55112293':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441698':{'en': 'Motherwell'},
 '441694':{'en': 'Church Stretton'},
 '441695':{'en': 'Skelmersdale'},
 '441690':{'en': 'Betws-y-Coed'},
 '441691':{'en': 'Oswestry'},
 '441692':{'en': 'North Walsham'},
 '435279':{'de': 'Sankt Jodok am Brenner', 'en': 'St. Jodok am Brenner'},
 '435278':{'de': 'Navis', 'en': 'Navis'},
 '435275':{'de': 'Trins', 'en': 'Trins'},
 '435274':{'de': 'Gries am Brenner', 'en': 'Gries am Brenner'},
 '435276':{'de': 'Gschnitz', 'en': 'Gschnitz'},
 '435273':{'de': 'Matrei am Brenner', 'en': 'Matrei am Brenner'},
 '435272':{'de': 'Steinach am Brenner', 'en': 'Steinach am Brenner'},
 '497623':{'de': 'Rheinfelden Baden', 'en': 'Rheinfelden Baden'},
 '496676':{'de': 'Hohenroda Hessen', 'en': 'Hohenroda Hessen'},
 '496677':{'de': 'Neuenstein Hessen', 'en': 'Neuenstein Hessen'},
 '496674':{'de': 'Friedewald Hessen', 'en': 'Friedewald Hessen'},
 '496675':{'de': 'Breitenbach am Herzberg', 'en': 'Breitenbach am Herzberg'},
 '496672':{'de': 'Eiterfeld', 'en': 'Eiterfeld'},
 '496673':{'de': 'Haunetal', 'en': 'Haunetal'},
 '496854':{'de': 'Oberthal Saar', 'en': 'Oberthal Saar'},
 '496855':{'de': 'Freisen', 'en': 'Freisen'},
 '496858':{'de': u('Ottweiler-F\u00fcrth'), 'en': u('Ottweiler-F\u00fcrth')},
 '496678':{'de': u('Wildeck-H\u00f6nebach'), 'en': u('Wildeck-H\u00f6nebach')},
 '492575':{'de': 'Greven-Reckenfeld', 'en': 'Greven-Reckenfeld'},
 '492574':{'de': 'Saerbeck', 'en': 'Saerbeck'},
 '492571':{'de': 'Greven Westfalen', 'en': 'Greven Westfalen'},
 '492573':{'de': 'Nordwalde', 'en': 'Nordwalde'},
 '492572':{'de': 'Emsdetten', 'en': 'Emsdetten'},
 '497620':{'de': 'Schopfheim-Gersbach', 'en': 'Schopfheim-Gersbach'},
 '4413872':{'en': 'Dumfries'},
 '4413873':{'en': 'Langholm'},
 '4413870':{'en': 'Dumfries'},
 '4413871':{'en': 'Dumfries'},
 '4413876':{'en': 'Dumfries'},
 '4413877':{'en': 'Dumfries'},
 '4413874':{'en': 'Dumfries'},
 '4413875':{'en': 'Dumfries'},
 '4413878':{'en': 'Dumfries'},
 '4413879':{'en': 'Dumfries'},
 '435414':{'de': 'Wenns', 'en': 'Wenns'},
 '435417':{'de': 'Roppen', 'en': 'Roppen'},
 '493774':{'de': 'Schwarzenberg', 'en': 'Schwarzenberg'},
 '497621':{'de': u('L\u00f6rrach'), 'en': u('L\u00f6rrach')},
 '493771':{'de': 'Aue Sachsen', 'en': 'Aue Sachsen'},
 '493772':{'de': 'Schneeberg Erzgebirge', 'en': 'Schneeberg Erzgebirge'},
 '493773':{'de': 'Johanngeorgenstadt', 'en': 'Johanngeorgenstadt'},
 '55112506':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114484':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55114485':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55114486':{'en': 'Terra Preta - SP', 'pt': 'Terra Preta - SP'},
 '55113569':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114481':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55114482':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55114483':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '55114488':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '55114489':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '52419':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '52418':{'en': 'Dolores Hidalgo/San Diego de la Union, GTO', 'es': u('Dolores Hidalgo/San Diego de la Uni\u00f3n, GTO')},
 '52415':{'en': 'San Miguel Allende, GTO', 'es': 'San Miguel Allende, GTO'},
 '52414':{'en': 'Tequisquiapan, QRO', 'es': 'Tequisquiapan, QRO'},
 '52417':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '55113107':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52411':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '55113101':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52413':{'en': 'Apaseo el Alto/Apaseo el Grande, GTO', 'es': 'Apaseo el Alto/Apaseo el Grande, GTO'},
 '52412':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '55113563':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114158':{'en': 'Vargem Grande Paulista - SP', 'pt': 'Vargem Grande Paulista - SP'},
 '55114159':{'en': 'Vargem Grande Paulista - SP', 'pt': 'Vargem Grande Paulista - SP'},
 '55114152':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114153':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114151':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114156':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114157':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114154':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114155':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '46433':{'en': u('Markaryd-Str\u00f6msn\u00e4sbruk'), 'sv': u('Markaryd-Str\u00f6msn\u00e4sbruk')},
 '46430':{'en': 'Laholm', 'sv': 'Laholm'},
 '46431':{'en': u('\u00c4ngelholm-B\u00e5stad'), 'sv': u('\u00c4ngelholm-B\u00e5stad')},
 '494209':{'de': 'Schwanewede', 'en': 'Schwanewede'},
 '494208':{'de': 'Grasberg', 'en': 'Grasberg'},
 '46435':{'en': 'Klippan-Perstorp', 'sv': 'Klippan-Perstorp'},
 '494205':{'de': 'Ottersberg', 'en': 'Ottersberg'},
 '494204':{'de': 'Thedinghausen', 'en': 'Thedinghausen'},
 '494207':{'de': 'Oyten', 'en': 'Oyten'},
 '494206':{'de': 'Stuhr-Heiligenrode', 'en': 'Stuhr-Heiligenrode'},
 '499637':{'de': 'Falkenberg Oberpfalz', 'en': 'Falkenberg Oberpfalz'},
 '499636':{'de': u('Pl\u00f6\u00dfberg'), 'en': u('Pl\u00f6ssberg')},
 '494203':{'de': 'Weyhe bei Bremen', 'en': 'Weyhe bei Bremen'},
 '494202':{'de': 'Achim bei Bremen', 'en': 'Achim bei Bremen'},
 '55113112':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498548':{'de': 'Vilshofen-Sandbach', 'en': 'Vilshofen-Sandbach'},
 '498549':{'de': 'Vilshofen-Pleinting', 'en': 'Vilshofen-Pleinting'},
 '498542':{'de': 'Ortenburg', 'en': 'Ortenburg'},
 '498543':{'de': 'Aidenbach', 'en': 'Aidenbach'},
 '498541':{'de': 'Vilshofen Niederbayern', 'en': 'Vilshofen Niederbayern'},
 '498546':{'de': 'Windorf-Otterskirchen', 'en': 'Windorf-Otterskirchen'},
 '498547':{'de': 'Osterhofen-Gergweis', 'en': 'Osterhofen-Gergweis'},
 '498544':{'de': 'Eging am See', 'en': 'Eging am See'},
 '498545':{'de': 'Hofkirchen Bayern', 'en': 'Hofkirchen Bayern'},
 '499497':{'de': 'Seubersdorf in der Oberpfalz', 'en': 'Seubersdorf in der Oberpfalz'},
 '499495':{'de': 'Breitenbrunn Oberpfalz', 'en': 'Breitenbrunn Oberpfalz'},
 '499493':{'de': 'Beratzhausen', 'en': 'Beratzhausen'},
 '499492':{'de': 'Parsberg', 'en': 'Parsberg'},
 '499491':{'de': 'Hemau', 'en': 'Hemau'},
 '499499':{'de': 'Painten', 'en': 'Painten'},
 '499498':{'de': 'Laaber', 'en': 'Laaber'},
 '499948':{'de': 'Eschlkam', 'en': 'Eschlkam'},
 '55115612':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499941':{'de': u('K\u00f6tzting'), 'en': u('K\u00f6tzting')},
 '49281':{'de': 'Wesel', 'en': 'Wesel'},
 '499943':{'de': 'Lam Oberpfalz', 'en': 'Lam Oberpfalz'},
 '499942':{'de': 'Viechtach', 'en': 'Viechtach'},
 '499945':{'de': 'Arnbruck', 'en': 'Arnbruck'},
 '499944':{'de': 'Miltach', 'en': 'Miltach'},
 '499947':{'de': 'Neukirchen bei Hl Blut', 'en': 'Neukirchen bei Hl Blut'},
 '499946':{'de': u('Hohenwarth bei K\u00f6tzing'), 'en': u('Hohenwarth bei K\u00f6tzing')},
 '495138':{'de': 'Sehnde', 'en': 'Sehnde'},
 '495139':{'de': 'Burgwedel', 'en': 'Burgwedel'},
 '495135':{'de': 'Burgwedel-Fuhrberg', 'en': 'Burgwedel-Fuhrberg'},
 '495136':{'de': 'Burgdorf Kreis Hannover', 'en': 'Burgdorf Kreis Hannover'},
 '495137':{'de': 'Seelze', 'en': 'Seelze'},
 '495130':{'de': 'Wedemark', 'en': 'Wedemark'},
 '495131':{'de': 'Garbsen', 'en': 'Garbsen'},
 '495132':{'de': 'Lehrte', 'en': 'Lehrte'},
 '441841':{'en': 'Newquay (Padstow)'},
 '441840':{'en': 'Camelford'},
 '441843':{'en': 'Thanet'},
 '441842':{'en': 'Thetford'},
 '441845':{'en': 'Thirsk'},
 '441844':{'en': 'Thame'},
 '55123004':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '441848':{'en': 'Thornhill'},
 '55113050':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112411':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112413':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112412':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112414':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112419':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55112967':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112966':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49861':{'de': 'Traunstein', 'en': 'Traunstein'},
 '55112960':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933877':{'de': 'Nitzahn', 'en': 'Nitzahn'},
 '4933652':{'de': 'Neuzelle', 'en': 'Neuzelle'},
 '4933875':{'de': 'Rhinow', 'en': 'Rhinow'},
 '4933874':{'de': 'Stechow Brandenburg', 'en': 'Stechow Brandenburg'},
 '4933873':{'de': 'Grosswudicke', 'en': 'Grosswudicke'},
 '4933872':{'de': 'Hohennauen', 'en': 'Hohennauen'},
 '4933655':{'de': 'Grunow Kreis Oder-Spree', 'en': 'Grunow Kreis Oder-Spree'},
 '4933654':{'de': u('F\u00fcnfeichen'), 'en': u('F\u00fcnfeichen')},
 '4933878':{'de': 'Nennhausen', 'en': 'Nennhausen'},
 '496449':{'de': 'Ehringshausen-Katzenfurt', 'en': 'Ehringshausen-Katzenfurt'},
 '498222':{'de': 'Burgau Schwaben', 'en': 'Burgau Schwaben'},
 '496445':{'de': u('Sch\u00f6ffengrund'), 'en': u('Sch\u00f6ffengrund')},
 '496444':{'de': 'Bischoffen', 'en': 'Bischoffen'},
 '496447':{'de': u('Langg\u00f6ns-Niederkleen'), 'en': u('Langg\u00f6ns-Niederkleen')},
 '496446':{'de': 'Hohenahr', 'en': 'Hohenahr'},
 '496441':{'de': 'Wetzlar', 'en': 'Wetzlar'},
 '496440':{'de': u('K\u00f6lschhausen'), 'en': u('K\u00f6lschhausen')},
 '496443':{'de': 'Ehringshausen Dill', 'en': 'Ehringshausen Dill'},
 '496442':{'de': 'Braunfels', 'en': 'Braunfels'},
 '498226':{'de': 'Bibertal', 'en': 'Bibertal'},
 '495862':{'de': 'Hitzacker Elbe', 'en': 'Hitzacker Elbe'},
 '495863':{'de': 'Zernien', 'en': 'Zernien'},
 '495861':{'de': 'Dannenberg Elbe', 'en': 'Dannenberg Elbe'},
 '495864':{'de': 'Jameln', 'en': 'Jameln'},
 '495865':{'de': 'Gusborn', 'en': 'Gusborn'},
 '46155':{'en': u('Nyk\u00f6ping-Oxel\u00f6sund'), 'sv': u('Nyk\u00f6ping-Oxel\u00f6sund')},
 '46157':{'en': u('Flen-Malmk\u00f6ping'), 'sv': u('Flen-Malmk\u00f6ping')},
 '55114714':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '55114715':{'en': u('Alum\u00ednio - SP'), 'pt': u('Alum\u00ednio - SP')},
 '55114716':{'en': u('S\u00e3o Jo\u00e3o Novo - SP'), 'pt': u('S\u00e3o Jo\u00e3o Novo - SP')},
 '46156':{'en': u('Trosa-Vagnh\u00e4rad'), 'sv': u('Trosa-Vagnh\u00e4rad')},
 '55114711':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '55114712':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '55114713':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '46151':{'en': u('Ving\u00e5ker'), 'sv': u('Ving\u00e5ker')},
 '55114718':{'en': 'Mairinque - SP', 'pt': 'Mairinque - SP'},
 '55114719':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '46150':{'en': 'Katrineholm', 'sv': 'Katrineholm'},
 '46152':{'en': u('Str\u00e4ngn\u00e4s'), 'sv': u('Str\u00e4ngn\u00e4s')},
 '55123896':{'en': 'Ilhabela - SP', 'pt': 'Ilhabela - SP'},
 '499574':{'de': 'Marktzeuln', 'en': 'Marktzeuln'},
 '499575':{'de': 'Weismain', 'en': 'Weismain'},
 '55113917':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497248':{'de': 'Marxzell', 'en': 'Marxzell'},
 '492369':{'de': 'Dorsten-Wulfen', 'en': 'Dorsten-Wulfen'},
 '497240':{'de': 'Pfinztal', 'en': 'Pfinztal'},
 '492361':{'de': 'Recklinghausen', 'en': 'Recklinghausen'},
 '497242':{'de': 'Rheinstetten', 'en': 'Rheinstetten'},
 '492363':{'de': 'Datteln', 'en': 'Datteln'},
 '497244':{'de': 'Weingarten Baden', 'en': 'Weingarten Baden'},
 '492365':{'de': 'Marl', 'en': 'Marl'},
 '492366':{'de': 'Herten Westfalen', 'en': 'Herten Westfalen'},
 '492367':{'de': 'Henrichenburg', 'en': 'Henrichenburg'},
 '55114365':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114367':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114366':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114361':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114360':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '4935828':{'de': 'Reichenbach OL', 'en': 'Reichenbach OL'},
 '4935829':{'de': u('Gersdorf bei G\u00f6rlitz'), 'en': u('Gersdorf bei G\u00f6rlitz')},
 '4935826':{'de': u('K\u00f6nigshain bei G\u00f6rlitz'), 'en': u('K\u00f6nigshain bei G\u00f6rlitz')},
 '4935827':{'de': 'Nieder-Seifersdorf', 'en': 'Nieder-Seifersdorf'},
 '4935825':{'de': 'Kodersdorf', 'en': 'Kodersdorf'},
 '4935822':{'de': 'Hagenwerder', 'en': 'Hagenwerder'},
 '4935823':{'de': 'Ostritz', 'en': 'Ostritz'},
 '4935820':{'de': 'Zodel', 'en': 'Zodel'},
 '497424':{'de': 'Spaichingen', 'en': 'Spaichingen'},
 '497425':{'de': 'Trossingen', 'en': 'Trossingen'},
 '497426':{'de': 'Gosheim', 'en': 'Gosheim'},
 '497427':{'de': u('Sch\u00f6mberg bei Balingen'), 'en': u('Sch\u00f6mberg bei Balingen')},
 '497420':{'de': 'Deisslingen', 'en': 'Deisslingen'},
 '497422':{'de': 'Schramberg', 'en': 'Schramberg'},
 '497423':{'de': 'Oberndorf am Neckar', 'en': 'Oberndorf am Neckar'},
 '497428':{'de': 'Rosenfeld', 'en': 'Rosenfeld'},
 '497429':{'de': 'Egesheim', 'en': 'Egesheim'},
 '498046':{'de': 'Bad Heilbrunn', 'en': 'Bad Heilbrunn'},
 '498045':{'de': 'Lenggries-Fall', 'en': 'Lenggries-Fall'},
 '498043':{'de': 'Jachenau', 'en': 'Jachenau'},
 '498042':{'de': 'Lenggries', 'en': 'Lenggries'},
 '498041':{'de': u('Bad T\u00f6lz'), 'en': u('Bad T\u00f6lz')},
 '497936':{'de': 'Schrozberg-Bartenstein', 'en': 'Schrozberg-Bartenstein'},
 '497937':{'de': u('D\u00f6rzbach'), 'en': u('D\u00f6rzbach')},
 '497934':{'de': 'Weikersheim', 'en': 'Weikersheim'},
 '497935':{'de': 'Schrozberg', 'en': 'Schrozberg'},
 '497932':{'de': u('Niederstetten W\u00fcrttemberg'), 'en': u('Niederstetten W\u00fcrttemberg')},
 '497933':{'de': 'Creglingen', 'en': 'Creglingen'},
 '497930':{'de': 'Boxberg Baden', 'en': 'Boxberg Baden'},
 '497931':{'de': 'Bad Mergentheim', 'en': 'Bad Mergentheim'},
 '436232':{'de': 'Mondsee', 'en': 'Mondsee'},
 '436233':{'de': 'Oberwang', 'en': 'Oberwang'},
 '436234':{'de': 'Zell am Moos', 'en': 'Zell am Moos'},
 '436235':{'de': 'Thalgau', 'en': 'Thalgau'},
 '497938':{'de': 'Mulfingen Jagst', 'en': 'Mulfingen Jagst'},
 '497939':{'de': 'Schrozberg-Spielbach', 'en': 'Schrozberg-Spielbach'},
 '499973':{'de': 'Furth im Wald', 'en': 'Furth im Wald'},
 '498223':{'de': 'Ichenhausen', 'en': 'Ichenhausen'},
 '493542':{'de': u('L\u00fcbbenau Spreewald'), 'en': u('L\u00fcbbenau Spreewald')},
 '493541':{'de': 'Calau', 'en': 'Calau'},
 '493546':{'de': u('L\u00fcbben Spreewald'), 'en': u('L\u00fcbben Spreewald')},
 '498225':{'de': 'Jettingen-Scheppach', 'en': 'Jettingen-Scheppach'},
 '493544':{'de': 'Luckau Brandenburg', 'en': 'Luckau Brandenburg'},
 '49671':{'de': 'Bad Kreuznach', 'en': 'Bad Kreuznach'},
 '499571':{'de': 'Lichtenfels Bayern', 'en': 'Lichtenfels Bayern'},
 '499572':{'de': 'Burgkunstadt', 'en': 'Burgkunstadt'},
 '499573':{'de': 'Staffelstein Oberfranken', 'en': 'Staffelstein Oberfranken'},
 '46371':{'en': 'Gislaved-Anderstorp', 'sv': 'Gislaved-Anderstorp'},
 '46370':{'en': u('V\u00e4rnamo'), 'sv': u('V\u00e4rnamo')},
 '499576':{'de': 'Lichtenfels-Isling', 'en': 'Lichtenfels-Isling'},
 '46372':{'en': 'Ljungby', 'sv': 'Ljungby'},
 '4936742':{'de': u('Uhlst\u00e4dt'), 'en': u('Uhlst\u00e4dt')},
 '4936743':{'de': 'Teichel', 'en': 'Teichel'},
 '4936741':{'de': 'Bad Blankenburg', 'en': 'Bad Blankenburg'},
 '4940':{'de': 'Hamburg', 'en': 'Hamburg'},
 '4936744':{'de': 'Remda', 'en': 'Remda'},
 '49491':{'de': 'Leer Ostfriesland', 'en': 'Leer Ostfriesland'},
 '52626':{'en': 'Ojinaga, CHIH', 'es': 'Ojinaga, CHIH'},
 '52627':{'en': 'Parral, CHIH', 'es': 'Parral, CHIH'},
 '4934298':{'de': 'Taucha bei Leipzig', 'en': 'Taucha bei Leipzig'},
 '4934299':{'de': 'Gaschwitz', 'en': 'Gaschwitz'},
 '52622':{'en': 'Guaymas/San Carlos, SON', 'es': 'Guaymas/San Carlos, SON'},
 '52623':{'en': 'Sonora', 'es': 'Sonora'},
 '52621':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '4934292':{'de': 'Brandis bei Wurzen', 'en': 'Brandis bei Wurzen'},
 '4934293':{'de': 'Naunhof bei Grimma', 'en': 'Naunhof bei Grimma'},
 '4934291':{'de': 'Borsdorf', 'en': 'Borsdorf'},
 '4934296':{'de': 'Groitzsch bei Pegau', 'en': 'Groitzsch bei Pegau'},
 '4934297':{'de': 'Liebertwolkwitz', 'en': 'Liebertwolkwitz'},
 '4934294':{'de': 'Rackwitz', 'en': 'Rackwitz'},
 '4934295':{'de': 'Krensitz', 'en': 'Krensitz'},
 '55113737':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113736':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113735':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113733':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113732':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113731':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113739':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '442879':{'en': 'Magherafelt'},
 '442871':{'en': 'Londonderry'},
 '442870':{'en': 'Coleraine'},
 '499293':{'de': 'Berg Oberfranken', 'en': 'Berg Oberfranken'},
 '442877':{'en': 'Limavady'},
 '55114961':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '4937369':{'de': 'Wolkenstein', 'en': 'Wolkenstein'},
 '4937368':{'de': 'Deutschneudorf', 'en': 'Deutschneudorf'},
 '4937367':{'de': 'Lengefeld Erzgebirge', 'en': 'Lengefeld Erzgebirge'},
 '4937366':{'de': u('R\u00fcbenau'), 'en': u('R\u00fcbenau')},
 '4937365':{'de': 'Sayda', 'en': 'Sayda'},
 '4937364':{'de': 'Reitzenhain Erzgebirge', 'en': 'Reitzenhain Erzgebirge'},
 '4937363':{'de': u('Z\u00f6blitz'), 'en': u('Z\u00f6blitz')},
 '4937362':{'de': 'Seiffen Erzgebirge', 'en': 'Seiffen Erzgebirge'},
 '4937361':{'de': 'Neuhausen Erzgebirge', 'en': 'Neuhausen Erzgebirge'},
 '4937360':{'de': 'Olbernhau', 'en': 'Olbernhau'},
 '44151':{'en': 'Liverpool'},
 '499465':{'de': 'Neukirchen-Balbini', 'en': 'Neukirchen-Balbini'},
 '55115539':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115538':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495651':{'de': 'Eschwege', 'en': 'Eschwege'},
 '495302':{'de': 'Vechelde', 'en': 'Vechelde'},
 '495653':{'de': 'Sontra', 'en': 'Sontra'},
 '495300':{'de': u('Salzgitter-\u00dcfingen'), 'en': u('Salzgitter-\u00dcfingen')},
 '495307':{'de': 'Braunschweig-Wenden', 'en': 'Braunschweig-Wenden'},
 '495306':{'de': 'Cremlingen', 'en': 'Cremlingen'},
 '495305':{'de': 'Sickte', 'en': 'Sickte'},
 '495304':{'de': 'Meine', 'en': 'Meine'},
 '495659':{'de': 'Ringgau', 'en': 'Ringgau'},
 '495658':{'de': 'Wehretal', 'en': 'Wehretal'},
 '495309':{'de': 'Lehre-Wendhausen', 'en': 'Lehre-Wendhausen'},
 '495308':{'de': 'Lehre', 'en': 'Lehre'},
 '55112064':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52624':{'en': 'Baja California Sur', 'es': 'Baja California Sur'},
 '55112066':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112067':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115533':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52625':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '55123949':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123948':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123946':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123945':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123944':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123943':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55112211':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123941':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55112217':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112216':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115535':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497653':{'de': 'Lenzkirch', 'en': 'Lenzkirch'},
 '497652':{'de': 'Hinterzarten', 'en': 'Hinterzarten'},
 '497651':{'de': 'Titisee-Neustadt', 'en': 'Titisee-Neustadt'},
 '55115534':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497657':{'de': 'Eisenbach Hochschwarzwald', 'en': 'Eisenbach Hochschwarzwald'},
 '497656':{'de': 'Schluchsee', 'en': 'Schluchsee'},
 '497655':{'de': u('Feldberg-Altglash\u00fctten'), 'en': u('Feldberg-Altglash\u00fctten')},
 '497654':{'de': u('L\u00f6ffingen'), 'en': u('L\u00f6ffingen')},
 '52628':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '52629':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '435256':{'de': 'Untergurgl', 'en': 'Untergurgl'},
 '435255':{'de': 'Umhausen', 'en': 'Umhausen'},
 '435254':{'de': u('S\u00f6lden'), 'en': u('S\u00f6lden')},
 '435253':{'de': u('L\u00e4ngenfeld'), 'en': u('L\u00e4ngenfeld')},
 '435252':{'de': 'Oetz', 'en': 'Oetz'},
 '55123011':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123013':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '496650':{'de': 'Hosenfeld', 'en': 'Hosenfeld'},
 '441874':{'en': 'Brecon'},
 '496652':{'de': u('H\u00fcnfeld'), 'en': u('H\u00fcnfeld')},
 '496653':{'de': 'Burghaun', 'en': 'Burghaun'},
 '496654':{'de': u('Gersfeld Rh\u00f6n'), 'en': u('Gersfeld Rh\u00f6n')},
 '496655':{'de': 'Neuhof Kreis Fulda', 'en': 'Neuhof Kreis Fulda'},
 '496656':{'de': 'Ebersburg', 'en': 'Ebersburg'},
 '441307':{'en': 'Forfar'},
 '496874':{'de': 'Wadern-Nunkirchen', 'en': 'Wadern-Nunkirchen'},
 '496659':{'de': 'Eichenzell', 'en': 'Eichenzell'},
 '496876':{'de': 'Weiskirchen Saar', 'en': 'Weiskirchen Saar'},
 '496305':{'de': 'Hochspeyer', 'en': 'Hochspeyer'},
 '496302':{'de': 'Winnweiler', 'en': 'Winnweiler'},
 '496303':{'de': 'Enkenbach-Alsenborn', 'en': 'Enkenbach-Alsenborn'},
 '496872':{'de': 'Losheim am See', 'en': 'Losheim am See'},
 '496301':{'de': 'Otterbach Pfalz', 'en': 'Otterbach Pfalz'},
 '441877':{'en': 'Callander'},
 '492558':{'de': 'Horstmar', 'en': 'Horstmar'},
 '492557':{'de': 'Wettringen Kreis Steinfurt', 'en': 'Wettringen Kreis Steinfurt'},
 '441870':{'en': 'Isle of Benbecula'},
 '492555':{'de': u('Sch\u00f6ppingen'), 'en': u('Sch\u00f6ppingen')},
 '492554':{'de': 'Laer Kreis Steinfurt', 'en': 'Laer Kreis Steinfurt'},
 '492553':{'de': 'Ochtrup', 'en': 'Ochtrup'},
 '492552':{'de': 'Steinfurt-Borghorst', 'en': 'Steinfurt-Borghorst'},
 '492551':{'de': 'Steinfurt-Burgsteinfurt', 'en': 'Steinfurt-Burgsteinfurt'},
 '441871':{'en': 'Castlebay'},
 '441872':{'en': 'Truro'},
 '441873':{'en': 'Abergavenny'},
 '436467':{'de': u('M\u00fchlbach am Hochk\u00f6nig'), 'en': u('M\u00fchlbach am Hochk\u00f6nig')},
 '436466':{'de': 'Werfenweng', 'en': 'Werfenweng'},
 '436461':{'de': u('Dienten am Hochk\u00f6nig'), 'en': u('Dienten am Hochk\u00f6nig')},
 '436463':{'de': u('Annaberg-Lung\u00f6tz'), 'en': u('Annaberg-Lung\u00f6tz')},
 '436462':{'de': 'Bischofshofen', 'en': 'Bischofshofen'},
 '495186':{'de': 'Salzhemmendorf-Wallensen', 'en': 'Salzhemmendorf-Wallensen'},
 '4935456':{'de': 'Terpt', 'en': 'Terpt'},
 '4935455':{'de': 'Walddrehna', 'en': 'Walddrehna'},
 '4935454':{'de': 'Uckro', 'en': 'Uckro'},
 '4935453':{'de': 'Drahnsdorf', 'en': 'Drahnsdorf'},
 '4935452':{'de': 'Golssen', 'en': 'Golssen'},
 '4935451':{'de': 'Dahme Brandenburg', 'en': 'Dahme Brandenburg'},
 '55115051':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113122':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113120':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52438':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52433':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '52432':{'en': 'Ciudad Manuel Doblado/Romita, GTO', 'es': 'Ciudad Manuel Doblado/Romita, GTO'},
 '52431':{'en': 'Jalostotitlan/Villa Obregon, JAL', 'es': u('Jalostotitl\u00e1n/Villa Obreg\u00f3n, JAL')},
 '55113129':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52437':{'en': 'Jalisco/Zacatecas', 'es': 'Jalisco/Zacatecas'},
 '52436':{'en': 'Zacapu, MICH', 'es': 'Zacapu, MICH'},
 '52435':{'en': 'Huetamo/San Lucas, MICH', 'es': 'Huetamo/San Lucas, MICH'},
 '52434':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '494224':{'de': 'Gross Ippener', 'en': 'Gross Ippener'},
 '494223':{'de': 'Ganderkesee-Bookholzberg', 'en': 'Ganderkesee-Bookholzberg'},
 '494222':{'de': 'Ganderkesee', 'en': 'Ganderkesee'},
 '494221':{'de': 'Delmenhorst', 'en': 'Delmenhorst'},
 '46418':{'en': u('Landskrona-Sval\u00f6v'), 'sv': u('Landskrona-Sval\u00f6v')},
 '46410':{'en': 'Trelleborg', 'sv': 'Trelleborg'},
 '46411':{'en': 'Ystad', 'sv': 'Ystad'},
 '46144':{'en': u('\u00d6desh\u00f6g'), 'sv': u('\u00d6desh\u00f6g')},
 '46413':{'en': u('Esl\u00f6v-H\u00f6\u00f6r'), 'sv': u('Esl\u00f6v-H\u00f6\u00f6r')},
 '46142':{'en': u('Mj\u00f6lby-Sk\u00e4nninge-Boxholm'), 'sv': u('Mj\u00f6lby-Sk\u00e4nninge-Boxholm')},
 '46143':{'en': 'Vadstena', 'sv': 'Vadstena'},
 '46140':{'en': u('Tran\u00e5s'), 'sv': u('Tran\u00e5s')},
 '46141':{'en': 'Motala', 'sv': 'Motala'},
 '492971':{'de': 'Schmallenberg-Dorlar', 'en': 'Schmallenberg-Dorlar'},
 '498565':{'de': 'Dietersburg-Baumgarten', 'en': 'Dietersburg-Baumgarten'},
 '492973':{'de': 'Eslohe Sauerland', 'en': 'Eslohe Sauerland'},
 '492972':{'de': 'Schmallenberg', 'en': 'Schmallenberg'},
 '492975':{'de': 'Schmallenberg-Oberkirchen', 'en': 'Schmallenberg-Oberkirchen'},
 '492974':{'de': 'Schmallenberg-Fredeburg', 'en': 'Schmallenberg-Fredeburg'},
 '492977':{'de': u('Schmallenberg-B\u00f6defeld'), 'en': u('Schmallenberg-B\u00f6defeld')},
 '498563':{'de': 'Bad Birnbach Rottal', 'en': 'Bad Birnbach Rottal'},
 '55113389':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4935026':{'de': u('D\u00fcrrr\u00f6hrsdorf-Dittersbach'), 'en': u('D\u00fcrrr\u00f6hrsdorf-Dittersbach')},
 '4935027':{'de': 'Weesenstein', 'en': 'Weesenstein'},
 '4935024':{'de': 'Stadt Wehlen', 'en': 'Stadt Wehlen'},
 '4935025':{'de': 'Liebstadt', 'en': 'Liebstadt'},
 '4935022':{'de': 'Bad Schandau', 'en': 'Bad Schandau'},
 '4935023':{'de': 'Bad Gottleuba', 'en': 'Bad Gottleuba'},
 '4935020':{'de': 'Struppen', 'en': 'Struppen'},
 '4935021':{'de': u('K\u00f6nigstein S\u00e4chsische Schweiz'), 'en': u('K\u00f6nigstein S\u00e4chsische Schweiz')},
 '4935028':{'de': 'Krippen', 'en': 'Krippen'},
 '499963':{'de': 'Konzell', 'en': 'Konzell'},
 '499962':{'de': 'Schwarzach Niederbayern', 'en': 'Schwarzach Niederbayern'},
 '499961':{'de': 'Mitterfels', 'en': 'Mitterfels'},
 '499966':{'de': 'Wiesenfelden', 'en': 'Wiesenfelden'},
 '499965':{'de': 'Sankt Englmar', 'en': 'Sankt Englmar'},
 '499964':{'de': 'Stallwang', 'en': 'Stallwang'},
 '55112466':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112467':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112392':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494462':{'de': 'Wittmund', 'en': 'Wittmund'},
 '55112461':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112463':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112653':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112652':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112651':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112657':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55115976':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112655':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112654':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115979':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112658':{'en': u('Po\u00e1 - SP'), 'pt': u('Po\u00e1 - SP')},
 '441869':{'en': 'Bicester'},
 '55113858':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441863':{'en': 'Ardgay'},
 '441862':{'en': 'Tain'},
 '55113859':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441866':{'en': 'Kilchrenan'},
 '441865':{'en': 'Oxford'},
 '441864':{'en': 'Abington (Crawford)'},
 '55123971':{'en': u('S\u00e3o Bento do Sapuca\u00ed - SP'), 'pt': u('S\u00e3o Bento do Sapuca\u00ed - SP')},
 '55113857':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113341':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113854':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113679':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113713':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4939484':{'de': 'Harzgerode', 'en': 'Harzgerode'},
 '4939485':{'de': 'Gernrode Harz', 'en': 'Gernrode Harz'},
 '55112475':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '4939487':{'de': 'Friedrichsbrunn', 'en': 'Friedrichsbrunn'},
 '55112473':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '4939481':{'de': 'Hedersleben bei Aschersleben', 'en': 'Hedersleben bei Aschersleben'},
 '4939482':{'de': 'Gatersleben', 'en': 'Gatersleben'},
 '4939483':{'de': 'Ballenstedt', 'en': 'Ballenstedt'},
 '55123686':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55113851':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4939488':{'de': u('G\u00fcntersberge'), 'en': u('G\u00fcntersberge')},
 '4939489':{'de': 'Strassberg Harz', 'en': 'Strassberg Harz'},
 '55112479':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '543574':{'en': u('R\u00edo Primero, C\u00f3rdoba'), 'es': u('R\u00edo Primero, C\u00f3rdoba')},
 '543575':{'en': u('La Puerta, C\u00f3rdoba'), 'es': u('La Puerta, C\u00f3rdoba')},
 '543576':{'en': u('Arroyito, C\u00f3rdoba'), 'es': u('Arroyito, C\u00f3rdoba')},
 '542355':{'en': 'Lincoln, Buenos Aires', 'es': 'Lincoln, Buenos Aires'},
 '543572':{'en': u('R\u00edo Segundo, C\u00f3rdoba'), 'es': u('R\u00edo Segundo, C\u00f3rdoba')},
 '543573':{'en': u('Villa del Rosario, C\u00f3rdoba'), 'es': u('Villa del Rosario, C\u00f3rdoba')},
 '543549':{'en': u('Cruz del Eje, C\u00f3rdoba'), 'es': u('Cruz del Eje, C\u00f3rdoba')},
 '4934973':{'de': 'Osternienburg', 'en': 'Osternienburg'},
 '4933679':{'de': 'Wendisch Rietz', 'en': 'Wendisch Rietz'},
 '4933678':{'de': 'Storkow Mark', 'en': 'Storkow Mark'},
 '497191':{'de': 'Backnang', 'en': 'Backnang'},
 '4933675':{'de': 'Tauche', 'en': 'Tauche'},
 '4933674':{'de': 'Trebatsch', 'en': 'Trebatsch'},
 '4933677':{'de': 'Glienicke bei Beeskow', 'en': 'Glienicke bei Beeskow'},
 '4933676':{'de': 'Friedland bei Beeskow', 'en': 'Friedland bei Beeskow'},
 '4933671':{'de': 'Lieberose', 'en': 'Lieberose'},
 '497192':{'de': 'Murrhardt', 'en': 'Murrhardt'},
 '4933673':{'de': 'Weichensdorf', 'en': 'Weichensdorf'},
 '4933672':{'de': 'Pfaffendorfb Beeskow', 'en': 'Pfaffendorfb Beeskow'},
 '496467':{'de': 'Hatzfeld Eder', 'en': 'Hatzfeld Eder'},
 '496466':{'de': 'Dautphetal-Friedensdorf', 'en': 'Dautphetal-Friedensdorf'},
 '496465':{'de': 'Breidenbach bei Biedenkopf', 'en': 'Breidenbach bei Biedenkopf'},
 '497193':{'de': 'Sulzbach an der Murr', 'en': 'Sulzbach an der Murr'},
 '54291':{'en': u('Bah\u00eda Blanca, Buenos Aires'), 'es': u('Bah\u00eda Blanca, Buenos Aires')},
 '496462':{'de': 'Gladenbach', 'en': 'Gladenbach'},
 '496461':{'de': 'Biedenkopf', 'en': 'Biedenkopf'},
 '497194':{'de': 'Spiegelberg', 'en': 'Spiegelberg'},
 '54299':{'en': u('Neuqu\u00e9n, Neuqu\u00e9n'), 'es': u('Neuqu\u00e9n, Neuqu\u00e9n')},
 '54298':{'en': u('General Roca, R\u00edo Negro'), 'es': u('General Roca, R\u00edo Negro')},
 '497195':{'de': 'Winnenden', 'en': 'Winnenden'},
 '435512':{'de': 'Egg', 'en': 'Egg'},
 '55123975':{'en': 'Santa Branca - SP', 'pt': 'Santa Branca - SP'},
 '542358':{'en': 'Los Toldos, Buenos Aires', 'es': 'Los Toldos, Buenos Aires'},
 '543846':{'en': 'Tintina, Santiago del Estero', 'es': 'Tintina, Santiago del Estero'},
 '543841':{'en': 'Monte Quemado, Santiago del Estero', 'es': 'Monte Quemado, Santiago del Estero'},
 '55114738':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114739':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '542982497':{'en': 'San Francisco de Bellocq, Buenos Aires', 'es': 'San Francisco de Bellocq, Buenos Aires'},
 '55114736':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114735':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55113453':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113881':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497222':{'de': 'Rastatt', 'en': 'Rastatt'},
 '497223':{'de': u('B\u00fchl Baden'), 'en': u('B\u00fchl Baden')},
 '497220':{'de': 'Forbach-Hundsbach', 'en': 'Forbach-Hundsbach'},
 '492301':{'de': 'Holzwickede', 'en': 'Holzwickede'},
 '492306':{'de': u('L\u00fcnen'), 'en': u('L\u00fcnen')},
 '492307':{'de': 'Kamen', 'en': 'Kamen'},
 '497224':{'de': 'Gernsbach', 'en': 'Gernsbach'},
 '497225':{'de': 'Gaggenau', 'en': 'Gaggenau'},
 '497228':{'de': 'Forbach', 'en': 'Forbach'},
 '497229':{'de': 'Iffezheim', 'en': 'Iffezheim'},
 '52825':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '495844':{'de': 'Clenze', 'en': 'Clenze'},
 '495845':{'de': 'Bergen Dumme', 'en': 'Bergen Dumme'},
 '495846':{'de': 'Gartow Niedersachsen', 'en': 'Gartow Niedersachsen'},
 '495840':{'de': 'Schnackenburg', 'en': 'Schnackenburg'},
 '495841':{'de': u('L\u00fcchow Wendland'), 'en': u('L\u00fcchow Wendland')},
 '495842':{'de': 'Schnega', 'en': 'Schnega'},
 '495843':{'de': 'Wustrow Wendland', 'en': 'Wustrow Wendland'},
 '495848':{'de': 'Trebel', 'en': 'Trebel'},
 '495849':{'de': 'Waddeweitz', 'en': 'Waddeweitz'},
 '497042':{'de': 'Vaihingen an der Enz', 'en': 'Vaihingen an der Enz'},
 '497043':{'de': 'Maulbronn', 'en': 'Maulbronn'},
 '55112119':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '4935841':{'de': u('Gro\u00dfsch\u00f6nau Sachsen'), 'en': u('Grosssch\u00f6nau Sachsen')},
 '4935842':{'de': 'Oderwitz', 'en': 'Oderwitz'},
 '4935843':{'de': 'Hirschfelde bei Zittau', 'en': 'Hirschfelde bei Zittau'},
 '4935844':{'de': 'Oybin Kurort', 'en': 'Oybin Kurort'},
 '46921':{'en': 'Boden', 'sv': 'Boden'},
 '46922':{'en': 'Haparanda', 'sv': 'Haparanda'},
 '46923':{'en': 'Kalix', 'sv': 'Kalix'},
 '46253':{'en': u('Idre-S\u00e4rna'), 'sv': u('Idre-S\u00e4rna')},
 '46926':{'en': u('\u00d6verkalix'), 'sv': u('\u00d6verkalix')},
 '46927':{'en': u('\u00d6vertorne\u00e5'), 'sv': u('\u00d6vertorne\u00e5')},
 '498021':{'de': 'Waakirchen', 'en': 'Waakirchen'},
 '49208':{'de': 'Oberhausen Rheinland', 'en': 'Oberhausen Rheinland'},
 '498023':{'de': 'Bayrischzell', 'en': 'Bayrischzell'},
 '498022':{'de': 'Tegernsee', 'en': 'Tegernsee'},
 '498025':{'de': 'Miesbach', 'en': 'Miesbach'},
 '498024':{'de': 'Holzkirchen', 'en': 'Holzkirchen'},
 '498027':{'de': 'Dietramszell', 'en': 'Dietramszell'},
 '49209':{'de': 'Gelsenkirchen', 'en': 'Gelsenkirchen'},
 '498029':{'de': 'Kreuth bei Tegernsee', 'en': 'Kreuth bei Tegernsee'},
 '498028':{'de': 'Fischbachau', 'en': 'Fischbachau'},
 '495303':{'de': 'Wendeburg', 'en': 'Wendeburg'},
 '499778':{'de': 'Fladungen', 'en': 'Fladungen'},
 '495650':{'de': 'Cornberg', 'en': 'Cornberg'},
 '499776':{'de': 'Mellrichstadt', 'en': 'Mellrichstadt'},
 '499777':{'de': u('Ostheim von der Rh\u00f6n'), 'en': u('Ostheim von der Rh\u00f6n')},
 '499774':{'de': 'Oberelsbach', 'en': 'Oberelsbach'},
 '499775':{'de': u('Sch\u00f6nau an der Brend'), 'en': u('Sch\u00f6nau an der Brend')},
 '499772':{'de': u('Bischofsheim an der Rh\u00f6n'), 'en': u('Bischofsheim an der Rh\u00f6n')},
 '495301':{'de': 'Lehre-Essenrode', 'en': 'Lehre-Essenrode'},
 '499771':{'de': 'Bad Neustadt an der Saale', 'en': 'Bad Neustadt an der Saale'},
 '55114355':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '495652':{'de': 'Bad Sooden-Allendorf', 'en': 'Bad Sooden-Allendorf'},
 '46258':{'en': 'Furudal'},
 '495655':{'de': 'Wanfried', 'en': 'Wanfried'},
 '495654':{'de': 'Herleshausen', 'en': 'Herleshausen'},
 '495657':{'de': 'Meissner', 'en': 'Meissner'},
 '495656':{'de': 'Waldkappel', 'en': 'Waldkappel'},
 '55112060':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112061':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123916':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55112062':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112063':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49651':{'de': 'Trier', 'en': 'Trier'},
 '55112065':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4690':{'en': u('Ume\u00e5'), 'sv': u('Ume\u00e5')},
 '5161':{'en': 'Ucayali'},
 '5162':{'en': u('Hu\u00e1nuco')},
 '5163':{'en': 'Pasco'},
 '5164':{'en': u('Jun\u00edn')},
 '5165':{'en': 'Loreto'},
 '5166':{'en': 'Ayacucho'},
 '5167':{'en': 'Huancavelica'},
 '55113249':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113248':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113719':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113718':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113243':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113242':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113241':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113240':{'en': 'Salvador - BA', 'pt': 'Salvador - BA'},
 '55113246':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113245':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113244':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123942':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '494968':{'de': 'Neulehe', 'en': 'Neulehe'},
 '4937349':{'de': 'Scheibenberg', 'en': 'Scheibenberg'},
 '4937348':{'de': 'Oberwiesenthal Kurort', 'en': 'Oberwiesenthal Kurort'},
 '4937341':{'de': 'Ehrenfriedersdorf', 'en': 'Ehrenfriedersdorf'},
 '4937343':{'de': u('J\u00f6hstadt'), 'en': u('J\u00f6hstadt')},
 '4937342':{'de': 'Cranzahl', 'en': 'Cranzahl'},
 '4937344':{'de': 'Crottendorf Sachsen', 'en': 'Crottendorf Sachsen'},
 '4937347':{'de': u('B\u00e4renstein Kreis Annaberg'), 'en': u('B\u00e4renstein Kreis Annaberg')},
 '4937346':{'de': 'Geyer', 'en': 'Geyer'},
 '494967':{'de': 'Rhauderfehn-Burlage', 'en': 'Rhauderfehn-Burlage'},
 '4939035':{'de': 'Kuhfelde', 'en': 'Kuhfelde'},
 '4939034':{'de': 'Fleetmark', 'en': 'Fleetmark'},
 '4939037':{'de': 'Pretzier', 'en': 'Pretzier'},
 '4939036':{'de': 'Binde', 'en': 'Binde'},
 '4939031':{'de': u('D\u00e4hre'), 'en': u('D\u00e4hre')},
 '4939030':{'de': 'Brunau', 'en': 'Brunau'},
 '4939033':{'de': 'Wallstawe', 'en': 'Wallstawe'},
 '4939032':{'de': 'Mahlsdorf bei Salzwedel', 'en': 'Mahlsdorf bei Salzwedel'},
 '4939039':{'de': 'Bonese', 'en': 'Bonese'},
 '4939038':{'de': 'Henningen', 'en': 'Henningen'},
 '495506':{'de': 'Adelebsen', 'en': 'Adelebsen'},
 '55112048':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112049':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495673':{'de': 'Immenhausen Hessen', 'en': 'Immenhausen Hessen'},
 '495672':{'de': 'Bad Karlshafen', 'en': 'Bad Karlshafen'},
 '495671':{'de': 'Hofgeismar', 'en': 'Hofgeismar'},
 '495677':{'de': 'Calden-Westuffeln', 'en': 'Calden-Westuffeln'},
 '495676':{'de': 'Liebenau Hessen', 'en': 'Liebenau Hessen'},
 '495675':{'de': 'Trendelburg', 'en': 'Trendelburg'},
 '495674':{'de': 'Grebenstein', 'en': 'Grebenstein'},
 '55123965':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123211':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '55123966':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123961':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123962':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '497402':{'de': 'Fluorn-Winzeln', 'en': 'Fluorn-Winzeln'},
 '5042617':{'en': u('Choloma, Cort\u00e9s')},
 '497403':{'de': 'Dunningen', 'en': 'Dunningen'},
 '543743':{'en': 'Puerto Rico, Misiones', 'es': 'Puerto Rico, Misiones'},
 '543741':{'en': 'Bernardo de Irigoyen, Misiones', 'es': 'Bernardo de Irigoyen, Misiones'},
 '55133505':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '495502':{'de': 'Dransfeld', 'en': 'Dransfeld'},
 '435230':{'de': 'Sellrain', 'en': 'Sellrain'},
 '435232':{'de': 'Kematen in Tirol', 'en': 'Kematen in Tirol'},
 '435234':{'de': 'Axams', 'en': 'Axams'},
 '435236':{'de': 'Gries im Sellrain', 'en': 'Gries im Sellrain'},
 '435239':{'de': u('K\u00fchtai'), 'en': u('K\u00fchtai')},
 '435238':{'de': 'Zirl', 'en': 'Zirl'},
 '4933334':{'de': 'Greiffenberg', 'en': 'Greiffenberg'},
 '4933335':{'de': 'Pinnow Kreis Uckermark', 'en': 'Pinnow Kreis Uckermark'},
 '4933336':{'de': 'Passow Kreis Uckermark', 'en': 'Passow Kreis Uckermark'},
 '4933337':{'de': u('Altk\u00fcnkendorf'), 'en': u('Altk\u00fcnkendorf')},
 '4933331':{'de': 'Casekow', 'en': 'Casekow'},
 '4933332':{'de': 'Gartz Oder', 'en': 'Gartz Oder'},
 '4933333':{'de': 'Tantow', 'en': 'Tantow'},
 '4933338':{'de': 'Stolpe/Oder', 'en': 'Stolpe/Oder'},
 '55113328':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113329':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496328':{'de': 'Elmstein', 'en': 'Elmstein'},
 '496329':{'de': 'Weidenthal Pfalz', 'en': 'Weidenthal Pfalz'},
 '496638':{'de': 'Schwalmtal-Renzendorf', 'en': 'Schwalmtal-Renzendorf'},
 '496639':{'de': 'Ottrau', 'en': 'Ottrau'},
 '496321':{'de': u('Neustadt an der Weinstra\u00dfe'), 'en': 'Neustadt an der Weinstrasse'},
 '496322':{'de': u('Bad D\u00fcrkheim'), 'en': u('Bad D\u00fcrkheim')},
 '496323':{'de': 'Edenkoben', 'en': 'Edenkoben'},
 '496636':{'de': 'Romrod', 'en': 'Romrod'},
 '496637':{'de': 'Feldatal', 'en': 'Feldatal'},
 '496634':{'de': u('Gem\u00fcnden Felda'), 'en': u('Gem\u00fcnden Felda')},
 '496327':{'de': 'Neustadt-Lachen', 'en': 'Neustadt-Lachen'},
 '492538':{'de': 'Drensteinfurt-Rinkerode', 'en': 'Drensteinfurt-Rinkerode'},
 '492533':{'de': u('M\u00fcnster-Nienberge'), 'en': u('M\u00fcnster-Nienberge')},
 '492532':{'de': 'Ostbevern', 'en': 'Ostbevern'},
 '492535':{'de': 'Sendenhorst-Albersloh', 'en': 'Sendenhorst-Albersloh'},
 '492534':{'de': u('M\u00fcnster-Roxel'), 'en': u('M\u00fcnster-Roxel')},
 '492536':{'de': u('M\u00fcnster-Albachten'), 'en': u('M\u00fcnster-Albachten')},
 '55123974':{'en': 'Paraibuna - SP', 'pt': 'Paraibuna - SP'},
 '55113321':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114708':{'en': 'Mairinque - SP', 'pt': 'Mairinque - SP'},
 '55113322':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113323':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113457':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113027':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113454':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113026':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497404':{'de': 'Epfendorf', 'en': 'Epfendorf'},
 '55113455':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113025':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113024':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133227':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133224':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55113023':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113022':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55122139':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '4935471':{'de': 'Birkenhainchen', 'en': 'Birkenhainchen'},
 '55114441':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '4935473':{'de': u('Neu L\u00fcbbenau'), 'en': u('Neu L\u00fcbbenau')},
 '4935472':{'de': 'Schlepzig', 'en': 'Schlepzig'},
 '4935475':{'de': 'Straupitz', 'en': 'Straupitz'},
 '4935474':{'de': u('Sch\u00f6nwalde bei L\u00fcbben'), 'en': u('Sch\u00f6nwalde bei L\u00fcbben')},
 '4935477':{'de': 'Rietzneuendorf-Friedrichshof', 'en': 'Rietzneuendorf-Friedrichshof'},
 '4935476':{'de': u('Wittmannsdorf-B\u00fcckchen'), 'en': u('Wittmannsdorf-B\u00fcckchen')},
 '55114448':{'en': 'Cajamar - SP', 'pt': 'Cajamar - SP'},
 '4935478':{'de': 'Goyatz', 'en': 'Goyatz'},
 '441993':{'en': 'Witney'},
 '441992':{'en': 'Lea Valley'},
 '55122136':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '493663':{'de': 'Schleiz', 'en': 'Schleiz'},
 '493661':{'de': 'Greiz', 'en': 'Greiz'},
 '436133':{'de': 'Ebensee', 'en': 'Ebensee'},
 '436132':{'de': 'Bad Ischl', 'en': 'Bad Ischl'},
 '441995':{'en': 'Garstang'},
 '441746':{'en': 'Bridgnorth'},
 '441747':{'en': 'Shaftesbury'},
 '441744':{'en': 'St Helens'},
 '494242':{'de': 'Syke', 'en': 'Syke'},
 '494245':{'de': 'Neuenkirchen bei Bassum', 'en': 'Neuenkirchen bei Bassum'},
 '494244':{'de': 'Harpstedt', 'en': 'Harpstedt'},
 '494247':{'de': 'Affinghausen', 'en': 'Affinghausen'},
 '494246':{'de': 'Twistringen-Heiligenloh', 'en': 'Twistringen-Heiligenloh'},
 '494249':{'de': 'Bassum-Nordwohlde', 'en': 'Bassum-Nordwohlde'},
 '494248':{'de': 'Bassum-Neubruchhausen', 'en': 'Bassum-Neubruchhausen'},
 '441748':{'en': 'Richmond'},
 '441749':{'en': 'Shepton Mallet'},
 '55115560':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492958':{'de': u('B\u00fcren-Harth'), 'en': u('B\u00fcren-Harth')},
 '492953':{'de': u('W\u00fcnnenberg'), 'en': u('W\u00fcnnenberg')},
 '492952':{'de': u('R\u00fcthen'), 'en': u('R\u00fcthen')},
 '492951':{'de': u('B\u00fcren'), 'en': u('B\u00fcren')},
 '498585':{'de': 'Grainet', 'en': 'Grainet'},
 '492957':{'de': u('W\u00fcnnenberg-Haaren'), 'en': u('W\u00fcnnenberg-Haaren')},
 '498583':{'de': 'Neureichenau', 'en': 'Neureichenau'},
 '492955':{'de': u('B\u00fcren-Wewelsburg'), 'en': u('B\u00fcren-Wewelsburg')},
 '492954':{'de': u('R\u00fcthen-Oestereiden'), 'en': u('R\u00fcthen-Oestereiden')},
 '46292':{'en': u('T\u00e4rnsj\u00f6-\u00d6sterv\u00e5la'), 'sv': u('T\u00e4rnsj\u00f6-\u00d6sterv\u00e5la')},
 '46293':{'en': u('Tierp-S\u00f6derfors'), 'sv': u('Tierp-S\u00f6derfors')},
 '46290':{'en': 'Hofors-Storvik', 'sv': 'Hofors-Storvik'},
 '46291':{'en': u('Hedesunda-\u00d6sterf\u00e4rnebo'), 'sv': u('Hedesunda-\u00d6sterf\u00e4rnebo')},
 '46297':{'en': u('Ockelbo-Hamr\u00e5nge'), 'sv': u('Ockelbo-Hamr\u00e5nge')},
 '46294':{'en': u('Karlholmsbruk-Sk\u00e4rplinge'), 'sv': u('Karlholmsbruk-Sk\u00e4rplinge')},
 '46295':{'en': u('\u00d6rbyhus-Dannemora'), 'sv': u('\u00d6rbyhus-Dannemora')},
 '4939934':{'de': u('Gro\u00df Plasten'), 'en': 'Gross Plasten'},
 '4939931':{'de': u('R\u00f6bel M\u00fcritz'), 'en': u('R\u00f6bel M\u00fcritz')},
 '4939932':{'de': 'Malchow bei Waren', 'en': 'Malchow bei Waren'},
 '4939933':{'de': 'Vollrathsruhe', 'en': 'Vollrathsruhe'},
 '52451':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52453':{'en': 'Apatzingan, MICH', 'es': u('Apatzing\u00e1n, MICH')},
 '499521':{'de': 'Hassfurt', 'en': 'Hassfurt'},
 '52455':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52454':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52457':{'en': 'Jalisco/Zacatecas', 'es': 'Jalisco/Zacatecas'},
 '52456':{'en': 'Valle de Santiago, GTO', 'es': 'Valle de Santiago, GTO'},
 '52459':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52458':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '55112679':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112678':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112671':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112673':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112672':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112675':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112674':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112676':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441337':{'en': 'Ladybank'},
 '499184':{'de': 'Deining Oberpfalz', 'en': 'Deining Oberpfalz'},
 '441335':{'en': 'Ashbourne'},
 '441334':{'en': 'St Andrews'},
 '441333':{'en': 'Peat Inn (Leven (Fife))'},
 '441332':{'en': 'Derby'},
 '499183':{'de': 'Burgthann', 'en': 'Burgthann'},
 '441330':{'en': 'Banchory'},
 '499189':{'de': 'Berg bei Neumarkt in der Oberpfalz', 'en': 'Berg bei Neumarkt in der Oberpfalz'},
 '499188':{'de': 'Postbauer-Heng', 'en': 'Postbauer-Heng'},
 '55123512':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '498640':{'de': 'Reit Im Winkl', 'en': 'Reit Im Winkl'},
 '4936465':{'de': 'Oberndorf bei Apolda', 'en': 'Oberndorf bei Apolda'},
 '4936464':{'de': 'Wormstedt', 'en': 'Wormstedt'},
 '4936463':{'de': 'Gebstedt', 'en': 'Gebstedt'},
 '4936462':{'de': 'Ossmannstedt', 'en': 'Ossmannstedt'},
 '4936461':{'de': 'Bad Sulza', 'en': 'Bad Sulza'},
 '498861':{'de': 'Schongau', 'en': 'Schongau'},
 '44291':{'en': 'Cardiff'},
 '44292':{'en': 'Cardiff'},
 '55112908':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112458':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55115489':{'en': u('S\u00e3o Paulo'), 'pt': u('S\u00e3o Paulo')},
 '55112455':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112902':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112901':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498862':{'de': 'Steingaden Oberbayern', 'en': 'Steingaden Oberbayern'},
 '55112451':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '492375':{'de': 'Balve', 'en': 'Balve'},
 '55112453':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112452':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '49821':{'de': 'Augsburg', 'en': 'Augsburg'},
 '492374':{'de': 'Iserlohn-Letmathe', 'en': 'Iserlohn-Letmathe'},
 '49351':{'de': 'Dresden', 'en': 'Dresden'},
 '492373':{'de': 'Menden Sauerland', 'en': 'Menden Sauerland'},
 '499235':{'de': 'Thierstein', 'en': 'Thierstein'},
 '499234':{'de': 'Neusorg', 'en': 'Neusorg'},
 '499233':{'de': 'Arzberg Oberfranken', 'en': 'Arzberg Oberfranken'},
 '499232':{'de': 'Wunsiedel', 'en': 'Wunsiedel'},
 '499231':{'de': 'Marktredwitz', 'en': 'Marktredwitz'},
 '492372':{'de': 'Hemer', 'en': 'Hemer'},
 '499843':{'de': 'Burgbernheim', 'en': 'Burgbernheim'},
 '497251':{'de': 'Bruchsal', 'en': 'Bruchsal'},
 '499844':{'de': 'Obernzenn', 'en': 'Obernzenn'},
 '4937752':{'de': 'Eibenstock', 'en': 'Eibenstock'},
 '4937756':{'de': 'Breitenbrunn Erzgebirge', 'en': 'Breitenbrunn Erzgebirge'},
 '4937757':{'de': u('Rittersgr\u00fcn'), 'en': u('Rittersgr\u00fcn')},
 '4937754':{'de': u('Zw\u00f6nitz'), 'en': u('Zw\u00f6nitz')},
 '4937755':{'de': u('Sch\u00f6nheide Erzgebirge'), 'en': u('Sch\u00f6nheide Erzgebirge')},
 '49521':{'de': 'Bielefeld', 'en': 'Bielefeld'},
 '4933839':{'de': 'Wusterwitz', 'en': 'Wusterwitz'},
 '4933838':{'de': u('P\u00e4wesin'), 'en': u('P\u00e4wesin')},
 '4933833':{'de': 'Wollin bei Brandenburg', 'en': 'Wollin bei Brandenburg'},
 '4933832':{'de': u('Rog\u00e4sen'), 'en': u('Rog\u00e4sen')},
 '4933831':{'de': 'Weseram', 'en': 'Weseram'},
 '4933830':{'de': 'Ziesar', 'en': 'Ziesar'},
 '4933837':{'de': 'Brielow', 'en': 'Brielow'},
 '4933836':{'de': 'Butzow bei Brandenburg', 'en': 'Butzow bei Brandenburg'},
 '4933835':{'de': 'Golzow bei Brandenburg', 'en': 'Golzow bei Brandenburg'},
 '4933834':{'de': 'Pritzerbe', 'en': 'Pritzerbe'},
 '496401':{'de': u('Gr\u00fcnberg Hessen'), 'en': u('Gr\u00fcnberg Hessen')},
 '496400':{'de': u('M\u00fccke'), 'en': u('M\u00fccke')},
 '496403':{'de': 'Linden Hessen', 'en': 'Linden Hessen'},
 '496402':{'de': 'Hungen', 'en': 'Hungen'},
 '496405':{'de': 'Laubach Hessen', 'en': 'Laubach Hessen'},
 '496404':{'de': 'Lich Hessen', 'en': 'Lich Hessen'},
 '496407':{'de': 'Rabenau Hessen', 'en': 'Rabenau Hessen'},
 '496406':{'de': 'Lollar', 'en': 'Lollar'},
 '496409':{'de': 'Biebertal', 'en': 'Biebertal'},
 '4939751':{'de': 'Penkun', 'en': 'Penkun'},
 '4939752':{'de': 'Blumenhagen bei Strasburg', 'en': 'Blumenhagen bei Strasburg'},
 '4939753':{'de': 'Strasburg', 'en': 'Strasburg'},
 '4939754':{'de': u('L\u00f6cknitz Vorpom'), 'en': u('L\u00f6cknitz Vorpom')},
 '496651':{'de': 'Rasdorf', 'en': 'Rasdorf'},
 '55113501':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113502':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113505':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113507':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496308':{'de': u('Olsbr\u00fccken'), 'en': u('Olsbr\u00fccken')},
 '496657':{'de': 'Hofbieber', 'en': 'Hofbieber'},
 '55114194':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '496306':{'de': 'Trippstadt', 'en': 'Trippstadt'},
 '496875':{'de': 'Nonnweiler-Primstal', 'en': 'Nonnweiler-Primstal'},
 '496304':{'de': 'Wolfstein Pfalz', 'en': 'Wolfstein Pfalz'},
 '55114195':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '496871':{'de': 'Wadern', 'en': 'Wadern'},
 '496873':{'de': 'Nonnweiler', 'en': 'Nonnweiler'},
 '543487':{'en': u('Z\u00e1rate, Buenos Aires'), 'es': u('Z\u00e1rate, Buenos Aires')},
 '497204':{'de': u('Malsch-V\u00f6lkersbach'), 'en': u('Malsch-V\u00f6lkersbach')},
 '492325':{'de': 'Wanne-Eickel', 'en': 'Wanne-Eickel'},
 '497754':{'de': u('G\u00f6rwihl'), 'en': u('G\u00f6rwihl')},
 '492327':{'de': 'Bochum-Wattenscheid', 'en': 'Bochum-Wattenscheid'},
 '497753':{'de': 'Albbruck', 'en': 'Albbruck'},
 '497202':{'de': 'Karlsbad', 'en': 'Karlsbad'},
 '497203':{'de': 'Walzbachtal', 'en': 'Walzbachtal'},
 '495531':{'de': 'Holzminden', 'en': 'Holzminden'},
 '495532':{'de': 'Stadtoldendorf', 'en': 'Stadtoldendorf'},
 '495533':{'de': 'Bodenwerder', 'en': 'Bodenwerder'},
 '495534':{'de': 'Eschershausen an der Lenne', 'en': 'Eschershausen an der Lenne'},
 '495535':{'de': 'Polle', 'en': 'Polle'},
 '495536':{'de': 'Holzminden-Neuhaus', 'en': 'Holzminden-Neuhaus'},
 '492556':{'de': 'Metelen', 'en': 'Metelen'},
 '441538':{'en': 'Ipstones'},
 '441535':{'en': 'Keighley'},
 '441534':{'en': 'Jersey'},
 '441536':{'en': 'Kettering'},
 '441531':{'en': 'Ledbury'},
 '441530':{'en': 'Coalville'},
 '55114191':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '492181':{'de': 'Grevenbroich', 'en': 'Grevenbroich'},
 '492182':{'de': 'Grevenbroich-Kapellen', 'en': 'Grevenbroich-Kapellen'},
 '492183':{'de': 'Rommerskirchen', 'en': 'Rommerskirchen'},
 '55113213':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '435576':{'de': 'Hohenems', 'en': 'Hohenems'},
 '435577':{'de': 'Lustenau', 'en': 'Lustenau'},
 '435574':{'de': 'Bregenz', 'en': 'Bregenz'},
 '435575':{'de': 'Langen bei Bregenz', 'en': 'Langen bei Bregenz'},
 '435572':{'de': 'Dornbirn', 'en': 'Dornbirn'},
 '435573':{'de': u('H\u00f6rbranz'), 'en': u('H\u00f6rbranz')},
 '543826':{'en': 'Chamical, La Rioja', 'es': 'Chamical, La Rioja'},
 '543827':{'en': 'Aimogasta, La Rioja', 'es': 'Aimogasta, La Rioja'},
 '543825':{'en': 'Chilecito, La Rioja', 'es': 'Chilecito, La Rioja'},
 '435578':{'de': u('H\u00f6chst'), 'en': u('H\u00f6chst')},
 '435579':{'de': 'Alberschwende', 'en': 'Alberschwende'},
 '52846':{'en': 'Veracruz', 'es': 'Veracruz'},
 '55115103':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52844':{'en': 'Saltillo, COAH', 'es': 'Saltillo, COAH'},
 '52845':{'en': 'Ebano/Ponciano Arriaga, SLP', 'es': 'Ebano/Ponciano Arriaga, SLP'},
 '52842':{'en': 'Coahuila', 'es': 'Coahuila'},
 '52841':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '497433':{'de': 'Balingen', 'en': 'Balingen'},
 '436278':{'de': 'Ostermiething', 'en': 'Ostermiething'},
 '497432':{'de': 'Albstadt-Tailfingen', 'en': 'Albstadt-Tailfingen'},
 '436274':{'de': 'Lamprechtshausen', 'en': 'Lamprechtshausen'},
 '436276':{'de': u('Nu\u00dfdorf am Haunsberg'), 'en': 'Nussdorf am Haunsberg'},
 '436277':{'de': 'Sankt Pantaleon', 'en': 'St. Pantaleon'},
 '497431':{'de': 'Albstadt-Ebingen', 'en': 'Albstadt-Ebingen'},
 '436272':{'de': 'Oberndorf bei Salzburg', 'en': 'Oberndorf bei Salzburg'},
 '497972':{'de': 'Gschwend bei Gaildorf', 'en': 'Gschwend bei Gaildorf'},
 '497973':{'de': 'Obersontheim', 'en': 'Obersontheim'},
 '497971':{'de': 'Gaildorf', 'en': 'Gaildorf'},
 '497976':{'de': 'Sulzbach-Laufen', 'en': 'Sulzbach-Laufen'},
 '497977':{'de': 'Oberrot bei Gaildorf', 'en': 'Oberrot bei Gaildorf'},
 '497974':{'de': u('B\u00fchlerzell'), 'en': u('B\u00fchlerzell')},
 '497436':{'de': 'Messstetten-Oberdigisheim', 'en': 'Messstetten-Oberdigisheim'},
 '55113885':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493586':{'de': 'Neugersdorf Sachsen', 'en': 'Neugersdorf Sachsen'},
 '493585':{'de': u('L\u00f6bau'), 'en': u('L\u00f6bau')},
 '55113886':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4936258':{'de': 'Friemar', 'en': 'Friemar'},
 '4936259':{'de': u('Tabarz Th\u00fcringer Wald'), 'en': u('Tabarz Th\u00fcringer Wald')},
 '493581':{'de': u('G\u00f6rlitz'), 'en': u('G\u00f6rlitz')},
 '55113882':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4936254':{'de': 'Friedrichswerth', 'en': 'Friedrichswerth'},
 '4936255':{'de': 'Goldbach bei Gotha', 'en': 'Goldbach bei Gotha'},
 '4936256':{'de': 'Wechmar', 'en': 'Wechmar'},
 '4936257':{'de': u('Luisenthal Th\u00fcringen'), 'en': u('Luisenthal Th\u00fcringen')},
 '55113889':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113888':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4936252':{'de': 'Tambach-Dietharz', 'en': 'Tambach-Dietharz'},
 '4936253':{'de': u('Georgenthal Th\u00fcringer Wald'), 'en': u('Georgenthal Th\u00fcringer Wald')},
 '46623':{'en': 'Ramsele', 'sv': 'Ramsele'},
 '46622':{'en': u('N\u00e4s\u00e5ker'), 'sv': u('N\u00e4s\u00e5ker')},
 '46621':{'en': 'Junsele', 'sv': 'Junsele'},
 '46620':{'en': u('Sollefte\u00e5'), 'sv': u('Sollefte\u00e5')},
 '46624':{'en': 'Backe', 'sv': 'Backe'},
 '4936784':{'de': u('St\u00fctzerbach'), 'en': u('St\u00fctzerbach')},
 '4936785':{'de': u('Gr\u00e4finau-Angstedt'), 'en': u('Gr\u00e4finau-Angstedt')},
 '4936782':{'de': 'Schmiedefeld am Rennsteig', 'en': 'Schmiedefeld am Rennsteig'},
 '4936783':{'de': u('Gehren Th\u00fcringen'), 'en': u('Gehren Th\u00fcringen')},
 '4936781':{'de': 'Grossbreitenbach', 'en': 'Grossbreitenbach'},
 '55113085':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113084':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113087':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113086':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113081':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113083':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113082':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497153':{'de': 'Plochingen', 'en': 'Plochingen'},
 '55114278':{'en': 'Santa Isabel - SP', 'pt': 'Santa Isabel - SP'},
 '55114273':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '55114272':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '55114275':{'en': u('Mairipor\u00e3 - SP'), 'pt': u('Mairipor\u00e3 - SP')},
 '52276':{'en': 'Puebla', 'es': 'Puebla'},
 '5144':{'en': 'La Libertad'},
 '5142':{'en': u('San Mart\u00edn')},
 '5143':{'en': 'Ancash'},
 '5141':{'en': 'Amazonas'},
 '52668':{'en': 'Sinoloa', 'es': 'Sinoloa'},
 '52669':{'en': 'Sinoloa', 'es': 'Sinoloa'},
 '55113265':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113264':{'en': 'Salvador - BA', 'pt': 'Salvador - BA'},
 '55113266':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52662':{'en': 'Sonora', 'es': 'Sonora'},
 '55113268':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52661':{'en': 'Primo Tapia/Rosarito, BCN', 'es': 'Primo Tapia/Rosarito, BCN'},
 '52666':{'en': 'Tijuana, BCN', 'es': 'Tijuana, BCN'},
 '52667':{'en': 'Sinoloa', 'es': 'Sinoloa'},
 '52665':{'en': 'Tecate, BCN', 'es': 'Tecate, BCN'},
 '499534':{'de': 'Burgpreppach', 'en': 'Burgpreppach'},
 '499535':{'de': 'Pfarrweisach', 'en': 'Pfarrweisach'},
 '494724':{'de': u('Cuxhaven-L\u00fcdingworth'), 'en': u('Cuxhaven-L\u00fcdingworth')},
 '494725':{'de': 'Helgoland', 'en': 'Helgoland'},
 '494722':{'de': 'Cuxhaven-Altenbruch', 'en': 'Cuxhaven-Altenbruch'},
 '494723':{'de': 'Cuxhaven-Altenwalde', 'en': 'Cuxhaven-Altenwalde'},
 '499532':{'de': 'Maroldsweisach', 'en': 'Maroldsweisach'},
 '494721':{'de': 'Cuxhaven', 'en': 'Cuxhaven'},
 '4937323':{'de': 'Lichtenberg Erzgebirge', 'en': 'Lichtenberg Erzgebirge'},
 '4937322':{'de': 'Brand-Erbisdorf', 'en': 'Brand-Erbisdorf'},
 '4937321':{'de': 'Frankenstein Sachsen', 'en': 'Frankenstein Sachsen'},
 '4937320':{'de': 'Mulda Sachsen', 'en': 'Mulda Sachsen'},
 '4937327':{'de': u('Rechenberg-Bienenm\u00fchle'), 'en': u('Rechenberg-Bienenm\u00fchle')},
 '4937326':{'de': 'Frauenstein Sachsen', 'en': 'Frauenstein Sachsen'},
 '4937325':{'de': 'Niederbobritzsch', 'en': 'Niederbobritzsch'},
 '4937324':{'de': 'Reinsberg Sachsen', 'en': 'Reinsberg Sachsen'},
 '4937329':{'de': 'Grosshartmannsdorf', 'en': 'Grosshartmannsdorf'},
 '4937328':{'de': 'Grossschirma', 'en': 'Grossschirma'},
 '495491':{'de': u('Damme D\u00fcmmer'), 'en': u('Damme D\u00fcmmer')},
 '499423':{'de': u('Geiselh\u00f6ring'), 'en': u('Geiselh\u00f6ring')},
 '441290':{'en': 'Cumnock'},
 '441291':{'en': 'Chepstow'},
 '441292':{'en': 'Ayr'},
 '441293':{'en': 'Crawley'},
 '441294':{'en': 'Ardrossan'},
 '441295':{'en': 'Banbury'},
 '441296':{'en': 'Aylesbury'},
 '441297':{'en': 'Axminster'},
 '441298':{'en': 'Buxton'},
 '441299':{'en': 'Bewdley'},
 '55123884':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123885':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55112024':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499524':{'de': 'Zeil am Main', 'en': 'Zeil am Main'},
 '55112027':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123521':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55112021':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112023':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112028':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55124715':{'en': u('Alum\u00ednio - SP'), 'pt': u('Alum\u00ednio - SP')},
 '55112952':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493877':{'de': 'Wittenberge', 'en': 'Wittenberge'},
 '493876':{'de': 'Perleberg', 'en': 'Perleberg'},
 '493874':{'de': 'Ludwigslust', 'en': 'Ludwigslust'},
 '493871':{'de': 'Parchim', 'en': 'Parchim'},
 '496665':{'de': 'Sinntal-Altengronau', 'en': 'Sinntal-Altengronau'},
 '435213':{'de': 'Scharnitz', 'en': 'Scharnitz'},
 '435212':{'de': 'Seefeld in Tirol', 'en': 'Seefeld in Tirol'},
 '435214':{'de': 'Leutasch', 'en': 'Leutasch'},
 '496342':{'de': 'Schweigen-Rechtenbach', 'en': 'Schweigen-Rechtenbach'},
 '496343':{'de': 'Bad Bergzabern', 'en': 'Bad Bergzabern'},
 '496340':{'de': u('W\u00f6rth-Schaidt'), 'en': u('W\u00f6rth-Schaidt')},
 '496341':{'de': 'Landau in der Pfalz', 'en': 'Landau in der Pfalz'},
 '496346':{'de': 'Annweiler am Trifels', 'en': 'Annweiler am Trifels'},
 '496347':{'de': 'Hochstadt Pfalz', 'en': 'Hochstadt Pfalz'},
 '496344':{'de': 'Schwegenheim', 'en': 'Schwegenheim'},
 '496345':{'de': 'Albersweiler', 'en': 'Albersweiler'},
 '496348':{'de': 'Offenbach an der Queich', 'en': 'Offenbach an der Queich'},
 '496349':{'de': 'Billigheim-Ingenheim', 'en': 'Billigheim-Ingenheim'},
 '55114332':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '497305':{'de': 'Erbach Donau', 'en': 'Erbach Donau'},
 '498035':{'de': 'Raubling', 'en': 'Raubling'},
 '55114331':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114462':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114463':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114461':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55112516':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114468':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114469':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '492045':{'de': 'Bottrop-Kirchhellen', 'en': 'Bottrop-Kirchhellen'},
 '497564':{'de': 'Bad Wurzach', 'en': 'Bad Wurzach'},
 '497567':{'de': 'Leutkirch-Friesenhofen', 'en': 'Leutkirch-Friesenhofen'},
 '497566':{'de': u('Argenb\u00fchl'), 'en': u('Argenb\u00fchl')},
 '492041':{'de': 'Bottrop', 'en': 'Bottrop'},
 '492043':{'de': 'Gladbeck', 'en': 'Gladbeck'},
 '497562':{'de': u('Isny im Allg\u00e4u'), 'en': u('Isny im Allg\u00e4u')},
 '497569':{'de': 'Isny-Eisenbach', 'en': 'Isny-Eisenbach'},
 '497568':{'de': 'Bad Wurzach-Hauerz', 'en': 'Bad Wurzach-Hauerz'},
 '493641':{'de': 'Jena', 'en': 'Jena'},
 '493643':{'de': u('Weimar Th\u00fcringen'), 'en': u('Weimar Th\u00fcringen')},
 '493644':{'de': 'Apolda', 'en': 'Apolda'},
 '493647':{'de': u('P\u00f6\u00dfneck'), 'en': u('P\u00f6ssneck')},
 '5042564':{'en': u('San Pedro Sula, Cort\u00e9s')},
 '441760':{'en': 'Swaffham'},
 '441761':{'en': 'Temple Cloud'},
 '494269':{'de': 'Ahausen-Kirchwalsede', 'en': 'Ahausen-Kirchwalsede'},
 '494268':{'de': u('B\u00f6tersen'), 'en': u('B\u00f6tersen')},
 '441764':{'en': 'Crieff'},
 '441765':{'en': 'Ripon'},
 '441766':{'en': 'Porthmadog'},
 '441767':{'en': 'Sandy'},
 '494263':{'de': 'Scheessel', 'en': 'Scheessel'},
 '494262':{'de': u('Visselh\u00f6vede'), 'en': u('Visselh\u00f6vede')},
 '494261':{'de': u('Rotenburg W\u00fcmme'), 'en': u('Rotenburg W\u00fcmme')},
 '494260':{'de': u('Visselh\u00f6vede-Wittorf'), 'en': u('Visselh\u00f6vede-Wittorf')},
 '494267':{'de': u('Lauenbr\u00fcck'), 'en': u('Lauenbr\u00fcck')},
 '494266':{'de': 'Brockel', 'en': 'Brockel'},
 '494265':{'de': 'Fintel', 'en': 'Fintel'},
 '494264':{'de': 'Sottrum Kreis Rotenburg', 'en': 'Sottrum Kreis Rotenburg'},
 '55133209':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133208':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '496190':{'de': 'Hattersheim am Main', 'en': 'Hattersheim am Main'},
 '55133201':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133203':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133202':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '497303':{'de': 'Illertissen', 'en': 'Illertissen'},
 '52478':{'en': 'Calera Victor Rosales, ZAC', 'es': 'Calera Victor Rosales, ZAC'},
 '52477':{'en': 'Leon, GTO', 'es': u('Le\u00f3n, GTO')},
 '52476':{'en': 'San Francisco Del Rincon, GTO', 'es': u('San Francisco del Rinc\u00f3n, GTO')},
 '52475':{'en': 'Bajio de San Jose/Encarnacion de Diaz, JAL', 'es': u('Baj\u00edo de San Jos\u00e9/Encarnaci\u00f3n de Diaz, JAL')},
 '52474':{'en': 'Lagos de Moreno/Paso de Cuarenta, JAL', 'es': 'Lagos de Moreno/Paso de Cuarenta, JAL'},
 '52473':{'en': 'Guanajuato, GTO', 'es': 'Guanajuato, GTO'},
 '52472':{'en': 'Silao, GTO', 'es': 'Silao, GTO'},
 '52471':{'en': 'Purepero/Tlazazalca, MICH', 'es': 'Purepero/Tlazazalca, MICH'},
 '55112618':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115934':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115933':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112612':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115931':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112610':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '49591':{'de': 'Lingen (Ems)', 'en': 'Lingen (Ems)'},
 '441353':{'en': 'Ely'},
 '441352':{'en': 'Mold'},
 '441355':{'en': 'East Kilbride'},
 '441354':{'en': 'Chatteris'},
 '441357':{'en': 'Strathaven'},
 '441356':{'en': 'Brechin'},
 '441359':{'en': 'Pakenham'},
 '441358':{'en': 'Ellon'},
 '499529':{'de': 'Oberaurach', 'en': 'Oberaurach'},
 '55112921':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49214':{'de': 'Leverkusen', 'en': 'Leverkusen'},
 '55112928':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112997':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112998':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499251':{'de': u('M\u00fcnchberg'), 'en': u('M\u00fcnchberg')},
 '49375':{'de': 'Zwickau', 'en': 'Zwickau'},
 '499253':{'de': 'Weissenstadt', 'en': 'Weissenstadt'},
 '499252':{'de': 'Helmbrechts', 'en': 'Helmbrechts'},
 '499255':{'de': 'Marktleugast', 'en': 'Marktleugast'},
 '49371':{'de': 'Chemnitz Sachsen', 'en': 'Chemnitz Sachsen'},
 '499257':{'de': 'Zell Oberfranken', 'en': 'Zell Oberfranken'},
 '499256':{'de': 'Stammbach', 'en': 'Stammbach'},
 '55113698':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113699':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113692':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113693':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113694':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113695':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113696':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113697':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '49212':{'de': 'Solingen', 'en': 'Solingen'},
 '4939772':{'de': u('Rothem\u00fchl'), 'en': u('Rothem\u00fchl')},
 '4939773':{'de': 'Altwarp', 'en': 'Altwarp'},
 '441977':{'en': 'Pontefract'},
 '4939771':{'de': u('Ueckerm\u00fcnde'), 'en': u('Ueckerm\u00fcnde')},
 '4939776':{'de': 'Hintersee', 'en': 'Hintersee'},
 '4939777':{'de': 'Borkenfriede', 'en': 'Borkenfriede'},
 '4939774':{'de': u('M\u00f6nkebude'), 'en': u('M\u00f6nkebude')},
 '4939775':{'de': 'Ahlbeck bei Torgelow', 'en': 'Ahlbeck bei Torgelow'},
 '4939778':{'de': 'Ferdinandshof bei Torgelow', 'en': 'Ferdinandshof bei Torgelow'},
 '4939779':{'de': 'Eggesin', 'en': 'Eggesin'},
 '441978':{'en': 'Wrexham'},
 '55113198':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '5331':{'en': 'Las Tunas Province'},
 '496429':{'de': 'Schweinsberg Hessen', 'en': 'Schweinsberg Hessen'},
 '496428':{'de': 'Stadtallendorf', 'en': 'Stadtallendorf'},
 '496423':{'de': 'Wetter Hessen', 'en': 'Wetter Hessen'},
 '496422':{'de': 'Kirchhain', 'en': 'Kirchhain'},
 '496421':{'de': 'Marburg', 'en': 'Marburg'},
 '496420':{'de': 'Lahntal', 'en': 'Lahntal'},
 '496427':{'de': u('C\u00f6lbe-Sch\u00f6nstadt'), 'en': u('C\u00f6lbe-Sch\u00f6nstadt')},
 '496426':{'de': 'Fronhausen', 'en': 'Fronhausen'},
 '496425':{'de': 'Rauschenberg Hessen', 'en': 'Rauschenberg Hessen'},
 '496424':{'de': 'Ebsdorfergrund', 'en': 'Ebsdorfergrund'},
 '498846':{'de': 'Uffing am Staffelsee', 'en': 'Uffing am Staffelsee'},
 '55113528':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113529':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113526':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113527':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113524':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542927':{'en': u('M\u00e9danos, Buenos Aires'), 'es': u('M\u00e9danos, Buenos Aires')},
 '55113523':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113521':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543466':{'en': 'Barrancas, Santa Fe', 'es': 'Barrancas, Santa Fe'},
 '492452':{'de': 'Heinsberg Rheinland', 'en': 'Heinsberg Rheinland'},
 '543464':{'en': 'Casilda, Santa Fe', 'es': 'Casilda, Santa Fe'},
 '543465':{'en': 'Firmat, Santa Fe', 'es': 'Firmat, Santa Fe'},
 '543462':{'en': 'Venado Tuerto, Santa Fe', 'es': 'Venado Tuerto, Santa Fe'},
 '543463':{'en': u('Canals, C\u00f3rdoba'), 'es': u('Canals, C\u00f3rdoba')},
 '543460':{'en': 'Santa Teresa, Santa Fe', 'es': 'Santa Teresa, Santa Fe'},
 '492453':{'de': 'Heinsberg-Randerath', 'en': 'Heinsberg-Randerath'},
 '543468':{'en': u('Corral de Bustos, C\u00f3rdoba'), 'es': u('Corral de Bustos, C\u00f3rdoba')},
 '543469':{'en': 'Acebal, Santa Fe', 'es': 'Acebal, Santa Fe'},
 '4938797':{'de': u('Karst\u00e4dt Kreis Prignitz'), 'en': u('Karst\u00e4dt Kreis Prignitz')},
 '4938796':{'de': 'Viesecke', 'en': 'Viesecke'},
 '4938794':{'de': 'Cumlosen', 'en': 'Cumlosen'},
 '4938793':{'de': 'Dergenthin', 'en': 'Dergenthin'},
 '4938792':{'de': 'Lenzen (Elbe)', 'en': 'Lenzen (Elbe)'},
 '4938791':{'de': 'Bad Wilsnack', 'en': 'Bad Wilsnack'},
 '492456':{'de': 'Selfkant', 'en': 'Selfkant'},
 '492454':{'de': 'Gangelt', 'en': 'Gangelt'},
 '46414':{'en': 'Simrishamn', 'sv': 'Simrishamn'},
 '492455':{'de': 'Waldfeucht', 'en': 'Waldfeucht'},
 '46415':{'en': u('H\u00f6rby'), 'sv': u('H\u00f6rby')},
 '495082':{'de': 'Langlingen', 'en': 'Langlingen'},
 '495083':{'de': 'Hohne bei Celle', 'en': 'Hohne bei Celle'},
 '495084':{'de': u('Hamb\u00fchren'), 'en': u('Hamb\u00fchren')},
 '495085':{'de': 'Burgdorf-Ehlershausen', 'en': 'Burgdorf-Ehlershausen'},
 '495086':{'de': 'Celle-Scheuen', 'en': 'Celle-Scheuen'},
 '499927':{'de': 'Kirchberg Wald', 'en': 'Kirchberg Wald'},
 '495734':{'de': 'Bergkirchen Westfalen', 'en': 'Bergkirchen Westfalen'},
 '46417':{'en': 'Tomelilla', 'sv': 'Tomelilla'},
 '495732':{'de': u('L\u00f6hne'), 'en': u('L\u00f6hne')},
 '495733':{'de': 'Vlotho', 'en': 'Vlotho'},
 '495731':{'de': 'Bad Oeynhausen', 'en': 'Bad Oeynhausen'},
 '498564':{'de': 'Johanniskirchen', 'en': 'Johanniskirchen'},
 '496287':{'de': 'Limbach Baden', 'en': 'Limbach Baden'},
 '496286':{'de': u('Walld\u00fcrn-Rippberg'), 'en': u('Walld\u00fcrn-Rippberg')},
 '496285':{'de': u('Walld\u00fcrn-Altheim'), 'en': u('Walld\u00fcrn-Altheim')},
 '496284':{'de': 'Mudau', 'en': 'Mudau'},
 '496283':{'de': 'Hardheim Odenwald', 'en': 'Hardheim Odenwald'},
 '496282':{'de': u('Walld\u00fcrn'), 'en': u('Walld\u00fcrn')},
 '496281':{'de': 'Buchen Odenwald', 'en': 'Buchen Odenwald'},
 '4938423':{'de': 'Bad Kleinen', 'en': 'Bad Kleinen'},
 '4938422':{'de': 'Neukloster', 'en': 'Neukloster'},
 '4938425':{'de': 'Kirchdorf Poel', 'en': 'Kirchdorf Poel'},
 '4938424':{'de': 'Bobitz', 'en': 'Bobitz'},
 '4938427':{'de': 'Blowatz', 'en': 'Blowatz'},
 '4938426':{'de': 'Neuburg-Steinhausen', 'en': 'Neuburg-Steinhausen'},
 '4938429':{'de': 'Glasin', 'en': 'Glasin'},
 '4938428':{'de': 'Hohenkirchen bei Wismar', 'en': 'Hohenkirchen bei Wismar'},
 '497573':{'de': 'Stetten am kalten Markt', 'en': 'Stetten am kalten Markt'},
 '498561':{'de': 'Pfarrkirchen Niederbayern', 'en': 'Pfarrkirchen Niederbayern'},
 '498562':{'de': 'Triftern', 'en': 'Triftern'},
 '497771':{'de': 'Stockach', 'en': 'Stockach'},
 '497773':{'de': 'Bodman-Ludwigshafen', 'en': 'Bodman-Ludwigshafen'},
 '497774':{'de': 'Eigeltingen', 'en': 'Eigeltingen'},
 '497775':{'de': u('M\u00fchlingen'), 'en': u('M\u00fchlingen')},
 '497777':{'de': 'Sauldorf', 'en': 'Sauldorf'},
 '499567':{'de': u('Se\u00dflach-Gem\u00fcnda'), 'en': u('Sesslach-Gem\u00fcnda')},
 '499925':{'de': 'Bayerisch Eisenstein', 'en': 'Bayerisch Eisenstein'},
 '499566':{'de': 'Meeder', 'en': 'Meeder'},
 '495552':{'de': 'Katlenburg', 'en': 'Katlenburg'},
 '495553':{'de': 'Kalefeld', 'en': 'Kalefeld'},
 '495882':{'de': 'Gorleben', 'en': 'Gorleben'},
 '495883':{'de': 'Lemgow', 'en': 'Lemgow'},
 '495556':{'de': 'Lindau Harz', 'en': 'Lindau Harz'},
 '499565':{'de': 'Untersiemau', 'en': 'Untersiemau'},
 '495554':{'de': 'Moringen', 'en': 'Moringen'},
 '495555':{'de': 'Moringen-Fredelsloh', 'en': 'Moringen-Fredelsloh'},
 '495761':{'de': 'Stolzenau', 'en': 'Stolzenau'},
 '499564':{'de': 'Bad Rodach', 'en': 'Bad Rodach'},
 '495763':{'de': 'Uchte', 'en': 'Uchte'},
 '497482':{'de': 'Horb-Dettingen', 'en': 'Horb-Dettingen'},
 '497483':{'de': u('Horb-M\u00fchringen'), 'en': u('Horb-M\u00fchringen')},
 '497486':{'de': 'Horb-Altheim', 'en': 'Horb-Altheim'},
 '499561':{'de': 'Coburg', 'en': 'Coburg'},
 '497484':{'de': 'Simmersfeld', 'en': 'Simmersfeld'},
 '497485':{'de': 'Empfingen', 'en': 'Empfingen'},
 '495765':{'de': 'Raddestorf', 'en': 'Raddestorf'},
 '499560':{'de': 'Grub am Forst', 'en': 'Grub am Forst'},
 '495764':{'de': 'Steyerberg', 'en': 'Steyerberg'},
 '4933767':{'de': 'Friedersdorf bei Berlin', 'en': 'Friedersdorf bei Berlin'},
 '4933766':{'de': 'Teupitz', 'en': 'Teupitz'},
 '4933765':{'de': u('M\u00e4rkisch Buchholz'), 'en': u('M\u00e4rkisch Buchholz')},
 '4933764':{'de': 'Mittenwalde Mark', 'en': 'Mittenwalde Mark'},
 '4933763':{'de': 'Bestensee', 'en': 'Bestensee'},
 '4933762':{'de': 'Zeuthen', 'en': 'Zeuthen'},
 '4933760':{'de': u('M\u00fcnchehofe Kreis Dahme-Spreewald'), 'en': u('M\u00fcnchehofe Kreis Dahme-Spreewald')},
 '55115693':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495766':{'de': 'Rehburg-Loccum', 'en': 'Rehburg-Loccum'},
 '55115696':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933769':{'de': u('T\u00f6pchin'), 'en': u('T\u00f6pchin')},
 '4933768':{'de': 'Prieros', 'en': 'Prieros'},
 '499923':{'de': 'Teisnach', 'en': 'Teisnach'},
 '499922':{'de': 'Zwiesel', 'en': 'Zwiesel'},
 '435550':{'de': u('Th\u00fcringen'), 'en': u('Th\u00fcringen')},
 '435552':{'de': 'Bludenz', 'en': 'Bludenz'},
 '435553':{'de': 'Raggal', 'en': 'Raggal'},
 '435554':{'de': 'Sonntag', 'en': 'Sonntag'},
 '52861':{'en': 'Nueva Rosita/Sabinas, COAH', 'es': 'Nueva Rosita/Sabinas, COAH'},
 '435556':{'de': 'Schruns', 'en': 'Schruns'},
 '435557':{'de': 'Sankt Gallenkirch', 'en': 'St. Gallenkirch'},
 '435558':{'de': 'Gaschurn', 'en': 'Gaschurn'},
 '435559':{'de': 'Brand', 'en': 'Brand'},
 '52868':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '52869':{'en': 'Cuatro Cienegas/San Buenaventura, COAH', 'es': u('Cuatro Ci\u00e9negas/San Buenaventura, COAH')},
 '497954':{'de': 'Kirchberg an der Jagst', 'en': 'Kirchberg an der Jagst'},
 '497955':{'de': u('Wallhausen W\u00fcrttemberg'), 'en': u('Wallhausen W\u00fcrttemberg')},
 '497957':{'de': 'Kressberg', 'en': 'Kressberg'},
 '497950':{'de': 'Schnelldorf', 'en': 'Schnelldorf'},
 '497951':{'de': 'Crailsheim', 'en': 'Crailsheim'},
 '497952':{'de': 'Gerabronn', 'en': 'Gerabronn'},
 '497953':{'de': 'Blaufelden', 'en': 'Blaufelden'},
 '499920':{'de': 'Bischofsmais', 'en': 'Bischofsmais'},
 '497958':{'de': 'Rot Am See-Brettheim', 'en': 'Rot Am See-Brettheim'},
 '4418900':{'en': 'Coldstream/Ayton'},
 '55113206':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4732':{'en': 'Buskerud'},
 '4733':{'en': 'Vestfold'},
 '498283':{'de': 'Neuburg an der Kammel', 'en': 'Neuburg an der Kammel'},
 '4731':{'en': 'Buskerud'},
 '498285':{'de': 'Burtenbach', 'en': 'Burtenbach'},
 '4737':{'en': 'Aust-Agder'},
 '4734':{'en': 'Vestfold'},
 '4735':{'en': 'Telemark'},
 '4738':{'en': 'Vest-Agder'},
 '494859':{'de': 'Windbergen', 'en': 'Windbergen'},
 '55113063':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4654':{'en': 'Karlstad', 'sv': 'Karlstad'},
 '55113061':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113060':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113067':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113066':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113065':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113064':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52392':{'en': 'Jamay/Ocotlan, JAL', 'es': u('Jamay/Ocotl\u00e1n, JAL')},
 '52393':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52391':{'en': 'Jalisco', 'es': 'Jalisco'},
 '494856':{'de': 'Kronprinzenkoog', 'en': 'Kronprinzenkoog'},
 '52394':{'en': 'Cotija de la Paz, MICH', 'es': 'Cotija de la Paz, MICH'},
 '52395':{'en': 'Jalisco', 'es': 'Jalisco'},
 '494857':{'de': 'Barlt', 'en': 'Barlt'},
 '499732':{'de': 'Hammelburg', 'en': 'Hammelburg'},
 '437585':{'de': 'Klaus an der Pyhrnbahn', 'en': 'Klaus an der Pyhrnbahn'},
 '499736':{'de': 'Oberthulba', 'en': 'Oberthulba'},
 '499737':{'de': 'Wartmannsroth', 'en': 'Wartmannsroth'},
 '499734':{'de': 'Burkardroth', 'en': 'Burkardroth'},
 '499735':{'de': 'Massbach', 'en': 'Massbach'},
 '499738':{'de': 'Rottershausen', 'en': 'Rottershausen'},
 '437587':{'de': 'Wartberg an der Krems', 'en': 'Wartberg an der Krems'},
 '52641':{'en': 'Benjamin Hill/Santa Ana, SON', 'es': u('Benjam\u00edn Hill/Santa Ana, SON')},
 '52642':{'en': 'Navojoa/Pueblo Mayo, SON', 'es': 'Navojoa/Pueblo Mayo, SON'},
 '437586':{'de': 'Pettenbach', 'en': 'Pettenbach'},
 '52644':{'en': 'Sonora', 'es': 'Sonora'},
 '52645':{'en': 'Cananea, SON', 'es': 'Cananea, SON'},
 '52646':{'en': 'Baja California', 'es': 'Baja California'},
 '52647':{'en': 'Sonora', 'es': 'Sonora'},
 '52648':{'en': 'Boquilla/Ciudad Camargo, CHIH', 'es': 'Boquilla/Ciudad Camargo, CHIH'},
 '52649':{'en': 'Chihuahua/Durango', 'es': 'Chihuahua/Durango'},
 '442897':{'en': 'Saintfield'},
 '442896':{'en': 'Belfast'},
 '442895':{'en': 'Belfast'},
 '442894':{'en': 'Antrim'},
 '442893':{'en': 'Ballyclare'},
 '442892':{'en': 'Lisburn'},
 '442891':{'en': 'Bangor (Co. Down)'},
 '442890':{'en': 'Belfast'},
 '492856':{'de': u('Hamminkeln-Br\u00fcnen'), 'en': u('Hamminkeln-Br\u00fcnen')},
 '492857':{'de': 'Rees-Mehr', 'en': 'Rees-Mehr'},
 '492855':{'de': 'Voerde Niederrhein', 'en': 'Voerde Niederrhein'},
 '492852':{'de': 'Hamminkeln', 'en': 'Hamminkeln'},
 '492853':{'de': 'Schermbeck', 'en': 'Schermbeck'},
 '492850':{'de': 'Rees-Haldern', 'en': 'Rees-Haldern'},
 '442898':{'en': 'Belfast'},
 '46640':{'en': 'Krokom', 'sv': 'Krokom'},
 '46643':{'en': 'Hallen-Oviken', 'sv': 'Hallen-Oviken'},
 '46642':{'en': 'Lit', 'sv': 'Lit'},
 '46645':{'en': u('F\u00f6llinge'), 'sv': u('F\u00f6llinge')},
 '46644':{'en': 'Hammerdal', 'sv': 'Hammerdal'},
 '46647':{'en': u('\u00c5re-J\u00e4rpen'), 'sv': u('\u00c5re-J\u00e4rpen')},
 '494707':{'de': 'Langen-Neuenwalde', 'en': 'Langen-Neuenwalde'},
 '494708':{'de': 'Ringstedt', 'en': 'Ringstedt'},
 '499085':{'de': 'Alerheim', 'en': 'Alerheim'},
 '499086':{'de': 'Fremdingen', 'en': 'Fremdingen'},
 '499087':{'de': 'Marktoffingen', 'en': 'Marktoffingen'},
 '499080':{'de': 'Harburg Schwaben', 'en': 'Harburg Schwaben'},
 '499081':{'de': u('N\u00f6rdlingen'), 'en': u('N\u00f6rdlingen')},
 '499082':{'de': 'Oettingen in Bayern', 'en': 'Oettingen in Bayern'},
 '499083':{'de': u('M\u00f6ttingen'), 'en': u('M\u00f6ttingen')},
 '4418908':{'en': 'Coldstream'},
 '55133473':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '4938308':{'de': u('G\u00f6hren R\u00fcgen'), 'en': u('G\u00f6hren R\u00fcgen')},
 '4938309':{'de': 'Trent', 'en': 'Trent'},
 '4938300':{'de': 'Insel Hiddensee', 'en': 'Insel Hiddensee'},
 '4938301':{'de': 'Putbus', 'en': 'Putbus'},
 '4938302':{'de': 'Sagard', 'en': 'Sagard'},
 '4938303':{'de': 'Sellin Ostseebad', 'en': 'Sellin Ostseebad'},
 '4938304':{'de': u('Garz R\u00fcgen'), 'en': u('Garz R\u00fcgen')},
 '4938305':{'de': 'Gingst', 'en': 'Gingst'},
 '4938306':{'de': 'Samtens', 'en': 'Samtens'},
 '4938307':{'de': 'Poseritz', 'en': 'Poseritz'},
 '55112558':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112559':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112551':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112552':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4939007':{'de': 'Tangeln', 'en': 'Tangeln'},
 '55112554':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112555':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112556':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112557':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113258':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49781':{'de': 'Offenburg', 'en': 'Offenburg'},
 '55115508':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113259':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115670':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115509':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115971':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112226':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112227':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115504':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112225':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115975':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497444':{'de': 'Alpirsbach', 'en': 'Alpirsbach'},
 '437729':{'de': 'Neukirchen an der Enknach', 'en': 'Neukirchen an der Enknach'},
 '437728':{'de': 'Schwand im Innkreis', 'en': 'Schwand im Innkreis'},
 '437724':{'de': 'Mauerkirchen', 'en': 'Mauerkirchen'},
 '437727':{'de': 'Ach', 'en': 'Ach'},
 '55112221':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437723':{'de': 'Altheim', 'en': 'Altheim'},
 '437722':{'de': 'Braunau am Inn', 'en': 'Braunau am Inn'},
 '543786':{'en': u('Ituzaing\u00f3, Corrientes'), 'es': u('Ituzaing\u00f3, Corrientes')},
 '55113253':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543782':{'en': 'Saladas, Corrientes', 'es': 'Saladas, Corrientes'},
 '543781':{'en': u('Ca\u00e1 Cat\u00ed, Corrientes'), 'es': u('Ca\u00e1 Cat\u00ed, Corrientes')},
 '497445':{'de': 'Pfalzgrafenweiler', 'en': 'Pfalzgrafenweiler'},
 '55113706':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113707':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55124159':{'en': 'Vargem Grande Paulista - SP', 'pt': 'Vargem Grande Paulista - SP'},
 '55124158':{'en': 'Vargem Grande Paulista - SP', 'pt': 'Vargem Grande Paulista - SP'},
 '55113037':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113704':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123125':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55113705':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '495945':{'de': 'Wilsum', 'en': 'Wilsum'},
 '495944':{'de': 'Hoogstede', 'en': 'Hoogstede'},
 '495947':{'de': 'Laar Vechte', 'en': 'Laar Vechte'},
 '495946':{'de': 'Georgsdorf', 'en': 'Georgsdorf'},
 '495941':{'de': 'Neuenhaus Dinkel', 'en': 'Neuenhaus Dinkel'},
 '495943':{'de': 'Emlichheim', 'en': 'Emlichheim'},
 '495942':{'de': 'Uelsen', 'en': 'Uelsen'},
 '495948':{'de': 'Itterbeck', 'en': 'Itterbeck'},
 '55123878':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123876':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55114899':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '496364':{'de': u('Nu\u00dfbach Pfalz'), 'en': 'Nussbach Pfalz'},
 '55114892':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55114891':{'en': u('Bom Jesus dos Perd\u00f5es - SP'), 'pt': u('Bom Jesus dos Perd\u00f5es - SP')},
 '55114897':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '496361':{'de': 'Rockenhausen', 'en': 'Rockenhausen'},
 '496362':{'de': 'Alsenz', 'en': 'Alsenz'},
 '496363':{'de': 'Niederkirchen', 'en': 'Niederkirchen'},
 '497440':{'de': 'Bad Rippoldsau', 'en': 'Bad Rippoldsau'},
 '55115676':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497441':{'de': 'Freudenstadt', 'en': 'Freudenstadt'},
 '4935435':{'de': 'Gollmitz bei Calau', 'en': 'Gollmitz bei Calau'},
 '4935434':{'de': u('Altd\u00f6bern'), 'en': u('Altd\u00f6bern')},
 '4935436':{'de': 'Laasow bei Calau', 'en': 'Laasow bei Calau'},
 '55114408':{'en': 'Cajamar - SP', 'pt': 'Cajamar - SP'},
 '55114409':{'en': u('Jacar\u00e9 - SP'), 'pt': u('Jacar\u00e9 - SP')},
 '4935433':{'de': 'Vetschau', 'en': 'Vetschau'},
 '55114405':{'en': 'Piracaia - SP', 'pt': 'Piracaia - SP'},
 '4935439':{'de': 'Zinnitz', 'en': 'Zinnitz'},
 '55114402':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114403':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '542226':{'en': u('Ca\u00f1uelas, Buenos Aires'), 'es': u('Ca\u00f1uelas, Buenos Aires')},
 '492066':{'de': 'Duisburg-Homberg', 'en': 'Duisburg-Homberg'},
 '492065':{'de': 'Duisburg-Rheinhausen', 'en': 'Duisburg-Rheinhausen'},
 '492064':{'de': 'Dinslaken', 'en': 'Dinslaken'},
 '497543':{'de': 'Kressbronn am Bodensee', 'en': 'Kressbronn am Bodensee'},
 '497542':{'de': 'Tettnang', 'en': 'Tettnang'},
 '497541':{'de': 'Friedrichshafen', 'en': 'Friedrichshafen'},
 '498638':{'de': 'Waldkraiburg', 'en': 'Waldkraiburg'},
 '498639':{'de': 'Neumarkt-Sankt Veit', 'en': 'Neumarkt-Sankt Veit'},
 '493628':{'de': 'Arnstadt', 'en': 'Arnstadt'},
 '493629':{'de': 'Stadtilm', 'en': 'Stadtilm'},
 '493622':{'de': u('Waltershausen Th\u00fcringen'), 'en': u('Waltershausen Th\u00fcringen')},
 '493623':{'de': 'Friedrichroda', 'en': 'Friedrichroda'},
 '493621':{'de': u('Gotha Th\u00fcringen'), 'en': u('Gotha Th\u00fcringen')},
 '498634':{'de': 'Garching an der Alz', 'en': 'Garching an der Alz'},
 '498635':{'de': 'Pleiskirchen', 'en': 'Pleiskirchen'},
 '493624':{'de': 'Ohrdruf', 'en': 'Ohrdruf'},
 '498637':{'de': 'Lohkirchen', 'en': 'Lohkirchen'},
 '494936':{'de': 'Grossheide', 'en': 'Grossheide'},
 '494935':{'de': 'Juist', 'en': 'Juist'},
 '494934':{'de': 'Marienhafe', 'en': 'Marienhafe'},
 '494933':{'de': 'Dornum Ostfriesland', 'en': 'Dornum Ostfriesland'},
 '494932':{'de': 'Norderney', 'en': 'Norderney'},
 '494931':{'de': 'Norden', 'en': 'Norden'},
 '494939':{'de': 'Baltrum', 'en': 'Baltrum'},
 '494938':{'de': 'Hagermarsch', 'en': 'Hagermarsch'},
 '441708':{'en': 'Romford'},
 '441709':{'en': 'Rotherham'},
 '441702':{'en': 'Southend-on-Sea'},
 '46121':{'en': u('S\u00f6derk\u00f6ping'), 'sv': u('S\u00f6derk\u00f6ping')},
 '441700':{'en': 'Rothesay'},
 '46123':{'en': 'Valdemarsvik', 'sv': 'Valdemarsvik'},
 '441706':{'en': 'Rochdale'},
 '46125':{'en': 'Vikbolandet', 'sv': 'Vikbolandet'},
 '441704':{'en': 'Southport'},
 '55133269':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55112895':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133261':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55132138':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '4939971':{'de': 'Gnoien', 'en': 'Gnoien'},
 '4939972':{'de': 'Walkendorf', 'en': 'Walkendorf'},
 '4939973':{'de': 'Altkalen', 'en': 'Altkalen'},
 '4939975':{'de': u('Th\u00fcrkow'), 'en': u('Th\u00fcrkow')},
 '4939976':{'de': u('Gro\u00df B\u00fctzin'), 'en': u('Gross B\u00fctzin')},
 '4939977':{'de': u('J\u00f6rdenstorf'), 'en': u('J\u00f6rdenstorf')},
 '4939978':{'de': 'Gross Roge', 'en': 'Gross Roge'},
 '4934745':{'de': 'Winningen Sachsen-Anhalt', 'en': 'Winningen Sachsen-Anhalt'},
 '4934746':{'de': 'Giersleben', 'en': 'Giersleben'},
 '4934741':{'de': 'Frose', 'en': 'Frose'},
 '4934742':{'de': 'Sylda', 'en': 'Sylda'},
 '4934743':{'de': 'Ermsleben', 'en': 'Ermsleben'},
 '497257':{'de': 'Bruchsal-Untergrombach', 'en': 'Bruchsal-Untergrombach'},
 '441350':{'en': 'Dunkeld'},
 '55112472':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112635':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112634':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112636':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112631':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112471':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112633':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112632':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '5042407':{'en': 'Roatan, Bay Islands'},
 '441379':{'en': 'Diss'},
 '55113842':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441373':{'en': 'Frome'},
 '441372':{'en': 'Esher'},
 '441371':{'en': 'Great Dunmow'},
 '441377':{'en': 'Driffield'},
 '441376':{'en': 'Braintree'},
 '441375':{'en': 'Grays Thurrock'},
 '49571':{'de': 'Minden Westfalen', 'en': 'Minden Westfalen'},
 '55123687':{'en': 'Quiririm - SP', 'pt': 'Quiririm - SP'},
 '499648':{'de': 'Neustadt am Kulm', 'en': 'Neustadt am Kulm'},
 '55113662':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123681':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '4936428':{'de': 'Stadtroda', 'en': 'Stadtroda'},
 '55123682':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '4936423':{'de': u('Orlam\u00fcnde'), 'en': u('Orlam\u00fcnde')},
 '4936422':{'de': u('Reinst\u00e4dt Th\u00fcringen'), 'en': u('Reinst\u00e4dt Th\u00fcringen')},
 '4936421':{'de': 'Camburg', 'en': 'Camburg'},
 '4936427':{'de': 'Dornburg Saale', 'en': 'Dornburg Saale'},
 '4936426':{'de': 'Ottendorf bei Stadtroda', 'en': 'Ottendorf bei Stadtroda'},
 '4936425':{'de': 'Isserstedt', 'en': 'Isserstedt'},
 '4936424':{'de': u('Kahla Th\u00fcringen'), 'en': u('Kahla Th\u00fcringen')},
 '499273':{'de': 'Bad Berneck im Fichtelgebirge', 'en': 'Bad Berneck im Fichtelgebirge'},
 '499272':{'de': 'Fichtelberg', 'en': 'Fichtelberg'},
 '499271':{'de': 'Thurnau-Alladorf', 'en': 'Thurnau-Alladorf'},
 '499270':{'de': 'Creussen', 'en': 'Creussen'},
 '499277':{'de': 'Warmensteinach', 'en': 'Warmensteinach'},
 '496586':{'de': 'Beuren Hochwald', 'en': 'Beuren Hochwald'},
 '499275':{'de': 'Speichersdorf', 'en': 'Speichersdorf'},
 '499274':{'de': 'Hollfeld', 'en': 'Hollfeld'},
 '499279':{'de': 'Mistelgau', 'en': 'Mistelgau'},
 '496239':{'de': 'Bobenheim-Roxheim', 'en': 'Bobenheim-Roxheim'},
 '55112949':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112948':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496588':{'de': 'Pluwig', 'en': 'Pluwig'},
 '496589':{'de': 'Kell am See', 'en': 'Kell am See'},
 '499905':{'de': 'Bernried Niederbayern', 'en': 'Bernried Niederbayern'},
 '499904':{'de': 'Lalling', 'en': 'Lalling'},
 '441959':{'en': 'Westerham'},
 '441957':{'en': 'Mid Yell'},
 '441955':{'en': 'Wick'},
 '441954':{'en': 'Madingley'},
 '441953':{'en': 'Wymondham'},
 '441952':{'en': 'Telford'},
 '441951':{'en': 'Colonsay'},
 '441950':{'en': 'Sandwick'},
 '55113544':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499907':{'de': 'Zenting', 'en': 'Zenting'},
 '55113546':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115851':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113541':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113542':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113543':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113334':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113548':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113549':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498734':{'de': 'Reisbach Niederbayern', 'en': 'Reisbach Niederbayern'},
 '55112499':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112498':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112490':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55112493':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55112492':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112497':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112496':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55114093':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '543442':{'en': u('Concepci\u00f3n del Uruguay, Entre R\u00edos'), 'es': u('Concepci\u00f3n del Uruguay, Entre R\u00edos')},
 '543444':{'en': u('Gualeguay, Entre R\u00edos'), 'es': u('Gualeguay, Entre R\u00edos')},
 '543445':{'en': u('Rosario del Tala, Entre R\u00edos'), 'es': u('Rosario del Tala, Entre R\u00edos')},
 '543446':{'en': u('Gualeguaych\u00fa, Entre R\u00edos'), 'es': u('Gualeguaych\u00fa, Entre R\u00edos')},
 '543447':{'en': u('Col\u00f3n, Entre R\u00edos'), 'es': u('Col\u00f3n, Entre R\u00edos')},
 '55114794':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '543857':{'en': 'Bandera, Santiago del Estero', 'es': 'Bandera, Santiago del Estero'},
 '55114796':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114797':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114790':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114091':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114792':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '543856':{'en': 'Villa Ojo de Agua, Santiago del Estero', 'es': 'Villa Ojo de Agua, Santiago del Estero'},
 '4937464':{'de': u('Sch\u00f6neck Vogtland'), 'en': u('Sch\u00f6neck Vogtland')},
 '4937465':{'de': 'Tannenbergsthal Vogtland', 'en': 'Tannenbergsthal Vogtland'},
 '4937467':{'de': 'Klingenthal Sachsen', 'en': 'Klingenthal Sachsen'},
 '543855':{'en': 'Suncho Corral, Santiago del Estero', 'es': 'Suncho Corral, Santiago del Estero'},
 '4937462':{'de': 'Rothenkirchen Vogtland', 'en': 'Rothenkirchen Vogtland'},
 '4937463':{'de': 'Bergen Vogtland', 'en': 'Bergen Vogtland'},
 '4937468':{'de': 'Treuen Vogtland', 'en': 'Treuen Vogtland'},
 '55114096':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114094':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '4936849':{'de': 'Kleinschmalkalden', 'en': 'Kleinschmalkalden'},
 '4936848':{'de': 'Wernshausen', 'en': 'Wernshausen'},
 '4936845':{'de': 'Gehlberg', 'en': 'Gehlberg'},
 '4936844':{'de': u('Rohr Th\u00fcringen'), 'en': u('Rohr Th\u00fcringen')},
 '4936847':{'de': 'Steinbach-Hallenberg', 'en': 'Steinbach-Hallenberg'},
 '4936846':{'de': 'Suhl-Dietzhausen', 'en': 'Suhl-Dietzhausen'},
 '4936841':{'de': 'Schleusingen', 'en': 'Schleusingen'},
 '4936840':{'de': 'Trusetal', 'en': 'Trusetal'},
 '4936843':{'de': 'Benshausen', 'en': 'Benshausen'},
 '4936842':{'de': u('Oberhof Th\u00fcringen'), 'en': u('Oberhof Th\u00fcringen')},
 '55114098':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '499833':{'de': 'Heidenheim Mittelfranken', 'en': 'Heidenheim Mittelfranken'},
 '495574':{'de': 'Oberweser', 'en': 'Oberweser'},
 '499832':{'de': u('Wassertr\u00fcdingen'), 'en': u('Wassertr\u00fcdingen')},
 '495571':{'de': 'Uslar', 'en': 'Uslar'},
 '495572':{'de': 'Bodenfelde', 'en': 'Bodenfelde'},
 '495573':{'de': 'Uslar-Volpriehausen', 'en': 'Uslar-Volpriehausen'},
 '437664':{'de': 'Weyregg am Attersee', 'en': 'Weyregg am Attersee'},
 '55112942':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437665':{'de': 'Unterach am Attersee', 'en': 'Unterach am Attersee'},
 '55123111':{'en': 'Cunha - SP', 'pt': 'Cunha - SP'},
 '55123112':{'en': 'Potim - SP', 'pt': 'Potim - SP'},
 '437666':{'de': 'Attersee', 'en': 'Attersee'},
 '55123116':{'en': 'Bananal - SP', 'pt': 'Bananal - SP'},
 '55123117':{'en': u('S\u00e3o Jos\u00e9 do Barreiro - SP'), 'pt': u('S\u00e3o Jos\u00e9 do Barreiro - SP')},
 '441571':{'en': 'Lochinver'},
 '441570':{'en': 'Lampeter'},
 '441573':{'en': 'Kelso'},
 '441572':{'en': 'Oakham'},
 '441575':{'en': 'Kirriemuir'},
 '441577':{'en': 'Kinross'},
 '441576':{'en': 'Lockerbie'},
 '441579':{'en': 'Liskeard'},
 '441578':{'en': 'Lauder'},
 '437662':{'de': 'Seewalchen am Attersee', 'en': 'Seewalchen am Attersee'},
 '437663':{'de': 'Steinbach am Attersee', 'en': 'Steinbach am Attersee'},
 '497506':{'de': 'Wangen-Leupolz', 'en': 'Wangen-Leupolz'},
 '4933741':{'de': u('Niederg\u00f6rsdorf'), 'en': u('Niederg\u00f6rsdorf')},
 '55115671':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933743':{'de': u('Bl\u00f6nsdorf'), 'en': u('Bl\u00f6nsdorf')},
 '4933742':{'de': 'Oehna Brandenburg', 'en': 'Oehna Brandenburg'},
 '4933745':{'de': 'Petkus', 'en': 'Petkus'},
 '4933744':{'de': 'Hohenseefeld', 'en': 'Hohenseefeld'},
 '4933747':{'de': 'Marzahna', 'en': 'Marzahna'},
 '4933746':{'de': u('Werbig bei J\u00fcterbog'), 'en': u('Werbig bei J\u00fcterbog')},
 '55115678':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933748':{'de': 'Treuenbrietzen', 'en': 'Treuenbrietzen'},
 '497504':{'de': 'Horgenzell', 'en': 'Horgenzell'},
 '54297':{'en': 'Comodoro Rivadavia, Chubut', 'es': 'Comodoro Rivadavia, Chubut'},
 '496464':{'de': 'Angelburg', 'en': 'Angelburg'},
 '543862':{'en': u('Trancas, Tucum\u00e1n'), 'es': u('Trancas, Tucum\u00e1n')},
 '543863':{'en': u('Monteros, Tucum\u00e1n'), 'es': u('Monteros, Tucum\u00e1n')},
 '543861':{'en': 'Nueva Esperanza, Santiago del Estero', 'es': 'Nueva Esperanza, Santiago del Estero'},
 '543867':{'en': u('Taf\u00ed del Valle, Tucum\u00e1n'), 'es': u('Taf\u00ed del Valle, Tucum\u00e1n')},
 '543865':{'en': u('Concepci\u00f3n, Tucum\u00e1n'), 'es': u('Concepci\u00f3n, Tucum\u00e1n')},
 '543868':{'en': 'Cafayate, Salta', 'es': 'Cafayate, Salta'},
 '543869':{'en': u('Ranchillos y San Miguel, Tucum\u00e1n'), 'es': u('Ranchillos y San Miguel, Tucum\u00e1n')},
 '497259':{'de': u('\u00d6stringen-Odenheim'), 'en': u('\u00d6stringen-Odenheim')},
 '499469':{'de': u('Roding-Neub\u00e4u'), 'en': u('Roding-Neub\u00e4u')},
 '55133048':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55113906':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497258':{'de': 'Oberderdingen-Flehingen', 'en': 'Oberderdingen-Flehingen'},
 '494142':{'de': 'Steinkirchen Kreis Stade', 'en': 'Steinkirchen Kreis Stade'},
 '496007':{'de': 'Rosbach-Rodheim', 'en': 'Rosbach-Rodheim'},
 '496003':{'de': u('Rosbach von der H\u00f6he'), 'en': u('Rosbach von der H\u00f6he')},
 '496002':{'de': u('Ober-M\u00f6rlen'), 'en': u('Ober-M\u00f6rlen')},
 '496468':{'de': 'Dautphetal-Mornshausen', 'en': 'Dautphetal-Mornshausen'},
 '494140':{'de': 'Estorf Kreis Stade', 'en': 'Estorf Kreis Stade'},
 '55113907':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '492721':{'de': 'Lennestadt', 'en': 'Lennestadt'},
 '492722':{'de': 'Attendorn', 'en': 'Attendorn'},
 '492723':{'de': 'Kirchhundem', 'en': 'Kirchhundem'},
 '492724':{'de': 'Finnentrop-Serkenrode', 'en': 'Finnentrop-Serkenrode'},
 '492725':{'de': 'Lennestadt-Oedingen', 'en': 'Lennestadt-Oedingen'},
 '494146':{'de': u('Stade-B\u00fctzfleth'), 'en': u('Stade-B\u00fctzfleth')},
 '55112079':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499395':{'de': 'Triefenstein', 'en': 'Triefenstein'},
 '55112078':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '49761':{'de': 'Freiburg im Breisgau', 'en': 'Freiburg im Breisgau'},
 '499397':{'de': 'Wertheim-Dertingen', 'en': 'Wertheim-Dertingen'},
 '4419466':{'en': 'Whitehaven'},
 '4751':{'en': 'Rogaland'},
 '4752':{'en': 'Rogaland'},
 '4753':{'en': 'Hordaland'},
 '4755':{'en': 'Hordaland'},
 '4756':{'en': 'Hordaland'},
 '4757':{'en': 'Sogn og Fjordane'},
 '55112073':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112072':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113901':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112071':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113049':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4419465':{'en': 'Whitehaven'},
 '55113041':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113045':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113044':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113046':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4633':{'en': u('Bor\u00e5s'), 'sv': u('Bor\u00e5s')},
 '4414371':{'en': 'Haverfordwest/Clynderwen (Clunderwen)'},
 '4414372':{'en': 'Clynderwen (Clunderwen)'},
 '4414373':{'en': 'Clynderwen (Clunderwen)'},
 '4414374':{'en': 'Clynderwen (Clunderwen)'},
 '4414375':{'en': 'Clynderwen (Clunderwen)'},
 '4635':{'en': 'Halmstad', 'sv': 'Halmstad'},
 '4414377':{'en': 'Haverfordwest'},
 '4414378':{'en': 'Haverfordwest'},
 '4414379':{'en': 'Haverfordwest'},
 '55113902':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112074':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494892':{'de': 'Schenefeld Mittelholstein', 'en': 'Schenefeld Mittelholstein'},
 '494893':{'de': 'Hohenaspe', 'en': 'Hohenaspe'},
 '55114233':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '499868':{'de': u('Schillingsf\u00fcrst'), 'en': u('Schillingsf\u00fcrst')},
 '499869':{'de': 'Wettringen Mittelfranken', 'en': 'Wettringen Mittelfranken'},
 '494546':{'de': 'Mustin Lauenburg', 'en': 'Mustin Lauenburg'},
 '494547':{'de': 'Gudow Lauenburg', 'en': 'Gudow Lauenburg'},
 '494544':{'de': 'Berkenthin', 'en': 'Berkenthin'},
 '494545':{'de': 'Seedorf Lauenburg', 'en': 'Seedorf Lauenburg'},
 '494542':{'de': u('M\u00f6lln Lauenburg'), 'en': u('M\u00f6lln Lauenburg')},
 '494543':{'de': 'Nusse', 'en': 'Nusse'},
 '494541':{'de': 'Ratzeburg', 'en': 'Ratzeburg'},
 '55113959':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113229':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113228':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113225':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113952':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113227':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113226':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113221':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113220':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113223':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113222':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52968':{'en': 'Chiapas', 'es': 'Chiapas'},
 '498407':{'de': 'Grossmehring', 'en': 'Grossmehring'},
 '492871':{'de': 'Bocholt', 'en': 'Bocholt'},
 '492872':{'de': 'Rhede Westfalen', 'en': 'Rhede Westfalen'},
 '492873':{'de': 'Isselburg-Werth', 'en': 'Isselburg-Werth'},
 '492874':{'de': 'Isselburg', 'en': 'Isselburg'},
 '498402':{'de': u('M\u00fcnchsm\u00fcnster'), 'en': u('M\u00fcnchsm\u00fcnster')},
 '55113192':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123979':{'en': 'Monteiro Lobato - SP', 'pt': 'Monteiro Lobato - SP'},
 '55113191':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494768':{'de': 'Hipstedt', 'en': 'Hipstedt'},
 '494769':{'de': u('Bremerv\u00f6rde-Iselersheim'), 'en': u('Bremerv\u00f6rde-Iselersheim')},
 '494762':{'de': 'Kutenholz', 'en': 'Kutenholz'},
 '494763':{'de': 'Gnarrenburg', 'en': 'Gnarrenburg'},
 '494761':{'de': u('Bremerv\u00f6rde'), 'en': u('Bremerv\u00f6rde')},
 '46663':{'en': 'Husum', 'sv': 'Husum'},
 '46662':{'en': u('Bj\u00f6rna'), 'sv': u('Bj\u00f6rna')},
 '46661':{'en': 'Bredbyn', 'sv': 'Bredbyn'},
 '46660':{'en': u('\u00d6rnsk\u00f6ldsvik'), 'sv': u('\u00d6rnsk\u00f6ldsvik')},
 '55133463':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55112798':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112793':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112790':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112791':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112796':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112797':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112795':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113438':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55112578':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112579':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495383':{'de': 'Lutter am Barenberge', 'en': 'Lutter am Barenberge'},
 '495382':{'de': 'Bad Gandersheim', 'en': 'Bad Gandersheim'},
 '495381':{'de': 'Seesen', 'en': 'Seesen'},
 '55112575':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112572':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112573':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495384':{'de': u('Seesen-Gro\u00df Rh\u00fcden'), 'en': u('Seesen-Gross Rh\u00fcden')},
 '55113439':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55133467':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '542902':{'en': u('R\u00edo Turbio, Santa Cruz'), 'es': u('R\u00edo Turbio, Santa Cruz')},
 '542903':{'en': u('R\u00edo Mayo, Chubut'), 'es': u('R\u00edo Mayo, Chubut')},
 '542901':{'en': 'Ushuaia, Tierra del Fuego', 'es': 'Ushuaia, Tierra del Fuego'},
 '493831':{'de': 'Stralsund', 'en': 'Stralsund'},
 '493836':{'de': 'Wolgast', 'en': 'Wolgast'},
 '493834':{'de': 'Greifswald', 'en': 'Greifswald'},
 '493838':{'de': u('Bergen auf R\u00fcgen'), 'en': u('Bergen auf R\u00fcgen')},
 '55113776':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114731':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '4938854':{'de': 'Redefin', 'en': 'Redefin'},
 '4938323':{'de': 'Prohn', 'en': 'Prohn'},
 '4938856':{'de': 'Pritzier bei Hagenow', 'en': 'Pritzier bei Hagenow'},
 '4938321':{'de': 'Martensdorf bei Stralsund', 'en': 'Martensdorf bei Stralsund'},
 '4938850':{'de': 'Gammelin', 'en': 'Gammelin'},
 '4938851':{'de': 'Zarrentin', 'en': 'Zarrentin'},
 '4938852':{'de': 'Wittenburg', 'en': 'Wittenburg'},
 '4938853':{'de': u('Dr\u00f6nnewitz bei Hagenow'), 'en': u('Dr\u00f6nnewitz bei Hagenow')},
 '4938328':{'de': 'Miltzow', 'en': 'Miltzow'},
 '4938858':{'de': 'Lassahn', 'en': 'Lassahn'},
 '4938859':{'de': 'Alt Zachun', 'en': 'Alt Zachun'},
 '437563':{'de': 'Spital am Pyhrn', 'en': 'Spital am Pyhrn'},
 '437562':{'de': 'Windischgarsten', 'en': 'Windischgarsten'},
 '437566':{'de': u('Rosenau am Hengstpa\u00df'), 'en': 'Rosenau am Hengstpass'},
 '437565':{'de': 'Sankt Pankraz', 'en': 'St. Pankraz'},
 '437564':{'de': 'Hinterstoder', 'en': 'Hinterstoder'},
 '495966':{'de': 'Meppen-Apeldorn', 'en': 'Meppen-Apeldorn'},
 '495965':{'de': 'Klein Berssen', 'en': 'Klein Berssen'},
 '495964':{'de': u('L\u00e4hden'), 'en': u('L\u00e4hden')},
 '495963':{'de': 'Bawinkel', 'en': 'Bawinkel'},
 '495962':{'de': 'Herzlake', 'en': 'Herzlake'},
 '495961':{'de': u('Hasel\u00fcnne'), 'en': u('Hasel\u00fcnne')},
 '55112137':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113833':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113449':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113448':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113333':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542658':{'en': 'Buena Esperanza, San Luis', 'es': 'Buena Esperanza, San Luis'},
 '55113332':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542656':{'en': 'Merlo, San Luis', 'es': 'Merlo, San Luis'},
 '542657':{'en': 'Villa Mercedes, San Luis', 'es': 'Villa Mercedes, San Luis'},
 '542655':{'en': 'La Toma, San Luis', 'es': 'La Toma, San Luis'},
 '542652':{'en': 'San Luis Province', 'es': 'Provincia de San Luis'},
 '55113331':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437582':{'de': 'Kirchdorf an der Krems', 'en': 'Kirchdorf an der Krems'},
 '542651':{'en': 'San Francisco del Monte de Oro, San Luis', 'es': 'San Francisco del Monte de Oro, San Luis'},
 '543755':{'en': u('Ober\u00e1, Misiones'), 'es': u('Ober\u00e1, Misiones')},
 '55113441':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113336':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492269':{'de': u('Kierspe-R\u00f6nsahl'), 'en': u('Kierspe-R\u00f6nsahl')},
 '492268':{'de': u('K\u00fcrten'), 'en': u('K\u00fcrten')},
 '492265':{'de': 'Reichshof-Eckenhagen', 'en': 'Reichshof-Eckenhagen'},
 '492264':{'de': 'Marienheide', 'en': 'Marienheide'},
 '492267':{'de': u('Wipperf\u00fcrth'), 'en': u('Wipperf\u00fcrth')},
 '492266':{'de': 'Lindlar', 'en': 'Lindlar'},
 '492261':{'de': 'Gummersbach', 'en': 'Gummersbach'},
 '492263':{'de': 'Engelskirchen', 'en': 'Engelskirchen'},
 '492262':{'de': 'Wiehl', 'en': 'Wiehl'},
 '55114421':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114427':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114424':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114428':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55112245':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '441499':{'en': 'Inveraray'},
 '497033':{'de': 'Weil Der Stadt', 'en': 'Weil Der Stadt'},
 '497032':{'de': 'Herrenberg', 'en': 'Herrenberg'},
 '497031':{'de': u('B\u00f6blingen'), 'en': u('B\u00f6blingen')},
 '441492':{'en': 'Colwyn Bay'},
 '441493':{'en': 'Great Yarmouth'},
 '441490':{'en': 'Corwen'},
 '441491':{'en': 'Henley-on-Thames'},
 '441496':{'en': 'Port Ellen'},
 '441497':{'en': 'Hay-on-Wye'},
 '441494':{'en': 'High Wycombe'},
 '441495':{'en': 'Pontypool'},
 '497529':{'de': u('Waldburg W\u00fcrttemberg'), 'en': u('Waldburg W\u00fcrttemberg')},
 '497528':{'de': 'Neukirch bei Tettnang', 'en': 'Neukirch bei Tettnang'},
 '497520':{'de': 'Bodnegg', 'en': 'Bodnegg'},
 '497522':{'de': u('Wangen im Allg\u00e4u'), 'en': u('Wangen im Allg\u00e4u')},
 '497525':{'de': 'Aulendorf', 'en': 'Aulendorf'},
 '497524':{'de': 'Bad Waldsee', 'en': 'Bad Waldsee'},
 '497527':{'de': 'Wolfegg', 'en': 'Wolfegg'},
 '55112983':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494951':{'de': 'Weener', 'en': 'Weener'},
 '441725':{'en': 'Rockbourne'},
 '441726':{'en': 'St Austell'},
 '441727':{'en': 'St Albans'},
 '441720':{'en': 'Isles of Scilly'},
 '494954':{'de': 'Moormerland', 'en': 'Moormerland'},
 '441722':{'en': 'Salisbury'},
 '441723':{'en': 'Scarborough'},
 '494959':{'de': 'Dollart', 'en': 'Dollart'},
 '494958':{'de': 'Jemgum', 'en': 'Jemgum'},
 '441728':{'en': 'Saxmundham'},
 '441729':{'en': 'Settle'},
 '55112982':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115089':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115088':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115083':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115082':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115081':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115080':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115087':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115086':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115085':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115084':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112981':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4939959':{'de': 'Dargun', 'en': 'Dargun'},
 '4939952':{'de': 'Grammentin', 'en': 'Grammentin'},
 '4939953':{'de': 'Schwinkendorf', 'en': 'Schwinkendorf'},
 '4939951':{'de': 'Faulenrost', 'en': 'Faulenrost'},
 '4939956':{'de': 'Neukalen', 'en': 'Neukalen'},
 '4939957':{'de': 'Gielow', 'en': 'Gielow'},
 '4939954':{'de': 'Stavenhagen Reuterstadt', 'en': 'Stavenhagen Reuterstadt'},
 '4939955':{'de': u('J\u00fcrgenstorf'), 'en': u('J\u00fcrgenstorf')},
 '55112980':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498652':{'de': 'Berchtesgaden', 'en': 'Berchtesgaden'},
 '493605':{'de': 'Leinefelde', 'en': 'Leinefelde'},
 '493606':{'de': 'Heiligenstadt Heilbad', 'en': 'Heiligenstadt Heilbad'},
 '498651':{'de': 'Bad Reichenhall', 'en': 'Bad Reichenhall'},
 '498656':{'de': 'Anger', 'en': 'Anger'},
 '493601':{'de': u('M\u00fchlhausen Th\u00fcringen'), 'en': u('M\u00fchlhausen Th\u00fcringen')},
 '498654':{'de': 'Freilassing', 'en': 'Freilassing'},
 '493603':{'de': 'Bad Langensalza', 'en': 'Bad Langensalza'},
 '55112987':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494371':{'de': 'Burg auf Fehmarn', 'en': 'Burg auf Fehmarn'},
 '49551':{'de': u('G\u00f6ttingen'), 'en': u('G\u00f6ttingen')},
 '494372':{'de': 'Westfehmarn', 'en': 'Westfehmarn'},
 '55115691':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112986':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498851':{'de': 'Kochel am See', 'en': 'Kochel am See'},
 '55115870':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498679':{'de': 'Burgkirchen an der Alz', 'en': 'Burgkirchen an der Alz'},
 '46506':{'en': u('T\u00f6reboda-Hova'), 'sv': u('T\u00f6reboda-Hova')},
 '49331':{'de': 'Potsdam', 'en': 'Potsdam'},
 '46504':{'en': 'Tibro', 'sv': 'Tibro'},
 '46505':{'en': 'Karlsborg', 'sv': 'Karlsborg'},
 '46502':{'en': 'Tidaholm', 'sv': 'Tidaholm'},
 '46503':{'en': 'Hjo', 'sv': 'Hjo'},
 '46500':{'en': u('Sk\u00f6vde'), 'sv': u('Sk\u00f6vde')},
 '46501':{'en': 'Mariestad', 'sv': 'Mariestad'},
 '4939404':{'de': 'Ausleben', 'en': 'Ausleben'},
 '4939405':{'de': u('H\u00f6tensleben'), 'en': u('H\u00f6tensleben')},
 '4939406':{'de': 'Harbke', 'en': 'Harbke'},
 '4939407':{'de': u('Seehausen B\u00f6rde'), 'en': u('Seehausen B\u00f6rde')},
 '4939400':{'de': 'Wefensleben', 'en': 'Wefensleben'},
 '4939401':{'de': 'Neuwegersleben', 'en': 'Neuwegersleben'},
 '4939402':{'de': u('V\u00f6lpke'), 'en': u('V\u00f6lpke')},
 '4939403':{'de': u('Gr\u00f6ningen Sachsen-Anhalt'), 'en': u('Gr\u00f6ningen Sachsen-Anhalt')},
 '498858':{'de': 'Kochel-Walchensee', 'en': 'Kochel-Walchensee'},
 '497221':{'de': 'Baden-Baden', 'en': 'Baden-Baden'},
 '497226':{'de': u('B\u00fchl-Sand'), 'en': u('B\u00fchl-Sand')},
 '55114053':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '497227':{'de': 'Lichtenau Baden', 'en': 'Lichtenau Baden'},
 '492304':{'de': 'Schwerte', 'en': 'Schwerte'},
 '52864':{'en': 'Coahuila', 'es': 'Coahuila'},
 '492305':{'de': 'Castrop-Rauxel', 'en': 'Castrop-Rauxel'},
 '55114052':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492308':{'de': 'Unna-Hemmerde', 'en': 'Unna-Hemmerde'},
 '441939':{'en': 'Wem'},
 '441938':{'en': 'Welshpool'},
 '492309':{'de': 'Waltrop', 'en': 'Waltrop'},
 '55113905':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441931':{'en': 'Shap'},
 '441933':{'en': 'Wellingborough'},
 '441932':{'en': 'Weybridge'},
 '441935':{'en': 'Yeovil'},
 '441934':{'en': 'Weston-super-Mare'},
 '441937':{'en': 'Wetherby'},
 '55113568':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498325':{'de': 'Oberstaufen-Thalkirchdorf', 'en': 'Oberstaufen-Thalkirchdorf'},
 '55113562':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498450':{'de': 'Ingolstadt-Zuchering', 'en': 'Ingolstadt-Zuchering'},
 '55113566':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113567':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113564':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498323':{'de': u('Immenstadt im Allg\u00e4u'), 'en': u('Immenstadt im Allg\u00e4u')},
 '52866':{'en': 'Castanos/Monclova, COAH', 'es': u('Casta\u00f1os/Monclova, COAH')},
 '498452':{'de': 'Geisenfeld', 'en': 'Geisenfeld'},
 '498453':{'de': 'Reichertshofen Oberbayern', 'en': 'Reichertshofen Oberbayern'},
 '499105':{'de': 'Grosshabersdorf', 'en': 'Grosshabersdorf'},
 '55112969':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499104':{'de': 'Emskirchen', 'en': 'Emskirchen'},
 '55112965':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112964':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '44238':{'en': 'Southampton'},
 '44239':{'en': 'Portsmouth'},
 '55112961':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499107':{'de': 'Trautskirchen', 'en': 'Trautskirchen'},
 '55112963':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112962':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499106':{'de': 'Markt Erlbach', 'en': 'Markt Erlbach'},
 '499101':{'de': 'Langenzenn', 'en': 'Langenzenn'},
 '55113909':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499103':{'de': 'Cadolzburg', 'en': 'Cadolzburg'},
 '496861':{'de': 'Merzig', 'en': 'Merzig'},
 '495772':{'de': 'Espelkamp', 'en': 'Espelkamp'},
 '495773':{'de': 'Stemwede-Wehdem', 'en': 'Stemwede-Wehdem'},
 '495771':{'de': 'Rahden Westfalen', 'en': 'Rahden Westfalen'},
 '495776':{'de': u('Preussisch Str\u00f6hen'), 'en': u('Preussisch Str\u00f6hen')},
 '495777':{'de': 'Diepenau-Essern', 'en': 'Diepenau-Essern'},
 '495774':{'de': u('Wagenfeld-Str\u00f6hen'), 'en': u('Wagenfeld-Str\u00f6hen')},
 '495775':{'de': 'Diepenau', 'en': 'Diepenau'},
 '496867':{'de': 'Perl', 'en': 'Perl'},
 '434825':{'de': u('Gro\u00dfkirchheim'), 'en': 'Grosskirchheim'},
 '496866':{'de': 'Perl-Nennig', 'en': 'Perl-Nennig'},
 '496641':{'de': 'Lauterbach Hessen', 'en': 'Lauterbach Hessen'},
 '4938464':{'de': 'Bernitt', 'en': 'Bernitt'},
 '55113845':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4938466':{'de': u('J\u00fcrgenshagen'), 'en': u('J\u00fcrgenshagen')},
 '4938461':{'de': u('B\u00fctzow'), 'en': u('B\u00fctzow')},
 '4938462':{'de': 'Baumgarten', 'en': 'Baumgarten'},
 '4936927':{'de': 'Unterellen', 'en': 'Unterellen'},
 '497738':{'de': 'Steisslingen', 'en': 'Steisslingen'},
 '497739':{'de': 'Hilzingen', 'en': 'Hilzingen'},
 '497734':{'de': 'Gailingen', 'en': 'Gailingen'},
 '497735':{'de': u('\u00d6hningen'), 'en': u('\u00d6hningen')},
 '497736':{'de': 'Tengen', 'en': 'Tengen'},
 '497731':{'de': 'Singen Hohentwiel', 'en': 'Singen Hohentwiel'},
 '497732':{'de': 'Radolfzell am Bodensee', 'en': 'Radolfzell am Bodensee'},
 '497733':{'de': 'Engen Hegau', 'en': 'Engen Hegau'},
 '55112219':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112218':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499474':{'de': u('Schmidm\u00fchlen'), 'en': u('Schmidm\u00fchlen')},
 '55112213':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115532':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495594':{'de': 'Bovenden-Reyershausen', 'en': 'Bovenden-Reyershausen'},
 '495592':{'de': 'Gleichen-Bremke', 'en': 'Gleichen-Bremke'},
 '495593':{'de': 'Bovenden-Lenglern', 'en': 'Bovenden-Lenglern'},
 '55112215':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112214':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123132':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55123133':{'en': u('Guaratinguet\u00e1 - SP'), 'pt': u('Guaratinguet\u00e1 - SP')},
 '55113847':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123131':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '441559':{'en': 'Llandysul'},
 '441558':{'en': 'Llandeilo'},
 '441553':{'en': 'Kings Lynn'},
 '441550':{'en': 'Llandovery'},
 '441557':{'en': 'Kirkcudbright'},
 '441556':{'en': 'Castle Douglas'},
 '441555':{'en': 'Lanark'},
 '441554':{'en': 'Llanelli'},
 '55113846':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '435514':{'de': 'Bezau', 'en': 'Bezau'},
 '435515':{'de': 'Au', 'en': 'Au'},
 '435516':{'de': 'Doren', 'en': 'Doren'},
 '435517':{'de': 'Riezlern', 'en': 'Riezlern'},
 '435510':{'de': u('Dam\u00fcls'), 'en': u('Dam\u00fcls')},
 '4934976':{'de': u('Gr\u00f6bzig'), 'en': u('Gr\u00f6bzig')},
 '4934975':{'de': u('G\u00f6rzig Kreis K\u00f6then'), 'en': u('G\u00f6rzig Kreis K\u00f6then')},
 '435513':{'de': 'Hittisau', 'en': 'Hittisau'},
 '543844':{'en': u('A\u00f1atuya, Santiago del Estero'), 'es': u('A\u00f1atuya, Santiago del Estero')},
 '543845':{'en': 'Loreto, Santiago del Estero', 'es': 'Loreto, Santiago del Estero'},
 '4934979':{'de': 'Wulfen Sachsen-Anhalt', 'en': 'Wulfen Sachsen-Anhalt'},
 '4934978':{'de': u('Radegast Kreis K\u00f6then'), 'en': u('Radegast Kreis K\u00f6then')},
 '435518':{'de': 'Mellau', 'en': 'Mellau'},
 '435519':{'de': u('Schr\u00f6cken'), 'en': u('Schr\u00f6cken')},
 '543843':{'en': u('Quimil\u00ed, Santiago del Estero'), 'es': u('Quimil\u00ed, Santiago del Estero')},
 '52828':{'en': 'Cadereyta, NL', 'es': 'Cadereyta, NL'},
 '52829':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '52821':{'en': 'Hualahuises/Linares, NL', 'es': 'Hualahuises/Linares, NL'},
 '52823':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '52824':{'en': 'Sabinas Hidalgo, NL', 'es': 'Sabinas Hidalgo, NL'},
 '499853':{'de': 'Wilburgstetten', 'en': 'Wilburgstetten'},
 '52826':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '52827':{'en': 'Santiago, NL', 'es': 'Santiago, NL'},
 '496029':{'de': u('M\u00f6mbris'), 'en': u('M\u00f6mbris')},
 '496028':{'de': 'Sulzbach am Main', 'en': 'Sulzbach am Main'},
 '496027':{'de': 'Stockstadt am Main', 'en': 'Stockstadt am Main'},
 '496026':{'de': 'Grossostheim', 'en': 'Grossostheim'},
 '496024':{'de': u('Sch\u00f6llkrippen'), 'en': u('Sch\u00f6llkrippen')},
 '496023':{'de': 'Alzenau in Unterfranken', 'en': 'Alzenau in Unterfranken'},
 '496022':{'de': 'Obernburg am Main', 'en': 'Obernburg am Main'},
 '496021':{'de': 'Aschaffenburg', 'en': 'Aschaffenburg'},
 '496020':{'de': u('Heigenbr\u00fccken'), 'en': u('Heigenbr\u00fccken')},
 '492742':{'de': 'Wissen', 'en': 'Wissen'},
 '492743':{'de': 'Daaden', 'en': 'Daaden'},
 '492741':{'de': 'Betzdorf', 'en': 'Betzdorf'},
 '492747':{'de': 'Molzhain', 'en': 'Molzhain'},
 '492744':{'de': 'Herdorf', 'en': 'Herdorf'},
 '492745':{'de': 'Brachbach Sieg', 'en': 'Brachbach Sieg'},
 '4776':{'en': 'Nordland'},
 '4777':{'en': 'Troms'},
 '4774':{'en': u('Nord-Tr\u00f8ndelag')},
 '4775':{'en': 'Nordland'},
 '4772':{'en': u('S\u00f8r-Tr\u00f8ndelag')},
 '4773':{'en': u('S\u00f8r-Tr\u00f8ndelag')},
 '4770':{'en': u('M\u00f8re og Romsdal')},
 '4771':{'en': u('M\u00f8re og Romsdal')},
 '4778':{'en': 'Finnmark'},
 '54376':{'en': 'Posadas, Misiones', 'es': 'Posadas, Misiones'},
 '54370':{'en': 'Formosa, Formosa', 'es': 'Formosa, Formosa'},
 '52358':{'en': 'Tamazula/Zapoltitic, JAL', 'es': 'Tamazula/Zapotiltic, JAL'},
 '55113028':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52356':{'en': 'Tanhuato/Yurecuaro, MICH', 'es': u('Tanhuato/Yur\u00e9cuaro, MICH')},
 '52357':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52354':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52355':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52352':{'en': 'La Piedad, MICH', 'es': 'La Piedad, MICH'},
 '52353':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '55113021':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52351':{'en': 'Ario de Rayon/Zamora, MICH', 'es': u('Ario de Ray\u00f3n/Zamora, MICH')},
 '4619':{'en': u('\u00d6rebro-Kumla'), 'sv': u('\u00d6rebro-Kumla')},
 '4618':{'en': 'Uppsala', 'sv': 'Uppsala'},
 '495494':{'de': 'Holdorf Niedersachsen', 'en': 'Holdorf Niedersachsen'},
 '4611':{'en': u('Norrk\u00f6ping'), 'sv': u('Norrk\u00f6ping')},
 '4613':{'en': u('Link\u00f6ping'), 'sv': u('Link\u00f6ping')},
 '4616':{'en': u('Eskilstuna-Torsh\u00e4lla'), 'sv': u('Eskilstuna-Torsh\u00e4lla')},
 '496569':{'de': 'Bickendorf', 'en': 'Bickendorf'},
 '55114217':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '499848':{'de': 'Simmershofen', 'en': 'Simmershofen'},
 '494561':{'de': 'Neustadt in Holstein', 'en': 'Neustadt in Holstein'},
 '494562':{'de': u('Gr\u00f6mitz'), 'en': u('Gr\u00f6mitz')},
 '494563':{'de': 'Scharbeutz-Haffkrug', 'en': 'Scharbeutz-Haffkrug'},
 '494564':{'de': 'Schashagen', 'en': 'Schashagen'},
 '499845':{'de': 'Oberdachstetten', 'en': 'Oberdachstetten'},
 '499846':{'de': 'Ipsheim', 'en': 'Ipsheim'},
 '499847':{'de': 'Ergersheim', 'en': 'Ergersheim'},
 '55113795':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113794':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113797':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113796':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113791':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113974':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113793':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113976':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113978':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113798':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498469':{'de': 'Freystadt-Burggriesbach', 'en': 'Freystadt-Burggriesbach'},
 '498468':{'de': 'Altmannstein-Pondorf', 'en': 'Altmannstein-Pondorf'},
 '498461':{'de': 'Beilngries', 'en': 'Beilngries'},
 '498460':{'de': 'Berching-Holnstein', 'en': 'Berching-Holnstein'},
 '498463':{'de': 'Greding', 'en': 'Greding'},
 '498462':{'de': 'Berching', 'en': 'Berching'},
 '498465':{'de': 'Kipfenberg', 'en': 'Kipfenberg'},
 '498464':{'de': u('Dietfurt an der Altm\u00fchl'), 'en': u('Dietfurt an der Altm\u00fchl')},
 '498467':{'de': 'Kinding', 'en': 'Kinding'},
 '498466':{'de': 'Denkendorf Oberbayern', 'en': 'Denkendorf Oberbayern'},
 '494744':{'de': 'Loxstedt', 'en': 'Loxstedt'},
 '494745':{'de': 'Bad Bederkesa', 'en': 'Bad Bederkesa'},
 '494746':{'de': 'Hagen bei Bremerhaven', 'en': 'Hagen bei Bremerhaven'},
 '494747':{'de': 'Beverstedt', 'en': 'Beverstedt'},
 '494740':{'de': 'Loxstedt-Dedesdorf', 'en': 'Loxstedt-Dedesdorf'},
 '494741':{'de': 'Nordholz bei Bremerhaven', 'en': 'Nordholz bei Bremerhaven'},
 '494742':{'de': 'Dorum', 'en': 'Dorum'},
 '494743':{'de': 'Langen bei Bremerhaven', 'en': 'Langen bei Bremerhaven'},
 '494748':{'de': 'Stubben bei Bremerhaven', 'en': 'Stubben bei Bremerhaven'},
 '494749':{'de': 'Schiffdorf-Geestenseth', 'en': 'Schiffdorf-Geestenseth'},
 '55113813':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115477':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55112771':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112772':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112773':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123895':{'en': 'Ilhabela - SP', 'pt': 'Ilhabela - SP'},
 '441239':{'en': 'Cardigan'},
 '441236':{'en': 'Coatbridge'},
 '441237':{'en': 'Bideford'},
 '441234':{'en': 'Bedford'},
 '441235':{'en': 'Abingdon'},
 '441233':{'en': 'Ashford (Kent)'},
 '52686':{'en': 'Baja California', 'es': 'Baja California'},
 '52687':{'en': 'Sinoloa', 'es': 'Sinoloa'},
 '49251':{'de': u('M\u00fcnster'), 'en': u('M\u00fcnster')},
 '55123893':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '55123892':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '499336':{'de': u('B\u00fctthard'), 'en': u('B\u00fctthard')},
 '499337':{'de': u('Gauk\u00f6nigshofen'), 'en': u('Gauk\u00f6nigshofen')},
 '499334':{'de': 'Giebelstadt', 'en': 'Giebelstadt'},
 '499335':{'de': u('Aub Kreis W\u00fcrzburg'), 'en': u('Aub Kreis W\u00fcrzburg')},
 '499332':{'de': 'Marktbreit', 'en': 'Marktbreit'},
 '499333':{'de': 'Sommerhausen', 'en': 'Sommerhausen'},
 '499331':{'de': 'Ochsenfurt', 'en': 'Ochsenfurt'},
 '55112518':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499338':{'de': u('R\u00f6ttingen Unterfranken'), 'en': u('R\u00f6ttingen Unterfranken')},
 '499339':{'de': 'Ippesheim', 'en': 'Ippesheim'},
 '4934498':{'de': 'Rositz', 'en': 'Rositz'},
 '4934491':{'de': u('Schm\u00f6lln Th\u00fcringen'), 'en': u('Schm\u00f6lln Th\u00fcringen')},
 '4934492':{'de': 'Lucka', 'en': 'Lucka'},
 '4934493':{'de': u('G\u00f6\u00dfnitz Th\u00fcringen'), 'en': u('G\u00f6ssnitz Th\u00fcringen')},
 '4934494':{'de': 'Ehrenhain', 'en': 'Ehrenhain'},
 '4934495':{'de': 'Dobitschen', 'en': 'Dobitschen'},
 '4934496':{'de': u('N\u00f6bdenitz'), 'en': u('N\u00f6bdenitz')},
 '4934497':{'de': 'Langenleuba-Niederhain', 'en': 'Langenleuba-Niederhain'},
 '542920':{'en': u('Viedma, R\u00edo Negro'), 'es': u('Viedma, R\u00edo Negro')},
 '542921':{'en': 'Coronel Dorrego, Buenos Aires', 'es': 'Coronel Dorrego, Buenos Aires'},
 '437763':{'de': 'Kopfing im Innkreis', 'en': 'Kopfing im Innkreis'},
 '437762':{'de': 'Raab', 'en': 'Raab'},
 '437765':{'de': 'Lambrechten', 'en': 'Lambrechten'},
 '437764':{'de': 'Riedau', 'en': 'Riedau'},
 '437767':{'de': 'Eggerding', 'en': 'Eggerding'},
 '437766':{'de': 'Andorf', 'en': 'Andorf'},
 '542928':{'en': 'Pedro Luro, Buenos Aires', 'es': 'Pedro Luro, Buenos Aires'},
 '542929':{'en': u('Guamin\u00ed, Buenos Aires'), 'es': u('Guamin\u00ed, Buenos Aires')},
 '5255':{'en': 'Mexico City, FD', 'es': u('Cuidad de M\u00e9xico, CDMX')},
 '497274':{'de': 'Germersheim', 'en': 'Germersheim'},
 '55124110':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '4938876':{'de': 'Roggendorf', 'en': 'Roggendorf'},
 '4938874':{'de': u('L\u00fctzow'), 'en': u('L\u00fctzow')},
 '4938875':{'de': 'Schlagsdorf bei Gadebusch', 'en': 'Schlagsdorf bei Gadebusch'},
 '4938872':{'de': 'Rehna', 'en': 'Rehna'},
 '4938873':{'de': 'Carlow', 'en': 'Carlow'},
 '4938871':{'de': u('M\u00fchlen Eichsen'), 'en': u('M\u00fchlen Eichsen')},
 '495909':{'de': 'Wettrup', 'en': 'Wettrup'},
 '495908':{'de': 'Wietmarschen-Lohne', 'en': 'Wietmarschen-Lohne'},
 '437588':{'de': 'Ried im Traunkreis', 'en': 'Ried im Traunkreis'},
 '495901':{'de': u('F\u00fcrstenau bei Bramsche'), 'en': u('F\u00fcrstenau bei Bramsche')},
 '437584':{'de': 'Molln', 'en': 'Molln'},
 '495903':{'de': u('Emsb\u00fcren'), 'en': u('Emsb\u00fcren')},
 '495902':{'de': 'Freren', 'en': 'Freren'},
 '495905':{'de': 'Beesten', 'en': 'Beesten'},
 '495904':{'de': 'Lengerich Emsl', 'en': 'Lengerich Emsl'},
 '437583':{'de': u('Kremsm\u00fcnster'), 'en': u('Kremsm\u00fcnster')},
 '495906':{'de': u('L\u00fcnne'), 'en': u('L\u00fcnne')},
 '55123836':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123835':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123834':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123833':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55123832':{'en': 'Ubatuba - SP', 'pt': 'Ubatuba - SP'},
 '55114174':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55112198':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492247':{'de': 'Neunkirchen-Seelscheid', 'en': 'Neunkirchen-Seelscheid'},
 '492246':{'de': 'Lohmar Rheinland', 'en': 'Lohmar Rheinland'},
 '492245':{'de': 'Much', 'en': 'Much'},
 '492244':{'de': u('K\u00f6nigswinter-Oberpleis'), 'en': u('K\u00f6nigswinter-Oberpleis')},
 '492243':{'de': 'Eitorf', 'en': 'Eitorf'},
 '492242':{'de': 'Hennef Sieg', 'en': 'Hennef Sieg'},
 '492241':{'de': 'Siegburg', 'en': 'Siegburg'},
 '498020':{'de': 'Weyarn', 'en': 'Weyarn'},
 '492248':{'de': 'Hennef-Uckerath', 'en': 'Hennef-Uckerath'},
 '55114037':{'en': 'Pedra Bela - SP', 'pt': 'Pedra Bela - SP'},
 '55114176':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '498026':{'de': 'Hausham', 'en': 'Hausham'},
 '497051':{'de': 'Calw', 'en': 'Calw'},
 '497502':{'de': 'Wolpertswende', 'en': 'Wolpertswende'},
 '497053':{'de': 'Bad Teinach-Zavelstein', 'en': 'Bad Teinach-Zavelstein'},
 '497052':{'de': 'Bad Liebenzell', 'en': 'Bad Liebenzell'},
 '497055':{'de': 'Neuweiler Kreis Calw', 'en': 'Neuweiler Kreis Calw'},
 '497054':{'de': u('Wildberg W\u00fcrttemberg'), 'en': u('Wildberg W\u00fcrttemberg')},
 '497505':{'de': 'Fronreute', 'en': 'Fronreute'},
 '497056':{'de': 'Gechingen', 'en': 'Gechingen'},
 '55112504':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112503':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543571':{'en': u('R\u00edo Tercero, C\u00f3rdoba'), 'es': u('R\u00edo Tercero, C\u00f3rdoba')},
 '55112501':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494973':{'de': 'Wittmund-Burhafe', 'en': 'Wittmund-Burhafe'},
 '494972':{'de': 'Langeoog', 'en': 'Langeoog'},
 '494971':{'de': 'Esens', 'en': 'Esens'},
 '494977':{'de': 'Blomberg Ostfriesland', 'en': 'Blomberg Ostfriesland'},
 '494976':{'de': 'Spiekeroog', 'en': 'Spiekeroog'},
 '494975':{'de': 'Westerholt Ostfriesland', 'en': 'Westerholt Ostfriesland'},
 '494974':{'de': 'Neuharlingersiel', 'en': 'Neuharlingersiel'},
 '55133519':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133513':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '499779':{'de': u('Nordheim von der Rh\u00f6n'), 'en': u('Nordheim von der Rh\u00f6n')},
 '499773':{'de': 'Unsleben', 'en': 'Unsleben'},
 '493371':{'de': 'Luckenwalde', 'en': 'Luckenwalde'},
 '493372':{'de': u('J\u00fcterbog'), 'en': u('J\u00fcterbog')},
 '498678':{'de': 'Marktl', 'en': 'Marktl'},
 '493375':{'de': u('K\u00f6nigs Wusterhausen'), 'en': u('K\u00f6nigs Wusterhausen')},
 '498856':{'de': 'Penzberg', 'en': 'Penzberg'},
 '493377':{'de': 'Zossen Brandenburg', 'en': 'Zossen Brandenburg'},
 '493378':{'de': 'Ludwigsfelde', 'en': 'Ludwigsfelde'},
 '493379':{'de': 'Mahlow', 'en': 'Mahlow'},
 '498677':{'de': 'Burghausen Salzach', 'en': 'Burghausen Salzach'},
 '498670':{'de': u('Reischach Kreis Alt\u00f6tting'), 'en': u('Reischach Kreis Alt\u00f6tting')},
 '498671':{'de': u('Alt\u00f6tting'), 'en': u('Alt\u00f6tting')},
 '49531':{'de': 'Braunschweig', 'en': 'Braunschweig'},
 '494358':{'de': u('Loose bei Eckernf\u00f6rde'), 'en': u('Loose bei Eckernf\u00f6rde')},
 '494357':{'de': 'Sehestedt Eider', 'en': 'Sehestedt Eider'},
 '494356':{'de': 'Gross Wittensee', 'en': 'Gross Wittensee'},
 '494355':{'de': 'Rieseby', 'en': 'Rieseby'},
 '494354':{'de': 'Fleckeby', 'en': 'Fleckeby'},
 '494353':{'de': 'Ascheffel', 'en': 'Ascheffel'},
 '494352':{'de': 'Damp', 'en': 'Damp'},
 '494351':{'de': u('Eckernf\u00f6rde'), 'en': u('Eckernf\u00f6rde')},
 '499102':{'de': 'Wilhermsdorf', 'en': 'Wilhermsdorf'},
 '4937600':{'de': 'Neumark Sachsen', 'en': 'Neumark Sachsen'},
 '4937601':{'de': u('M\u00fclsen Skt Jacob'), 'en': u('M\u00fclsen Skt Jacob')},
 '4936605':{'de': u('Bad K\u00f6stritz'), 'en': u('Bad K\u00f6stritz')},
 '4936604':{'de': u('M\u00fcnchenbernsdorf'), 'en': u('M\u00fcnchenbernsdorf')},
 '4936603':{'de': 'Weida', 'en': 'Weida'},
 '4936602':{'de': u('Ronneburg Th\u00fcringen'), 'en': u('Ronneburg Th\u00fcringen')},
 '46528':{'en': u('F\u00e4rgelanda'), 'sv': u('F\u00e4rgelanda')},
 '4936601':{'de': u('Hermsdorf Th\u00fcringen'), 'en': u('Hermsdorf Th\u00fcringen')},
 '46524':{'en': 'Munkedal', 'sv': 'Munkedal'},
 '46525':{'en': 'Grebbestad', 'sv': 'Grebbestad'},
 '46526':{'en': u('Str\u00f6mstad'), 'sv': u('Str\u00f6mstad')},
 '46520':{'en': u('Trollh\u00e4ttan'), 'sv': u('Trollh\u00e4ttan')},
 '46521':{'en': u('V\u00e4nersborg'), 'sv': u('V\u00e4nersborg')},
 '46522':{'en': 'Uddevalla', 'sv': 'Uddevalla'},
 '46523':{'en': 'Lysekil', 'sv': 'Lysekil'},
 '55133448':{'en': u('Mongagu\u00e1 - SP'), 'pt': u('Mongagu\u00e1 - SP')},
 '55114009':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114000':{'en': u('Aruj\u00e1 - SP'), 'pt': u('Aruj\u00e1 - SP')},
 '55114005':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114007':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113342':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '54230':{'en': 'Pilar, Buenos Aires', 'es': 'Pilar, Buenos Aires'},
 '54237':{'en': 'Moreno, Buenos Aires', 'es': 'Moreno, Buenos Aires'},
 '54236':{'en': u('Jun\u00edn, Buenos Aires'), 'es': u('Jun\u00edn, Buenos Aires')},
 '55113581':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55113583':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113584':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113585':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114032':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55112195':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '46250':{'en': 'Mora-Orsa', 'sv': 'Mora-Orsa'},
 '4939426':{'de': 'Hessen', 'en': 'Hessen'},
 '4939427':{'de': u('Str\u00f6beck'), 'en': u('Str\u00f6beck')},
 '4939424':{'de': 'Schwanebeck Sachsen-Anhalt', 'en': 'Schwanebeck Sachsen-Anhalt'},
 '4939425':{'de': 'Dingelstedt am Huy', 'en': 'Dingelstedt am Huy'},
 '4939422':{'de': 'Badersleben', 'en': 'Badersleben'},
 '4939423':{'de': 'Wegeleben', 'en': 'Wegeleben'},
 '4939421':{'de': 'Osterwieck', 'en': 'Osterwieck'},
 '55112989':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4939428':{'de': 'Pabstorf', 'en': 'Pabstorf'},
 '55113806':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497161':{'de': u('G\u00f6ppingen'), 'en': u('G\u00f6ppingen')},
 '542934':{'en': u('San Antonio Oeste, R\u00edo Negro'), 'es': u('San Antonio Oeste, R\u00edo Negro')},
 '542933':{'en': u('Huanguel\u00e9n, Buenos Aires'), 'es': u('Huanguel\u00e9n, Buenos Aires')},
 '46251':{'en': u('\u00c4lvdalen'), 'sv': u('\u00c4lvdalen')},
 '497163':{'de': 'Ebersbach an der Fils', 'en': 'Ebersbach an der Fils'},
 '542932':{'en': 'Punta Alta, Buenos Aires', 'es': 'Punta Alta, Buenos Aires'},
 '55133378':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '542931':{'en': u('R\u00edo Colorado, R\u00edo Negro'), 'es': u('R\u00edo Colorado, R\u00edo Negro')},
 '4937421':{'de': 'Oelsnitz Vogtland', 'en': 'Oelsnitz Vogtland'},
 '4937422':{'de': 'Markneukirchen', 'en': 'Markneukirchen'},
 '4937423':{'de': 'Adorf Vogtland', 'en': 'Adorf Vogtland'},
 '55113801':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497164':{'de': u('Boll Kreis G\u00f6ppingen'), 'en': u('Boll Kreis G\u00f6ppingen')},
 '55112189':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112188':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495028':{'de': 'Pennigsehl', 'en': 'Pennigsehl'},
 '495754':{'de': 'Extertal-Bremke', 'en': 'Extertal-Bremke'},
 '495027':{'de': 'Linsburg', 'en': 'Linsburg'},
 '495024':{'de': 'Rohrsen Kreis Nienburg Weser', 'en': 'Rohrsen Kreis Nienburg Weser'},
 '492446':{'de': 'Heimbach Eifel', 'en': 'Heimbach Eifel'},
 '495022':{'de': 'Wietzen', 'en': 'Wietzen'},
 '495023':{'de': 'Liebenau Kreis Nieburg Weser', 'en': 'Liebenau Kreis Nieburg Weser'},
 '495752':{'de': 'Auetal-Hattendorf', 'en': 'Auetal-Hattendorf'},
 '495021':{'de': 'Nienburg Weser', 'en': 'Nienburg Weser'},
 '441913':{'en': 'Durham'},
 '441912':{'en': 'Tyneside'},
 '441911':{'en': 'Tyneside/Durham/Sunderland'},
 '441910':{'en': 'Tyneside/Durham/Sunderland'},
 '441917':{'en': 'Sunderland'},
 '441916':{'en': 'Tyneside'},
 '441915':{'en': 'Sunderland'},
 '441914':{'en': 'Tyneside'},
 '441919':{'en': 'Durham'},
 '441918':{'en': 'Tyneside'},
 '4938488':{'de': 'Demen', 'en': 'Demen'},
 '4938486':{'de': u('Gust\u00e4vel'), 'en': u('Gust\u00e4vel')},
 '4938485':{'de': 'Dabel', 'en': 'Dabel'},
 '4938484':{'de': 'Ventschow', 'en': 'Ventschow'},
 '4938483':{'de': u('Br\u00fcel'), 'en': u('Br\u00fcel')},
 '4938482':{'de': 'Warin', 'en': 'Warin'},
 '4938481':{'de': 'Witzin', 'en': 'Witzin'},
 '55114036':{'en': 'Piracaia - SP', 'pt': 'Piracaia - SP'},
 '55113343':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493976':{'de': u('Torgelow bei Ueckerm\u00fcnde'), 'en': u('Torgelow bei Ueckerm\u00fcnde')},
 '55115510':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112233':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112232':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112235':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493973':{'de': 'Pasewalk', 'en': 'Pasewalk'},
 '55115517':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493971':{'de': 'Anklam', 'en': 'Anklam'},
 '55112239':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112238':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543404':{'en': 'Las Colonias Dept., Santa Fe', 'es': 'Dpto. Las Colonias, Santa Fe'},
 '543405':{'en': 'San Javier, Santa Fe', 'es': 'San Javier, Santa Fe'},
 '543406':{'en': 'San Jorge, Santa Fe', 'es': 'San Jorge, Santa Fe'},
 '543407':{'en': 'Ramallo, Buenos Aires', 'es': 'Ramallo, Buenos Aires'},
 '543400':{'en': u('Villa Constituci\u00f3n, Santa Fe'), 'es': u('Villa Constituci\u00f3n, Santa Fe')},
 '437289':{'de': u('Rohrbach in Ober\u00f6sterreich'), 'en': u('Rohrbach in Ober\u00f6sterreich')},
 '543402':{'en': 'Arroyo Seco, Santa Fe', 'es': 'Arroyo Seco, Santa Fe'},
 '55123153':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '543408':{'en': u('San Crist\u00f3bal, Santa Fe'), 'es': u('San Crist\u00f3bal, Santa Fe')},
 '543409':{'en': u('Mois\u00e9s Ville, Santa Fe'), 'es': u('Mois\u00e9s Ville, Santa Fe')},
 '543388':{'en': 'General Villegas, Buenos Aires', 'es': 'General Villegas, Buenos Aires'},
 '437246':{'de': 'Gunskirchen', 'en': 'Gunskirchen'},
 '437247':{'de': 'Kematen am Innbach', 'en': 'Kematen am Innbach'},
 '437244':{'de': 'Sattledt', 'en': 'Sattledt'},
 '437245':{'de': 'Lambach', 'en': 'Lambach'},
 '4933701':{'de': 'Grossbeeren', 'en': 'Grossbeeren'},
 '437243':{'de': 'Marchtrenk', 'en': 'Marchtrenk'},
 '437240':{'de': 'Sipbachzell', 'en': 'Sipbachzell'},
 '437241':{'de': 'Steinerkirchen an der Traun', 'en': 'Steinerkirchen an der Traun'},
 '55115634':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115635':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933708':{'de': 'Rangsdorf', 'en': 'Rangsdorf'},
 '437248':{'de': 'Grieskirchen', 'en': 'Grieskirchen'},
 '437249':{'de': 'Bad Schallerbach', 'en': 'Bad Schallerbach'},
 '495026':{'de': 'Steimbke', 'en': 'Steimbke'},
 '496229':{'de': 'Neckarsteinach', 'en': 'Neckarsteinach'},
 '496228':{'de': u('Sch\u00f6nau Odenwald'), 'en': u('Sch\u00f6nau Odenwald')},
 '496599':{'de': 'Weidenbach bei Gerolstein', 'en': 'Weidenbach bei Gerolstein'},
 '495755':{'de': 'Kalletal-Varenholz', 'en': 'Kalletal-Varenholz'},
 '496597':{'de': u('J\u00fcnkerath'), 'en': u('J\u00fcnkerath')},
 '496224':{'de': 'Sandhausen Baden', 'en': 'Sandhausen Baden'},
 '496227':{'de': 'Walldorf Baden', 'en': 'Walldorf Baden'},
 '496594':{'de': 'Birresborn', 'en': 'Birresborn'},
 '496221':{'de': 'Heidelberg', 'en': 'Heidelberg'},
 '496220':{'de': 'Wilhelmsfeld', 'en': 'Wilhelmsfeld'},
 '496223':{'de': u('Neckargem\u00fcnd'), 'en': u('Neckargem\u00fcnd')},
 '496222':{'de': 'Wiesloch', 'en': 'Wiesloch'},
 '495025':{'de': 'Estorf Weser', 'en': 'Estorf Weser'},
 '4934955':{'de': 'Gossa', 'en': 'Gossa'},
 '4934954':{'de': 'Roitzsch bei Bitterfeld', 'en': 'Roitzsch bei Bitterfeld'},
 '4934956':{'de': u('Z\u00f6rbig'), 'en': u('Z\u00f6rbig')},
 '4934953':{'de': u('Gr\u00e4fenhainichen'), 'en': u('Gr\u00e4fenhainichen')},
 '495751':{'de': 'Rinteln', 'en': 'Rinteln'},
 '55115182':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115183':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115181':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112185':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115184':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495753':{'de': 'Auetal-Bernsen', 'en': 'Auetal-Bernsen'},
 '55113823':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113447':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '496049':{'de': 'Kefenrod', 'en': 'Kefenrod'},
 '496048':{'de': u('B\u00fcdingen-Eckartshausen'), 'en': u('B\u00fcdingen-Eckartshausen')},
 '496041':{'de': 'Glauburg', 'en': 'Glauburg'},
 '496043':{'de': 'Nidda', 'en': 'Nidda'},
 '496042':{'de': u('B\u00fcdingen Hessen'), 'en': u('B\u00fcdingen Hessen')},
 '496045':{'de': 'Gedern', 'en': 'Gedern'},
 '496044':{'de': 'Schotten Hessen', 'en': 'Schotten Hessen'},
 '496047':{'de': 'Altenstadt Hessen', 'en': 'Altenstadt Hessen'},
 '496046':{'de': 'Ortenberg Hessen', 'en': 'Ortenberg Hessen'},
 '46280':{'en': 'Malung', 'sv': 'Malung'},
 '55114588':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55122128':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55114585':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114584':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114587':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '4939928':{'de': u('M\u00f6llenhagen'), 'en': u('M\u00f6llenhagen')},
 '55114581':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114583':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114582':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '498191':{'de': 'Landsberg am Lech', 'en': 'Landsberg am Lech'},
 '498193':{'de': 'Geltendorf', 'en': 'Geltendorf'},
 '498192':{'de': 'Schondorf am Ammersee', 'en': 'Schondorf am Ammersee'},
 '498195':{'de': 'Weil Kreis Landsberg am Lech', 'en': 'Weil Kreis Landsberg am Lech'},
 '498194':{'de': 'Vilgertshofen', 'en': 'Vilgertshofen'},
 '498196':{'de': u('P\u00fcrgen'), 'en': u('P\u00fcrgen')},
 '494502':{'de': u('L\u00fcbeck-Travem\u00fcnde'), 'en': u('L\u00fcbeck-Travem\u00fcnde')},
 '494503':{'de': 'Timmendorfer Strand', 'en': 'Timmendorfer Strand'},
 '499820':{'de': 'Lehrberg', 'en': 'Lehrberg'},
 '494501':{'de': 'Kastorf Holstein', 'en': 'Kastorf Holstein'},
 '494506':{'de': 'Stockelsdorf-Krumbeck', 'en': 'Stockelsdorf-Krumbeck'},
 '499827':{'de': 'Lichtenau Mittelfranken', 'en': 'Lichtenau Mittelfranken'},
 '494504':{'de': 'Ratekau', 'en': 'Ratekau'},
 '494505':{'de': 'Stockelsdorf-Curau', 'en': 'Stockelsdorf-Curau'},
 '494508':{'de': 'Krummesse', 'en': 'Krummesse'},
 '494509':{'de': u('Gro\u00df Gr\u00f6nau'), 'en': u('Gross Gr\u00f6nau')},
 '437223':{'de': 'Enns', 'en': 'Enns'},
 '492764':{'de': 'Welschen Ennest', 'en': 'Welschen Ennest'},
 '52427':{'en': 'Mexico/Quintana Roo', 'es': u('M\u00e9xico/Quintana Roo')},
 '492761':{'de': 'Olpe Biggesee', 'en': 'Olpe Biggesee'},
 '492762':{'de': u('Wenden S\u00fcdsauerland'), 'en': u('Wenden S\u00fcdsauerland')},
 '492763':{'de': 'Drolshagen-Bleche', 'en': 'Drolshagen-Bleche'},
 '498335':{'de': 'Fellheim', 'en': 'Fellheim'},
 '498334':{'de': u('Bad Gr\u00f6nenbach'), 'en': u('Bad Gr\u00f6nenbach')},
 '498337':{'de': 'Altenstadt Iller', 'en': 'Altenstadt Iller'},
 '498336':{'de': 'Erkheim', 'en': 'Erkheim'},
 '492838':{'de': 'Sonsbeck', 'en': 'Sonsbeck'},
 '492839':{'de': 'Straelen-Herongen', 'en': 'Straelen-Herongen'},
 '498333':{'de': 'Babenhausen Schwaben', 'en': 'Babenhausen Schwaben'},
 '498332':{'de': 'Ottobeuren', 'en': 'Ottobeuren'},
 '492834':{'de': 'Straelen', 'en': 'Straelen'},
 '492835':{'de': 'Issum', 'en': 'Issum'},
 '492836':{'de': 'Wachtendonk', 'en': 'Wachtendonk'},
 '492837':{'de': 'Weeze', 'en': 'Weeze'},
 '492831':{'de': 'Geldern', 'en': 'Geldern'},
 '492832':{'de': 'Kevelaer', 'en': 'Kevelaer'},
 '492833':{'de': 'Kerken', 'en': 'Kerken'},
 '434852':{'de': 'Lienz', 'en': 'Lienz'},
 '434853':{'de': 'Ainet', 'en': 'Ainet'},
 '434855':{'de': 'Assling', 'en': 'Assling'},
 '434858':{'de': 'Nikolsdorf', 'en': 'Nikolsdorf'},
 '4939859':{'de': u('F\u00fcrstenwerder'), 'en': u('F\u00fcrstenwerder')},
 '4939858':{'de': 'Bietikow', 'en': 'Bietikow'},
 '4939857':{'de': 'Drense', 'en': 'Drense'},
 '4939856':{'de': 'Beenz bei Prenzlau', 'en': 'Beenz bei Prenzlau'},
 '4939855':{'de': 'Parmen-Weggun', 'en': 'Parmen-Weggun'},
 '4939854':{'de': 'Kleptow', 'en': 'Kleptow'},
 '4939853':{'de': 'Holzendorf bei Prenzlau', 'en': 'Holzendorf bei Prenzlau'},
 '4939852':{'de': u('Sch\u00f6nermark bei Prenzlau'), 'en': u('Sch\u00f6nermark bei Prenzlau')},
 '4939851':{'de': u('G\u00f6ritz bei Prenzlau'), 'en': u('G\u00f6ritz bei Prenzlau')},
 '52374':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52375':{'en': 'Ameca, JAL', 'es': 'Ameca, JAL'},
 '52376':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52377':{'en': 'Cocula/Estipac, JAL', 'es': 'Cocula/Estipac, JAL'},
 '52371':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52372':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52373':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52378':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52379':{'en': 'Jalisco/Michoacan', 'es': u('Jalisco/Michoac\u00e1n')},
 '55133462':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55133465':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '4891':{'en': 'Szczecin', 'pl': 'Szczecin'},
 '4895':{'en': u('Gorz\u00f3w Wielkopolski'), 'pl': u('Gorz\u00f3w Wielkopolski')},
 '4894':{'en': 'Koszalin', 'pl': 'Koszalin'},
 '55112754':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112752':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112753':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112751':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133466':{'en': u('S\u00e3o Vicente - SP'), 'pt': u('S\u00e3o Vicente - SP')},
 '55112900':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112231':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112532':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112533':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112536':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115513':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112535':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '46954':{'en': u('T\u00e4rnaby'), 'sv': u('T\u00e4rnaby')},
 '55115512':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49271':{'de': 'Siegen', 'en': 'Siegen'},
 '46950':{'en': 'Lycksele', 'sv': 'Lycksele'},
 '46953':{'en': u('Mal\u00e5'), 'sv': u('Mal\u00e5')},
 '46952':{'en': 'Sorsele', 'sv': 'Sorsele'},
 '55115515':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112234':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112236':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112664':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55112662':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112663':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542948':{'en': u('Chos Malal, Neuqu\u00e9n'), 'es': u('Chos Malal, Neuqu\u00e9n')},
 '437748':{'de': 'Eggelsberg', 'en': 'Eggelsberg'},
 '4936948':{'de': u('R\u00f6mhild'), 'en': u('R\u00f6mhild')},
 '4936949':{'de': u('Oberma\u00dffeld-Grimmenthal'), 'en': 'Obermassfeld-Grimmenthal'},
 '437743':{'de': 'Maria Schmolln', 'en': 'Maria Schmolln'},
 '4936945':{'de': 'Henneberg', 'en': 'Henneberg'},
 '4936946':{'de': u('Erbenhausen Th\u00fcringen'), 'en': u('Erbenhausen Th\u00fcringen')},
 '4936947':{'de': u('J\u00fcchsen'), 'en': u('J\u00fcchsen')},
 '437747':{'de': 'Kirchberg bei Mattighofen', 'en': 'Kirchberg bei Mattighofen'},
 '437746':{'de': 'Friedburg', 'en': 'Friedburg'},
 '437745':{'de': 'Lochen', 'en': 'Lochen'},
 '437744':{'de': 'Munderfing', 'en': 'Munderfing'},
 '55113715':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113714':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113716':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '5233':{'en': 'Guadalajara, JAL', 'es': 'Guadalajara, JAL'},
 '55123156':{'en': 'Piquete - SP', 'pt': 'Piquete - SP'},
 '55123157':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '55112668':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55113712':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543401':{'en': u('El Tr\u00e9bol, Santa Fe'), 'es': u('El Tr\u00e9bol, Santa Fe')},
 '55123152':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '496698':{'de': 'Schrecksbach', 'en': 'Schrecksbach'},
 '496694':{'de': u('Neukirchen Kn\u00fcll'), 'en': u('Neukirchen Kn\u00fcll')},
 '496695':{'de': 'Jesberg', 'en': 'Jesberg'},
 '496696':{'de': 'Gilserberg', 'en': 'Gilserberg'},
 '496697':{'de': 'Willingshausen', 'en': 'Willingshausen'},
 '496691':{'de': 'Schwalmstadt', 'en': 'Schwalmstadt'},
 '496692':{'de': 'Neustadt Hessen', 'en': 'Neustadt Hessen'},
 '496693':{'de': 'Neuental', 'en': 'Neuental'},
 '55113943':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123159':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '498338':{'de': u('B\u00f6hen'), 'en': u('B\u00f6hen')},
 '492223':{'de': u('K\u00f6nigswinter'), 'en': u('K\u00f6nigswinter')},
 '492222':{'de': 'Bornheim Rheinland', 'en': 'Bornheim Rheinland'},
 '492225':{'de': 'Meckenheim Rheinland', 'en': 'Meckenheim Rheinland'},
 '492224':{'de': 'Bad Honnef', 'en': 'Bad Honnef'},
 '492227':{'de': 'Bornheim-Merten', 'en': 'Bornheim-Merten'},
 '492226':{'de': 'Rheinbach', 'en': 'Rheinbach'},
 '492228':{'de': 'Remagen-Rolandseck', 'en': 'Remagen-Rolandseck'},
 '495923':{'de': u('Sch\u00fcttorf'), 'en': u('Sch\u00fcttorf')},
 '495922':{'de': 'Bad Bentheim', 'en': 'Bad Bentheim'},
 '495921':{'de': 'Nordhorn', 'en': 'Nordhorn'},
 '4933395':{'de': 'Zerpenschleuse', 'en': 'Zerpenschleuse'},
 '495251':{'de': 'Paderborn', 'en': 'Paderborn'},
 '495926':{'de': 'Engden', 'en': 'Engden'},
 '495253':{'de': 'Bad Driburg', 'en': 'Bad Driburg'},
 '495924':{'de': 'Bad Bentheim-Gildehaus', 'en': 'Bad Bentheim-Gildehaus'},
 '495259':{'de': 'Bad Driburg-Neuenheerse', 'en': 'Bad Driburg-Neuenheerse'},
 '495258':{'de': 'Salzkotten', 'en': 'Salzkotten'},
 '4933398':{'de': 'Werneuchen', 'en': 'Werneuchen'},
 '55114312':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '441458':{'en': 'Glastonbury'},
 '441456':{'en': 'Glenurquhart'},
 '441457':{'en': 'Glossop'},
 '441454':{'en': 'Chipping Sodbury'},
 '441455':{'en': 'Hinckley'},
 '441452':{'en': 'Gloucester'},
 '441453':{'en': 'Dursley'},
 '441450':{'en': 'Hawick'},
 '441451':{'en': 'Stow-on-the-Wold'},
 '492599':{'de': 'Ascheberg-Herbern', 'en': 'Ascheberg-Herbern'},
 '492598':{'de': 'Senden-Ottmarsbocholt', 'en': 'Senden-Ottmarsbocholt'},
 '4933704':{'de': 'Baruth Mark', 'en': 'Baruth Mark'},
 '492593':{'de': 'Ascheberg Westfalen', 'en': 'Ascheberg Westfalen'},
 '492592':{'de': 'Selm', 'en': 'Selm'},
 '492591':{'de': u('L\u00fcdinghausen'), 'en': u('L\u00fcdinghausen')},
 '492590':{'de': u('D\u00fclmen-Buldern'), 'en': u('D\u00fclmen-Buldern')},
 '492597':{'de': 'Senden Westfalen', 'en': 'Senden Westfalen'},
 '492596':{'de': 'Nordkirchen', 'en': 'Nordkirchen'},
 '492595':{'de': 'Olfen', 'en': 'Olfen'},
 '492594':{'de': u('D\u00fclmen'), 'en': u('D\u00fclmen')},
 '437242':{'de': 'Wels', 'en': 'Wels'},
 '4933703':{'de': 'Sperenberg', 'en': 'Sperenberg'},
 '4933702':{'de': u('W\u00fcnsdorf'), 'en': u('W\u00fcnsdorf')},
 '542257':{'en': u('Mar de Aj\u00f3, Buenos Aires'), 'es': u('Mar de Aj\u00f3, Buenos Aires')},
 '55115631':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112910':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115632':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112443':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112912':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55124448':{'en': 'Cajamar - SP', 'pt': 'Cajamar - SP'},
 '55112914':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112915':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4934722':{'de': 'Preusslitz', 'en': 'Preusslitz'},
 '4934721':{'de': 'Nienburg Saale', 'en': 'Nienburg Saale'},
 '55112916':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112917':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499220':{'de': 'Kasendorf-Azendorf', 'en': 'Kasendorf-Azendorf'},
 '4936379':{'de': 'Holzengel', 'en': 'Holzengel'},
 '4936378':{'de': 'Ostramondra', 'en': 'Ostramondra'},
 '4936377':{'de': 'Rastenberg', 'en': 'Rastenberg'},
 '4936376':{'de': 'Straussfurt', 'en': 'Straussfurt'},
 '4936375':{'de': u('Kindelbr\u00fcck'), 'en': u('Kindelbr\u00fcck')},
 '4936374':{'de': 'Weissensee', 'en': 'Weissensee'},
 '4936373':{'de': u('Buttst\u00e4dt'), 'en': u('Buttst\u00e4dt')},
 '4936372':{'de': 'Kleinneuhausen', 'en': 'Kleinneuhausen'},
 '4936371':{'de': 'Schlossvippach', 'en': 'Schlossvippach'},
 '4936370':{'de': 'Grossenehrich', 'en': 'Grossenehrich'},
 '499225':{'de': 'Stadtsteinach', 'en': 'Stadtsteinach'},
 '494339':{'de': 'Christiansholm', 'en': 'Christiansholm'},
 '494338':{'de': 'Alt Duvenstedt', 'en': 'Alt Duvenstedt'},
 '498257':{'de': 'Inchenhofen', 'en': 'Inchenhofen'},
 '494331':{'de': 'Rendsburg', 'en': 'Rendsburg'},
 '494330':{'de': 'Emkendorf', 'en': 'Emkendorf'},
 '494333':{'de': 'Erfde', 'en': 'Erfde'},
 '494332':{'de': 'Hamdorf bei Rendsburg', 'en': 'Hamdorf bei Rendsburg'},
 '494335':{'de': 'Hohn bei Rendsburg', 'en': 'Hohn bei Rendsburg'},
 '494334':{'de': 'Bredenbek bei Rendsburg', 'en': 'Bredenbek bei Rendsburg'},
 '494337':{'de': 'Jevenstedt', 'en': 'Jevenstedt'},
 '494336':{'de': 'Owschlag', 'en': 'Owschlag'},
 '498707':{'de': 'Adlkofen', 'en': 'Adlkofen'},
 '499659':{'de': 'Leuchtenberg', 'en': 'Leuchtenberg'},
 '55133391':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '498253':{'de': u('P\u00f6ttmes'), 'en': u('P\u00f6ttmes')},
 '495934':{'de': u('Haren-R\u00fctenbrock'), 'en': u('Haren-R\u00fctenbrock')},
 '498702':{'de': u('W\u00f6rth an der Isar'), 'en': u('W\u00f6rth an der Isar')},
 '495935':{'de': u('Twist-Sch\u00f6ninghsdorf'), 'en': u('Twist-Sch\u00f6ninghsdorf')},
 '498251':{'de': 'Aichach', 'en': 'Aichach'},
 '495936':{'de': 'Twist', 'en': 'Twist'},
 '55114398':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '499655':{'de': u('T\u00e4nnesberg'), 'en': u('T\u00e4nnesberg')},
 '495245':{'de': 'Herzebrock-Clarholz', 'en': 'Herzebrock-Clarholz'},
 '499654':{'de': 'Pleystein', 'en': 'Pleystein'},
 '55114390':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114391':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114393':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114394':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114396':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114397':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '499871':{'de': 'Windsbach', 'en': 'Windsbach'},
 '495933':{'de': 'Lathen', 'en': 'Lathen'},
 '55113839':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113611':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113612':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113613':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113614':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113615':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113616':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496596':{'de': u('\u00dcdersdorf'), 'en': u('\u00dcdersdorf')},
 '55113618':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113619':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496595':{'de': 'Dockweiler', 'en': 'Dockweiler'},
 '496226':{'de': 'Meckesheim', 'en': 'Meckesheim'},
 '496593':{'de': 'Hillesheim Eifel', 'en': 'Hillesheim Eifel'},
 '496592':{'de': 'Daun', 'en': 'Daun'},
 '499127':{'de': 'Rosstal Mittelfrankenanken', 'en': 'Rosstal Mittelfrankenanken'},
 '499126':{'de': 'Eckental', 'en': 'Eckental'},
 '499123':{'de': 'Lauf an der Pegnitz', 'en': 'Lauf an der Pegnitz'},
 '496591':{'de': 'Gerolstein', 'en': 'Gerolstein'},
 '55114028':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '499120':{'de': 'Leinburg', 'en': 'Leinburg'},
 '55114026':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114027':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55114024':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114025':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114022':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114023':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '499129':{'de': 'Wendelstein', 'en': 'Wendelstein'},
 '499128':{'de': 'Feucht', 'en': 'Feucht'},
 '499873':{'de': 'Abenberg-Wassermungenau', 'en': 'Abenberg-Wassermungenau'},
 '499872':{'de': 'Heilsbronn', 'en': 'Heilsbronn'},
 '4415078':{'en': 'Alford (Lincs)'},
 '4415079':{'en': 'Alford (Lincs)'},
 '4415074':{'en': 'Alford (Lincs)'},
 '4415075':{'en': 'Spilsby (Horncastle)'},
 '4415076':{'en': 'Louth'},
 '4415077':{'en': 'Louth'},
 '4415070':{'en': 'Louth/Alford (Lincs)/Spilsby (Horncastle)'},
 '4415071':{'en': 'Louth/Alford (Lincs)/Spilsby (Horncastle)'},
 '4415072':{'en': 'Spilsby (Horncastle)'},
 '4415073':{'en': 'Louth'},
 '499431':{'de': 'Schwandorf', 'en': 'Schwandorf'},
 '55123311':{'en': 'Aparecida - SP', 'pt': 'Aparecida - SP'},
 '55115187':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437484':{'de': u('G\u00f6stling an der Ybbs'), 'en': u('G\u00f6stling an der Ybbs')},
 '4933094':{'de': u('L\u00f6wenberg'), 'en': u('L\u00f6wenberg')},
 '437486':{'de': 'Lunz am See', 'en': 'Lunz am See'},
 '437487':{'de': 'Gresten', 'en': 'Gresten'},
 '437480':{'de': 'Langau, Gaming', 'en': 'Langau, Gaming'},
 '4933093':{'de': u('F\u00fcrstenberg Havel'), 'en': u('F\u00fcrstenberg Havel')},
 '437483':{'de': 'Oberndorf an der Melk', 'en': 'Oberndorf an der Melk'},
 '437488':{'de': 'Steinakirchen am Forst', 'en': 'Steinakirchen am Forst'},
 '437489':{'de': 'Purgstall an der Erlauf', 'en': 'Purgstall an der Erlauf'},
 '55112257':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112256':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112255':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115189':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112253':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112252':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112251':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112259':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112258':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '437673':{'de': 'Schwanenstadt', 'en': 'Schwanenstadt'},
 '4934263':{'de': 'Hohburg', 'en': 'Hohburg'},
 '4934262':{'de': 'Falkenhain bei Wurzen', 'en': 'Falkenhain bei Wurzen'},
 '4934261':{'de': u('K\u00fchren bei Wurzen'), 'en': u('K\u00fchren bei Wurzen')},
 '437672':{'de': u('V\u00f6cklabruck'), 'en': u('V\u00f6cklabruck')},
 '437676':{'de': 'Ottnang am Hausruck', 'en': 'Ottnang am Hausruck'},
 '437260':{'de': 'Waldhausen', 'en': 'Waldhausen'},
 '437261':{'de': u('Sch\u00f6nau im M\u00fchlkreis'), 'en': u('Sch\u00f6nau im M\u00fchlkreis')},
 '437262':{'de': 'Perg', 'en': 'Perg'},
 '437263':{'de': 'Bad Zell', 'en': 'Bad Zell'},
 '437264':{'de': 'Windhaag bei Perg', 'en': 'Windhaag bei Perg'},
 '437265':{'de': 'Pabneukirchen', 'en': 'Pabneukirchen'},
 '437266':{'de': 'Bad Kreuzen', 'en': 'Bad Kreuzen'},
 '437267':{'de': u('M\u00f6nchdorf'), 'en': u('M\u00f6nchdorf')},
 '437268':{'de': 'Grein', 'en': 'Grein'},
 '437269':{'de': 'Baumgartenberg', 'en': 'Baumgartenberg'},
 '437674':{'de': 'Attnang-Puchheim', 'en': 'Attnang-Puchheim'},
 '496207':{'de': 'Wald-Michelbach', 'en': 'Wald-Michelbach'},
 '496206':{'de': 'Lampertheim', 'en': 'Lampertheim'},
 '496205':{'de': 'Hockenheim', 'en': 'Hockenheim'},
 '496204':{'de': 'Viernheim', 'en': 'Viernheim'},
 '496203':{'de': 'Ladenburg', 'en': 'Ladenburg'},
 '496202':{'de': 'Schwetzingen', 'en': 'Schwetzingen'},
 '496201':{'de': 'Weinheim Bergstr', 'en': 'Weinheim Bergstr'},
 '498384':{'de': u('R\u00f6thenbach Allg\u00e4u'), 'en': u('R\u00f6thenbach Allg\u00e4u')},
 '496209':{'de': u('M\u00f6rlenbach'), 'en': u('M\u00f6rlenbach')},
 '497066':{'de': 'Bad Rappenau-Bonfeld', 'en': 'Bad Rappenau-Bonfeld'},
 '442310':{'en': 'Portsmouth'},
 '492582':{'de': 'Everswinkel', 'en': 'Everswinkel'},
 '492583':{'de': 'Sassenberg', 'en': 'Sassenberg'},
 '543887':{'en': 'Humahuaca, Jujuy', 'es': 'Humahuaca, Jujuy'},
 '496063':{'de': u('Bad K\u00f6nig'), 'en': u('Bad K\u00f6nig')},
 '496062':{'de': 'Erbach Odenwald', 'en': 'Erbach Odenwald'},
 '496061':{'de': 'Michelstadt', 'en': 'Michelstadt'},
 '496066':{'de': 'Michelstadt-Vielbrunn', 'en': 'Michelstadt-Vielbrunn'},
 '55114620':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55114622':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '496068':{'de': 'Beerfelden', 'en': 'Beerfelden'},
 '55114624':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '499471':{'de': 'Burglengenfeld', 'en': 'Burglengenfeld'},
 '55124004':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '499473':{'de': u('Kallm\u00fcnz'), 'en': u('Kallm\u00fcnz')},
 '55133494':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133495':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '499472':{'de': 'Hohenfels Oberpfalz', 'en': 'Hohenfels Oberpfalz'},
 '55133491':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133493':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '494155':{'de': u('B\u00fcchen'), 'en': u('B\u00fcchen')},
 '55133499':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '494154':{'de': 'Trittau', 'en': 'Trittau'},
 '4938295':{'de': 'Satow bei Bad Doberan', 'en': 'Satow bei Bad Doberan'},
 '55114566':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '494837':{'de': 'Neuenkirchen Dithmarschen', 'en': 'Neuenkirchen Dithmarschen'},
 '55112040':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441665':{'en': 'Alnwick'},
 '441664':{'en': 'Melton Mowbray'},
 '441667':{'en': 'Nairn'},
 '441666':{'en': 'Malmesbury'},
 '441661':{'en': 'Prudhoe'},
 '494529':{'de': u('S\u00fcsel-Bujendorf'), 'en': u('S\u00fcsel-Bujendorf')},
 '494838':{'de': 'Tellingstedt', 'en': 'Tellingstedt'},
 '494839':{'de': u('W\u00f6hrden Dithmarschen'), 'en': u('W\u00f6hrden Dithmarschen')},
 '494836':{'de': 'Hennstedt Dithmarschen', 'en': 'Hennstedt Dithmarschen'},
 '494525':{'de': u('Ahrensb\u00f6k'), 'en': u('Ahrensb\u00f6k')},
 '494834':{'de': u('B\u00fcsum'), 'en': u('B\u00fcsum')},
 '494527':{'de': 'Bosau', 'en': 'Bosau'},
 '494832':{'de': 'Meldorf', 'en': 'Meldorf'},
 '441668':{'en': 'Bamburgh'},
 '494522':{'de': u('Pl\u00f6n'), 'en': u('Pl\u00f6n')},
 '494523':{'de': 'Malente', 'en': 'Malente'},
 '497331':{'de': 'Geislingen an der Steige', 'en': 'Geislingen an der Steige'},
 '497332':{'de': 'Lauterstein', 'en': 'Lauterstein'},
 '497333':{'de': 'Laichingen', 'en': 'Laichingen'},
 '497334':{'de': 'Deggingen', 'en': 'Deggingen'},
 '497335':{'de': 'Wiesensteig', 'en': 'Wiesensteig'},
 '497336':{'de': 'Lonsee', 'en': 'Lonsee'},
 '497337':{'de': 'Nellingen Alb', 'en': 'Nellingen Alb'},
 '493437':{'de': 'Grimma', 'en': 'Grimma'},
 '493435':{'de': 'Oschatz', 'en': 'Oschatz'},
 '493433':{'de': 'Borna Stadt', 'en': 'Borna Stadt'},
 '493431':{'de': u('D\u00f6beln'), 'en': u('D\u00f6beln')},
 '4935728':{'de': 'Uhyst Spree', 'en': 'Uhyst Spree'},
 '4935725':{'de': 'Wittichenau', 'en': 'Wittichenau'},
 '4935724':{'de': 'Lohsa', 'en': 'Lohsa'},
 '4935727':{'de': 'Burghammer', 'en': 'Burghammer'},
 '4935726':{'de': u('Gro\u00df S\u00e4rchen'), 'en': u('Gross S\u00e4rchen')},
 '4935723':{'de': 'Bernsdorf OL', 'en': 'Bernsdorf OL'},
 '434873':{'de': 'Sankt Jakob in Defereggen', 'en': 'St. Jakob in Defereggen'},
 '46393':{'en': 'Vaggeryd', 'sv': 'Vaggeryd'},
 '46392':{'en': u('Mullsj\u00f6'), 'sv': u('Mullsj\u00f6')},
 '46390':{'en': u('Gr\u00e4nna'), 'sv': u('Gr\u00e4nna')},
 '52312':{'en': 'Colima/Los Tepames, COL', 'es': 'Colima/Los Tepames, COL'},
 '52313':{'en': 'Colima', 'es': 'Colima'},
 '52311':{'en': 'Nayarit', 'es': 'Nayarit'},
 '52316':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52317':{'en': 'Autlan/El Chante, JAL', 'es': u('Autl\u00e1n/El Chante, JAL')},
 '52314':{'en': 'Manzanillo/Pena Colorada, COL', 'es': u('Manzanillo/Pe\u00f1a Colorada, COL')},
 '52315':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52318':{'en': 'Colima/Jalisco', 'es': 'Colima/Jalisco'},
 '52319':{'en': 'Nayarit', 'es': 'Nayarit'},
 '55112739':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '436471':{'de': 'Tweng', 'en': 'Tweng'},
 '55112734':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112735':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112736':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112730':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112731':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112884':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55112885':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '441273':{'en': 'Brighton'},
 '441270':{'en': 'Crewe'},
 '441271':{'en': 'Barnstaple'},
 '441276':{'en': 'Camberley'},
 '441277':{'en': 'Brentwood'},
 '441274':{'en': 'Bradford'},
 '441275':{'en': 'Clevedon'},
 '441278':{'en': 'Bridgwater'},
 '441279':{'en': 'Bishops Stortford'},
 '55113938':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113289':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113288':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113287':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113286':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113285':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113284':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113283':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113281':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113932':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112081':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112086':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112087':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112084':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112085':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112088':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112089':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '46973':{'en': 'Porjus'},
 '55114130':{'en': u('S\u00e3o Roque - SP'), 'pt': u('S\u00e3o Roque - SP')},
 '4939389':{'de': 'Schollene', 'en': 'Schollene'},
 '4939388':{'de': 'Goldbeck Altm', 'en': 'Goldbeck Altm'},
 '46977':{'en': 'Korpilombolo', 'sv': 'Korpilombolo'},
 '46976':{'en': 'Vuollerim', 'sv': 'Vuollerim'},
 '46975':{'en': 'Hakkas', 'sv': 'Hakkas'},
 '55114131':{'en': 'Pirapora do Bom Jesus - SP', 'pt': 'Pirapora do Bom Jesus - SP'},
 '4939383':{'de': 'Sandau Elbe', 'en': 'Sandau Elbe'},
 '4939382':{'de': 'Kamern', 'en': 'Kamern'},
 '46978':{'en': 'Pajala', 'sv': 'Pajala'},
 '4939387':{'de': 'Havelberg', 'en': 'Havelberg'},
 '4939386':{'de': 'Seehausen Altmark', 'en': 'Seehausen Altmark'},
 '499374':{'de': 'Eschau', 'en': 'Eschau'},
 '4939384':{'de': 'Arendsee Altmark', 'en': 'Arendsee Altmark'},
 '55112834':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114135':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '55114136':{'en': u('Ara\u00e7ariguama - SP'), 'pt': u('Ara\u00e7ariguama - SP')},
 '441896':{'en': 'Galashiels'},
 '441895':{'en': 'Uxbridge'},
 '441892':{'en': 'Tunbridge Wells'},
 '441899':{'en': 'Biggar'},
 '55113429':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55124408':{'en': 'Polvilho - SP', 'pt': 'Polvilho - SP'},
 '55113423':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113422':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55113421':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55113427':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55113426':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55113425':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55113424':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '54294':{'en': u('San Carlos de Bariloche, R\u00edo Negro'), 'es': u('San Carlos de Bariloche, R\u00edo Negro')},
 '55114722':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114813':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114812':{'en': 'Campo Limpo Paulista - SP', 'pt': 'Campo Limpo Paulista - SP'},
 '55114811':{'en': 'Franco da Rocha - SP', 'pt': 'Franco da Rocha - SP'},
 '55114817':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55112127':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114815':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114819':{'en': 'Franco da Rocha - SP', 'pt': 'Franco da Rocha - SP'},
 '55114818':{'en': 'Terra Preta - SP', 'pt': 'Terra Preta - SP'},
 '495493':{'de': 'Neuenkirchen Kreis Vechta', 'en': 'Neuenkirchen Kreis Vechta'},
 '495492':{'de': 'Steinfeld Oldenburg', 'en': 'Steinfeld Oldenburg'},
 '4936964':{'de': u('Dermbach Rh\u00f6n'), 'en': u('Dermbach Rh\u00f6n')},
 '4419464':{'en': 'Whitehaven'},
 '4419463':{'en': 'Whitehaven'},
 '4419462':{'en': 'Whitehaven'},
 '4419461':{'en': 'Whitehaven'},
 '4419460':{'en': 'Whitehaven'},
 '542936':{'en': u('Carhu\u00e9, Buenos Aires'), 'es': u('Carhu\u00e9, Buenos Aires')},
 '4419469':{'en': 'Whitehaven'},
 '4936969':{'de': 'Merkers', 'en': 'Merkers'},
 '55113304':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492208':{'de': 'Niederkassel', 'en': 'Niederkassel'},
 '494637':{'de': 'Sterup', 'en': 'Sterup'},
 '492203':{'de': u('K\u00f6ln-Porz'), 'en': 'Cologne-Porz'},
 '492202':{'de': 'Bergisch Gladbach', 'en': 'Bergisch Gladbach'},
 '492207':{'de': u('K\u00fcrten-D\u00fcrscheid'), 'en': u('K\u00fcrten-D\u00fcrscheid')},
 '492206':{'de': 'Overath', 'en': 'Overath'},
 '492205':{'de': u('R\u00f6srath'), 'en': u('R\u00f6srath')},
 '492204':{'de': 'Bensberg', 'en': 'Bensberg'},
 '495278':{'de': u('H\u00f6xter-Ovenhausen'), 'en': u('H\u00f6xter-Ovenhausen')},
 '495277':{'de': u('H\u00f6xter-F\u00fcrstenau'), 'en': u('H\u00f6xter-F\u00fcrstenau')},
 '495276':{'de': u('Marienm\u00fcnster'), 'en': u('Marienm\u00fcnster')},
 '495275':{'de': u('H\u00f6xter-Ottbergen'), 'en': u('H\u00f6xter-Ottbergen')},
 '495274':{'de': 'Nieheim', 'en': 'Nieheim'},
 '495273':{'de': 'Beverungen', 'en': 'Beverungen'},
 '495272':{'de': 'Brakel Westfalen', 'en': 'Brakel Westfalen'},
 '495271':{'de': u('H\u00f6xter'), 'en': u('H\u00f6xter')},
 '441478':{'en': 'Isle of Skye - Portree'},
 '441470':{'en': 'Isle of Skye - Edinbane'},
 '441471':{'en': 'Isle of Skye - Broadford'},
 '441472':{'en': 'Grimsby'},
 '441473':{'en': 'Ipswich'},
 '441474':{'en': 'Gravesend'},
 '441475':{'en': 'Greenock'},
 '441476':{'en': 'Grantham'},
 '441477':{'en': 'Holmes Chapel'},
 '499556':{'de': 'Geiselwind', 'en': 'Geiselwind'},
 '441782':{'en': 'Stoke-on-Trent'},
 '441780':{'en': 'Stamford'},
 '441786':{'en': 'Stirling'},
 '441787':{'en': 'Sudbury'},
 '441784':{'en': 'Staines'},
 '441785':{'en': 'Stafford'},
 '441788':{'en': 'Rugby'},
 '441789':{'en': 'Stratford-upon-Avon'},
 '499822':{'de': 'Bechhofen an der Heide', 'en': 'Bechhofen an der Heide'},
 '499823':{'de': 'Leutershausen', 'en': 'Leutershausen'},
 '492391':{'de': 'Plettenberg', 'en': 'Plettenberg'},
 '499555':{'de': u('Schl\u00fcsselfeld-Aschbach'), 'en': u('Schl\u00fcsselfeld-Aschbach')},
 '499826':{'de': 'Weidenbach Mittelfranken', 'en': 'Weidenbach Mittelfranken'},
 '493334':{'de': 'Eberswalde', 'en': 'Eberswalde'},
 '493335':{'de': 'Finowfurt', 'en': 'Finowfurt'},
 '493337':{'de': 'Biesenthal Brandenburg', 'en': 'Biesenthal Brandenburg'},
 '493331':{'de': u('Angerm\u00fcnde'), 'en': u('Angerm\u00fcnde')},
 '493332':{'de': 'Schwedt/Oder', 'en': 'Schwedt/Oder'},
 '499825':{'de': 'Herrieden', 'en': 'Herrieden'},
 '493338':{'de': 'Bernau Brandenburg', 'en': 'Bernau Brandenburg'},
 '499552':{'de': 'Burghaslach', 'en': 'Burghaslach'},
 '499828':{'de': u('R\u00fcgland'), 'en': u('R\u00fcgland')},
 '499829':{'de': 'Flachslanden', 'en': 'Flachslanden'},
 '52638':{'en': 'Puerto Penasco, SON', 'es': 'Puerto Penasco, SON'},
 '499551':{'de': 'Burgwindheim', 'en': 'Burgwindheim'},
 '498766':{'de': 'Gammelsdorf', 'en': 'Gammelsdorf'},
 '498847':{'de': u('Obers\u00f6chering'), 'en': u('Obers\u00f6chering')},
 '498764':{'de': 'Mauern Kreis Freising', 'en': 'Mauern Kreis Freising'},
 '498765':{'de': 'Bruckberg Niederbayern', 'en': 'Bruckberg Niederbayern'},
 '498762':{'de': 'Wartenberg Oberbayern', 'en': 'Wartenberg Oberbayern'},
 '55113633':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498662':{'de': 'Siegsdorf Kreis Traunstein', 'en': 'Siegsdorf Kreis Traunstein'},
 '498845':{'de': 'Bad Kohlgrub', 'en': 'Bad Kohlgrub'},
 '55113638':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '542393':{'en': 'Salazar, Buenos Aires', 'es': 'Salazar, Buenos Aires'},
 '542392':{'en': 'Trenque Lauquen, Buenos Aires', 'es': 'Trenque Lauquen, Buenos Aires'},
 '542396':{'en': u('Pehuaj\u00f3, Buenos Aires'), 'es': u('Pehuaj\u00f3, Buenos Aires')},
 '542395':{'en': 'Carlos Casares, Buenos Aires', 'es': 'Carlos Casares, Buenos Aires'},
 '542394':{'en': u('Tres Lomas/Salliquel\u00f3, Buenos Aires'), 'es': u('Tres Lomas/Salliquel\u00f3, Buenos Aires')},
 '498666':{'de': 'Teisendorf', 'en': 'Teisendorf'},
 '499141':{'de': u('Wei\u00dfenburg in Bayern'), 'en': 'Weissenburg in Bayern'},
 '494644':{'de': 'Karby', 'en': 'Karby'},
 '499143':{'de': 'Pappenheim Mittelfranken', 'en': 'Pappenheim Mittelfranken'},
 '494646':{'de': 'Mohrkirch', 'en': 'Mohrkirch'},
 '494641':{'de': u('S\u00fcderbrarup'), 'en': u('S\u00fcderbrarup')},
 '498665':{'de': 'Inzell', 'en': 'Inzell'},
 '494643':{'de': 'Gelting Angeln', 'en': 'Gelting Angeln'},
 '494642':{'de': 'Kappeln Schlei', 'en': 'Kappeln Schlei'},
 '499149':{'de': 'Weissenburg-Suffersheim', 'en': 'Weissenburg-Suffersheim'},
 '499148':{'de': 'Ettenstatt', 'en': 'Ettenstatt'},
 '55133372':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '55114048':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114049':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '498443':{'de': 'Hohenwart Paar', 'en': 'Hohenwart Paar'},
 '498442':{'de': 'Wolnzach', 'en': 'Wolnzach'},
 '498441':{'de': 'Pfaffenhofen an der Ilm', 'en': 'Pfaffenhofen an der Ilm'},
 '498331':{'de': 'Memmingen', 'en': 'Memmingen'},
 '498330':{'de': 'Legau', 'en': 'Legau'},
 '495505':{'de': 'Hardegsen', 'en': 'Hardegsen'},
 '498445':{'de': 'Gerolsbach', 'en': 'Gerolsbach'},
 '495504':{'de': u('Friedland Kreis G\u00f6ttingen'), 'en': u('Friedland Kreis G\u00f6ttingen')},
 '498444':{'de': 'Schweitenkirchen', 'en': 'Schweitenkirchen'},
 '495507':{'de': u('Eberg\u00f6tzen'), 'en': u('Eberg\u00f6tzen')},
 '46560':{'en': 'Torsby', 'sv': 'Torsby'},
 '46563':{'en': 'Hagfors-Munkfors', 'sv': 'Hagfors-Munkfors'},
 '46564':{'en': u('Syssleb\u00e4ck'), 'sv': u('Syssleb\u00e4ck')},
 '46565':{'en': 'Sunne', 'sv': 'Sunne'},
 '49395':{'de': 'Neubrandenburg', 'en': 'Neubrandenburg'},
 '499132':{'de': 'Herzogenaurach', 'en': 'Herzogenaurach'},
 '4938738':{'de': u('Karow bei L\u00fcbz'), 'en': u('Karow bei L\u00fcbz')},
 '499133':{'de': 'Baiersdorf Mittelfrankenanken', 'en': 'Baiersdorf Mittelfrankenanken'},
 '495503':{'de': u('N\u00f6rten-Hardenberg'), 'en': u('N\u00f6rten-Hardenberg')},
 '4938731':{'de': u('L\u00fcbz'), 'en': u('L\u00fcbz')},
 '499134':{'de': 'Neunkirchen am Brand', 'en': 'Neunkirchen am Brand'},
 '4938733':{'de': u('Karbow-Vietl\u00fcbbe'), 'en': u('Karbow-Vietl\u00fcbbe')},
 '4938732':{'de': u('Gallin bei L\u00fcbz'), 'en': u('Gallin bei L\u00fcbz')},
 '4938735':{'de': 'Plau am See', 'en': 'Plau am See'},
 '4938737':{'de': 'Ganzlin', 'en': 'Ganzlin'},
 '4938736':{'de': 'Goldberg', 'en': 'Goldberg'},
 '495062':{'de': 'Holle bei Hildesheim', 'en': 'Holle bei Hildesheim'},
 '495063':{'de': 'Bad Salzdetfurth', 'en': 'Bad Salzdetfurth'},
 '495060':{'de': 'Bodenburg', 'en': 'Bodenburg'},
 '495066':{'de': 'Sarstedt', 'en': 'Sarstedt'},
 '495067':{'de': 'Bockenem', 'en': 'Bockenem'},
 '495064':{'de': u('Gro\u00df D\u00fcngen'), 'en': u('Gross D\u00fcngen')},
 '496633':{'de': 'Homberg Ohm', 'en': 'Homberg Ohm'},
 '495068':{'de': 'Elze Leine', 'en': 'Elze Leine'},
 '495069':{'de': 'Nordstemmen', 'en': 'Nordstemmen'},
 '496630':{'de': 'Schwalmtal-Storndorf', 'en': 'Schwalmtal-Storndorf'},
 '496631':{'de': 'Alsfeld', 'en': 'Alsfeld'},
 '496324':{'de': 'Hassloch', 'en': 'Hassloch'},
 '55114132':{'en': 'Pirapora do Bom Jesus - SP', 'pt': 'Pirapora do Bom Jesus - SP'},
 '496325':{'de': 'Lambrecht Pfalz', 'en': 'Lambrecht Pfalz'},
 '495404':{'de': 'Westerkappeln', 'en': 'Westerkappeln'},
 '496326':{'de': 'Deidesheim', 'en': 'Deidesheim'},
 '495405':{'de': u('Hasbergen Kreis Osnabr\u00fcck'), 'en': u('Hasbergen Kreis Osnabr\u00fcck')},
 '496635':{'de': 'Kirtorf', 'en': 'Kirtorf'},
 '495406':{'de': 'Belm', 'en': 'Belm'},
 '495407':{'de': 'Wallenhorst', 'en': 'Wallenhorst'},
 '55114133':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '495401':{'de': u('Georgsmarienh\u00fctte'), 'en': u('Georgsmarienh\u00fctte')},
 '55112279':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112278':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112275':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112274':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112277':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '495403':{'de': 'Bad Iburg', 'en': 'Bad Iburg'},
 '55112271':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112273':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112272':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49931':{'de': u('W\u00fcrzburg'), 'en': u('W\u00fcrzburg')},
 '493933':{'de': 'Genthin', 'en': 'Genthin'},
 '493931':{'de': 'Stendal', 'en': 'Stendal'},
 '493937':{'de': 'Osterburg Altmark', 'en': 'Osterburg Altmark'},
 '5042244':{'en': 'Tegucigalpa'},
 '493935':{'de': u('Tangerh\u00fctte'), 'en': u('Tangerh\u00fctte')},
 '4934241':{'de': 'Jesewitz', 'en': 'Jesewitz'},
 '4934243':{'de': u('Bad D\u00fcben'), 'en': u('Bad D\u00fcben')},
 '4934242':{'de': 'Hohenpriessnitz', 'en': 'Hohenpriessnitz'},
 '4934244':{'de': 'Mockrehna', 'en': 'Mockrehna'},
 '495686':{'de': u('Schwarzenborn Kn\u00fcll'), 'en': u('Schwarzenborn Kn\u00fcll')},
 '495684':{'de': 'Frielendorf', 'en': 'Frielendorf'},
 '495685':{'de': u('Kn\u00fcllwald'), 'en': u('Kn\u00fcllwald')},
 '495682':{'de': 'Borken Hessen', 'en': 'Borken Hessen'},
 '495683':{'de': 'Wabern Hessen', 'en': 'Wabern Hessen'},
 '495681':{'de': 'Homberg Efze', 'en': 'Homberg Efze'},
 '496261':{'de': 'Mosbach Baden', 'en': 'Mosbach Baden'},
 '496263':{'de': 'Neckargerach', 'en': 'Neckargerach'},
 '496262':{'de': 'Aglasterhausen', 'en': 'Aglasterhausen'},
 '496265':{'de': 'Billigheim Baden', 'en': 'Billigheim Baden'},
 '496264':{'de': 'Neudenau', 'en': 'Neudenau'},
 '496267':{'de': 'Fahrenbach Baden', 'en': 'Fahrenbach Baden'},
 '496266':{'de': 'Hassmersheim', 'en': 'Hassmersheim'},
 '496269':{'de': u('Gundelsheim W\u00fcrttemberg'), 'en': u('Gundelsheim W\u00fcrttemberg')},
 '496268':{'de': u('H\u00fcffenhardt'), 'en': u('H\u00fcffenhardt')},
 '55124611':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '499468':{'de': 'Zell Oberpfalz', 'en': 'Zell Oberpfalz'},
 '55114608':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '55114609':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '496085':{'de': 'Waldsolms', 'en': 'Waldsolms'},
 '496084':{'de': 'Schmitten Taunus', 'en': 'Schmitten Taunus'},
 '496087':{'de': 'Waldems', 'en': 'Waldems'},
 '496086':{'de': u('Gr\u00e4venwiesbach'), 'en': u('Gr\u00e4venwiesbach')},
 '496081':{'de': 'Usingen', 'en': 'Usingen'},
 '55114603':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '496083':{'de': 'Weilrod', 'en': 'Weilrod'},
 '496082':{'de': 'Niederreifenberg', 'en': 'Niederreifenberg'},
 '498807':{'de': u('Die\u00dfen am Ammersee'), 'en': 'Diessen am Ammersee'},
 '55112247':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114549':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114548':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '496887':{'de': 'Schmelz Saar', 'en': 'Schmelz Saar'},
 '496881':{'de': 'Lebach', 'en': 'Lebach'},
 '55114543':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114545':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '496888':{'de': 'Lebach-Steinbach', 'en': 'Lebach-Steinbach'},
 '55114547':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '55114546':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '54343':{'en': u('Paran\u00e1, Entre R\u00edos'), 'es': u('Paran\u00e1, Entre R\u00edos')},
 '54341':{'en': 'Rosario, Santa Fe', 'es': 'Rosario, Santa Fe'},
 '497681':{'de': 'Waldkirch Breisgau', 'en': 'Waldkirch Breisgau'},
 '497682':{'de': 'Elzach', 'en': 'Elzach'},
 '497683':{'de': 'Simonswald', 'en': 'Simonswald'},
 '497684':{'de': 'Glottertal', 'en': 'Glottertal'},
 '497685':{'de': 'Gutach-Bleibach', 'en': 'Gutach-Bleibach'},
 '497138':{'de': 'Schwaigern', 'en': 'Schwaigern'},
 '497139':{'de': 'Neuenstadt am Kocher', 'en': 'Neuenstadt am Kocher'},
 '497136':{'de': 'Bad Friedrichshall', 'en': 'Bad Friedrichshall'},
 '497134':{'de': 'Weinsberg', 'en': 'Weinsberg'},
 '497135':{'de': 'Brackenheim', 'en': 'Brackenheim'},
 '497132':{'de': 'Neckarsulm', 'en': 'Neckarsulm'},
 '497133':{'de': 'Lauffen am Neckar', 'en': 'Lauffen am Neckar'},
 '497130':{'de': u('L\u00f6wenstein W\u00fcrttemberg'), 'en': u('L\u00f6wenstein W\u00fcrttemberg')},
 '497131':{'de': 'Heilbronn Neckar', 'en': 'Heilbronn Neckar'},
 '498158':{'de': 'Tutzing', 'en': 'Tutzing'},
 '498157':{'de': 'Feldafing', 'en': 'Feldafing'},
 '498151':{'de': 'Starnberg', 'en': 'Starnberg'},
 '498153':{'de': 'Wessling', 'en': 'Wessling'},
 '498152':{'de': 'Herrsching am Ammersee', 'en': 'Herrsching am Ammersee'},
 '441647':{'en': 'Moretonhampstead'},
 '441646':{'en': 'Milford Haven'},
 '441644':{'en': 'New Galloway'},
 '441643':{'en': 'Minehead'},
 '441642':{'en': 'Middlesbrough'},
 '441641':{'en': 'Strathy'},
 '5018':{'en': 'Cayo District'},
 '497358':{'de': u('Eberhardzell-F\u00fcramoos'), 'en': u('Eberhardzell-F\u00fcramoos')},
 '497352':{'de': 'Ochsenhausen', 'en': 'Ochsenhausen'},
 '497353':{'de': 'Schwendi', 'en': 'Schwendi'},
 '497351':{'de': u('Biberach an der Ri\u00df'), 'en': 'Biberach an der Riss'},
 '497356':{'de': 'Schemmerhofen', 'en': 'Schemmerhofen'},
 '497357':{'de': 'Attenweiler', 'en': 'Attenweiler'},
 '497354':{'de': 'Erolzheim', 'en': 'Erolzheim'},
 '497355':{'de': u('Hochdorf Ri\u00df'), 'en': 'Hochdorf Riss'},
 '498379':{'de': 'Waltenhofen-Oberdorf', 'en': 'Waltenhofen-Oberdorf'},
 '498378':{'de': 'Buchenberg bei Kempten', 'en': 'Buchenberg bei Kempten'},
 '498586':{'de': 'Hauzenberg', 'en': 'Hauzenberg'},
 '498370':{'de': 'Wiggensbach', 'en': 'Wiggensbach'},
 '498373':{'de': 'Altusried', 'en': 'Altusried'},
 '498372':{'de': u('Oberg\u00fcnzburg'), 'en': u('Oberg\u00fcnzburg')},
 '498375':{'de': 'Weitnau', 'en': 'Weitnau'},
 '498374':{'de': 'Dietmannsried', 'en': 'Dietmannsried'},
 '498377':{'de': 'Unterthingau', 'en': 'Unterthingau'},
 '498376':{'de': u('Sulzberg Allg\u00e4u'), 'en': u('Sulzberg Allg\u00e4u')},
 '52998':{'en': 'Quintana Roo', 'es': 'Quintana Roo'},
 '52999':{'en': 'Conkal/Merida, YUC', 'es': u('Conkal/M\u00e9rida, YUC')},
 '52994':{'en': 'Oaxaca', 'es': 'Oaxaca'},
 '52995':{'en': 'Magdalena Tequisistlan/Santa Maria Jalapa Del Marquez, OAX', 'es': u('Magdalena Tequisistl\u00e1n/Santa Maria Jalapa del Marqu\u00e9s, OAX')},
 '52996':{'en': 'Campeche', 'es': 'Campeche'},
 '52997':{'en': 'Yucatan', 'es': u('Yucat\u00e1n')},
 '52991':{'en': 'Yucatan', 'es': u('Yucat\u00e1n')},
 '52992':{'en': 'Chiapas', 'es': 'Chiapas'},
 '52993':{'en': 'Tabasco', 'es': 'Tabasco'},
 '55112712':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112861':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112862':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112864':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112717':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112715':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55113354':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112719':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441258':{'en': 'Blandford'},
 '441259':{'en': 'Alloa'},
 '441254':{'en': 'Blackburn'},
 '441255':{'en': 'Clacton-on-Sea'},
 '441256':{'en': 'Basingstoke'},
 '441257':{'en': 'Coppull'},
 '441250':{'en': 'Blairgowrie'},
 '441252':{'en': 'Aldershot'},
 '441253':{'en': 'Blackpool'},
 '498582':{'de': u('R\u00f6hrnbach'), 'en': u('R\u00f6hrnbach')},
 '494106':{'de': 'Quickborn Kreis Pinneberg', 'en': 'Quickborn Kreis Pinneberg'},
 '494107':{'de': 'Siek Kreis Stormarn', 'en': 'Siek Kreis Stormarn'},
 '494104':{'de': u('Aum\u00fchle bei Hamburg'), 'en': u('Aum\u00fchle bei Hamburg')},
 '494105':{'de': 'Seevetal', 'en': 'Seevetal'},
 '494102':{'de': 'Ahrensburg', 'en': 'Ahrensburg'},
 '494103':{'de': 'Wedel', 'en': 'Wedel'},
 '499352':{'de': 'Lohr am Main', 'en': 'Lohr am Main'},
 '494101':{'de': 'Pinneberg', 'en': 'Pinneberg'},
 '499365':{'de': 'Rimpar', 'en': 'Rimpar'},
 '499358':{'de': u('G\u00f6ssenheim'), 'en': u('G\u00f6ssenheim')},
 '499359':{'de': 'Karlstadt-Wiesenfeld', 'en': 'Karlstadt-Wiesenfeld'},
 '494108':{'de': 'Rosengarten Kreis Harburg', 'en': 'Rosengarten Kreis Harburg'},
 '494109':{'de': 'Tangstedt Bz Hamburg', 'en': 'Tangstedt Bz Hamburg'},
 '46918':{'en': u('Norsj\u00f6'), 'sv': u('Norsj\u00f6')},
 '49231':{'de': 'Dortmund', 'en': 'Dortmund'},
 '46910':{'en': u('Skellefte\u00e5'), 'sv': u('Skellefte\u00e5')},
 '49721':{'de': 'Karlsruhe', 'en': 'Karlsruhe'},
 '46912':{'en': 'Byske', 'sv': 'Byske'},
 '46915':{'en': u('Bastutr\u00e4sk'), 'sv': u('Bastutr\u00e4sk')},
 '49234':{'de': 'Bochum', 'en': 'Bochum'},
 '46916':{'en': u('J\u00f6rn'), 'sv': u('J\u00f6rn')},
 '497944':{'de': 'Kupferzell', 'en': 'Kupferzell'},
 '494770':{'de': 'Wischhafen', 'en': 'Wischhafen'},
 '4859':{'en': 'Slupsk', 'pl': u('S\u0142upsk')},
 '4858':{'en': u('Gda\u0144sk'), 'pl': u('Gda\u0144sk')},
 '4856':{'en': u('Toru\u0144'), 'pl': u('Toru\u0144')},
 '4936652':{'de': 'Wurzbach', 'en': 'Wurzbach'},
 '4936653':{'de': u('Lehesten Th\u00fcringer Wald'), 'en': u('Lehesten Th\u00fcringer Wald')},
 '4852':{'en': 'Bydgoszcz', 'pl': 'Bydgoszcz'},
 '55113403':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55113402':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55113404':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '55113409':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55113408':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '494772':{'de': 'Oberndorf Oste', 'en': 'Oberndorf Oste'},
 '543585':{'en': u('Adelia Mar\u00eda, C\u00f3rdoba'), 'es': u('Adelia Mar\u00eda, C\u00f3rdoba')},
 '543584':{'en': u('La Carlota, C\u00f3rdoba'), 'es': u('La Carlota, C\u00f3rdoba')},
 '543583':{'en': u('Vicu\u00f1a Mackenna, C\u00f3rdoba'), 'es': u('Vicu\u00f1a Mackenna, C\u00f3rdoba')},
 '543582':{'en': u('Sampacho, C\u00f3rdoba'), 'es': u('Sampacho, C\u00f3rdoba')},
 '55114442':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '55114837':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114443':{'en': 'Franco da Rocha - SP', 'pt': 'Franco da Rocha - SP'},
 '55114444':{'en': 'Franco da Rocha - SP', 'pt': 'Franco da Rocha - SP'},
 '499364':{'de': 'Zellingen', 'en': 'Zellingen'},
 '55114445':{'en': 'Caieiras - SP', 'pt': 'Caieiras - SP'},
 '55114446':{'en': 'Cajamar - SP', 'pt': 'Cajamar - SP'},
 '55114449':{'en': 'Franco da Rocha - SP', 'pt': 'Franco da Rocha - SP'},
 '495475':{'de': 'Bohmte-Hunteburg', 'en': 'Bohmte-Hunteburg'},
 '495474':{'de': 'Stemwede-Dielingen', 'en': 'Stemwede-Dielingen'},
 '495476':{'de': 'Ostercappeln-Venne', 'en': 'Ostercappeln-Venne'},
 '495471':{'de': 'Bohmte', 'en': 'Bohmte'},
 '542983':{'en': 'Tres Arroyos, Buenos Aires', 'es': 'Tres Arroyos, Buenos Aires'},
 '495473':{'de': 'Ostercappeln', 'en': 'Ostercappeln'},
 '495472':{'de': 'Bad Essen', 'en': 'Bad Essen'},
 '55115973':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115972':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113919':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '46928':{'en': 'Harads', 'sv': 'Harads'},
 '46951':{'en': 'Storuman', 'sv': 'Storuman'},
 '55113596':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '46929':{'en': u('\u00c4lvsbyn'), 'sv': u('\u00c4lvsbyn')},
 '55113594':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496746':{'de': 'Pfalzfeld', 'en': 'Pfalzfeld'},
 '496747':{'de': 'Emmelshausen', 'en': 'Emmelshausen'},
 '496744':{'de': 'Oberwesel', 'en': 'Oberwesel'},
 '496745':{'de': 'Gondershausen', 'en': 'Gondershausen'},
 '496742':{'de': 'Boppard', 'en': 'Boppard'},
 '496743':{'de': 'Bacharach', 'en': 'Bacharach'},
 '496741':{'de': 'St Goar', 'en': 'St Goar'},
 '492625':{'de': 'Ochtendung', 'en': 'Ochtendung'},
 '492624':{'de': u('H\u00f6hr-Grenzhausen'), 'en': u('H\u00f6hr-Grenzhausen')},
 '492627':{'de': 'Braubach', 'en': 'Braubach'},
 '492626':{'de': 'Selters Westferwald', 'en': 'Selters Westferwald'},
 '492621':{'de': 'Lahnstein', 'en': 'Lahnstein'},
 '492620':{'de': u('Neuh\u00e4usel Westerwald'), 'en': u('Neuh\u00e4usel Westerwald')},
 '492623':{'de': 'Ransbach-Baumbach', 'en': 'Ransbach-Baumbach'},
 '492622':{'de': 'Bendorf am Rhein', 'en': 'Bendorf am Rhein'},
 '492628':{'de': 'Rhens', 'en': 'Rhens'},
 '4936333':{'de': 'Heringen Helme', 'en': 'Heringen Helme'},
 '4936332':{'de': 'Ellrich', 'en': 'Ellrich'},
 '4936331':{'de': 'Ilfeld', 'en': 'Ilfeld'},
 '4936330':{'de': 'Grossberndten', 'en': 'Grossberndten'},
 '4936337':{'de': 'Schiedungen', 'en': 'Schiedungen'},
 '4936336':{'de': 'Klettenberg', 'en': 'Klettenberg'},
 '4936335':{'de': 'Grosswechsungen', 'en': 'Grosswechsungen'},
 '4936334':{'de': 'Wolkramshausen', 'en': 'Wolkramshausen'},
 '4936338':{'de': 'Bleicherode', 'en': 'Bleicherode'},
 '43732':{'de': 'Linz', 'en': 'Linz'},
 '493685':{'de': 'Hildburghausen', 'en': 'Hildburghausen'},
 '493686':{'de': 'Eisfeld', 'en': 'Eisfeld'},
 '493681':{'de': 'Suhl', 'en': 'Suhl'},
 '493682':{'de': 'Zella-Mehlis', 'en': 'Zella-Mehlis'},
 '493683':{'de': 'Schmalkalden', 'en': 'Schmalkalden'},
 '52297':{'en': 'Alvarado, VER', 'es': 'Alvarado, VER'},
 '52296':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52294':{'en': 'Veracruz', 'es': 'Veracruz'},
 '4936484':{'de': u('Knau bei P\u00f6\u00dfneck'), 'en': u('Knau bei P\u00f6ssneck')},
 '4936481':{'de': 'Neustadt an der Orla', 'en': 'Neustadt an der Orla'},
 '497905':{'de': 'Langenburg', 'en': 'Langenburg'},
 '4936483':{'de': u('Ziegenr\u00fcck'), 'en': u('Ziegenr\u00fcck')},
 '4936482':{'de': 'Triptis', 'en': 'Triptis'},
 '497904':{'de': 'Ilshofen', 'en': 'Ilshofen'},
 '494483':{'de': u('Ovelg\u00f6nne-Gro\u00dfenmeer'), 'en': u('Ovelg\u00f6nne-Grossenmeer')},
 '494482':{'de': 'Hatten', 'en': 'Hatten'},
 '494481':{'de': 'Hatten-Sandkrug', 'en': 'Hatten-Sandkrug'},
 '494480':{'de': u('Ovelg\u00f6nne-Str\u00fcckhausen'), 'en': u('Ovelg\u00f6nne-Str\u00fcckhausen')},
 '494487':{'de': 'Grossenkneten-Huntlosen', 'en': 'Grossenkneten-Huntlosen'},
 '494486':{'de': 'Edewecht-Friedrichsfehn', 'en': 'Edewecht-Friedrichsfehn'},
 '494485':{'de': 'Elsfleth-Huntorf', 'en': 'Elsfleth-Huntorf'},
 '494484':{'de': u('Hude-W\u00fcsting'), 'en': u('Hude-W\u00fcsting')},
 '494489':{'de': 'Apen', 'en': 'Apen'},
 '494488':{'de': 'Westerstede', 'en': 'Westerstede'},
 '494241':{'de': 'Bassum', 'en': 'Bassum'},
 '55113659':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '494240':{'de': 'Syke-Heiligenfelde', 'en': 'Syke-Heiligenfelde'},
 '55113654':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113871':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113872':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113873':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113874':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494243':{'de': 'Twistringen', 'en': 'Twistringen'},
 '55113652':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113653':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '498741':{'de': 'Vilsbiburg', 'en': 'Vilsbiburg'},
 '498742':{'de': 'Velden Vils', 'en': 'Velden Vils'},
 '441745':{'en': 'Rhyl'},
 '498744':{'de': 'Gerzen', 'en': 'Gerzen'},
 '498745':{'de': 'Bodenkirchen', 'en': 'Bodenkirchen'},
 '55114192':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55115978':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441743':{'en': 'Shrewsbury'},
 '55114069':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '441740':{'en': 'Sedgefield'},
 '55115073':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114062':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114061':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114066':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114067':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '494668':{'de': u('Klanxb\u00fcll'), 'en': u('Klanxb\u00fcll')},
 '494667':{'de': u('Dageb\u00fcll'), 'en': u('Dageb\u00fcll')},
 '494666':{'de': 'Ladelund', 'en': 'Ladelund'},
 '494665':{'de': u('Emmelsb\u00fcll-Horsb\u00fcll'), 'en': u('Emmelsb\u00fcll-Horsb\u00fcll')},
 '494664':{'de': u('Neukirchen bei Nieb\u00fcll'), 'en': u('Neukirchen bei Nieb\u00fcll')},
 '494663':{'de': u('S\u00fcderl\u00fcgum'), 'en': u('S\u00fcderl\u00fcgum')},
 '494662':{'de': 'Leck', 'en': 'Leck'},
 '494661':{'de': u('Nieb\u00fcll'), 'en': u('Nieb\u00fcll')},
 '499164':{'de': 'Langenfeld Mittelfranken', 'en': 'Langenfeld Mittelfranken'},
 '499462':{'de': 'Falkenstein Oberpfalz', 'en': 'Falkenstein Oberpfalz'},
 '55114198':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '4936944':{'de': 'Rentwertshausen', 'en': 'Rentwertshausen'},
 '437742':{'de': 'Mattighofen', 'en': 'Mattighofen'},
 '46586':{'en': 'Karlskoga-Degerfors'},
 '46587':{'en': 'Nora', 'sv': 'Nora'},
 '46584':{'en': u('Lax\u00e5'), 'sv': u('Lax\u00e5')},
 '46585':{'en': u('Fjugesta-Svart\u00e5'), 'sv': u('Fjugesta-Svart\u00e5')},
 '46582':{'en': 'Hallsberg', 'sv': 'Hallsberg'},
 '46583':{'en': 'Askersund', 'sv': 'Askersund'},
 '46580':{'en': 'Kopparberg', 'sv': 'Kopparberg'},
 '46581':{'en': 'Lindesberg', 'sv': 'Lindesberg'},
 '4936940':{'de': 'Oepfershausen', 'en': 'Oepfershausen'},
 '4936941':{'de': 'Wasungen', 'en': 'Wasungen'},
 '495044':{'de': 'Springe-Eldagsen', 'en': 'Springe-Eldagsen'},
 '495045':{'de': 'Springe-Bennigsen', 'en': 'Springe-Bennigsen'},
 '4936943':{'de': u('Bettenhausen Th\u00fcringen'), 'en': u('Bettenhausen Th\u00fcringen')},
 '495041':{'de': 'Springe Deister', 'en': 'Springe Deister'},
 '495042':{'de': u('Bad M\u00fcnder am Deister'), 'en': u('Bad M\u00fcnder am Deister')},
 '495043':{'de': 'Lauenau', 'en': 'Lauenau'},
 '55123421':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123351':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123424':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123354':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123018':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '497154':{'de': 'Kornwestheim', 'en': 'Kornwestheim'},
 '497624':{'de': 'Grenzach-Wyhlen', 'en': 'Grenzach-Wyhlen'},
 '497625':{'de': 'Zell im Wiesental', 'en': 'Zell im Wiesental'},
 '497622':{'de': 'Schopfheim', 'en': 'Schopfheim'},
 '498446':{'de': u('P\u00f6rnbach'), 'en': u('P\u00f6rnbach')},
 '497151':{'de': 'Waiblingen', 'en': 'Waiblingen'},
 '437448':{'de': 'Kematen an der Ybbs', 'en': 'Kematen an der Ybbs'},
 '55112292':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112291':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112297':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492472':{'de': 'Monschau', 'en': 'Monschau'},
 '55112295':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112294':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933051':{'de': 'Nassenheide', 'en': 'Nassenheide'},
 '437442':{'de': 'Waidhofen an der Ybbs', 'en': 'Waidhofen an der Ybbs'},
 '437443':{'de': 'Ybbsitz', 'en': 'Ybbsitz'},
 '437444':{'de': 'Opponitz', 'en': 'Opponitz'},
 '437445':{'de': 'Hollenstein an der Ybbs', 'en': 'Hollenstein an der Ybbs'},
 '4933056':{'de': u('M\u00fchlenbeck Kreis Oberhavel'), 'en': u('M\u00fchlenbeck Kreis Oberhavel')},
 '55112456':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '499088':{'de': u('M\u00f6nchsdeggingen'), 'en': u('M\u00f6nchsdeggingen')},
 '49911':{'de': u('N\u00fcrnberg'), 'en': 'Nuremberg'},
 '4938753':{'de': u('W\u00f6bbelin'), 'en': u('W\u00f6bbelin')},
 '4938752':{'de': 'Zierzow bei Ludwigslust', 'en': 'Zierzow bei Ludwigslust'},
 '4938751':{'de': 'Picher', 'en': 'Picher'},
 '4938750':{'de': 'Malliss', 'en': 'Malliss'},
 '4938757':{'de': 'Neustadt-Glewe', 'en': 'Neustadt-Glewe'},
 '4938756':{'de': 'Grabow', 'en': 'Grabow'},
 '4938755':{'de': 'Eldena', 'en': 'Eldena'},
 '46345':{'en': 'Hyltebruk-Torup', 'sv': 'Hyltebruk-Torup'},
 '4934223':{'de': 'Dommitzsch', 'en': 'Dommitzsch'},
 '4934222':{'de': 'Arzberg bei Torgau', 'en': 'Arzberg bei Torgau'},
 '4938759':{'de': 'Tewswoos', 'en': 'Tewswoos'},
 '4938758':{'de': u('D\u00f6mitz'), 'en': u('D\u00f6mitz')},
 '498584':{'de': 'Breitenberg Niederbayern', 'en': 'Breitenberg Niederbayern'},
 '4418909':{'en': 'Ayton'},
 '4934224':{'de': 'Belgern Sachsen', 'en': 'Belgern Sachsen'},
 '4933235':{'de': 'Friesack', 'en': 'Friesack'},
 '4933234':{'de': 'Wustermark', 'en': 'Wustermark'},
 '4933237':{'de': 'Paulinenaue', 'en': 'Paulinenaue'},
 '437227':{'de': 'Neuhofen an der Krems', 'en': 'Neuhofen an der Krems'},
 '4933231':{'de': 'Pausin', 'en': 'Pausin'},
 '4933230':{'de': u('B\u00f6rnicke Kreis Havelland'), 'en': u('B\u00f6rnicke Kreis Havelland')},
 '4933233':{'de': 'Ketzin', 'en': 'Ketzin'},
 '4933232':{'de': 'Brieselang', 'en': 'Brieselang'},
 '46612':{'en': 'Kramfors', 'sv': 'Kramfors'},
 '4933239':{'de': 'Gross Behnitz', 'en': 'Gross Behnitz'},
 '4933238':{'de': 'Senzke', 'en': 'Senzke'},
 '499504':{'de': 'Stadelhofen', 'en': 'Stadelhofen'},
 '499135':{'de': u('He\u00dfdorf Mittelfrankenanken'), 'en': 'Hessdorf Mittelfrankenanken'},
 '498581':{'de': 'Waldkirchen Niederbayern', 'en': 'Waldkirchen Niederbayern'},
 '496249':{'de': 'Guntersblum', 'en': 'Guntersblum'},
 '44141':{'en': 'Glasgow'},
 '55114998':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '496243':{'de': 'Monsheim', 'en': 'Monsheim'},
 '496534':{'de': u('M\u00fclheim Mosel'), 'en': u('M\u00fclheim Mosel')},
 '496241':{'de': 'Worms', 'en': 'Worms'},
 '496536':{'de': 'Kleinich', 'en': 'Kleinich'},
 '496531':{'de': 'Bernkastel-Kues', 'en': 'Bernkastel-Kues'},
 '496246':{'de': 'Eich Rheinhessen', 'en': 'Eich Rheinhessen'},
 '496533':{'de': u('Morbach Hunsr\u00fcck'), 'en': u('Morbach Hunsr\u00fcck')},
 '496244':{'de': 'Westhofen Rheinhessenen', 'en': 'Westhofen Rheinhessenen'},
 '495743':{'de': 'Espelkamp-Gestringen', 'en': 'Espelkamp-Gestringen'},
 '495034':{'de': 'Neustadt-Hagen', 'en': 'Neustadt-Hagen'},
 '495741':{'de': u('L\u00fcbbecke'), 'en': u('L\u00fcbbecke')},
 '495745':{'de': 'Stemwede-Levern', 'en': 'Stemwede-Levern'},
 '495032':{'de': u('Neustadt am R\u00fcbenberge'), 'en': u('Neustadt am R\u00fcbenberge')},
 '55114664':{'en': u('Embu-Gua\u00e7u - SP'), 'pt': u('Embu-Gua\u00e7u - SP')},
 '55114665':{'en': u('Embu-Gua\u00e7u - SP'), 'pt': u('Embu-Gua\u00e7u - SP')},
 '55114666':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114667':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114661':{'en': u('Embu-Gua\u00e7u - SP'), 'pt': u('Embu-Gua\u00e7u - SP')},
 '55114662':{'en': u('Embu-Gua\u00e7u - SP'), 'pt': u('Embu-Gua\u00e7u - SP')},
 '55114663':{'en': u('Embu-Gua\u00e7u - SP'), 'pt': u('Embu-Gua\u00e7u - SP')},
 '55114668':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114669':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55113392':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498326':{'de': u('Fischen im Allg\u00e4u'), 'en': u('Fischen im Allg\u00e4u')},
 '54223':{'en': 'Mar del Plata, Buenos Aires', 'es': 'Mar del Plata, Buenos Aires'},
 '498642':{'de': u('\u00dcbersee'), 'en': u('\u00dcbersee')},
 '55114529':{'en': u('Jacar\u00e9 - SP'), 'pt': u('Jacar\u00e9 - SP')},
 '55114528':{'en': u('Cabre\u00fava - SP'), 'pt': u('Cabre\u00fava - SP')},
 '55114527':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114526':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114525':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114524':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114523':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114522':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114521':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '492431':{'de': 'Erkelenz', 'en': 'Erkelenz'},
 '492432':{'de': 'Wassenberg', 'en': 'Wassenberg'},
 '492433':{'de': u('H\u00fcckelhoven'), 'en': u('H\u00fcckelhoven')},
 '492434':{'de': 'Wegberg', 'en': 'Wegberg'},
 '492435':{'de': u('Erkelenz-L\u00f6venich'), 'en': u('Erkelenz-L\u00f6venich')},
 '492436':{'de': u('Wegberg-R\u00f6dgen'), 'en': u('Wegberg-R\u00f6dgen')},
 '494872':{'de': 'Hanerau-Hademarschen', 'en': 'Hanerau-Hademarschen'},
 '494873':{'de': 'Aukrug', 'en': 'Aukrug'},
 '494871':{'de': 'Hohenwestedt', 'en': 'Hohenwestedt'},
 '494876':{'de': 'Reher Holstein', 'en': 'Reher Holstein'},
 '494877':{'de': 'Hennstedt bei Itzehoe', 'en': 'Hennstedt bei Itzehoe'},
 '494874':{'de': u('Todenb\u00fcttel'), 'en': u('Todenb\u00fcttel')},
 '494875':{'de': 'Stafstedt', 'en': 'Stafstedt'},
 '441629':{'en': 'Matlock'},
 '441628':{'en': 'Maidenhead'},
 '497376':{'de': 'Langenenslingen', 'en': 'Langenenslingen'},
 '497371':{'de': u('Riedlingen W\u00fcrttemberg'), 'en': u('Riedlingen W\u00fcrttemberg')},
 '497373':{'de': 'Zwiefalten', 'en': 'Zwiefalten'},
 '441621':{'en': 'Maldon'},
 '441620':{'en': 'North Berwick'},
 '441623':{'en': 'Mansfield'},
 '441622':{'en': 'Maidstone'},
 '441625':{'en': 'Macclesfield'},
 '441624':{'en': 'Isle of Man'},
 '441626':{'en': 'Newton Abbot'},
 '55133451':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '52452':{'en': 'Nuevo San Juan Parangaricutiro/Uruapan, MICH', 'es': 'Nuevo San Juan Parangaricutiro/Uruapan, MICH'},
 '55133454':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '55133455':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '55133456':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '55133457':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '55133458':{'en': u('Peru\u00edbe - SP'), 'pt': u('Peru\u00edbe - SP')},
 '436478':{'de': 'Zederhaus', 'en': 'Zederhaus'},
 '436479':{'de': 'Muhr', 'en': 'Muhr'},
 '436476':{'de': 'Sankt Margarethen im Lungau', 'en': 'St. Margarethen im Lungau'},
 '436477':{'de': 'Sankt Michael im Lungau', 'en': 'St. Michael im Lungau'},
 '436474':{'de': 'Tamsweg', 'en': 'Tamsweg'},
 '436475':{'de': 'Ramingstein', 'en': 'Ramingstein'},
 '4939831':{'de': 'Feldberg', 'en': 'Feldberg'},
 '436473':{'de': 'Mariapfarr', 'en': 'Mariapfarr'},
 '4939833':{'de': 'Mirow Kreis Neustrelitz', 'en': 'Mirow Kreis Neustrelitz'},
 '4939832':{'de': 'Wesenberg', 'en': 'Wesenberg'},
 '498177':{'de': u('M\u00fcnsing Starnberger See'), 'en': u('M\u00fcnsing Starnberger See')},
 '498176':{'de': 'Egling bei Wolfratshausen', 'en': 'Egling bei Wolfratshausen'},
 '498171':{'de': 'Wolfratshausen', 'en': 'Wolfratshausen'},
 '498170':{'de': u('Stra\u00dflach-Dingharting'), 'en': 'Strasslach-Dingharting'},
 '55113841':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115212':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115213':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498179':{'de': 'Eurasburg an der Loisach', 'en': 'Eurasburg an der Loisach'},
 '498178':{'de': 'Icking', 'en': 'Icking'},
 '494296':{'de': 'Schwanewede-Aschwarden', 'en': 'Schwanewede-Aschwarden'},
 '494297':{'de': 'Ottersberg-Posthausen', 'en': 'Ottersberg-Posthausen'},
 '494294':{'de': 'Riede Kreis Verden', 'en': 'Riede Kreis Verden'},
 '494295':{'de': 'Emtinghausen', 'en': 'Emtinghausen'},
 '494292':{'de': 'Ritterhude', 'en': 'Ritterhude'},
 '494293':{'de': 'Ottersberg-Fischerhude', 'en': 'Ottersberg-Fischerhude'},
 '55112840':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55112841':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494298':{'de': 'Lilienthal', 'en': 'Lilienthal'},
 '55112849':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497806':{'de': 'Bad Peterstal-Griesbach', 'en': 'Bad Peterstal-Griesbach'},
 '497807':{'de': 'Neuried Ortenaukreis', 'en': 'Neuried Ortenaukreis'},
 '497804':{'de': 'Oppenau', 'en': 'Oppenau'},
 '497805':{'de': 'Appenweier', 'en': 'Appenweier'},
 '497802':{'de': 'Oberkirch Baden', 'en': 'Oberkirch Baden'},
 '497803':{'de': 'Gengenbach', 'en': 'Gengenbach'},
 '497808':{'de': 'Hohberg bei Offenburg', 'en': 'Hohberg bei Offenburg'},
 '4933927':{'de': 'Linum', 'en': 'Linum'},
 '5174':{'en': 'Lambayeque'},
 '493473':{'de': 'Aschersleben Sachsen-Anhalt', 'en': 'Aschersleben Sachsen-Anhalt'},
 '493471':{'de': 'Bernburg Saale', 'en': 'Bernburg Saale'},
 '493476':{'de': 'Hettstedt Sachsen-Anhalt', 'en': 'Hettstedt Sachsen-Anhalt'},
 '493475':{'de': 'Lutherstadt Eisleben', 'en': 'Lutherstadt Eisleben'},
 '494120':{'de': 'Ellerhoop', 'en': 'Ellerhoop'},
 '494121':{'de': 'Elmshorn', 'en': 'Elmshorn'},
 '46935':{'en': u('V\u00e4nn\u00e4s'), 'sv': u('V\u00e4nn\u00e4s')},
 '46934':{'en': 'Robertsfors', 'sv': 'Robertsfors'},
 '46933':{'en': 'Vindeln', 'sv': 'Vindeln'},
 '494125':{'de': u('Seesterm\u00fche'), 'en': u('Seesterm\u00fche')},
 '49211':{'de': u('D\u00fcsseldorf'), 'en': u('D\u00fcsseldorf')},
 '4939348':{'de': 'Klitsche', 'en': 'Klitsche'},
 '494128':{'de': 'Kollmar', 'en': 'Kollmar'},
 '494129':{'de': 'Haseldorf', 'en': 'Haseldorf'},
 '4939345':{'de': 'Parchen', 'en': 'Parchen'},
 '4939344':{'de': u('G\u00fcsen'), 'en': u('G\u00fcsen')},
 '4939343':{'de': 'Jerichow', 'en': 'Jerichow'},
 '46248':{'en': u('R\u00e4ttvik'), 'sv': u('R\u00e4ttvik')},
 '4939341':{'de': 'Redekin', 'en': 'Redekin'},
 '493966':{'de': u('C\u00f6lpin'), 'en': u('C\u00f6lpin')},
 '55112240':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115561':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4875':{'en': u('Jelenia G\u00f3ra'), 'pl': u('Jelenia G\u00f3ra')},
 '4874':{'en': 'Walbrzych', 'pl': u('Wa\u0142brzych')},
 '4877':{'en': 'Opole', 'pl': 'Opole'},
 '4876':{'en': 'Legnica', 'pl': 'Legnica'},
 '4871':{'en': 'Wroclaw', 'pl': u('Wroc\u0142aw')},
 '55112242':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112243':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499187':{'de': u('Altdorf bei N\u00fcrnberg'), 'en': u('Altdorf bei N\u00fcrnberg')},
 '499186':{'de': 'Lauterhofen Oberpfalz', 'en': 'Lauterhofen Oberpfalz'},
 '499181':{'de': 'Neumarkt in der Oberpfalz', 'en': 'Neumarkt in der Oberpfalz'},
 '492302':{'de': 'Witten', 'en': 'Witten'},
 '499180':{'de': 'Pyrbaum', 'en': 'Pyrbaum'},
 '55112248':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499182':{'de': 'Velburg', 'en': 'Velburg'},
 '499701':{'de': 'Sandberg Unterfranken', 'en': 'Sandberg Unterfranken'},
 '55112249':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4416970':{'en': 'Brampton'},
 '4416971':{'en': 'Brampton'},
 '4416972':{'en': 'Brampton'},
 '4416973':{'en': 'Wigton'},
 '4416974':{'en': 'Raughton Head'},
 '4416975':{'en': 'Brampton'},
 '4416976':{'en': 'Brampton'},
 '4416977':{'en': 'Brampton'},
 '4416978':{'en': 'Brampton'},
 '492303':{'de': 'Unna', 'en': 'Unna'},
 '52718':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '4933923':{'de': 'Flecken Zechlin', 'en': 'Flecken Zechlin'},
 '55113467':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492981':{'de': 'Winterberg Westfalen', 'en': 'Winterberg Westfalen'},
 '492982':{'de': 'Medebach', 'en': 'Medebach'},
 '492983':{'de': 'Winterberg-Siedlinghausen', 'en': 'Winterberg-Siedlinghausen'},
 '492984':{'de': 'Hallenberg', 'en': 'Hallenberg'},
 '492985':{'de': 'Winterberg-Niedersfeld', 'en': 'Winterberg-Niedersfeld'},
 '55113461':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113272':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55122126':{'en': 'Pindamonhangaba - SP', 'pt': 'Pindamonhangaba - SP'},
 '55122127':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55122124':{'en': 'Lorena - SP', 'pt': 'Lorena - SP'},
 '55113273':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112599':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112594':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52676':{'en': 'Durango', 'es': 'Durango'},
 '4933922':{'de': 'Karwesee', 'en': 'Karwesee'},
 '55112592':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123141':{'en': 'Cruzeiro - SP', 'pt': 'Cruzeiro - SP'},
 '55114853':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55114852':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114850':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '495457':{'de': 'Hopsten-Schale', 'en': 'Hopsten-Schale'},
 '495456':{'de': 'Westerkappeln-Velpe', 'en': 'Westerkappeln-Velpe'},
 '495455':{'de': 'Tecklenburg-Brochterbeck', 'en': 'Tecklenburg-Brochterbeck'},
 '495454':{'de': u('H\u00f6rstel-Riesenbeck'), 'en': u('H\u00f6rstel-Riesenbeck')},
 '495453':{'de': 'Recke', 'en': 'Recke'},
 '495452':{'de': 'Mettingen Westfalen', 'en': 'Mettingen Westfalen'},
 '495451':{'de': u('Ibbenb\u00fcren'), 'en': u('Ibbenb\u00fcren')},
 '495459':{'de': u('H\u00f6rstel'), 'en': u('H\u00f6rstel')},
 '495458':{'de': 'Hopsten', 'en': 'Hopsten'},
 '4936928':{'de': u('Neuenhof Th\u00fcringen'), 'en': u('Neuenhof Th\u00fcringen')},
 '4936929':{'de': 'Ruhla', 'en': 'Ruhla'},
 '4935325':{'de': u('R\u00fcckersdorf bei Finsterwalde'), 'en': u('R\u00fcckersdorf bei Finsterwalde')},
 '4935324':{'de': 'Crinitz', 'en': 'Crinitz'},
 '4935327':{'de': 'Priessen', 'en': 'Priessen'},
 '4935326':{'de': u('Sch\u00f6nborn Kreis Elbe-Elster'), 'en': u('Sch\u00f6nborn Kreis Elbe-Elster')},
 '4936922':{'de': 'Gerstungen', 'en': 'Gerstungen'},
 '4936923':{'de': 'Treffurt', 'en': 'Treffurt'},
 '495183':{'de': 'Lamspringe', 'en': 'Lamspringe'},
 '495182':{'de': 'Gronau Leine', 'en': 'Gronau Leine'},
 '495185':{'de': 'Duingen', 'en': 'Duingen'},
 '495184':{'de': 'Freden Leine', 'en': 'Freden Leine'},
 '495187':{'de': 'Delligsen', 'en': 'Delligsen'},
 '4936925':{'de': 'Marksuhl', 'en': 'Marksuhl'},
 '495233':{'de': 'Steinheim Westfalen', 'en': 'Steinheim Westfalen'},
 '495232':{'de': 'Lage Lippe', 'en': 'Lage Lippe'},
 '495231':{'de': 'Detmold', 'en': 'Detmold'},
 '495237':{'de': 'Augustdorf', 'en': 'Augustdorf'},
 '495236':{'de': 'Blomberg-Grossenmarpe', 'en': 'Blomberg-Grossenmarpe'},
 '495235':{'de': 'Blomberg Lippe', 'en': 'Blomberg Lippe'},
 '495234':{'de': 'Horn-Bad Meinberg', 'en': 'Horn-Bad Meinberg'},
 '55112331':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495238':{'de': 'Nieheim-Himmighausen', 'en': 'Nieheim-Himmighausen'},
 '55112334':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112335':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112336':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123653':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '55123652':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '55123655':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '55123654':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '441438':{'en': 'Stevenage'},
 '468':{'en': 'Stockholm', 'sv': 'Stockholm'},
 '55114302':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441435':{'en': 'Heathfield'},
 '441436':{'en': 'Helensburgh'},
 '441431':{'en': 'Helmsdale'},
 '441432':{'en': 'Hereford'},
 '441433':{'en': 'Hathersage'},
 '497583':{'de': 'Bad Schussenried', 'en': 'Bad Schussenried'},
 '497582':{'de': 'Bad Buchau', 'en': 'Bad Buchau'},
 '497581':{'de': 'Saulgau', 'en': 'Saulgau'},
 '497587':{'de': 'Hosskirch', 'en': 'Hosskirch'},
 '497586':{'de': 'Herbertingen', 'en': 'Herbertingen'},
 '497585':{'de': 'Ostrach', 'en': 'Ostrach'},
 '497584':{'de': 'Altshausen', 'en': 'Altshausen'},
 '496184':{'de': 'Langenselbold', 'en': 'Langenselbold'},
 '496185':{'de': 'Hammersbach Hessen', 'en': 'Hammersbach Hessen'},
 '496186':{'de': 'Grosskrotzenburg', 'en': 'Grosskrotzenburg'},
 '496187':{'de': u('Sch\u00f6neck'), 'en': u('Sch\u00f6neck')},
 '496181':{'de': 'Hanau', 'en': 'Hanau'},
 '496182':{'de': 'Seligenstadt', 'en': 'Seligenstadt'},
 '496183':{'de': 'Erlensee', 'en': 'Erlensee'},
 '496188':{'de': 'Kahl am Main', 'en': 'Kahl am Main'},
 '55114308':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '499464':{'de': 'Walderbach', 'en': 'Walderbach'},
 '55112909':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115029':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115021':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497446':{'de': 'Lossburg', 'en': 'Lossburg'},
 '497447':{'de': 'Baiersbronn-Schwarzenberg', 'en': 'Baiersbronn-Schwarzenberg'},
 '4936071':{'de': 'Teistungen', 'en': 'Teistungen'},
 '4936072':{'de': u('Wei\u00dfenborn-L\u00fcderode'), 'en': u('Weissenborn-L\u00fcderode')},
 '4936074':{'de': 'Worbis', 'en': 'Worbis'},
 '4936075':{'de': u('Dingelst\u00e4dt Eichsfeld'), 'en': u('Dingelst\u00e4dt Eichsfeld')},
 '4936076':{'de': 'Niederorschel', 'en': 'Niederorschel'},
 '4936077':{'de': 'Grossbodungen', 'en': 'Grossbodungen'},
 '496761':{'de': u('Simmern Hunsr\u00fcck'), 'en': u('Simmern Hunsr\u00fcck')},
 '496762':{'de': 'Kastellaun', 'en': 'Kastellaun'},
 '496763':{'de': u('Kirchberg Hunsr\u00fcck'), 'en': u('Kirchberg Hunsr\u00fcck')},
 '496764':{'de': u('Rheinb\u00f6llen'), 'en': u('Rheinb\u00f6llen')},
 '496765':{'de': u('Gem\u00fcnden Hunsr\u00fcck'), 'en': u('Gem\u00fcnden Hunsr\u00fcck')},
 '496766':{'de': 'Kisselbach', 'en': 'Kisselbach'},
 '55115486':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498705':{'de': 'Altfraunhofen', 'en': 'Altfraunhofen'},
 '55112069':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497443':{'de': 'Dornstetten', 'en': 'Dornstetten'},
 '4934781':{'de': 'Greifenhagen', 'en': 'Greifenhagen'},
 '4934782':{'de': u('Mansfeld S\u00fcdharz'), 'en': u('Mansfeld S\u00fcdharz')},
 '4934783':{'de': 'Gerbstedt', 'en': 'Gerbstedt'},
 '4934785':{'de': 'Sandersleben', 'en': 'Sandersleben'},
 '492608':{'de': 'Welschneudorf', 'en': 'Welschneudorf'},
 '492607':{'de': 'Kobern-Gondorf', 'en': 'Kobern-Gondorf'},
 '492606':{'de': 'Winningen Mosel', 'en': 'Winningen Mosel'},
 '492605':{'de': u('L\u00f6f'), 'en': u('L\u00f6f')},
 '492604':{'de': 'Nassau Lahn', 'en': 'Nassau Lahn'},
 '492603':{'de': 'Bad Ems', 'en': 'Bad Ems'},
 '492602':{'de': 'Montabaur', 'en': 'Montabaur'},
 '492601':{'de': 'Nauort', 'en': 'Nauort'},
 '55112906':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112905':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498706':{'de': 'Vilsheim', 'en': 'Vilsheim'},
 '55112904':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49355':{'de': 'Cottbus', 'en': 'Cottbus'},
 '497449':{'de': 'Baiersbronn-Obertal', 'en': 'Baiersbronn-Obertal'},
 '498245':{'de': u('T\u00fcrkheim Wertach'), 'en': u('T\u00fcrkheim Wertach')},
 '52279':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52278':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52275':{'en': 'Puebla', 'es': 'Puebla'},
 '52274':{'en': 'Oaxaca', 'es': 'Oaxaca'},
 '499238':{'de': u('R\u00f6slau'), 'en': u('R\u00f6slau')},
 '52271':{'en': 'Veracruz', 'es': 'Veracruz'},
 '55113825':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52273':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52272':{'en': 'Maltrata/Orizaba, VER', 'es': 'Maltrata/Orizaba, VER'},
 '55113824':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4414239':{'en': 'Boroughbridge'},
 '4414238':{'en': 'Harrogate'},
 '499236':{'de': 'Nagel', 'en': 'Nagel'},
 '4414235':{'en': 'Harrogate'},
 '4414234':{'en': 'Boroughbridge'},
 '4414237':{'en': 'Harrogate'},
 '4414236':{'en': 'Harrogate'},
 '4414231':{'en': 'Harrogate/Boroughbridge'},
 '4414230':{'en': 'Harrogate/Boroughbridge'},
 '4414233':{'en': 'Boroughbridge'},
 '4414232':{'en': 'Harrogate'},
 '4933396':{'de': 'Klosterfelde', 'en': 'Klosterfelde'},
 '498243':{'de': 'Fuchstal', 'en': 'Fuchstal'},
 '4933397':{'de': 'Wandlitz', 'en': 'Wandlitz'},
 '55113820':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '4933394':{'de': 'Blumberg Kreis Barnim', 'en': 'Blumberg Kreis Barnim'},
 '494469':{'de': 'Wangerooge', 'en': 'Wangerooge'},
 '494468':{'de': 'Friedeburg-Reepsholt', 'en': 'Friedeburg-Reepsholt'},
 '494465':{'de': 'Friedeburg Ostfriesland', 'en': 'Friedeburg Ostfriesland'},
 '494464':{'de': 'Wittmund-Carolinensiel', 'en': 'Wittmund-Carolinensiel'},
 '494467':{'de': 'Wittmund-Funnix', 'en': 'Wittmund-Funnix'},
 '494466':{'de': 'Wittmund-Ardorf', 'en': 'Wittmund-Ardorf'},
 '494461':{'de': 'Jever', 'en': 'Jever'},
 '494463':{'de': 'Wangerland', 'en': 'Wangerland'},
 '495250':{'de': u('Delbr\u00fcck Westfalen'), 'en': u('Delbr\u00fcck Westfalen')},
 '55113672':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113673':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113670':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113676':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495925':{'de': 'Wietmarschen', 'en': 'Wietmarschen'},
 '55113674':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113675':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113856':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498249':{'de': 'Ettringen Wertach', 'en': 'Ettringen Wertach'},
 '55113678':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495252':{'de': 'Bad Lippspringe', 'en': 'Bad Lippspringe'},
 '55113852':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113853':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498248':{'de': 'Lamerdingen', 'en': 'Lamerdingen'},
 '542357':{'en': 'Carlos Tejedor, Buenos Aires', 'es': 'Carlos Tejedor, Buenos Aires'},
 '542356':{'en': 'General Pinto, Buenos Aires', 'es': 'General Pinto, Buenos Aires'},
 '498728':{'de': 'Geratskirchen', 'en': 'Geratskirchen'},
 '542354':{'en': 'Vedia, Buenos Aires', 'es': 'Vedia, Buenos Aires'},
 '542353':{'en': 'General Arenales, Buenos Aires', 'es': 'General Arenales, Buenos Aires'},
 '542352':{'en': 'Chacabuco, Buenos Aires', 'es': 'Chacabuco, Buenos Aires'},
 '498722':{'de': 'Gangkofen', 'en': 'Gangkofen'},
 '498723':{'de': 'Arnstorf', 'en': 'Arnstorf'},
 '498721':{'de': 'Eggenfelden', 'en': 'Eggenfelden'},
 '498726':{'de': u('Sch\u00f6nau Niederbayern'), 'en': u('Sch\u00f6nau Niederbayern')},
 '498727':{'de': 'Falkenberg Niederbayern', 'en': 'Falkenberg Niederbayern'},
 '498724':{'de': 'Massing', 'en': 'Massing'},
 '498725':{'de': 'Wurmannsquick', 'en': 'Wurmannsquick'},
 '55114081':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114082':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114083':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114084':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498703':{'de': 'Essenbach', 'en': 'Essenbach'},
 '494609':{'de': 'Eggebek', 'en': 'Eggebek'},
 '494608':{'de': 'Handewitt', 'en': 'Handewitt'},
 '494603':{'de': 'Havetoft', 'en': 'Havetoft'},
 '494602':{'de': 'Freienwill', 'en': 'Freienwill'},
 '494605':{'de': 'Medelby', 'en': 'Medelby'},
 '494604':{'de': 'Grossenwiehe', 'en': 'Grossenwiehe'},
 '494607':{'de': 'Janneby', 'en': 'Janneby'},
 '494606':{'de': 'Wanderup', 'en': 'Wanderup'},
 '497842':{'de': 'Kappelrodeck', 'en': 'Kappelrodeck'},
 '55112103':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112102':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112107':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112106':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112105':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112104':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112108':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494521':{'de': 'Eutin', 'en': 'Eutin'},
 '436138':{'de': 'Sankt Wolfgang im Salzkammergut', 'en': 'St. Wolfgang im Salzkammergut'},
 '436137':{'de': 'Strobl', 'en': 'Strobl'},
 '436136':{'de': 'Gosau', 'en': 'Gosau'},
 '436135':{'de': 'Bad Goisern', 'en': 'Bad Goisern'},
 '436134':{'de': 'Hallstatt', 'en': 'Hallstatt'},
 '441997':{'en': 'Strathpeffer'},
 '49681':{'de': u('Saarbr\u00fccken'), 'en': u('Saarbr\u00fccken')},
 '436131':{'de': 'Obertraun', 'en': 'Obertraun'},
 '441994':{'en': 'St Clears'},
 '55115599':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115591':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115593':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115592':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115595':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115594':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494381':{'de': u('L\u00fctjenburg'), 'en': u('L\u00fctjenburg')},
 '55115845':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4934205':{'de': u('Markranst\u00e4dt'), 'en': u('Markranst\u00e4dt')},
 '4934204':{'de': 'Schkeuditz', 'en': 'Schkeuditz'},
 '4934207':{'de': 'Zwochau', 'en': 'Zwochau'},
 '4934206':{'de': u('R\u00f6tha'), 'en': u('R\u00f6tha')},
 '543489':{'en': 'Campana, Buenos Aires', 'es': 'Campana, Buenos Aires'},
 '4934203':{'de': 'Zwenkau', 'en': 'Zwenkau'},
 '4934202':{'de': 'Delitzsch', 'en': 'Delitzsch'},
 '49971':{'de': 'Bad Kissingen', 'en': 'Bad Kissingen'},
 '4934208':{'de': u('L\u00f6bnitz bei Delitzsch'), 'en': u('L\u00f6bnitz bei Delitzsch')},
 '543482':{'en': 'Reconquista, Santa Fe', 'es': 'Reconquista, Santa Fe'},
 '543483':{'en': 'Vera, Santa Fe', 'es': 'Vera, Santa Fe'},
 '4933963':{'de': 'Wulfersdorf bei Wittstock', 'en': 'Wulfersdorf bei Wittstock'},
 '4933962':{'de': 'Heiligengrabe', 'en': 'Heiligengrabe'},
 '4933965':{'de': 'Herzsprung bei Wittstock', 'en': 'Herzsprung bei Wittstock'},
 '4933964':{'de': 'Fretzdorf', 'en': 'Fretzdorf'},
 '4933967':{'de': 'Freyenstein', 'en': 'Freyenstein'},
 '4933966':{'de': 'Dranse', 'en': 'Dranse'},
 '4933969':{'de': 'Stepenitz', 'en': 'Stepenitz'},
 '4933968':{'de': 'Meyenburg Kreis Prignitz', 'en': 'Meyenburg Kreis Prignitz'},
 '54364':{'en': u('Presidencia Roque S\u00e1enz Pe\u00f1a, Chaco'), 'es': u('Presidencia Roque S\u00e1enz Pe\u00f1a, Chaco')},
 '54362':{'en': 'Resistencia, Chaco', 'es': 'Resistencia, Chaco'},
 '497073':{'de': 'Ammerbuch', 'en': 'Ammerbuch'},
 '497072':{'de': 'Gomaringen', 'en': 'Gomaringen'},
 '497071':{'de': u('T\u00fcbingen'), 'en': u('T\u00fcbingen')},
 '55113211':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114649':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '496408':{'de': 'Buseck', 'en': 'Buseck'},
 '55114641':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55114646':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55114644':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55114645':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55114505':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114504':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114506':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114501':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114502':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114509':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114508':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497172':{'de': u('Lorch W\u00fcrttemberg'), 'en': u('Lorch W\u00fcrttemberg')},
 '497173':{'de': 'Heubach', 'en': 'Heubach'},
 '497171':{'de': u('Schw\u00e4bisch Gm\u00fcnd'), 'en': u('Schw\u00e4bisch Gm\u00fcnd')},
 '497176':{'de': 'Spraitbach', 'en': 'Spraitbach'},
 '497174':{'de': u('M\u00f6gglingen'), 'en': u('M\u00f6gglingen')},
 '497175':{'de': 'Leinzell', 'en': 'Leinzell'},
 '4939881':{'de': 'Ringenwalde bei Templin', 'en': 'Ringenwalde bei Templin'},
 '4939882':{'de': 'Gollin', 'en': 'Gollin'},
 '441603':{'en': 'Norwich'},
 '441600':{'en': 'Monmouth'},
 '494858':{'de': 'Sankt Margarethen Holstein', 'en': 'Sankt Margarethen Holstein'},
 '441606':{'en': 'Northwich'},
 '441604':{'en': 'Northampton'},
 '494854':{'de': 'Friedrichskoog', 'en': 'Friedrichskoog'},
 '494855':{'de': 'Eddelak', 'en': 'Eddelak'},
 '441609':{'en': 'Northallerton'},
 '441608':{'en': 'Chipping Norton'},
 '494851':{'de': 'Marne', 'en': 'Marne'},
 '494852':{'de': u('Brunsb\u00fcttel'), 'en': u('Brunsb\u00fcttel')},
 '494853':{'de': 'Sankt Michaelisdonn', 'en': 'Sankt Michaelisdonn'},
 '55113664':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497394':{'de': 'Schelklingen', 'en': 'Schelklingen'},
 '497395':{'de': u('Ehingen-D\u00e4chingen'), 'en': u('Ehingen-D\u00e4chingen')},
 '497392':{'de': 'Laupheim', 'en': 'Laupheim'},
 '497393':{'de': 'Munderkingen', 'en': 'Munderkingen'},
 '497391':{'de': 'Ehingen Donau', 'en': 'Ehingen Donau'},
 '55133477':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133474':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133472':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55123322':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55133471':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133478':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '55133479':{'en': 'Praia Grande - SP', 'pt': 'Praia Grande - SP'},
 '436458':{'de': u('H\u00fcttau'), 'en': u('H\u00fcttau')},
 '436452':{'de': 'Radstadt', 'en': 'Radstadt'},
 '436453':{'de': 'Filzmoos', 'en': 'Filzmoos'},
 '436454':{'de': 'Mandling', 'en': 'Mandling'},
 '436455':{'de': 'Untertauern', 'en': 'Untertauern'},
 '436456':{'de': 'Obertauern', 'en': 'Obertauern'},
 '436457':{'de': 'Flachau', 'en': 'Flachau'},
 '46486':{'en': u('Tors\u00e5s'), 'sv': u('Tors\u00e5s')},
 '46485':{'en': u('\u00d6land'), 'sv': u('\u00d6land')},
 '46481':{'en': 'Nybro', 'sv': 'Nybro'},
 '46480':{'en': 'Kalmar', 'sv': 'Kalmar'},
 '499646':{'de': 'Freihung', 'en': 'Freihung'},
 '499647':{'de': 'Kirchenthumbach', 'en': 'Kirchenthumbach'},
 '499644':{'de': 'Pressath', 'en': 'Pressath'},
 '499645':{'de': 'Eschenbach in der Oberpfalz', 'en': 'Eschenbach in der Oberpfalz'},
 '499642':{'de': 'Kemnath Stadt', 'en': 'Kemnath Stadt'},
 '499643':{'de': 'Auerbach in der Oberpfalz', 'en': 'Auerbach in der Oberpfalz'},
 '499641':{'de': u('Grafenw\u00f6hr'), 'en': u('Grafenw\u00f6hr')},
 '497821':{'de': 'Lahr Schwarzwald', 'en': 'Lahr Schwarzwald'},
 '497822':{'de': 'Ettenheim', 'en': 'Ettenheim'},
 '497823':{'de': 'Seelbach Schutter', 'en': 'Seelbach Schutter'},
 '497824':{'de': 'Schwanau', 'en': 'Schwanau'},
 '497825':{'de': 'Kippenheim', 'en': 'Kippenheim'},
 '497826':{'de': 'Schuttertal', 'en': 'Schuttertal'},
 '55113999':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113998':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113997':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113994':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113993':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113992':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113991':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113990':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493494':{'de': 'Wolfen', 'en': 'Wolfen'},
 '493496':{'de': u('K\u00f6then Anhalt'), 'en': u('K\u00f6then Anhalt')},
 '493491':{'de': 'Lutherstadt Wittenberg', 'en': 'Lutherstadt Wittenberg'},
 '493493':{'de': 'Bitterfeld', 'en': 'Bitterfeld'},
 '499398':{'de': u('Birkenfeld bei W\u00fcrzburg'), 'en': u('Birkenfeld bei W\u00fcrzburg')},
 '494148':{'de': 'Drochtersen-Assel', 'en': 'Drochtersen-Assel'},
 '494149':{'de': 'Fredenbeck', 'en': 'Fredenbeck'},
 '4934977':{'de': 'Quellendorf', 'en': 'Quellendorf'},
 '4939361':{'de': u('L\u00fcderitz'), 'en': u('L\u00fcderitz')},
 '494143':{'de': 'Drochtersen', 'en': 'Drochtersen'},
 '4939363':{'de': 'Angern', 'en': 'Angern'},
 '494141':{'de': 'Stade', 'en': 'Stade'},
 '4939365':{'de': 'Bellingen bei Stendal', 'en': 'Bellingen bei Stendal'},
 '4939364':{'de': 'Dolle', 'en': 'Dolle'},
 '494144':{'de': 'Himmelpforten', 'en': 'Himmelpforten'},
 '4939366':{'de': 'Kehnert', 'en': 'Kehnert'},
 '52486':{'en': 'San Luis Potosi', 'es': u('San Luis Potos\u00ed')},
 '52487':{'en': 'San Luis Potosi', 'es': u('San Luis Potos\u00ed')},
 '52485':{'en': 'San Luis Potosi', 'es': u('San Luis Potos\u00ed')},
 '52482':{'en': 'San Luis Potosi', 'es': u('San Luis Potos\u00ed')},
 '52483':{'en': 'San Luis Potosi', 'es': u('San Luis Potos\u00ed')},
 '52481':{'en': 'Ciudad Valles, SLP', 'es': 'Ciudad Valles, SLP'},
 '52488':{'en': 'San Luis Potosi', 'es': u('San Luis Potos\u00ed')},
 '52489':{'en': 'San Luis Potosi', 'es': u('San Luis Potos\u00ed')},
 '4813':{'en': 'Krosno', 'pl': 'Krosno'},
 '4812':{'en': u('Krak\u00f3w'), 'pl': u('Krak\u00f3w')},
 '4817':{'en': u('Rzesz\u00f3w'), 'pl': u('Rzesz\u00f3w')},
 '4816':{'en': u('Przemy\u015bl'), 'pl': u('Przemy\u015bl')},
 '4815':{'en': 'Tarnobrzeg', 'pl': 'Tarnobrzeg'},
 '4814':{'en': u('Tarn\u00f3w'), 'pl': u('Tarn\u00f3w')},
 '4936694':{'de': u('Schk\u00f6len Th\u00fcringen'), 'en': u('Schk\u00f6len Th\u00fcringen')},
 '4936695':{'de': u('S\u00f6llmnitz'), 'en': u('S\u00f6llmnitz')},
 '4818':{'en': u('Nowy S\u0105cz'), 'pl': u('Nowy S\u0105cz')},
 '4936691':{'de': u('Eisenberg Th\u00fcringen'), 'en': u('Eisenberg Th\u00fcringen')},
 '4936692':{'de': u('B\u00fcrgel'), 'en': u('B\u00fcrgel')},
 '4936693':{'de': 'Crossen an der Elster', 'en': 'Crossen an der Elster'},
 '55112828':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55112829':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55112827':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112822':{'en': 'Osasco - SP', 'pt': 'Osasco - SP'},
 '55113339':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113338':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52738':{'en': 'Mixquiahuala/Tepatepec, HGO', 'es': 'Mixquiahuala/Tepatepec, HGO'},
 '52739':{'en': 'Huitzilac/Tepoztlan, MOR', 'es': 'Huitzilac/Tepoztlan, MOR'},
 '52734':{'en': 'Morelos', 'es': 'Morelos'},
 '52735':{'en': 'Cuautla/Jonacatepec, MOR', 'es': 'Cuautla/Jonacatepec, MOR'},
 '52736':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52737':{'en': 'Morelos', 'es': 'Morelos'},
 '55113337':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52731':{'en': 'Morelos', 'es': 'Morelos'},
 '52732':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52733':{'en': 'Iguala, GRO', 'es': 'Iguala, GRO'},
 '55114871':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114873':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114878':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '495431':{'de': u('Quakenbr\u00fcck'), 'en': u('Quakenbr\u00fcck')},
 '495433':{'de': 'Badbergen', 'en': 'Badbergen'},
 '495432':{'de': u('L\u00f6ningen'), 'en': u('L\u00f6ningen')},
 '495435':{'de': u('Berge bei Quakenbr\u00fcck'), 'en': u('Berge bei Quakenbr\u00fcck')},
 '495434':{'de': 'Essen Oldenburg', 'en': 'Essen Oldenburg'},
 '495437':{'de': 'Menslage', 'en': 'Menslage'},
 '495436':{'de': 'Nortrup', 'en': 'Nortrup'},
 '495439':{'de': u('Bersenbr\u00fcck'), 'en': u('Bersenbr\u00fcck')},
 '495438':{'de': u('Bakum-L\u00fcsche'), 'en': u('Bakum-L\u00fcsche')},
 '55113313':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441386':{'en': 'Evesham'},
 '441384':{'en': 'Dudley'},
 '55113312':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441382':{'en': 'Dundee'},
 '441383':{'en': 'Dunfermline'},
 '441380':{'en': 'Devizes'},
 '441381':{'en': 'Fortrose'},
 '4935343':{'de': 'Hirschfeld bei Elsterwerda', 'en': 'Hirschfeld bei Elsterwerda'},
 '4935342':{'de': u('M\u00fchlberg Elbe'), 'en': u('M\u00fchlberg Elbe')},
 '4935341':{'de': 'Bad Liebenwerda', 'en': 'Bad Liebenwerda'},
 '441389':{'en': 'Dumbarton'},
 '4938234':{'de': u('Born Dar\u00df'), 'en': 'Born Darss'},
 '4938231':{'de': 'Barth', 'en': 'Barth'},
 '4938232':{'de': 'Zingst Ostseebad', 'en': 'Zingst Ostseebad'},
 '4938233':{'de': 'Prerow Ostseebad', 'en': 'Prerow Ostseebad'},
 '55113668':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113319':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113318':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113781':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112318':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112319':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112317':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112312':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55123671':{'en': u('S\u00e3o Lu\u00eds do Paraitinga - SP'), 'pt': u('S\u00e3o Lu\u00eds do Paraitinga - SP')},
 '55123894':{'en': 'Ilhabela - SP', 'pt': 'Ilhabela - SP'},
 '55123897':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55123672':{'en': u('Trememb\u00e9 - SP'), 'pt': u('Trememb\u00e9 - SP')},
 '55123891':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '55123674':{'en': u('Trememb\u00e9 - SP'), 'pt': u('Trememb\u00e9 - SP')},
 '55123677':{'en': 'Natividade da Serra - SP', 'pt': 'Natividade da Serra - SP'},
 '55123676':{'en': u('Reden\u00e7\u00e3o da Serra - SP'), 'pt': u('Reden\u00e7\u00e3o da Serra - SP')},
 '55123678':{'en': 'Natividade da Serra - SP', 'pt': 'Natividade da Serra - SP'},
 '55113787':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113784':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496166':{'de': 'Fischbachtal', 'en': 'Fischbachtal'},
 '496167':{'de': 'Modautal', 'en': 'Modautal'},
 '496164':{'de': 'Reichelsheim Odenwald', 'en': 'Reichelsheim Odenwald'},
 '496165':{'de': 'Breuberg', 'en': 'Breuberg'},
 '496162':{'de': 'Reinheim Odenwald', 'en': 'Reinheim Odenwald'},
 '496163':{'de': u('H\u00f6chst im Odenwald'), 'en': u('H\u00f6chst im Odenwald')},
 '496161':{'de': 'Brensbach', 'en': 'Brensbach'},
 '55115049':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115044':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115042':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115041':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499444':{'de': 'Siegenburg', 'en': 'Siegenburg'},
 '499445':{'de': 'Neustadt an der Donau', 'en': 'Neustadt an der Donau'},
 '499446':{'de': 'Altmannstein', 'en': 'Altmannstein'},
 '496708':{'de': u('Bad M\u00fcnster am Stein-Ebernburg'), 'en': u('Bad M\u00fcnster am Stein-Ebernburg')},
 '496709':{'de': u('F\u00fcrfeld Kreis Bad Kreuznach'), 'en': u('F\u00fcrfeld Kreis Bad Kreuznach')},
 '496703':{'de': u('W\u00f6llstein Rheinhessen'), 'en': u('W\u00f6llstein Rheinhessen')},
 '496701':{'de': 'Sprendlingen Rheinhessen', 'en': 'Sprendlingen Rheinhessen'},
 '496706':{'de': 'Wallhausen Nahe', 'en': 'Wallhausen Nahe'},
 '496707':{'de': 'Windesheim', 'en': 'Windesheim'},
 '496704':{'de': 'Langenlonsheim', 'en': 'Langenlonsheim'},
 '499441':{'de': 'Kelheim', 'en': 'Kelheim'},
 '499831':{'de': 'Gunzenhausen', 'en': 'Gunzenhausen'},
 '499442':{'de': 'Riedenburg', 'en': 'Riedenburg'},
 '492661':{'de': 'Bad Marienberg Westerwald', 'en': 'Bad Marienberg Westerwald'},
 '492663':{'de': 'Westerburg Westerwald', 'en': 'Westerburg Westerwald'},
 '492662':{'de': 'Hachenburg', 'en': 'Hachenburg'},
 '492664':{'de': 'Rennerod', 'en': 'Rennerod'},
 '492667':{'de': 'Stein-Neukirch', 'en': 'Stein-Neukirch'},
 '492666':{'de': 'Freilingen Westerwald', 'en': 'Freilingen Westerwald'},
 '493391':{'de': 'Neuruppin', 'en': 'Neuruppin'},
 '493394':{'de': 'Wittstock Dosse', 'en': 'Wittstock Dosse'},
 '493395':{'de': 'Pritzwalk', 'en': 'Pritzwalk'},
 '499835':{'de': 'Ehingen Mittelfranken', 'en': 'Ehingen Mittelfranken'},
 '499834':{'de': 'Theilenhofen', 'en': 'Theilenhofen'},
 '499837':{'de': 'Haundorf', 'en': 'Haundorf'},
 '499448':{'de': 'Hausen Niederbayern', 'en': 'Hausen Niederbayern'},
 '499836':{'de': 'Gunzenhausen-Cronheim', 'en': 'Gunzenhausen-Cronheim'},
 '55133313':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55133312':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55133311':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55133317':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55133316':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '55115891':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133319':{'en': 'Bertioga - SP', 'pt': 'Bertioga - SP'},
 '494447':{'de': u('Vechta-Langf\u00f6rden'), 'en': u('Vechta-Langf\u00f6rden')},
 '494446':{'de': 'Bakum Kreis Vechta', 'en': 'Bakum Kreis Vechta'},
 '494445':{'de': 'Visbek Kreis Vechta', 'en': 'Visbek Kreis Vechta'},
 '494444':{'de': 'Goldenstedt', 'en': 'Goldenstedt'},
 '494443':{'de': 'Dinklage', 'en': 'Dinklage'},
 '494442':{'de': 'Lohne Oldenburg', 'en': 'Lohne Oldenburg'},
 '494441':{'de': 'Vechta', 'en': 'Vechta'},
 '497304':{'de': u('Blaustein W\u00fcrttemberg'), 'en': u('Blaustein W\u00fcrttemberg')},
 '542252':{'en': u('San Clemente del Tuy\u00fa, Buenos Aires'), 'es': u('San Clemente del Tuy\u00fa, Buenos Aires')},
 '55115897':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497307':{'de': 'Senden Iller', 'en': 'Senden Iller'},
 '542254':{'en': 'Pinamar, Buenos Aires', 'es': 'Pinamar, Buenos Aires'},
 '542255':{'en': 'Villa Gesell, Buenos Aires', 'es': 'Villa Gesell, Buenos Aires'},
 '497306':{'de': u('V\u00f6hringen Iller'), 'en': u('V\u00f6hringen Iller')},
 '55115899':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497300':{'de': 'Roggenburg', 'en': 'Roggenburg'},
 '498704':{'de': 'Altdorf-Pfettrach', 'en': 'Altdorf-Pfettrach'},
 '493537':{'de': 'Jessen Elster', 'en': 'Jessen Elster'},
 '498254':{'de': u('Altom\u00fcnster'), 'en': u('Altom\u00fcnster')},
 '493535':{'de': 'Herzberg Elster', 'en': 'Herzberg Elster'},
 '498252':{'de': 'Schrobenhausen', 'en': 'Schrobenhausen'},
 '493533':{'de': 'Elsterwerda', 'en': 'Elsterwerda'},
 '498250':{'de': 'Hilgertshausen-Tandern', 'en': 'Hilgertshausen-Tandern'},
 '493531':{'de': 'Finsterwalde', 'en': 'Finsterwalde'},
 '497302':{'de': 'Pfaffenhofen an der Roth', 'en': 'Pfaffenhofen an der Roth'},
 '498708':{'de': 'Weihmichl-Unterneuhausen', 'en': 'Weihmichl-Unterneuhausen'},
 '498709':{'de': 'Eching Niederbayern', 'en': 'Eching Niederbayern'},
 '498258':{'de': 'Sielenbach', 'en': 'Sielenbach'},
 '498259':{'de': 'Schiltberg', 'en': 'Schiltberg'},
 '542331':{'en': u('Realic\u00f3, La Pampa'), 'es': u('Realic\u00f3, La Pampa')},
 '542333':{'en': u('Quem\u00fa Quem\u00fa, La Pampa'), 'es': u('Quem\u00fa Quem\u00fa, La Pampa')},
 '542335':{'en': u('Realic\u00f3/Rancul Dept., La Pampa'), 'es': u('Dpto. Realic\u00f3/Rancul, La Pampa')},
 '542334':{'en': 'Eduardo Castex, La Pampa', 'es': 'Eduardo Castex, La Pampa'},
 '542337':{'en': u('Am\u00e9rica/Rivadavia, Buenos Aires'), 'es': u('Am\u00e9rica/Rivadavia, Buenos Aires')},
 '542336':{'en': u('Huinca Renanc\u00f3/Villa Huidobro, C\u00f3rdoba'), 'es': u('Huinca Renanc\u00f3/Villa Huidobro, C\u00f3rdoba')},
 '542338':{'en': 'Victorica, La Pampa', 'es': 'Victorica, La Pampa'},
 '494623':{'de': u('B\u00f6klund'), 'en': u('B\u00f6klund')},
 '494622':{'de': 'Taarstedt', 'en': 'Taarstedt'},
 '494621':{'de': 'Schleswig', 'en': 'Schleswig'},
 '494627':{'de': u('D\u00f6rpstedt'), 'en': u('D\u00f6rpstedt')},
 '494626':{'de': 'Treia', 'en': 'Treia'},
 '494625':{'de': u('J\u00fcbek'), 'en': u('J\u00fcbek')},
 '494624':{'de': 'Kropp', 'en': 'Kropp'},
 '492324':{'de': 'Hattingen Ruhr', 'en': 'Hattingen Ruhr'},
 '55113972':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497755':{'de': 'Weilheim Kreis Waldshut', 'en': 'Weilheim Kreis Waldshut'},
 '492828':{'de': 'Emmerich-Elten', 'en': 'Emmerich-Elten'},
 '492323':{'de': 'Herne', 'en': 'Herne'},
 '49511':{'de': 'Hannover', 'en': 'Hannover'},
 '55112121':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112123':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112125':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112124':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4419467':{'en': 'Gosforth'},
 '55112126':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499075':{'de': u('Gl\u00f6tt'), 'en': u('Gl\u00f6tt')},
 '499074':{'de': u('H\u00f6chst\u00e4dt an der Donau'), 'en': u('H\u00f6chst\u00e4dt an der Donau')},
 '499077':{'de': 'Bachhagel', 'en': 'Bachhagel'},
 '499076':{'de': 'Wittislingen', 'en': 'Wittislingen'},
 '499071':{'de': 'Dillingen an der Donau', 'en': 'Dillingen an der Donau'},
 '499070':{'de': 'Tapfheim', 'en': 'Tapfheim'},
 '499073':{'de': 'Gundelfingen an der Donau', 'en': 'Gundelfingen an der Donau'},
 '499072':{'de': 'Lauingen Donau', 'en': 'Lauingen Donau'},
 '4935361':{'de': 'Schlieben', 'en': 'Schlieben'},
 '499078':{'de': 'Mertingen', 'en': 'Mertingen'},
 '4936737':{'de': 'Drognitz', 'en': 'Drognitz'},
 '4936736':{'de': 'Arnsgereuth', 'en': 'Arnsgereuth'},
 '4936735':{'de': 'Probstzella', 'en': 'Probstzella'},
 '4936734':{'de': 'Leutenberg', 'en': 'Leutenberg'},
 '4936733':{'de': 'Kaulsdorf', 'en': 'Kaulsdorf'},
 '4936732':{'de': u('K\u00f6nitz'), 'en': u('K\u00f6nitz')},
 '4936731':{'de': 'Unterloquitz', 'en': 'Unterloquitz'},
 '4936730':{'de': 'Sitzendorf', 'en': 'Sitzendorf'},
 '4936739':{'de': 'Rottenbach', 'en': 'Rottenbach'},
 '4936738':{'de': u('K\u00f6nigsee'), 'en': u('K\u00f6nigsee')},
 '55113975':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49951':{'de': 'Bamberg', 'en': 'Bamberg'},
 '55133392':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '496571':{'de': 'Wittlich', 'en': 'Wittlich'},
 '54342':{'en': 'Santa Fe, Santa Fe', 'es': 'Santa Fe, Santa Fe'},
 '496573':{'de': 'Gillenfeld', 'en': 'Gillenfeld'},
 '496572':{'de': 'Manderscheid Eifel', 'en': 'Manderscheid Eifel'},
 '496575':{'de': 'Landscheid', 'en': 'Landscheid'},
 '496574':{'de': 'Hasborn', 'en': 'Hasborn'},
 '54345':{'en': u('Concordia, Entre R\u00edos'), 'es': u('Concordia, Entre R\u00edos')},
 '496578':{'de': 'Salmtal', 'en': 'Salmtal'},
 '54348':{'en': 'Escobar, Buenos Aires', 'es': 'Escobar, Buenos Aires'},
 '55133305':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55114399':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55115511':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495376':{'de': 'Wesendorf Kreis Gifhorn', 'en': 'Wesendorf Kreis Gifhorn'},
 '495377':{'de': 'Ehra-Lessien', 'en': 'Ehra-Lessien'},
 '495374':{'de': u('Isenb\u00fcttel'), 'en': u('Isenb\u00fcttel')},
 '495375':{'de': u('M\u00fcden Aller'), 'en': u('M\u00fcden Aller')},
 '495372':{'de': 'Meinersen', 'en': 'Meinersen'},
 '495373':{'de': 'Hillerse Kreis Gifhorn', 'en': 'Hillerse Kreis Gifhorn'},
 '495371':{'de': 'Gifhorn', 'en': 'Gifhorn'},
 '495378':{'de': 'Sassenburg-Platendorf', 'en': 'Sassenburg-Platendorf'},
 '495379':{'de': 'Sassenburg-Grussendorf', 'en': 'Sassenburg-Grussendorf'},
 '496395':{'de': u('M\u00fcnchweiler an der Rodalb'), 'en': u('M\u00fcnchweiler an der Rodalb')},
 '496394':{'de': 'Bundenthal', 'en': 'Bundenthal'},
 '496397':{'de': 'Leimen Pfalz', 'en': 'Leimen Pfalz'},
 '496396':{'de': 'Hinterweidenthal', 'en': 'Hinterweidenthal'},
 '496391':{'de': 'Dahn', 'en': 'Dahn'},
 '496393':{'de': 'Fischbach bei Dahn', 'en': 'Fischbach bei Dahn'},
 '496392':{'de': 'Hauenstein Pfalz', 'en': 'Hauenstein Pfalz'},
 '496398':{'de': 'Vorderweidenthal', 'en': 'Vorderweidenthal'},
 '437618':{'de': u('Neukirchen, Altm\u00fcnster'), 'en': u('Neukirchen, Altm\u00fcnster')},
 '497158':{'de': 'Neuhausen auf den Fildern', 'en': 'Neuhausen auf den Fildern'},
 '497159':{'de': 'Renningen', 'en': 'Renningen'},
 '497628':{'de': 'Efringen-Kirchen', 'en': 'Efringen-Kirchen'},
 '497629':{'de': 'Tegernau Baden', 'en': 'Tegernau Baden'},
 '492474':{'de': 'Nideggen-Schmidt', 'en': 'Nideggen-Schmidt'},
 '497627':{'de': u('Steinen Kreis L\u00f6rrach'), 'en': u('Steinen Kreis L\u00f6rrach')},
 '497156':{'de': 'Ditzingen', 'en': 'Ditzingen'},
 '497157':{'de': 'Waldenbuch', 'en': 'Waldenbuch'},
 '497150':{'de': u('Korntal-M\u00fcnchingen'), 'en': u('Korntal-M\u00fcnchingen')},
 '492471':{'de': 'Roetgen Eifel', 'en': 'Roetgen Eifel'},
 '497152':{'de': u('Leonberg W\u00fcrttemberg'), 'en': u('Leonberg W\u00fcrttemberg')},
 '492473':{'de': 'Simmerath', 'en': 'Simmerath'},
 '4413399':{'en': 'Ballater'},
 '4413398':{'en': 'Aboyne'},
 '4413397':{'en': 'Ballater'},
 '4413396':{'en': 'Ballater'},
 '4413395':{'en': 'Aboyne'},
 '4413394':{'en': 'Ballater'},
 '4413393':{'en': 'Aboyne'},
 '4413392':{'en': 'Aboyne'},
 '4413391':{'en': 'Aboyne/Ballater'},
 '4413390':{'en': 'Aboyne/Ballater'},
 '55114043':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '499360':{'de': u('Th\u00fcngen'), 'en': u('Th\u00fcngen')},
 '55112460':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55133418':{'en': 'Itariri - SP', 'pt': 'Itariri - SP'},
 '55133419':{'en': 'Pedro de Toledo - SP', 'pt': 'Pedro de Toledo - SP'},
 '55133416':{'en': 'Ana Dias - SP', 'pt': 'Ana Dias - SP'},
 '437615':{'de': 'Scharnstein', 'en': 'Scharnstein'},
 '54351':{'en': u('C\u00f3rdoba, C\u00f3rdoba'), 'es': u('C\u00f3rdoba, C\u00f3rdoba')},
 '55115787':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '54353':{'en': u('Villa Mar\u00eda, C\u00f3rdoba'), 'es': u('Villa Mar\u00eda, C\u00f3rdoba')},
 '499363':{'de': 'Arnstein Unterfranken', 'en': 'Arnstein Unterfranken'},
 '436432':{'de': 'Bad Hofgastein', 'en': 'Bad Hofgastein'},
 '436433':{'de': 'Dorfgastein', 'en': 'Dorfgastein'},
 '55115514':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '436434':{'de': 'Bad Gastein', 'en': 'Bad Gastein'},
 '437614':{'de': 'Vorchdorf', 'en': 'Vorchdorf'},
 '435446':{'de': 'Sankt Anton am Arlberg', 'en': 'St. Anton am Arlberg'},
 '435447':{'de': 'Flirsch', 'en': 'Flirsch'},
 '435444':{'de': 'Ischgl', 'en': 'Ischgl'},
 '435445':{'de': 'Kappl', 'en': 'Kappl'},
 '435442':{'de': 'Landeck', 'en': 'Landeck'},
 '435443':{'de': u('Galt\u00fcr'), 'en': u('Galt\u00fcr')},
 '435441':{'de': 'See', 'en': 'See'},
 '435448':{'de': 'Pettneu am Arlberg', 'en': 'Pettneu am Arlberg'},
 '435449':{'de': u('Flie\u00df'), 'en': 'Fliess'},
 '52938':{'en': 'Ciudad Del Carmen, CAMP', 'es': 'Ciudad del Carmen, CAMP'},
 '52936':{'en': 'Tabasco', 'es': 'Tabasco'},
 '52937':{'en': 'Cardenas, TAB', 'es': u('C\u00e1rdenas, TAB')},
 '52934':{'en': 'Tabasco', 'es': 'Tabasco'},
 '52932':{'en': 'Chiapas/Tabasco', 'es': 'Chiapas/Tabasco'},
 '52933':{'en': 'Tabasco', 'es': 'Tabasco'},
 '498139':{'de': u('R\u00f6hrmoos'), 'en': u('R\u00f6hrmoos')},
 '498138':{'de': 'Schwabhausen bei Dachau', 'en': 'Schwabhausen bei Dachau'},
 '498133':{'de': 'Haimhausen Oberbayern', 'en': 'Haimhausen Oberbayern'},
 '498131':{'de': 'Dachau', 'en': 'Dachau'},
 '498137':{'de': 'Petershausen', 'en': 'Petershausen'},
 '498136':{'de': 'Markt Indersdorf', 'en': 'Markt Indersdorf'},
 '498135':{'de': 'Sulzemoos', 'en': 'Sulzemoos'},
 '498134':{'de': 'Odelzhausen', 'en': 'Odelzhausen'},
 '55115516':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499661':{'de': 'Sulzbach-Rosenberg', 'en': 'Sulzbach-Rosenberg'},
 '499662':{'de': 'Vilseck', 'en': 'Vilseck'},
 '499663':{'de': 'Neukirchen bei Sulzbach-Rosenberg', 'en': 'Neukirchen bei Sulzbach-Rosenberg'},
 '499664':{'de': 'Hahnbach', 'en': 'Hahnbach'},
 '499665':{'de': u('K\u00f6nigstein Oberpfalz'), 'en': u('K\u00f6nigstein Oberpfalz')},
 '499666':{'de': 'Illschwang', 'en': 'Illschwang'},
 '46961':{'en': 'Arjeplog', 'sv': 'Arjeplog'},
 '497843':{'de': 'Renchen', 'en': 'Renchen'},
 '497841':{'de': 'Achern', 'en': 'Achern'},
 '497844':{'de': 'Rheinau', 'en': 'Rheinau'},
 '498395':{'de': u('Tannheim W\u00fcrttemberg'), 'en': u('Tannheim W\u00fcrttemberg')},
 '498394':{'de': 'Lautrach', 'en': 'Lautrach'},
 '498393':{'de': u('Holzg\u00fcnz'), 'en': u('Holzg\u00fcnz')},
 '498392':{'de': 'Markt Rettenbach', 'en': 'Markt Rettenbach'},
 '55133211':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '499367':{'de': 'Unterpleichfeld', 'en': 'Unterpleichfeld'},
 '499366':{'de': 'Geroldshausen Unterfranken', 'en': 'Geroldshausen Unterfranken'},
 '4833':{'en': 'Bielsko-Biala', 'pl': u('Bielsko-Bia\u0142a')},
 '4832':{'en': 'Katowice', 'pl': 'Katowice'},
 '4834':{'en': u('Cz\u0119stochowa'), 'pl': u('Cz\u0119stochowa')},
 '55112803':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55114129':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114128':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55112806':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55112807':{'en': 'Embu das Artes - SP', 'pt': 'Embu das Artes - SP'},
 '55112805':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114123':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114122':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114121':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55112809':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55114127':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114126':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114125':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114124':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '5297':{'en': 'Oaxaca', 'es': 'Oaxaca'},
 '5295':{'en': 'Oaxaca', 'es': 'Oaxaca'},
 '55113311':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52758':{'en': 'Petatlan/San Jeronimito, GRO', 'es': 'Petatlan/San Jeronimito, GRO'},
 '52759':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '55113315':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113314':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113316':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52752':{'en': 'Morelos', 'es': 'Morelos'},
 '52753':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52751':{'en': 'Morelos', 'es': 'Morelos'},
 '52756':{'en': 'Chilapa/Olinala, GRO', 'es': u('Chilapa/Olinal\u00e1, GRO')},
 '52757':{'en': 'Huamuxtitlan/Tlapa de Comonfort, GRO', 'es': 'Huamuxtitlan/Tlapa de Comonfort, GRO'},
 '52754':{'en': 'Guerrero', 'es': 'Guerrero'},
 '52755':{'en': 'Ixtapa/Zihuatanejo, GRO', 'es': 'Ixtapa/Zihuatanejo, GRO'},
 '494164':{'de': 'Harsefeld', 'en': 'Harsefeld'},
 '494165':{'de': 'Hollenstedt Nordheide', 'en': 'Hollenstedt Nordheide'},
 '494166':{'de': 'Ahlerstedt', 'en': 'Ahlerstedt'},
 '494167':{'de': 'Apensen', 'en': 'Apensen'},
 '494161':{'de': 'Buxtehude', 'en': 'Buxtehude'},
 '494162':{'de': 'Jork', 'en': 'Jork'},
 '494163':{'de': 'Horneburg Niederelbe', 'en': 'Horneburg Niederelbe'},
 '55113648':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543821':{'en': 'Chepes, La Rioja', 'es': 'Chepes, La Rioja'},
 '494168':{'de': 'Neu Wulmstorf-Elstorf', 'en': 'Neu Wulmstorf-Elstorf'},
 '494169':{'de': 'Sauensiek', 'en': 'Sauensiek'},
 '499122':{'de': 'Schwabach', 'en': 'Schwabach'},
 '55114029':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '4935365':{'de': 'Falkenberg Elster', 'en': 'Falkenberg Elster'},
 '4935364':{'de': 'Lebusa', 'en': 'Lebusa'},
 '55113921':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495149':{'de': 'Wienhausen', 'en': 'Wienhausen'},
 '495148':{'de': 'Steinhorst Niedersachsen', 'en': 'Steinhorst Niedersachsen'},
 '4935363':{'de': 'Fermerswalde', 'en': 'Fermerswalde'},
 '4935362':{'de': u('Sch\u00f6newalde bei Herzberg'), 'en': u('Sch\u00f6newalde bei Herzberg')},
 '495145':{'de': 'Beedenbostel', 'en': 'Beedenbostel'},
 '495144':{'de': 'Wathlingen', 'en': 'Wathlingen'},
 '495147':{'de': u('Uetze-H\u00e4nigsen'), 'en': u('Uetze-H\u00e4nigsen')},
 '495146':{'de': 'Wietze', 'en': 'Wietze'},
 '495141':{'de': 'Celle', 'en': 'Celle'},
 '495143':{'de': 'Winsen Aller', 'en': 'Winsen Aller'},
 '495142':{'de': 'Eschede', 'en': 'Eschede'},
 '55115102':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113924':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114021':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '4937298':{'de': 'Oelsnitz Erzgebirge', 'en': 'Oelsnitz Erzgebirge'},
 '4937297':{'de': 'Thum Sachsen', 'en': 'Thum Sachsen'},
 '4937296':{'de': 'Stollberg Erzgebirge', 'en': 'Stollberg Erzgebirge'},
 '4937295':{'de': 'Lugau Erzgebirge', 'en': 'Lugau Erzgebirge'},
 '4937294':{'de': u('Gr\u00fcnhainichen'), 'en': u('Gr\u00fcnhainichen')},
 '4937293':{'de': 'Eppendorf Sachsen', 'en': 'Eppendorf Sachsen'},
 '4937292':{'de': 'Oederan', 'en': 'Oederan'},
 '4937291':{'de': 'Augustusburg', 'en': 'Augustusburg'},
 '492403':{'de': 'Eschweiler Rheinland', 'en': 'Eschweiler Rheinland'},
 '55115105':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492056':{'de': 'Heiligenhaus', 'en': 'Heiligenhaus'},
 '497577':{'de': 'Veringenstadt', 'en': 'Veringenstadt'},
 '55112378':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '492054':{'de': 'Essen-Kettwig', 'en': 'Essen-Kettwig'},
 '497575':{'de': 'Messkirch', 'en': 'Messkirch'},
 '497572':{'de': u('Mengen W\u00fcrttemberg'), 'en': u('Mengen W\u00fcrttemberg')},
 '492053':{'de': 'Velbert-Neviges', 'en': 'Velbert-Neviges'},
 '497570':{'de': 'Sigmaringen-Gutenstein', 'en': 'Sigmaringen-Gutenstein'},
 '497571':{'de': 'Sigmaringen', 'en': 'Sigmaringen'},
 '497578':{'de': 'Wald Hohenz', 'en': 'Wald Hohenz'},
 '496142':{'de': u('R\u00fcsselsheim'), 'en': u('R\u00fcsselsheim')},
 '496144':{'de': u('Bischofsheim bei R\u00fcsselsheim'), 'en': u('Bischofsheim bei R\u00fcsselsheim')},
 '496145':{'de': u('Fl\u00f6rsheim am Main'), 'en': u('Fl\u00f6rsheim am Main')},
 '496146':{'de': 'Hochheim am Main', 'en': 'Hochheim am Main'},
 '496147':{'de': 'Trebur', 'en': 'Trebur'},
 '435635':{'de': 'Elmen', 'en': 'Elmen'},
 '435634':{'de': 'Elbigenalp', 'en': 'Elbigenalp'},
 '492393':{'de': 'Sundern-Allendorf', 'en': 'Sundern-Allendorf'},
 '492392':{'de': 'Werdohl', 'en': 'Werdohl'},
 '492395':{'de': u('Finnentrop-R\u00f6nkhausen'), 'en': u('Finnentrop-R\u00f6nkhausen')},
 '492394':{'de': 'Neuenrade-Affeln', 'en': 'Neuenrade-Affeln'},
 '435633':{'de': u('H\u00e4gerau'), 'en': u('H\u00e4gerau')},
 '435632':{'de': 'Stanzach', 'en': 'Stanzach'},
 '55115066':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115061':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115063':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115062':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115068':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '496724':{'de': u('Stromberg Hunsr\u00fcck'), 'en': u('Stromberg Hunsr\u00fcck')},
 '496725':{'de': 'Gau-Algesheim', 'en': 'Gau-Algesheim'},
 '496726':{'de': 'Lorch Rheingau', 'en': 'Lorch Rheingau'},
 '496727':{'de': 'Gensingen', 'en': 'Gensingen'},
 '496721':{'de': 'Bingen am Rhein', 'en': 'Bingen am Rhein'},
 '496722':{'de': u('R\u00fcdesheim am Rhein'), 'en': u('R\u00fcdesheim am Rhein')},
 '496723':{'de': 'Oestrich-Winkel', 'en': 'Oestrich-Winkel'},
 '499404':{'de': 'Nittendorf', 'en': 'Nittendorf'},
 '496728':{'de': 'Ober-Hilbersheim', 'en': 'Ober-Hilbersheim'},
 '55113277':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498094':{'de': u('Steinh\u00f6ring'), 'en': u('Steinh\u00f6ring')},
 '498095':{'de': 'Aying', 'en': 'Aying'},
 '498091':{'de': 'Kirchseeon', 'en': 'Kirchseeon'},
 '498092':{'de': u('Grafing bei M\u00fcnchen'), 'en': u('Grafing bei M\u00fcnchen')},
 '498093':{'de': 'Glonn Kreis Ebersberg', 'en': 'Glonn Kreis Ebersberg'},
 '542274':{'en': 'Carlos Spegazzini, Buenos Aires', 'es': 'Carlos Spegazzini, Buenos Aires'},
 '542271':{'en': 'San Miguel del Monte, Buenos Aires', 'es': 'San Miguel del Monte, Buenos Aires'},
 '542272':{'en': 'Navarro, Buenos Aires', 'es': 'Navarro, Buenos Aires'},
 '542273':{'en': 'Carmen de Areco, Buenos Aires', 'es': 'Carmen de Areco, Buenos Aires'},
 '494421':{'de': 'Wilhelmshaven', 'en': 'Wilhelmshaven'},
 '55114337':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '494423':{'de': 'Fedderwarden', 'en': 'Fedderwarden'},
 '494422':{'de': 'Sande Kreis Friesl', 'en': 'Sande Kreis Friesl'},
 '494425':{'de': 'Wangerland-Hooksiel', 'en': 'Wangerland-Hooksiel'},
 '55114330':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '494426':{'de': 'Wangerland-Horumersiel', 'en': 'Wangerland-Horumersiel'},
 '499402':{'de': 'Regenstauf', 'en': 'Regenstauf'},
 '55114338':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114184':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '492643':{'de': 'Altenahr', 'en': 'Altenahr'},
 '492642':{'de': 'Remagen', 'en': 'Remagen'},
 '492137':{'de': 'Neuss-Norf', 'en': 'Neuss-Norf'},
 '497456':{'de': 'Haiterbach', 'en': 'Haiterbach'},
 '492131':{'de': 'Neuss', 'en': 'Neuss'},
 '492646':{'de': u('K\u00f6nigsfeld Eifel'), 'en': u('K\u00f6nigsfeld Eifel')},
 '492133':{'de': 'Dormagen', 'en': 'Dormagen'},
 '492644':{'de': 'Linz am Rhein', 'en': 'Linz am Rhein'},
 '497975':{'de': u('Untergr\u00f6ningen'), 'en': u('Untergr\u00f6ningen')},
 '497459':{'de': 'Nagold-Hochdorf', 'en': 'Nagold-Hochdorf'},
 '497458':{'de': 'Ebhausen', 'en': 'Ebhausen'},
 '498271':{'de': 'Meitingen', 'en': 'Meitingen'},
 '498272':{'de': 'Wertingen', 'en': 'Wertingen'},
 '498273':{'de': 'Nordendorf', 'en': 'Nordendorf'},
 '498274':{'de': 'Buttenwiesen', 'en': 'Buttenwiesen'},
 '498276':{'de': 'Baar Schwaben', 'en': 'Baar Schwaben'},
 '55113884':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113887':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493583':{'de': 'Zittau', 'en': 'Zittau'},
 '542317':{'en': '9 de Julio, Buenos Aires', 'es': '9 de Julio, Buenos Aires'},
 '542316':{'en': 'Daireaux, Buenos Aires', 'es': 'Daireaux, Buenos Aires'},
 '542314':{'en': u('Bol\u00edvar, Buenos Aires'), 'es': u('Bol\u00edvar, Buenos Aires')},
 '55113883':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494393':{'de': 'Boostedt', 'en': 'Boostedt'},
 '494392':{'de': u('Nortorf bei Neum\u00fcnster'), 'en': u('Nortorf bei Neum\u00fcnster')},
 '494394':{'de': 'Bokhorst', 'en': 'Bokhorst'},
 '52231':{'en': 'Teteles/Teziutlan, PUE', 'es': u('Teteles/Teziutl\u00e1n, PUE')},
 '52233':{'en': 'Puebla', 'es': 'Puebla'},
 '52232':{'en': 'La Vigueta/Martinez de la Torre, VER', 'es': u('La Vigueta/Mart\u00ednez de la Torre, VER')},
 '52235':{'en': 'Veracruz', 'es': 'Veracruz'},
 '52237':{'en': 'Puebla', 'es': 'Puebla'},
 '52236':{'en': 'Oaxaca/Puebla', 'es': 'Oaxaca/Puebla'},
 '55113271':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52238':{'en': 'Santiago Miahuatlan/Tehuacan, PUE', 'es': u('Santiago Miahuatl\u00e1n/Tehuac\u00e1n, PUE')},
 '441759':{'en': 'Pocklington'},
 '494903':{'de': 'Wymeer', 'en': 'Wymeer'},
 '493588':{'de': 'Niesky', 'en': 'Niesky'},
 '55113819':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52589':{'en': 'Juchitepec/Ozumba, MEX', 'es': 'Juchitepec/Ozumba, MEX'},
 '52588':{'en': 'Estado de Mexico', 'es': 'Estado de Mexico'},
 '52587':{'en': 'Amecameca, MEX', 'es': 'Amecameca, MEX'},
 '52586':{'en': 'Tlalmanalco, MEX', 'es': 'Tlalmanalco, MEX'},
 '55113811':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113816':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113817':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113814':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113815':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499403':{'de': 'Donaustauf', 'en': 'Donaustauf'},
 '55112149':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112148':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112147':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112146':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112145':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112144':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112142':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112141':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '46696':{'en': 'Hammarstrand', 'sv': 'Hammarstrand'},
 '46695':{'en': 'Stugun'},
 '46692':{'en': 'Liden', 'sv': 'Liden'},
 '46693':{'en': u('Br\u00e4cke-G\u00e4ll\u00f6'), 'sv': u('Br\u00e4cke-G\u00e4ll\u00f6')},
 '46690':{'en': u('\u00c5nge'), 'sv': u('\u00c5nge')},
 '46691':{'en': 'Torpshammar', 'sv': 'Torpshammar'},
 '497143':{'de': 'Besigheim', 'en': 'Besigheim'},
 '497142':{'de': 'Bietigheim-Bissingen', 'en': 'Bietigheim-Bissingen'},
 '497141':{'de': u('Ludwigsburg W\u00fcrttemberg'), 'en': u('Ludwigsburg W\u00fcrttemberg')},
 '497631':{'de': u('M\u00fcllheim Baden'), 'en': u('M\u00fcllheim Baden')},
 '44121':{'en': 'Birmingham'},
 '497145':{'de': u('Markgr\u00f6ningen'), 'en': u('Markgr\u00f6ningen')},
 '497144':{'de': 'Marbach am Neckar', 'en': 'Marbach am Neckar'},
 '49421':{'de': 'Bremen', 'en': 'Bremen'},
 '55113768':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113760':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113761':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113762':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113763':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113765':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113766':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '442827':{'en': 'Ballymoney'},
 '442825':{'en': 'Ballymena'},
 '442820':{'en': 'Ballycastle'},
 '442821':{'en': 'Martinstown'},
 '442828':{'en': 'Larne'},
 '442829':{'en': 'Kilrea'},
 '4938393':{'de': 'Binz Ostseebad', 'en': 'Binz Ostseebad'},
 '55123912':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123913':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55113481':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4938392':{'de': 'Sassnitz', 'en': 'Sassnitz'},
 '498591':{'de': 'Obernzell', 'en': 'Obernzell'},
 '4938391':{'de': u('Altenkirchen R\u00fcgen'), 'en': u('Altenkirchen R\u00fcgen')},
 '496559':{'de': 'Leidenborn', 'en': 'Leidenborn'},
 '496558':{'de': u('B\u00fcdesheim Eifel'), 'en': u('B\u00fcdesheim Eifel')},
 '498593':{'de': 'Untergriesbach', 'en': 'Untergriesbach'},
 '496553':{'de': u('Sch\u00f6necken'), 'en': u('Sch\u00f6necken')},
 '496552':{'de': 'Olzheim', 'en': 'Olzheim'},
 '496551':{'de': u('Pr\u00fcm'), 'en': u('Pr\u00fcm')},
 '496550':{'de': 'Irrhausen', 'en': 'Irrhausen'},
 '496557':{'de': 'Hallschlag', 'en': 'Hallschlag'},
 '496556':{'de': 'Pronsfeld', 'en': 'Pronsfeld'},
 '496555':{'de': 'Bleialf', 'en': 'Bleialf'},
 '496554':{'de': 'Waxweiler', 'en': 'Waxweiler'},
 '55113089':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113088':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '543734':{'en': 'Machagai/Presidencia de la Plaza, Chaco', 'es': 'Machagai/Presidencia de la Plaza, Chaco'},
 '543735':{'en': u('Villa \u00c1ngela, Chaco'), 'es': u('Villa \u00c1ngela, Chaco')},
 '543731':{'en': 'Charata, Chaco', 'es': 'Charata, Chaco'},
 '55113435':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55114686':{'en': u('S\u00e3o Louren\u00e7o da Serra - SP'), 'pt': u('S\u00e3o Louren\u00e7o da Serra - SP')},
 '55114687':{'en': u('S\u00e3o Louren\u00e7o da Serra - SP'), 'pt': u('S\u00e3o Louren\u00e7o da Serra - SP')},
 '55113335':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114682':{'en': 'Juquitiba - SP', 'pt': 'Juquitiba - SP'},
 '55113436':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55114680':{'en': 'Santa Isabel - SP', 'pt': 'Santa Isabel - SP'},
 '55114681':{'en': 'Juquitiba - SP', 'pt': 'Juquitiba - SP'},
 '55114688':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '437282':{'de': 'Neufelden', 'en': 'Neufelden'},
 '437283':{'de': 'Sarleinsbach', 'en': 'Sarleinsbach'},
 '437280':{'de': u('Schwarzenberg am B\u00f6hmerwald'), 'en': u('Schwarzenberg am B\u00f6hmerwald')},
 '437281':{'de': u('Aigen im M\u00fchlkreis'), 'en': u('Aigen im M\u00fchlkreis')},
 '437286':{'de': u('Lembach im M\u00fchlkreis'), 'en': u('Lembach im M\u00fchlkreis')},
 '437287':{'de': u('Peilstein im M\u00fchlviertel'), 'en': u('Peilstein im M\u00fchlviertel')},
 '495608':{'de': u('S\u00f6hrewald'), 'en': u('S\u00f6hrewald')},
 '437285':{'de': u('Hofkirchen im M\u00fchlkreis'), 'en': u('Hofkirchen im M\u00fchlkreis')},
 '495358':{'de': 'Bahrdorf-Mackendorf', 'en': 'Bahrdorf-Mackendorf'},
 '495607':{'de': 'Fuldatal', 'en': 'Fuldatal'},
 '495604':{'de': 'Grossalmerode', 'en': 'Grossalmerode'},
 '495605':{'de': 'Kaufungen Hessen', 'en': 'Kaufungen Hessen'},
 '4933929':{'de': u('G\u00fchlen-Glienicke'), 'en': u('G\u00fchlen-Glienicke')},
 '495603':{'de': 'Gudensberg', 'en': 'Gudensberg'},
 '495601':{'de': 'Schauenburg', 'en': 'Schauenburg'},
 '496809':{'de': 'Grossrosseln', 'en': 'Grossrosseln'},
 '496805':{'de': 'Kleinblittersdorf', 'en': 'Kleinblittersdorf'},
 '496804':{'de': 'Mandelbachtal', 'en': 'Mandelbachtal'},
 '496806':{'de': 'Heusweiler', 'en': 'Heusweiler'},
 '496803':{'de': 'Mandelbachtal-Ommersheim', 'en': 'Mandelbachtal-Ommersheim'},
 '496802':{'de': u('V\u00f6lklingen-Lauterbach'), 'en': u('V\u00f6lklingen-Lauterbach')},
 '497602':{'de': 'Oberried Breisgau', 'en': 'Oberried Breisgau'},
 '499405':{'de': 'Bad Abbach', 'en': 'Bad Abbach'},
 '435284':{'de': 'Gerlos', 'en': 'Gerlos'},
 '435285':{'de': 'Mayrhofen', 'en': 'Mayrhofen'},
 '435286':{'de': 'Ginzling', 'en': 'Ginzling'},
 '435287':{'de': 'Tux', 'en': 'Tux'},
 '435280':{'de': u('Hochf\u00fcgen'), 'en': u('Hochf\u00fcgen')},
 '435282':{'de': 'Zell am Ziller', 'en': 'Zell am Ziller'},
 '435283':{'de': 'Kaltenbach', 'en': 'Kaltenbach'},
 '435288':{'de': u('F\u00fcgen'), 'en': u('F\u00fcgen')},
 '435289':{'de': u('H\u00e4usling'), 'en': u('H\u00e4usling')},
 '4933437':{'de': 'Reichenberg bei Strausberg', 'en': 'Reichenberg bei Strausberg'},
 '4933436':{'de': u('Pr\u00f6tzel'), 'en': u('Pr\u00f6tzel')},
 '4933435':{'de': 'Rehfelde', 'en': 'Rehfelde'},
 '4933434':{'de': 'Herzfelde bei Strausberg', 'en': 'Herzfelde bei Strausberg'},
 '4933433':{'de': u('Buckow M\u00e4rkische Schweiz'), 'en': u('Buckow M\u00e4rkische Schweiz')},
 '4933432':{'de': u('M\u00fcncheberg'), 'en': u('M\u00fcncheberg')},
 '4933439':{'de': 'Fredersdorf-Vogelsdorf', 'en': 'Fredersdorf-Vogelsdorf'},
 '4933438':{'de': 'Altlandsberg', 'en': 'Altlandsberg'},
 '46941':{'en': u('\u00c5sele'), 'sv': u('\u00c5sele')},
 '436418':{'de': 'Kleinarl', 'en': 'Kleinarl'},
 '436414':{'de': u('Gro\u00dfarl'), 'en': 'Grossarl'},
 '436415':{'de': 'Schwarzach im Pongau', 'en': 'Schwarzach im Pongau'},
 '436416':{'de': 'Lend', 'en': 'Lend'},
 '436417':{'de': u('H\u00fcttschlag'), 'en': u('H\u00fcttschlag')},
 '436412':{'de': 'Sankt Johann im Pongau', 'en': 'St. Johann im Pongau'},
 '436413':{'de': 'Wagrain', 'en': 'Wagrain'},
 '52914':{'en': 'Tabasco', 'es': 'Tabasco'},
 '52916':{'en': 'Chiapas', 'es': 'Chiapas'},
 '52917':{'en': 'Tabasco', 'es': 'Tabasco'},
 '52913':{'en': 'Tabasco', 'es': 'Tabasco'},
 '52918':{'en': 'Chiapas', 'es': 'Chiapas'},
 '52919':{'en': 'Chiapas', 'es': 'Chiapas'},
 '493727':{'de': 'Mittweida', 'en': 'Mittweida'},
 '493726':{'de': u('Fl\u00f6ha'), 'en': u('Fl\u00f6ha')},
 '493725':{'de': 'Zschopau', 'en': 'Zschopau'},
 '493724':{'de': u('Burgst\u00e4dt'), 'en': u('Burgst\u00e4dt')},
 '493723':{'de': 'Hohenstein-Ernstthal', 'en': 'Hohenstein-Ernstthal'},
 '493722':{'de': 'Limbach-Oberfrohna', 'en': 'Limbach-Oberfrohna'},
 '493721':{'de': 'Meinersdorf', 'en': 'Meinersdorf'},
 '437485':{'de': 'Gaming', 'en': 'Gaming'},
 '499406':{'de': 'Mintraching', 'en': 'Mintraching'},
 '437482':{'de': 'Scheibbs', 'en': 'Scheibbs'},
 '55114808':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55133298':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133299':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55113105':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55133295':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55115929':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115924':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933393':{'de': u('Gross Sch\u00f6nebeck Kreis Barnim'), 'en': u('Gross Sch\u00f6nebeck Kreis Barnim')},
 '55115926':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115927':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115576':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115575':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115921':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113153':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113152':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113151':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115574':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115922':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115573':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113159':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113158':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115572':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115571':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113263':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499602':{'de': 'Neustadt an der Waldnaab', 'en': 'Neustadt an der Waldnaab'},
 '499603':{'de': 'Floss', 'en': 'Floss'},
 '55114103':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113262':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499606':{'de': 'Pfreimd', 'en': 'Pfreimd'},
 '499607':{'de': 'Luhe-Wildenau', 'en': 'Luhe-Wildenau'},
 '499604':{'de': u('Wernberg-K\u00f6blitz'), 'en': u('Wernberg-K\u00f6blitz')},
 '499605':{'de': 'Weiherhammer', 'en': 'Weiherhammer'},
 '55114109':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '499608':{'de': 'Kohlberg Oberpfalz', 'en': 'Kohlberg Oberpfalz'},
 '52771':{'en': 'Pachuca/Real Del Monte, HGO', 'es': 'Pachuca/Real del Monte, HGO'},
 '52772':{'en': 'Actopan, HGO', 'es': 'Actopan, HGO'},
 '52773':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '52774':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '441344':{'en': 'Bracknell'},
 '52776':{'en': 'Puebla', 'es': 'Puebla'},
 '52777':{'en': 'Morelos', 'es': 'Morelos'},
 '52778':{'en': 'Hidalgo', 'es': 'Hidalgo'},
 '52779':{'en': 'Tizayuca, HGO', 'es': 'Tizayuca, HGO'},
 '55113483':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113482':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113485':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113484':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113487':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113486':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113377':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113269':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113375':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113374':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55115579':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492928':{'de': u('Soest-Ost\u00f6nnen'), 'en': u('Soest-Ost\u00f6nnen')},
 '492927':{'de': 'Neuengeseke', 'en': 'Neuengeseke'},
 '492924':{'de': u('M\u00f6hnesee'), 'en': u('M\u00f6hnesee')},
 '492925':{'de': 'Warstein-Allagen', 'en': 'Warstein-Allagen'},
 '492922':{'de': 'Werl', 'en': 'Werl'},
 '492923':{'de': 'Lippetal-Herzfeld', 'en': 'Lippetal-Herzfeld'},
 '55113379':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '492921':{'de': 'Soest', 'en': 'Soest'},
 '46227':{'en': u('Kungs\u00f6r'), 'sv': u('Kungs\u00f6r')},
 '46226':{'en': 'Avesta-Krylbo', 'sv': 'Avesta-Krylbo'},
 '46225':{'en': u('Hedemora-S\u00e4ter'), 'sv': u('Hedemora-S\u00e4ter')},
 '46224':{'en': 'Sala-Heby', 'sv': 'Sala-Heby'},
 '4939329':{'de': u('M\u00f6ringen'), 'en': u('M\u00f6ringen')},
 '46222':{'en': 'Skinnskatteberg', 'sv': 'Skinnskatteberg'},
 '494188':{'de': 'Welle Nordheide', 'en': 'Welle Nordheide'},
 '494189':{'de': 'Undeloh', 'en': 'Undeloh'},
 '494186':{'de': 'Buchholz-Trelde', 'en': 'Buchholz-Trelde'},
 '494187':{'de': 'Holm-Seppensen', 'en': 'Holm-Seppensen'},
 '494184':{'de': 'Hanstedt Nordheide', 'en': 'Hanstedt Nordheide'},
 '494185':{'de': 'Marxen Auetal', 'en': 'Marxen Auetal'},
 '494182':{'de': 'Tostedt', 'en': 'Tostedt'},
 '494183':{'de': 'Jesteburg', 'en': 'Jesteburg'},
 '4939323':{'de': u('Sch\u00f6nhausen Elbe'), 'en': u('Sch\u00f6nhausen Elbe')},
 '494181':{'de': 'Buchholz in der Nordheide', 'en': 'Buchholz in der Nordheide'},
 '55113103':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495167':{'de': 'Walsrode-Westenholz', 'en': 'Walsrode-Westenholz'},
 '495166':{'de': 'Walsrode-Kirchboitzen', 'en': 'Walsrode-Kirchboitzen'},
 '495165':{'de': 'Rethem Aller', 'en': 'Rethem Aller'},
 '495164':{'de': 'Hodenhagen', 'en': 'Hodenhagen'},
 '495163':{'de': 'Fallingbostel-Dorfmark', 'en': 'Fallingbostel-Dorfmark'},
 '495162':{'de': 'Fallingbostel', 'en': 'Fallingbostel'},
 '495161':{'de': 'Walsrode', 'en': 'Walsrode'},
 '495168':{'de': 'Walsrode-Stellichte', 'en': 'Walsrode-Stellichte'},
 '4415243':{'en': 'Lancaster'},
 '4415242':{'en': 'Hornby'},
 '4415241':{'en': 'Lancaster'},
 '4415240':{'en': 'Lancaster'},
 '4415247':{'en': 'Lancaster'},
 '4415246':{'en': 'Lancaster'},
 '4415245':{'en': 'Lancaster'},
 '4415244':{'en': 'Lancaster'},
 '4935387':{'de': 'Seyda', 'en': 'Seyda'},
 '4935386':{'de': 'Prettin', 'en': 'Prettin'},
 '4415249':{'en': 'Lancaster'},
 '4415248':{'en': 'Lancaster'},
 '4935383':{'de': 'Elster Elbe', 'en': 'Elster Elbe'},
 '441838':{'en': 'Dalmally'},
 '55115537':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441830':{'en': 'Kirkwhelpington'},
 '441832':{'en': 'Clopton'},
 '441833':{'en': 'Barnard Castle'},
 '441834':{'en': 'Narberth'},
 '441835':{'en': 'St Boswells'},
 '441837':{'en': 'Okehampton'},
 '55112429':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '495293':{'de': 'Paderborn-Dahl', 'en': 'Paderborn-Dahl'},
 '495292':{'de': 'Lichtenau-Atteln', 'en': 'Lichtenau-Atteln'},
 '495295':{'de': 'Lichtenau Westfalen', 'en': 'Lichtenau Westfalen'},
 '495294':{'de': u('H\u00f6velhof-Espeln'), 'en': u('H\u00f6velhof-Espeln')},
 '55112352':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112421':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112350':{'en': u('Po\u00e1 - SP'), 'pt': u('Po\u00e1 - SP')},
 '55112425':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112354':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112427':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '49851':{'de': 'Passau', 'en': 'Passau'},
 '55123635':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123634':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123637':{'en': u('Moreira C\u00e9sar - SP'), 'pt': u('Moreira C\u00e9sar - SP')},
 '55123631':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '499536':{'de': 'Kirchlauter', 'en': 'Kirchlauter'},
 '55123633':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '55123632':{'en': u('Taubat\u00e9 - SP'), 'pt': u('Taubat\u00e9 - SP')},
 '4934384':{'de': 'Grossbothen', 'en': 'Grossbothen'},
 '4934385':{'de': 'Mutzschen', 'en': 'Mutzschen'},
 '4934386':{'de': u('D\u00fcrrweitzschen bei Grimma'), 'en': u('D\u00fcrrweitzschen bei Grimma')},
 '4934381':{'de': 'Colditz', 'en': 'Colditz'},
 '4934382':{'de': 'Nerchau', 'en': 'Nerchau'},
 '4934383':{'de': 'Trebsen Mulde', 'en': 'Trebsen Mulde'},
 '499531':{'de': 'Ebern', 'en': 'Ebern'},
 '499533':{'de': 'Untermerzbach', 'en': 'Untermerzbach'},
 '55114334':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114335':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '4933608':{'de': 'Jacobsdorf Mark', 'en': 'Jacobsdorf Mark'},
 '4933609':{'de': 'Brieskow-Finkenheerd', 'en': 'Brieskow-Finkenheerd'},
 '4933604':{'de': 'Lebus', 'en': 'Lebus'},
 '4933605':{'de': 'Boossen', 'en': 'Boossen'},
 '4933606':{'de': u('M\u00fcllrose'), 'en': u('M\u00fcllrose')},
 '4933607':{'de': 'Briesen Mark', 'en': 'Briesen Mark'},
 '4933601':{'de': 'Podelzig', 'en': 'Podelzig'},
 '4933602':{'de': 'Alt Zeschdorf', 'en': 'Alt Zeschdorf'},
 '4933603':{'de': 'Falkenhagen bei Seelow', 'en': 'Falkenhagen bei Seelow'},
 '496122':{'de': 'Hofheim-Wallau', 'en': 'Hofheim-Wallau'},
 '496123':{'de': 'Eltville am Rhein', 'en': 'Eltville am Rhein'},
 '496120':{'de': 'Aarbergen', 'en': 'Aarbergen'},
 '496126':{'de': 'Idstein', 'en': 'Idstein'},
 '496127':{'de': 'Niedernhausen Taunus', 'en': 'Niedernhausen Taunus'},
 '496124':{'de': 'Bad Schwalbach', 'en': 'Bad Schwalbach'},
 '496128':{'de': 'Taunusstein', 'en': 'Taunusstein'},
 '496129':{'de': 'Schlangenbad', 'en': 'Schlangenbad'},
 '55115611':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115616':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495835':{'de': 'Wahrenholz', 'en': 'Wahrenholz'},
 '495834':{'de': 'Wittingen-Knesebeck', 'en': 'Wittingen-Knesebeck'},
 '495837':{'de': 'Sprakensehl', 'en': 'Sprakensehl'},
 '495836':{'de': 'Wittingen-Radenbeck', 'en': 'Wittingen-Radenbeck'},
 '495831':{'de': 'Wittingen', 'en': 'Wittingen'},
 '55115614':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495833':{'de': 'Brome', 'en': 'Brome'},
 '495832':{'de': u('Hankensb\u00fcttel'), 'en': u('Hankensb\u00fcttel')},
 '55115615':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495839':{'de': 'Wittingen-Ohrdorf', 'en': 'Wittingen-Ohrdorf'},
 '495838':{'de': 'Gross Oesingen', 'en': 'Gross Oesingen'},
 '55114339':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '498423':{'de': 'Titting', 'en': 'Titting'},
 '497455':{'de': 'Dornhan', 'en': 'Dornhan'},
 '55133296':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55114748':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '497454':{'de': 'Sulz am Neckar', 'en': 'Sulz am Neckar'},
 '55114743':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55114742':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55114741':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '55114747':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '492641':{'de': 'Bad Neuenahr-Ahrweiler', 'en': 'Bad Neuenahr-Ahrweiler'},
 '55114744':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '492647':{'de': 'Kesseling', 'en': 'Kesseling'},
 '498422':{'de': 'Dollnstein', 'en': 'Dollnstein'},
 '492645':{'de': 'Vettelschoss', 'en': 'Vettelschoss'},
 '492132':{'de': u('Meerbusch-B\u00fcderich'), 'en': u('Meerbusch-B\u00fcderich')},
 '498076':{'de': 'Pfaffing', 'en': 'Pfaffing'},
 '498074':{'de': 'Schnaitsee', 'en': 'Schnaitsee'},
 '498075':{'de': 'Amerang', 'en': 'Amerang'},
 '498072':{'de': 'Haag in Oberbayern', 'en': 'Haag in Oberbayern'},
 '498073':{'de': 'Gars am Inn', 'en': 'Gars am Inn'},
 '498071':{'de': 'Wasserburg am Inn', 'en': 'Wasserburg am Inn'},
 '55114358':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114359':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '542296':{'en': 'Ayacucho, Buenos Aires', 'es': 'Ayacucho, Buenos Aires'},
 '542297':{'en': 'Rauch, Buenos Aires', 'es': 'Rauch, Buenos Aires'},
 '55114356':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114357':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '542292':{'en': u('Benito Ju\u00e1rez, Buenos Aires'), 'es': u('Benito Ju\u00e1rez, Buenos Aires')},
 '55114351':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55114352':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '542291':{'en': 'Miramar, Buenos Aires', 'es': 'Miramar, Buenos Aires'},
 '441580':{'en': 'Cranbrook'},
 '441581':{'en': 'New Luce'},
 '441582':{'en': 'Luton'},
 '494408':{'de': 'Hude Oldenburg', 'en': 'Hude Oldenburg'},
 '441584':{'en': 'Ludlow'},
 '441586':{'en': 'Campbeltown'},
 '441588':{'en': 'Bishops Castle'},
 '494402':{'de': 'Rastede', 'en': 'Rastede'},
 '494401':{'de': 'Brake Unterweser', 'en': 'Brake Unterweser'},
 '494407':{'de': 'Wardenburg', 'en': 'Wardenburg'},
 '494406':{'de': 'Berne', 'en': 'Berne'},
 '494405':{'de': 'Edewecht', 'en': 'Edewecht'},
 '494404':{'de': 'Elsfleth', 'en': 'Elsfleth'},
 '55114354':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '497478':{'de': 'Hirrlingen', 'en': 'Hirrlingen'},
 '497477':{'de': 'Jungingen bei Hechingen', 'en': 'Jungingen bei Hechingen'},
 '497476':{'de': 'Bisingen', 'en': 'Bisingen'},
 '497475':{'de': 'Burladingen', 'en': 'Burladingen'},
 '497474':{'de': 'Haigerloch', 'en': 'Haigerloch'},
 '497473':{'de': u('M\u00f6ssingen'), 'en': u('M\u00f6ssingen')},
 '497472':{'de': 'Rottenburg am Neckar', 'en': 'Rottenburg am Neckar'},
 '497471':{'de': 'Hechingen', 'en': 'Hechingen'},
 '55114777':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '493578':{'de': 'Kamenz', 'en': 'Kamenz'},
 '55133398':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '493573':{'de': 'Senftenberg', 'en': 'Senftenberg'},
 '493571':{'de': 'Hoyerswerda', 'en': 'Hoyerswerda'},
 '493576':{'de': 'Weisswasser', 'en': 'Weisswasser'},
 '493574':{'de': 'Lauchhammer', 'en': 'Lauchhammer'},
 '4935608':{'de': 'Gross Ossnig', 'en': 'Gross Ossnig'},
 '4935609':{'de': 'Drachhausen', 'en': 'Drachhausen'},
 '4935602':{'de': 'Drebkau', 'en': 'Drebkau'},
 '4935603':{'de': 'Burg Spreewald', 'en': 'Burg Spreewald'},
 '4935600':{'de': u('D\u00f6bern NL'), 'en': u('D\u00f6bern NL')},
 '4935601':{'de': 'Peitz', 'en': 'Peitz'},
 '4935606':{'de': 'Briesen bei Cottbus', 'en': 'Briesen bei Cottbus'},
 '4935607':{'de': u('J\u00e4nschwalde'), 'en': u('J\u00e4nschwalde')},
 '4935604':{'de': 'Krieschow', 'en': 'Krieschow'},
 '4935605':{'de': 'Komptendorf', 'en': 'Komptendorf'},
 '55133359':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133358':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133355':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133354':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133353':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133352':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '55133351':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '4934635':{'de': u('Bad Lauchst\u00e4dt'), 'en': u('Bad Lauchst\u00e4dt')},
 '4934636':{'de': u('Schafst\u00e4dt'), 'en': u('Schafst\u00e4dt')},
 '4934637':{'de': 'Frankleben', 'en': 'Frankleben'},
 '4934632':{'de': u('M\u00fccheln Geiseltal'), 'en': u('M\u00fccheln Geiseltal')},
 '4934633':{'de': 'Braunsbedra', 'en': 'Braunsbedra'},
 '4934638':{'de': u('Z\u00f6schen'), 'en': u('Z\u00f6schen')},
 '4934639':{'de': 'Wallendorf Luppe', 'en': 'Wallendorf Luppe'},
 '55112165':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112164':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112167':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112166':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55112161':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112163':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112162':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112169':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112168':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49621':{'de': 'Mannheim', 'en': 'Mannheim'},
 '442311':{'en': 'Southampton'},
 '493998':{'de': 'Demmin', 'en': 'Demmin'},
 '49991':{'de': 'Deggendorf', 'en': 'Deggendorf'},
 '493994':{'de': 'Malchin', 'en': 'Malchin'},
 '493996':{'de': 'Teterow', 'en': 'Teterow'},
 '493991':{'de': u('Waren M\u00fcritz'), 'en': u('Waren M\u00fcritz')},
 '49441':{'de': 'Oldenburg', 'en': 'Oldenburg'},
 '55113748':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113749':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113746':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113747':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113744':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113745':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113742':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113743':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113740':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113741':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123936':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123937':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123934':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123935':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123933':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123931':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123938':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123939':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55114916':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114914':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114912':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114911':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497635':{'de': 'Schliengen', 'en': 'Schliengen'},
 '5322':{'en': 'Santiago de Cuba Province'},
 '5323':{'en': 'Granma Province'},
 '543711':{'en': u('Ingeniero Ju\u00e1rez, Formosa'), 'es': u('Ingeniero Ju\u00e1rez, Formosa')},
 '543715':{'en': 'Las Lomitas, Formosa', 'es': 'Las Lomitas, Formosa'},
 '543716':{'en': 'Comandante Fontana, Formosa', 'es': 'Comandante Fontana, Formosa'},
 '543718':{'en': 'Clorinda, Formosa', 'es': 'Clorinda, Formosa'},
 '497634':{'de': 'Sulzburg', 'en': 'Sulzburg'},
 '495339':{'de': 'Gielde', 'en': 'Gielde'},
 '495332':{'de': u('Sch\u00f6ppenstedt'), 'en': u('Sch\u00f6ppenstedt')},
 '495333':{'de': 'Dettum', 'en': 'Dettum'},
 '495622':{'de': 'Fritzlar', 'en': 'Fritzlar'},
 '495623':{'de': 'Edertal', 'en': 'Edertal'},
 '495336':{'de': 'Semmenstedt', 'en': 'Semmenstedt'},
 '495337':{'de': u('Kissenbr\u00fcck'), 'en': u('Kissenbr\u00fcck')},
 '495334':{'de': u('Hornburg Kreis Wolfenb\u00fcttel'), 'en': u('Hornburg Kreis Wolfenb\u00fcttel')},
 '495335':{'de': 'Schladen', 'en': 'Schladen'},
 '55112025':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497662':{'de': 'Vogtsburg im Kaiserstuhl', 'en': 'Vogtsburg im Kaiserstuhl'},
 '497663':{'de': 'Eichstetten', 'en': 'Eichstetten'},
 '497660':{'de': 'St Peter Schwarzwald', 'en': 'St Peter Schwarzwald'},
 '497661':{'de': 'Kirchzarten', 'en': 'Kirchzarten'},
 '497666':{'de': 'Denzlingen', 'en': 'Denzlingen'},
 '497667':{'de': 'Breisach am Rhein', 'en': 'Breisach am Rhein'},
 '497664':{'de': 'Freiburg-Tiengen', 'en': 'Freiburg-Tiengen'},
 '497665':{'de': 'March Breisgau', 'en': 'March Breisgau'},
 '497668':{'de': 'Ihringen', 'en': 'Ihringen'},
 '497669':{'de': u('St M\u00e4rgen'), 'en': u('St M\u00e4rgen')},
 '435266':{'de': u('\u00d6tztal-Bahnhof'), 'en': u('\u00d6tztal-Bahnhof')},
 '435264':{'de': 'Mieming', 'en': 'Mieming'},
 '435265':{'de': 'Nassereith', 'en': 'Nassereith'},
 '435262':{'de': 'Telfs', 'en': 'Telfs'},
 '435263':{'de': 'Silz', 'en': 'Silz'},
 '497633':{'de': 'Staufen im Breisgau', 'en': 'Staufen im Breisgau'},
 '496827':{'de': 'Eppelborn', 'en': 'Eppelborn'},
 '496826':{'de': 'Bexbach', 'en': 'Bexbach'},
 '496825':{'de': 'Illingen Saar', 'en': 'Illingen Saar'},
 '496824':{'de': 'Ottweiler', 'en': 'Ottweiler'},
 '496821':{'de': 'Neunkirchen Saar', 'en': 'Neunkirchen Saar'},
 '497632':{'de': 'Badenweiler', 'en': 'Badenweiler'},
 '492566':{'de': 'Legden', 'en': 'Legden'},
 '492567':{'de': u('Ahaus-Alst\u00e4tte'), 'en': u('Ahaus-Alst\u00e4tte')},
 '492564':{'de': 'Vreden', 'en': 'Vreden'},
 '492565':{'de': 'Gronau-Epe', 'en': 'Gronau-Epe'},
 '492562':{'de': 'Gronau Westfalen', 'en': 'Gronau Westfalen'},
 '492563':{'de': 'Stadtlohn', 'en': 'Stadtlohn'},
 '492561':{'de': 'Ahaus', 'en': 'Ahaus'},
 '492568':{'de': 'Heek', 'en': 'Heek'},
 '493741':{'de': 'Plauen', 'en': 'Plauen'},
 '493745':{'de': 'Falkenstein Vogtland', 'en': 'Falkenstein Vogtland'},
 '493744':{'de': 'Auerbach Vogtland', 'en': 'Auerbach Vogtland'},
 '55114996':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55112814':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '55112811':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55113178':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112813':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113171':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113170':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113175':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113177':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498685':{'de': u('Kirchansch\u00f6ring'), 'en': u('Kirchansch\u00f6ring')},
 '498684':{'de': 'Fridolfing', 'en': 'Fridolfing'},
 '498687':{'de': 'Taching-Tengling', 'en': 'Taching-Tengling'},
 '498686':{'de': 'Petting', 'en': 'Petting'},
 '498681':{'de': 'Waging am See', 'en': 'Waging am See'},
 '498683':{'de': 'Tittmoning', 'en': 'Tittmoning'},
 '498682':{'de': 'Laufen Salzach', 'en': 'Laufen Salzach'},
 '55114166':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114165':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114164':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '499628':{'de': 'Ursensollen', 'en': 'Ursensollen'},
 '55114162':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55114161':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '499624':{'de': 'Ensdorf Oberpfalz', 'en': 'Ensdorf Oberpfalz'},
 '499625':{'de': 'Kastl bei Amberg', 'en': 'Kastl bei Amberg'},
 '499626':{'de': 'Hohenburg', 'en': 'Hohenburg'},
 '499627':{'de': 'Freudenberg Oberpfalz', 'en': 'Freudenberg Oberpfalz'},
 '499621':{'de': 'Amberg Oberpfalz', 'en': 'Amberg Oberpfalz'},
 '499622':{'de': 'Hirschau Oberpfalz', 'en': 'Hirschau Oberpfalz'},
 '55114168':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55113359':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114992':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '52797':{'en': 'Puebla', 'es': 'Puebla'},
 '55113357':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113353':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52791':{'en': 'Ciudad Sahagun, HGO', 'es': u('Ciudad Sahag\u00fan, HGO')},
 '498538':{'de': 'Pocking-Hartkirchen', 'en': 'Pocking-Hartkirchen'},
 '498537':{'de': u('Bad F\u00fcssing-Aigen'), 'en': u('Bad F\u00fcssing-Aigen')},
 '498536':{'de': u('K\u00f6\u00dflarn'), 'en': u('K\u00f6sslarn')},
 '492902':{'de': 'Warstein', 'en': 'Warstein'},
 '492903':{'de': 'Meschede-Freienohl', 'en': 'Meschede-Freienohl'},
 '492904':{'de': 'Bestwig', 'en': 'Bestwig'},
 '492905':{'de': 'Bestwig-Ramsbeck', 'en': 'Bestwig-Ramsbeck'},
 '498531':{'de': 'Pocking', 'en': 'Pocking'},
 '55114993':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '499480':{'de': u('S\u00fcnching'), 'en': u('S\u00fcnching')},
 '499481':{'de': 'Pfatter', 'en': 'Pfatter'},
 '499482':{'de': u('W\u00f6rth an der Donau'), 'en': u('W\u00f6rth an der Donau')},
 '499951':{'de': 'Landau an der Isar', 'en': 'Landau an der Isar'},
 '499484':{'de': 'Brennberg', 'en': 'Brennberg'},
 '49291':{'de': 'Meschede', 'en': 'Meschede'},
 '499955':{'de': 'Mamming', 'en': 'Mamming'},
 '5017':{'en': 'Toledo District'},
 '55114990':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '495101':{'de': 'Pattensen', 'en': 'Pattensen'},
 '495103':{'de': 'Wennigsen Deister', 'en': 'Wennigsen Deister'},
 '495102':{'de': 'Laatzen', 'en': 'Laatzen'},
 '495105':{'de': 'Barsinghausen', 'en': 'Barsinghausen'},
 '495109':{'de': 'Ronnenberg', 'en': 'Ronnenberg'},
 '495108':{'de': 'Gehrden Han', 'en': 'Gehrden Han'},
 '55114991':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '441852':{'en': 'Kilmelford'},
 '55113496':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441856':{'en': 'Orkney'},
 '441857':{'en': 'Sanday'},
 '441854':{'en': 'Ullapool'},
 '441855':{'en': 'Ballachulish'},
 '441858':{'en': 'Market Harborough'},
 '441859':{'en': 'Harris'},
 '55113494':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113367':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113492':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113361':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113491':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112408':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112409':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112406':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112407':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112405':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112401':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '49871':{'de': 'Landshut', 'en': 'Landshut'},
 '543524':{'en': u('Villa del Totoral, C\u00f3rdoba'), 'es': u('Villa del Totoral, C\u00f3rdoba')},
 '543522':{'en': u('Villa de Mar\u00eda, C\u00f3rdoba'), 'es': u('Villa de Mar\u00eda, C\u00f3rdoba')},
 '543521':{'en': u('De\u00e1n Funes, C\u00f3rdoba'), 'es': u('De\u00e1n Funes, C\u00f3rdoba')},
 '55113499':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497434':{'de': 'Winterlingen', 'en': 'Winterlingen'},
 '5042780':{'en': 'Choluteca'},
 '542923':{'en': u('Pig\u00fc\u00e9, Buenos Aires'), 'es': u('Pig\u00fc\u00e9, Buenos Aires')},
 '5345':{'en': 'Matanzas Province'},
 '5346':{'en': 'Isle of Youth'},
 '5347':{'en': 'Havana Province'},
 '496108':{'de': u('M\u00fchlheim am Main'), 'en': u('M\u00fchlheim am Main')},
 '496109':{'de': 'Frankfurt-Bergen-Enkheim', 'en': 'Frankfurt-Bergen-Enkheim'},
 '496458':{'de': 'Rosenthal Hessen', 'en': 'Rosenthal Hessen'},
 '5343':{'en': 'Cienfuegos Province'},
 '496104':{'de': 'Heusenstamm', 'en': 'Heusenstamm'},
 '496457':{'de': 'Burgwald Eder', 'en': 'Burgwald Eder'},
 '496106':{'de': 'Rodgau', 'en': 'Rodgau'},
 '496455':{'de': 'Frankenau Hessen', 'en': 'Frankenau Hessen'},
 '496452':{'de': 'Battenberg Eder', 'en': 'Battenberg Eder'},
 '496453':{'de': u('Gem\u00fcnden Wohra'), 'en': u('Gem\u00fcnden Wohra')},
 '496102':{'de': 'Neu-Isenburg', 'en': 'Neu-Isenburg'},
 '496451':{'de': 'Frankenberg Eder', 'en': 'Frankenberg Eder'},
 '435333':{'de': u('S\u00f6ll'), 'en': u('S\u00f6ll')},
 '496295':{'de': 'Rosenberg Baden', 'en': 'Rosenberg Baden'},
 '55114761':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '499453':{'de': 'Thalmassing', 'en': 'Thalmassing'},
 '55114762':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '499452':{'de': 'Langquaid', 'en': 'Langquaid'},
 '55114759':{'en': 'Suzano - SP', 'pt': 'Suzano - SP'},
 '499451':{'de': 'Schierling', 'en': 'Schierling'},
 '499185':{'de': u('M\u00fchlhausen Oberpfalz'), 'en': u('M\u00fchlhausen Oberpfalz')},
 '499901':{'de': 'Hengersberg Bayern', 'en': 'Hengersberg Bayern'},
 '499903':{'de': u('Sch\u00f6llnach'), 'en': u('Sch\u00f6llnach')},
 '55114362':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '499454':{'de': 'Aufhausen Oberpfalz', 'en': 'Aufhausen Oberpfalz'},
 '494528':{'de': u('Sch\u00f6nwalde am Bungsberg'), 'en': u('Sch\u00f6nwalde am Bungsberg')},
 '441663':{'en': 'New Mills'},
 '494524':{'de': u('Scharbeutz-P\u00f6nitz'), 'en': u('Scharbeutz-P\u00f6nitz')},
 '435673':{'de': 'Ehrwald', 'en': 'Ehrwald'},
 '435672':{'de': 'Reutte', 'en': 'Reutte'},
 '435675':{'de': 'Tannheim', 'en': 'Tannheim'},
 '435674':{'de': 'Bichlbach', 'en': 'Bichlbach'},
 '435677':{'de': 'Vils', 'en': 'Vils'},
 '435676':{'de': 'Jungholz', 'en': 'Jungholz'},
 '492355':{'de': u('Schalksm\u00fchle'), 'en': u('Schalksm\u00fchle')},
 '435678':{'de': u('Wei\u00dfenbach am Lech'), 'en': 'Weissenbach am Lech'},
 '492357':{'de': 'Herscheid Westfalen', 'en': 'Herscheid Westfalen'},
 '497276':{'de': 'Herxheim bei Landau Pfalz', 'en': 'Herxheim bei Landau Pfalz'},
 '492351':{'de': u('L\u00fcdenscheid'), 'en': u('L\u00fcdenscheid')},
 '494526':{'de': 'Ascheberg Holstein', 'en': 'Ascheberg Holstein'},
 '492353':{'de': 'Halver', 'en': 'Halver'},
 '492352':{'de': 'Altena Westfalen', 'en': 'Altena Westfalen'},
 '494835':{'de': 'Albersdorf Holstein', 'en': 'Albersdorf Holstein'},
 '441669':{'en': 'Rothbury'},
 '498052':{'de': 'Aschau im Chiemgau', 'en': 'Aschau im Chiemgau'},
 '498053':{'de': 'Bad Endorf', 'en': 'Bad Endorf'},
 '498054':{'de': 'Breitbrunn am Chiemsee', 'en': 'Breitbrunn am Chiemsee'},
 '498055':{'de': 'Halfing', 'en': 'Halfing'},
 '498056':{'de': u('Eggst\u00e4tt'), 'en': u('Eggst\u00e4tt')},
 '494833':{'de': 'Wesselburen', 'en': 'Wesselburen'},
 '55114373':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494830':{'de': u('S\u00fcderhastedt'), 'en': u('S\u00fcderhastedt')},
 '55114374':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '499803':{'de': 'Colmberg', 'en': 'Colmberg'},
 '492687':{'de': 'Horhausen Westerwald', 'en': 'Horhausen Westerwald'},
 '492686':{'de': 'Weyerbusch', 'en': 'Weyerbusch'},
 '492685':{'de': 'Flammersfeld', 'en': 'Flammersfeld'},
 '492684':{'de': 'Puderbach Westerwald', 'en': 'Puderbach Westerwald'},
 '492683':{'de': 'Asbach Westerwald', 'en': 'Asbach Westerwald'},
 '492682':{'de': 'Hamm Sieg', 'en': 'Hamm Sieg'},
 '492681':{'de': 'Altenkirchen Westerwald', 'en': 'Altenkirchen Westerwald'},
 '492680':{'de': u('M\u00fcndersbach'), 'en': u('M\u00fcndersbach')},
 '492689':{'de': 'Dierdorf', 'en': 'Dierdorf'},
 '492688':{'de': 'Kroppach', 'en': 'Kroppach'},
 '492171':{'de': 'Leverkusen-Opladen', 'en': 'Leverkusen-Opladen'},
 '492173':{'de': 'Langenfeld Rheinland', 'en': 'Langenfeld Rheinland'},
 '492175':{'de': 'Leichlingen Rheinland', 'en': 'Leichlingen Rheinland'},
 '492174':{'de': 'Burscheid Rheinland', 'en': 'Burscheid Rheinland'},
 '494681':{'de': u('Wyk auf F\u00f6hr'), 'en': u('Wyk auf F\u00f6hr')},
 '498821':{'de': 'Garmisch-Partenkirchen', 'en': 'Garmisch-Partenkirchen'},
 '494683':{'de': 'Oldsum', 'en': 'Oldsum'},
 '494682':{'de': 'Amrum', 'en': 'Amrum'},
 '494684':{'de': u('Langene\u00df Hallig'), 'en': 'Langeness Hallig'},
 '498823':{'de': 'Mittenwald', 'en': 'Mittenwald'},
 '498822':{'de': 'Oberammergau', 'en': 'Oberammergau'},
 '543894':{'en': u('Burruyac\u00fa, Tucum\u00e1n'), 'es': u('Burruyac\u00fa, Tucum\u00e1n')},
 '543892':{'en': u('Amaicha del Valle, Tucum\u00e1n'), 'es': u('Amaicha del Valle, Tucum\u00e1n')},
 '543891':{'en': u('Graneros, Tucum\u00e1n'), 'es': u('Graneros, Tucum\u00e1n')},
 '498824':{'de': 'Oberau Loisach', 'en': 'Oberau Loisach'},
 '52899':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '497745':{'de': 'Jestetten', 'en': 'Jestetten'},
 '55133377':{'en': u('Cubat\u00e3o - SP'), 'pt': u('Cubat\u00e3o - SP')},
 '497744':{'de': u('St\u00fchlingen'), 'en': u('St\u00fchlingen')},
 '52891':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '52892':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '497747':{'de': 'Berau', 'en': 'Berau'},
 '52897':{'en': 'Tamaulipas', 'es': 'Tamaulipas'},
 '497746':{'de': u('Wut\u00f6schingen'), 'en': u('Wut\u00f6schingen')},
 '497741':{'de': 'Tiengen Hochrhein', 'en': 'Tiengen Hochrhein'},
 '497743':{'de': u('\u00dchlingen-Birkendorf'), 'en': u('\u00dchlingen-Birkendorf')},
 '492334':{'de': 'Hagen-Hohenlimburg', 'en': 'Hagen-Hohenlimburg'},
 '498234':{'de': 'Bobingen', 'en': 'Bobingen'},
 '498236':{'de': 'Fischach', 'en': 'Fischach'},
 '498237':{'de': 'Aindling', 'en': 'Aindling'},
 '498230':{'de': 'Gablingen', 'en': 'Gablingen'},
 '498231':{'de': u('K\u00f6nigsbrunn bei Augsburg'), 'en': u('K\u00f6nigsbrunn bei Augsburg')},
 '498232':{'de': u('Schwabm\u00fcnchen'), 'en': u('Schwabm\u00fcnchen')},
 '498233':{'de': 'Kissing', 'en': 'Kissing'},
 '498238':{'de': 'Gessertshausen', 'en': 'Gessertshausen'},
 '498239':{'de': 'Langenneufnach', 'en': 'Langenneufnach'},
 '499545':{'de': 'Buttenheim', 'en': 'Buttenheim'},
 '499544':{'de': 'Baunach', 'en': 'Baunach'},
 '499547':{'de': 'Zapfendorf', 'en': 'Zapfendorf'},
 '499546':{'de': 'Burgebrach', 'en': 'Burgebrach'},
 '499543':{'de': 'Hirschaid', 'en': 'Hirschaid'},
 '499542':{'de': 'Schesslitz', 'en': 'Schesslitz'},
 '495528':{'de': 'Gieboldehausen', 'en': 'Gieboldehausen'},
 '499549':{'de': 'Lisberg', 'en': 'Lisberg'},
 '499548':{'de': u('M\u00fchlhausen Mittelfranken'), 'en': u('M\u00fchlhausen Mittelfranken')},
 '434879':{'de': 'Sankt Veit in Defereggen', 'en': 'St. Veit in Defereggen'},
 '49461':{'de': 'Flensburg', 'en': 'Flensburg'},
 '4939062':{'de': 'Bebertal', 'en': 'Bebertal'},
 '4939061':{'de': 'Weferlingen', 'en': 'Weferlingen'},
 '52635':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '434874':{'de': 'Virgen', 'en': 'Virgen'},
 '52637':{'en': 'Altar/Caborca, SON', 'es': 'Altar/Caborca, SON'},
 '52636':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '52631':{'en': 'Nogales, SON', 'es': 'Nogales, SON'},
 '52633':{'en': 'Sonora', 'es': 'Sonora'},
 '434875':{'de': 'Matrei in Osttirol', 'en': 'Matrei in Osttirol'},
 '52639':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '434876':{'de': u('Kals am Gro\u00dfglockner'), 'en': 'Kals am Grossglockner'},
 '55113724':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113725':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113726':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '434877':{'de': u('Pr\u00e4graten am Gro\u00dfvenediger'), 'en': u('Pr\u00e4graten am Grossvenediger')},
 '55113721':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113722':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113723':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494532':{'de': 'Bargteheide', 'en': 'Bargteheide'},
 '442868':{'en': 'Kesh'},
 '434872':{'de': 'Huben', 'en': 'Huben'},
 '55123042':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '4935722':{'de': 'Lauta bei Hoyerswerda', 'en': 'Lauta bei Hoyerswerda'},
 '442866':{'en': 'Enniskillen'},
 '442867':{'en': 'Lisnaskea'},
 '55114978':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114979':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55114976':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '4935892':{'de': 'Horka OL', 'en': 'Horka OL'},
 '497751':{'de': 'Waldshut', 'en': 'Waldshut'},
 '441509':{'en': 'Loughborough'},
 '44161':{'en': 'Manchester'},
 '492192':{'de': u('H\u00fcckeswagen'), 'en': u('H\u00fcckeswagen')},
 '55123911':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '543772':{'en': 'Paso de los Libres, Corrientes', 'es': 'Paso de los Libres, Corrientes'},
 '543773':{'en': 'Mercedes, Corrientes', 'es': 'Mercedes, Corrientes'},
 '543777':{'en': 'Goya, Corrientes', 'es': 'Goya, Corrientes'},
 '543774':{'en': u('Curuz\u00fa Cuati\u00e1, Corrientes'), 'es': u('Curuz\u00fa Cuati\u00e1, Corrientes')},
 '543775':{'en': 'Monte Caseros, Corrientes', 'es': 'Monte Caseros, Corrientes'},
 '441501':{'en': 'Harthill'},
 '495642':{'de': 'Warburg-Scherfede', 'en': 'Warburg-Scherfede'},
 '495643':{'de': 'Borgentreich', 'en': 'Borgentreich'},
 '495641':{'de': 'Warburg', 'en': 'Warburg'},
 '495646':{'de': 'Willebadessen', 'en': 'Willebadessen'},
 '495647':{'de': 'Lichtenau-Kleinenberg', 'en': 'Lichtenau-Kleinenberg'},
 '495644':{'de': 'Willebadessen-Peckelsheim', 'en': 'Willebadessen-Peckelsheim'},
 '495645':{'de': 'Borgentreich-Borgholz', 'en': 'Borgentreich-Borgholz'},
 '495648':{'de': 'Brakel-Gehrden', 'en': 'Brakel-Gehrden'},
 '55123917':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123958':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123959':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123919':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123954':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123955':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123956':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123957':{'en': u('S\u00e3o Silvestre - SP'), 'pt': u('S\u00e3o Silvestre - SP')},
 '55123951':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123952':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55123953':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '497644':{'de': 'Kenzingen', 'en': 'Kenzingen'},
 '497645':{'de': 'Freiamt', 'en': 'Freiamt'},
 '497646':{'de': 'Weisweil Breisgau', 'en': 'Weisweil Breisgau'},
 '497641':{'de': 'Emmendingen', 'en': 'Emmendingen'},
 '497642':{'de': 'Endingen Kaiserstuhl', 'en': 'Endingen Kaiserstuhl'},
 '497643':{'de': 'Herbolzheim Breisgau', 'en': 'Herbolzheim Breisgau'},
 '55113276':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441689':{'en': 'Orpington'},
 '441688':{'en': 'Isle of Mull - Tobermory'},
 '441683':{'en': 'Moffat'},
 '441681':{'en': 'Isle of Mull - Fionnphort'},
 '441680':{'en': 'Isle of Mull - Craignure'},
 '441687':{'en': 'Mallaig'},
 '441685':{'en': 'Merthyr Tydfil'},
 '441684':{'en': 'Malvern'},
 '435248':{'de': 'Steinberg am Rofan', 'en': 'Steinberg am Rofan'},
 '435242':{'de': 'Schwaz', 'en': 'Schwaz'},
 '435243':{'de': 'Maurach', 'en': 'Maurach'},
 '435244':{'de': 'Jenbach', 'en': 'Jenbach'},
 '435245':{'de': u('Hinterri\u00df'), 'en': 'Hinterriss'},
 '435246':{'de': 'Achenkirch', 'en': 'Achenkirch'},
 '4933479':{'de': u('K\u00fcstrin-Kietz'), 'en': u('K\u00fcstrin-Kietz')},
 '4933478':{'de': 'Gross Neuendorf', 'en': 'Gross Neuendorf'},
 '4933473':{'de': 'Zechin', 'en': 'Zechin'},
 '4933472':{'de': 'Golzow bei Seelow', 'en': 'Golzow bei Seelow'},
 '4933470':{'de': 'Lietzen', 'en': 'Lietzen'},
 '4933477':{'de': u('Trebnitz bei M\u00fcncheberg'), 'en': u('Trebnitz bei M\u00fcncheberg')},
 '4933476':{'de': 'Neuhardenberg', 'en': 'Neuhardenberg'},
 '4933475':{'de': 'Letschin', 'en': 'Letschin'},
 '4933474':{'de': 'Neutrebbin', 'en': 'Neutrebbin'},
 '496841':{'de': 'Homburg Saar', 'en': 'Homburg Saar'},
 '496664':{'de': 'Sinntal-Sterbfritz', 'en': 'Sinntal-Sterbfritz'},
 '496843':{'de': 'Gersheim', 'en': 'Gersheim'},
 '496842':{'de': 'Blieskastel', 'en': 'Blieskastel'},
 '496661':{'de': u('Schl\u00fcchtern'), 'en': u('Schl\u00fcchtern')},
 '496844':{'de': 'Blieskastel-Altheim', 'en': 'Blieskastel-Altheim'},
 '496663':{'de': u('Steinau an der Stra\u00dfe'), 'en': 'Steinau an der Strasse'},
 '55112883':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '496849':{'de': 'Kirkel', 'en': 'Kirkel'},
 '496848':{'de': u('Homburg-Ein\u00f6d'), 'en': u('Homburg-Ein\u00f6d')},
 '496669':{'de': 'Neuhof-Hauswurz', 'en': 'Neuhof-Hauswurz'},
 '496668':{'de': 'Birstein-Lichenroth', 'en': 'Birstein-Lichenroth'},
 '492541':{'de': 'Coesfeld', 'en': 'Coesfeld'},
 '492542':{'de': 'Gescher', 'en': 'Gescher'},
 '492543':{'de': 'Billerbeck Westfalen', 'en': 'Billerbeck Westfalen'},
 '492545':{'de': 'Rosendahl-Darfeld', 'en': 'Rosendahl-Darfeld'},
 '492546':{'de': 'Coesfeld-Lette', 'en': 'Coesfeld-Lette'},
 '492547':{'de': 'Rosendahl-Osterwick', 'en': 'Rosendahl-Osterwick'},
 '492548':{'de': u('D\u00fclmen-Rorup'), 'en': u('D\u00fclmen-Rorup')},
 '55112886':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112887':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '4413889':{'en': 'Bishop Auckland'},
 '4413888':{'en': 'Bishop Auckland'},
 '4413887':{'en': 'Bishop Auckland'},
 '4413886':{'en': 'Bishop Auckland'},
 '4413885':{'en': 'Stanhope (Eastgate)'},
 '4413884':{'en': 'Bishop Auckland'},
 '4413883':{'en': 'Bishop Auckland'},
 '4413882':{'en': 'Stanhope (Eastgate)'},
 '4413881':{'en': 'Bishop Auckland/Stanhope (Eastgate)'},
 '4413880':{'en': 'Bishop Auckland/Stanhope (Eastgate)'},
 '493763':{'de': 'Glauchau', 'en': 'Glauchau'},
 '493762':{'de': 'Crimmitschau', 'en': 'Crimmitschau'},
 '493761':{'de': 'Werdau Sachsen', 'en': 'Werdau Sachsen'},
 '493765':{'de': 'Reichenbach Vogtland', 'en': 'Reichenbach Vogtland'},
 '493764':{'de': 'Meerane', 'en': 'Meerane'},
 '55114497':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114496':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '55114495':{'en': 'Itatiba - SP', 'pt': 'Itatiba - SP'},
 '55114494':{'en': 'Atibaia - SP', 'pt': 'Atibaia - SP'},
 '55114493':{'en': u('V\u00e1rzea Paulista - SP'), 'pt': u('V\u00e1rzea Paulista - SP')},
 '55114492':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55113117':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113115':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113113':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492359':{'de': 'Kierspe', 'en': 'Kierspe'},
 '55114092':{'en': 'Diadema - SP', 'pt': 'Diadema - SP'},
 '55114148':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114145':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55114144':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55114147':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '55114141':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55114143':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '55114142':{'en': 'Itapevi - SP', 'pt': 'Itapevi - SP'},
 '494238':{'de': 'Neddenaverbergen', 'en': 'Neddenaverbergen'},
 '494239':{'de': u('D\u00f6rverden-Westen'), 'en': u('D\u00f6rverden-Westen')},
 '46159':{'en': 'Mariefred', 'sv': 'Mariefred'},
 '46158':{'en': 'Gnesta', 'sv': 'Gnesta'},
 '55112661':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '494230':{'de': 'Verden-Walle', 'en': 'Verden-Walle'},
 '494231':{'de': 'Verden Aller', 'en': 'Verden Aller'},
 '494232':{'de': 'Langwedel Kreis Verden', 'en': 'Langwedel Kreis Verden'},
 '494233':{'de': 'Blender', 'en': 'Blender'},
 '494234':{'de': u('D\u00f6rverden'), 'en': u('D\u00f6rverden')},
 '494235':{'de': 'Langwedel-Etelsen', 'en': 'Langwedel-Etelsen'},
 '494236':{'de': 'Kirchlinteln', 'en': 'Kirchlinteln'},
 '494237':{'de': 'Bendingbostel', 'en': 'Bendingbostel'},
 '492962':{'de': 'Olsberg', 'en': 'Olsberg'},
 '492963':{'de': 'Brilon-Messinghausen', 'en': 'Brilon-Messinghausen'},
 '492961':{'de': 'Brilon', 'en': 'Brilon'},
 '492964':{'de': 'Brilon-Alme', 'en': 'Brilon-Alme'},
 '498558':{'de': 'Hohenau Niederbayern', 'en': 'Hohenau Niederbayern'},
 '498551':{'de': 'Freyung', 'en': 'Freyung'},
 '498550':{'de': 'Philippsreut', 'en': 'Philippsreut'},
 '498553':{'de': 'Spiegelau', 'en': 'Spiegelau'},
 '498552':{'de': 'Grafenau Niederbayern', 'en': 'Grafenau Niederbayern'},
 '498555':{'de': 'Perlesreut', 'en': 'Perlesreut'},
 '498554':{'de': u('Sch\u00f6nberg Niederbayern'), 'en': u('Sch\u00f6nberg Niederbayern')},
 '498557':{'de': 'Mauth', 'en': 'Mauth'},
 '498556':{'de': u('Haidm\u00fchle'), 'en': u('Haidm\u00fchle')},
 '499974':{'de': 'Traitsching', 'en': 'Traitsching'},
 '499975':{'de': u('Waldm\u00fcnchen-Geigant'), 'en': u('Waldm\u00fcnchen-Geigant')},
 '499976':{'de': u('R\u00f6tz'), 'en': u('R\u00f6tz')},
 '499977':{'de': 'Arnschwang', 'en': 'Arnschwang'},
 '499971':{'de': 'Cham', 'en': 'Cham'},
 '499972':{'de': u('Waldm\u00fcnchen'), 'en': u('Waldm\u00fcnchen')},
 '499153':{'de': 'Schnaittach', 'en': 'Schnaittach'},
 '4935033':{'de': u('Rosenthal S\u00e4chsische Schweiz'), 'en': u('Rosenthal S\u00e4chsische Schweiz')},
 '4935032':{'de': 'Langenhennersdorf', 'en': 'Langenhennersdorf'},
 '499978':{'de': u('Sch\u00f6nthal Oberpfalz'), 'en': u('Sch\u00f6nthal Oberpfalz')},
 '499151':{'de': 'Hersbruck', 'en': 'Hersbruck'},
 '55114035':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '543832':{'en': 'Recreo, Catamarca', 'es': 'Recreo, Catamarca'},
 '55114034':{'en': u('Bragan\u00e7a Paulista - SP'), 'pt': u('Bragan\u00e7a Paulista - SP')},
 '499154':{'de': 'Pommelsbrunn', 'en': 'Pommelsbrunn'},
 '494651':{'de': 'Sylt', 'en': 'Sylt'},
 '55112641':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495129':{'de': u('S\u00f6hlde'), 'en': u('S\u00f6hlde')},
 '495128':{'de': 'Hohenhameln', 'en': 'Hohenhameln'},
 '55112646':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112647':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495123':{'de': 'Schellerten', 'en': 'Schellerten'},
 '495121':{'de': 'Hildesheim', 'en': 'Hildesheim'},
 '495127':{'de': 'Harsum', 'en': 'Harsum'},
 '495126':{'de': 'Algermissen', 'en': 'Algermissen'},
 '55123014':{'en': u('Jacare\u00ed - SP'), 'pt': u('Jacare\u00ed - SP')},
 '55113936':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441878':{'en': 'Lochboisdale'},
 '441879':{'en': 'Scarinish'},
 '441308':{'en': 'Bridport'},
 '441309':{'en': 'Forres'},
 '441306':{'en': 'Dorking'},
 '441875':{'en': 'Tranent'},
 '441876':{'en': 'Lochmaddy'},
 '441305':{'en': 'Dorchester'},
 '441302':{'en': 'Doncaster'},
 '441303':{'en': 'Folkestone'},
 '441300':{'en': 'Cerne Abbas'},
 '441301':{'en': 'Arrochar'},
 '437353':{'de': 'Gaflenz', 'en': 'Gaflenz'},
 '55114683':{'en': 'Juquitiba - SP', 'pt': 'Juquitiba - SP'},
 '55115111':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499206':{'de': 'Mistelgau-Obernsees', 'en': 'Mistelgau-Obernsees'},
 '499207':{'de': u('K\u00f6nigsfeld Oberfranken'), 'en': u('K\u00f6nigsfeld Oberfranken')},
 '499204':{'de': 'Plankenfels', 'en': 'Plankenfels'},
 '499205':{'de': 'Vorbach', 'en': 'Vorbach'},
 '499202':{'de': 'Waischenfeld', 'en': 'Waischenfeld'},
 '499203':{'de': 'Neudrossenfeld', 'en': 'Neudrossenfeld'},
 '55112462':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '499201':{'de': 'Gesees', 'en': 'Gesees'},
 '55112468':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112469':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '499208':{'de': 'Bindlach', 'en': 'Bindlach'},
 '499209':{'de': 'Emtmannsberg', 'en': 'Emtmannsberg'},
 '543541':{'en': u('Villa Carlos Paz, C\u00f3rdoba'), 'es': u('Villa Carlos Paz, C\u00f3rdoba')},
 '497565':{'de': 'Aichstetten Kreis Ravensburg', 'en': 'Aichstetten Kreis Ravensburg'},
 '543543':{'en': u('C\u00f3rdoba (Arg\u00fcello), C\u00f3rdoba'), 'es': u('C\u00f3rdoba (Arg\u00fcello), C\u00f3rdoba')},
 '543542':{'en': u('Salsacate, C\u00f3rdoba'), 'es': u('Salsacate, C\u00f3rdoba')},
 '543544':{'en': u('Villa Dolores, C\u00f3rdoba'), 'es': u('Villa Dolores, C\u00f3rdoba')},
 '543547':{'en': u('Alta Gracia, C\u00f3rdoba'), 'es': u('Alta Gracia, C\u00f3rdoba')},
 '543546':{'en': u('Santa Rosa de Calamuchita, C\u00f3rdoba'), 'es': u('Santa Rosa de Calamuchita, C\u00f3rdoba')},
 '49811':{'de': 'Hallbergmoos', 'en': 'Hallbergmoos'},
 '543548':{'en': u('La Falda, C\u00f3rdoba'), 'es': u('La Falda, C\u00f3rdoba')},
 '497561':{'de': u('Leutkirch im Allg\u00e4u'), 'en': u('Leutkirch im Allg\u00e4u')},
 '55113275':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '497563':{'de': 'Kisslegg', 'en': 'Kisslegg'},
 '4939721':{'de': 'Liepen bei Anklam', 'en': 'Liepen bei Anklam'},
 '4939723':{'de': 'Krien', 'en': 'Krien'},
 '4939722':{'de': 'Sarnow bei Anklam', 'en': 'Sarnow bei Anklam'},
 '4939724':{'de': u('Klein B\u00fcnzow'), 'en': u('Klein B\u00fcnzow')},
 '4939727':{'de': 'Spantekow', 'en': 'Spantekow'},
 '4939726':{'de': 'Ducherow', 'en': 'Ducherow'},
 '4939728':{'de': 'Medow bei Anklam', 'en': 'Medow bei Anklam'},
 '55113445':{'en': 'Itaquaquecetuba - SP', 'pt': 'Itaquaquecetuba - SP'},
 '496478':{'de': 'Greifenstein-Ulm', 'en': 'Greifenstein-Ulm'},
 '496479':{'de': 'Waldbrunn Westerwald', 'en': 'Waldbrunn Westerwald'},
 '496471':{'de': 'Weilburg', 'en': 'Weilburg'},
 '496472':{'de': u('Weilm\u00fcnster'), 'en': u('Weilm\u00fcnster')},
 '496473':{'de': 'Leun', 'en': 'Leun'},
 '496474':{'de': 'Villmar-Aumenau', 'en': 'Villmar-Aumenau'},
 '496475':{'de': u('Weilm\u00fcnster-Wolfenhausen'), 'en': u('Weilm\u00fcnster-Wolfenhausen')},
 '496476':{'de': 'Mengerskirchen', 'en': 'Mengerskirchen'},
 '496477':{'de': 'Greifenstein-Nenderoth', 'en': 'Greifenstein-Nenderoth'},
 '46970':{'en': u('G\u00e4llivare'), 'sv': u('G\u00e4llivare')},
 '55124242':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55113444':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495873':{'de': 'Eimke', 'en': 'Eimke'},
 '495872':{'de': 'Stoetze', 'en': 'Stoetze'},
 '495875':{'de': 'Emmendorf', 'en': 'Emmendorf'},
 '495874':{'de': 'Soltendieck', 'en': 'Soltendieck'},
 '496782':{'de': 'Birkenfeld Nahe', 'en': 'Birkenfeld Nahe'},
 '496783':{'de': 'Baumholder', 'en': 'Baumholder'},
 '496781':{'de': 'Idar-Oberstein', 'en': 'Idar-Oberstein'},
 '496786':{'de': 'Kempfeld', 'en': 'Kempfeld'},
 '496787':{'de': 'Niederbrombach', 'en': 'Niederbrombach'},
 '496784':{'de': 'Weierbach', 'en': 'Weierbach'},
 '496785':{'de': 'Herrstein', 'en': 'Herrstein'},
 '496788':{'de': 'Sien', 'en': 'Sien'},
 '496789':{'de': 'Heimbach Nahe', 'en': 'Heimbach Nahe'},
 '55114707':{'en': 'Jandira - SP', 'pt': 'Jandira - SP'},
 '4933925':{'de': 'Wustrau-Altfriesack', 'en': 'Wustrau-Altfriesack'},
 '55114705':{'en': u('Santana de Parna\u00edba - SP'), 'pt': u('Santana de Parna\u00edba - SP')},
 '499371':{'de': 'Miltenberg', 'en': 'Miltenberg'},
 '55114703':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114702':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '55114701':{'en': u('Tabo\u00e3o da Serra - SP'), 'pt': u('Tabo\u00e3o da Serra - SP')},
 '4933924':{'de': u('R\u00e4gelin'), 'en': u('R\u00e4gelin')},
 '499376':{'de': 'Collenberg', 'en': 'Collenberg'},
 '495352':{'de': u('Sch\u00f6ningen'), 'en': u('Sch\u00f6ningen')},
 '499377':{'de': 'Freudenberg-Boxtal', 'en': 'Freudenberg-Boxtal'},
 '4933926':{'de': 'Herzberg Mark', 'en': 'Herzberg Mark'},
 '4933921':{'de': u('Zechlinerh\u00fctte'), 'en': u('Zechlinerh\u00fctte')},
 '499375':{'de': 'Freudenberg Baden', 'en': 'Freudenberg Baden'},
 '4933920':{'de': 'Walsleben bei Neuruppin', 'en': 'Walsleben bei Neuruppin'},
 '437284':{'de': 'Oberkappel', 'en': 'Oberkappel'},
 '495609':{'de': 'Ahnatal', 'en': 'Ahnatal'},
 '495606':{'de': 'Zierenberg', 'en': 'Zierenberg'},
 '437288':{'de': 'Ulrichsberg', 'en': 'Ulrichsberg'},
 '492377':{'de': 'Wickede Ruhr', 'en': 'Wickede Ruhr'},
 '497256':{'de': 'Philippsburg', 'en': 'Philippsburg'},
 '497255':{'de': 'Graben-Neudorf', 'en': 'Graben-Neudorf'},
 '497254':{'de': u('Wagh\u00e4usel'), 'en': u('Wagh\u00e4usel')},
 '497253':{'de': u('Bad Sch\u00f6nborn'), 'en': u('Bad Sch\u00f6nborn')},
 '497252':{'de': 'Bretten', 'en': 'Bretten'},
 '492371':{'de': 'Iserlohn', 'en': 'Iserlohn'},
 '497250':{'de': 'Kraichtal', 'en': 'Kraichtal'},
 '495602':{'de': 'Hessisch Lichtenau', 'en': 'Hessisch Lichtenau'},
 '492379':{'de': 'Menden-Asbeck', 'en': 'Menden-Asbeck'},
 '4933928':{'de': 'Wildberg Brandenburg', 'en': 'Wildberg Brandenburg'},
 '55113617':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113443':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492153':{'de': 'Nettetal-Lobberich', 'en': 'Nettetal-Lobberich'},
 '492152':{'de': 'Kempen', 'en': 'Kempen'},
 '492151':{'de': 'Krefeld', 'en': 'Krefeld'},
 '492150':{'de': 'Meerbusch-Lank', 'en': 'Meerbusch-Lank'},
 '492157':{'de': 'Nettetal-Kaldenkirchen', 'en': 'Nettetal-Kaldenkirchen'},
 '492156':{'de': 'Willich-Anrath', 'en': 'Willich-Anrath'},
 '497435':{'de': 'Albstadt-Laufen', 'en': 'Albstadt-Laufen'},
 '492154':{'de': 'Willich', 'en': 'Willich'},
 '492159':{'de': 'Meerbusch-Osterath', 'en': 'Meerbusch-Osterath'},
 '492158':{'de': 'Grefrath bei Krefeld', 'en': 'Grefrath bei Krefeld'},
 '55113442':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49385':{'de': 'Schwerin', 'en': 'Schwerin'},
 '55114347':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55115623':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441763':{'en': 'Royston'},
 '55113865':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115622':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498032':{'de': 'Rohrdorf Kreis Rosenheim', 'en': 'Rohrdorf Kreis Rosenheim'},
 '498033':{'de': 'Oberaudorf', 'en': 'Oberaudorf'},
 '498031':{'de': 'Rosenheim Oberbayern', 'en': 'Rosenheim Oberbayern'},
 '498036':{'de': 'Stephanskirchen Simssee', 'en': 'Stephanskirchen Simssee'},
 '498034':{'de': 'Brannenburg', 'en': 'Brannenburg'},
 '441769':{'en': 'South Molton'},
 '498038':{'de': 'Vogtareuth', 'en': 'Vogtareuth'},
 '498039':{'de': 'Rott am Inn', 'en': 'Rott am Inn'},
 '436227':{'de': 'Sankt Gilgen', 'en': 'St. Gilgen'},
 '436226':{'de': 'Fuschl am See', 'en': 'Fuschl am See'},
 '436225':{'de': 'Eugendorf', 'en': 'Eugendorf'},
 '436224':{'de': 'Hintersee', 'en': 'Hintersee'},
 '436223':{'de': 'Anthering', 'en': 'Anthering'},
 '436221':{'de': 'Koppl', 'en': 'Koppl'},
 '436229':{'de': 'Hof bei Salzburg', 'en': 'Hof bei Salzburg'},
 '436228':{'de': 'Faistenau', 'en': 'Faistenau'},
 '4934671':{'de': u('Bad Frankenhausen Kyffh\u00e4user'), 'en': u('Bad Frankenhausen Kyffh\u00e4user')},
 '4934672':{'de': 'Rossleben', 'en': 'Rossleben'},
 '4934673':{'de': 'Heldrungen', 'en': 'Heldrungen'},
 '498784':{'de': 'Hohenthann', 'en': 'Hohenthann'},
 '498785':{'de': 'Rottenburg-Oberroning', 'en': 'Rottenburg-Oberroning'},
 '498781':{'de': 'Rottenburg an der Laaber', 'en': 'Rottenburg an der Laaber'},
 '498782':{'de': 'Pfeffenhausen', 'en': 'Pfeffenhausen'},
 '498783':{'de': 'Rohr in Niederbayern', 'en': 'Rohr in Niederbayern'},
 '49661':{'de': 'Fulda', 'en': 'Fulda'},
 '4939268':{'de': 'Egeln', 'en': 'Egeln'},
 '499569':{'de': 'Sesslach', 'en': 'Sesslach'},
 '499568':{'de': 'Neustadt bei Coburg', 'en': 'Neustadt bei Coburg'},
 '4939264':{'de': 'Kroppenstedt', 'en': 'Kroppenstedt'},
 '4939265':{'de': u('L\u00f6derburg'), 'en': u('L\u00f6derburg')},
 '4939266':{'de': u('F\u00f6rderstedt'), 'en': u('F\u00f6rderstedt')},
 '4939267':{'de': 'Schneidlingen', 'en': 'Schneidlingen'},
 '499563':{'de': u('R\u00f6dental'), 'en': u('R\u00f6dental')},
 '499562':{'de': 'Sonnefeld', 'en': 'Sonnefeld'},
 '4939262':{'de': u('G\u00fcsten Anh'), 'en': u('G\u00fcsten Anh')},
 '4939263':{'de': 'Unseburg', 'en': 'Unseburg'},
 '4930':{'de': 'Berlin', 'en': 'Berlin'},
 '55123889':{'en': 'Caraguatatuba - SP', 'pt': 'Caraguatatuba - SP'},
 '55114341':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '4939008':{'de': 'Kunrau', 'en': 'Kunrau'},
 '4939009':{'de': 'Badel', 'en': 'Badel'},
 '4939000':{'de': 'Beetzendorf', 'en': 'Beetzendorf'},
 '4939001':{'de': 'Apenburg', 'en': 'Apenburg'},
 '4939002':{'de': 'Oebisfelde', 'en': 'Oebisfelde'},
 '4939003':{'de': u('J\u00fcbar'), 'en': u('J\u00fcbar')},
 '4939004':{'de': u('K\u00f6ckte bei Gardelegen'), 'en': u('K\u00f6ckte bei Gardelegen')},
 '4939005':{'de': 'Kusey', 'en': 'Kusey'},
 '4939006':{'de': 'Miesterhorst', 'en': 'Miesterhorst'},
 '49481':{'de': 'Heide Holstein', 'en': 'Heide Holstein'},
 '52613':{'en': 'Baja California Sur', 'es': 'Baja California Sur'},
 '52612':{'en': 'La Paz/Todos Santos, BCS', 'es': 'La Paz/Todos Santos, BCS'},
 '55113708':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113709':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52616':{'en': 'Baja California', 'es': 'Baja California'},
 '52615':{'en': 'Baja California Sur', 'es': 'Baja California Sur'},
 '52614':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '55113251':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113252':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52618':{'en': 'Colonia Hidalgo/Durango, DGO', 'es': 'Colonia Hidalgo/Durango, DGO'},
 '55113254':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113255':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113256':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113257':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '442844':{'en': 'Downpatrick'},
 '442840':{'en': 'Banbridge'},
 '442841':{'en': 'Rostrevor'},
 '442842':{'en': 'Kircubbin'},
 '442843':{'en': 'Newcastle (Co. Down)'},
 '4939050':{'de': 'Bartensleben', 'en': 'Bartensleben'},
 '55113071':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113565':{'en': u('S\u00e3o Caetano do Sul - SP'), 'pt': u('S\u00e3o Caetano do Sul - SP')},
 '55113073':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4935208':{'de': 'Radeburg', 'en': 'Radeburg'},
 '4935209':{'de': 'Mohorn', 'en': 'Mohorn'},
 '4935206':{'de': 'Kreischa bei Dresden', 'en': 'Kreischa bei Dresden'},
 '4935207':{'de': 'Moritzburg', 'en': 'Moritzburg'},
 '4935204':{'de': 'Wilsdruff', 'en': 'Wilsdruff'},
 '4935205':{'de': 'Ottendorf-Okrilla', 'en': 'Ottendorf-Okrilla'},
 '4935202':{'de': 'Klingenberg Sachsen', 'en': 'Klingenberg Sachsen'},
 '4935203':{'de': 'Tharandt', 'en': 'Tharandt'},
 '4935200':{'de': 'Arnsdorf bei Dresden', 'en': 'Arnsdorf bei Dresden'},
 '4935201':{'de': u('Langebr\u00fcck'), 'en': u('Langebr\u00fcck')},
 '4938356':{'de': 'Behrenhoff', 'en': 'Behrenhoff'},
 '4938355':{'de': u('Z\u00fcssow'), 'en': u('Z\u00fcssow')},
 '4938354':{'de': 'Wusterhusen', 'en': 'Wusterhusen'},
 '4938353':{'de': u('G\u00fctzkow bei Greifswald'), 'en': u('G\u00fctzkow bei Greifswald')},
 '4938352':{'de': 'Kemnitz bei Greifswald', 'en': 'Kemnitz bei Greifswald'},
 '4938351':{'de': 'Mesekenhagen', 'en': 'Mesekenhagen'},
 '55113078':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933983':{'de': 'Gross Pankow Kreis Prignitz', 'en': 'Gross Pankow Kreis Prignitz'},
 '4933982':{'de': 'Hoppenrade Kreis Prignitz', 'en': 'Hoppenrade Kreis Prignitz'},
 '4933981':{'de': 'Putlitz', 'en': 'Putlitz'},
 '52382':{'en': 'Jalisco', 'es': 'Jalisco'},
 '4933986':{'de': 'Falkenhagen Kreis Prignitz', 'en': 'Falkenhagen Kreis Prignitz'},
 '4933984':{'de': 'Blumenthal bei Pritzwalk', 'en': 'Blumenthal bei Pritzwalk'},
 '495664':{'de': 'Morschen', 'en': 'Morschen'},
 '495665':{'de': 'Guxhagen', 'en': 'Guxhagen'},
 '4933989':{'de': 'Sadenbeck', 'en': 'Sadenbeck'},
 '55112070':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495661':{'de': 'Melsungen', 'en': 'Melsungen'},
 '495662':{'de': 'Felsberg Hessen', 'en': 'Felsberg Hessen'},
 '495663':{'de': 'Spangenberg', 'en': 'Spangenberg'},
 '55123972':{'en': 'Santa Branca - SP', 'pt': 'Santa Branca - SP'},
 '55123201':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123202':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123203':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123204':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123206':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123207':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55123978':{'en': 'Jambeiro - SP', 'pt': 'Jambeiro - SP'},
 '52386':{'en': 'Jalisco', 'es': 'Jalisco'},
 '493847':{'de': 'Sternberg', 'en': 'Sternberg'},
 '493844':{'de': 'Schwaan', 'en': 'Schwaan'},
 '54249':{'en': 'Tandil, Buenos Aires', 'es': 'Tandil, Buenos Aires'},
 '493843':{'de': u('G\u00fcstrow'), 'en': u('G\u00fcstrow')},
 '493841':{'de': 'Wismar', 'en': 'Wismar'},
 '52467':{'en': 'Zacatecas', 'es': 'Zacatecas'},
 '543754':{'en': 'Leandro N. Alem, Misiones', 'es': 'Leandro N. Alem, Misiones'},
 '4414301':{'en': 'North Cave/Market Weighton'},
 '543756':{'en': u('Santo Tom\u00e9, Corrientes'), 'es': u('Santo Tom\u00e9, Corrientes')},
 '543757':{'en': u('Puerto Iguaz\u00fa, Misiones'), 'es': u('Puerto Iguaz\u00fa, Misiones')},
 '543751':{'en': 'Eldorado, Misiones', 'es': 'Eldorado, Misiones'},
 '543758':{'en': u('Ap\u00f3stoles, Misiones'), 'es': u('Ap\u00f3stoles, Misiones')},
 '4414303':{'en': 'North Cave'},
 '435223':{'de': 'Hall in Tirol', 'en': 'Hall in Tirol'},
 '4414302':{'en': 'North Cave'},
 '435226':{'de': 'Neustift im Stubaital', 'en': 'Neustift im Stubaital'},
 '496247':{'de': 'Worms-Pfeddersheim', 'en': 'Worms-Pfeddersheim'},
 '435224':{'de': 'Wattens', 'en': 'Wattens'},
 '435225':{'de': 'Fulpmes', 'en': 'Fulpmes'},
 '4414305':{'en': 'North Cave'},
 '4933454':{'de': u('W\u00f6lsickendorf/Wollenberg'), 'en': u('W\u00f6lsickendorf/Wollenberg')},
 '4933457':{'de': 'Altreetz', 'en': 'Altreetz'},
 '4933456':{'de': 'Wriezen', 'en': 'Wriezen'},
 '4933451':{'de': 'Heckelberg', 'en': 'Heckelberg'},
 '4414307':{'en': 'Market Weighton'},
 '4933452':{'de': 'Neulewin', 'en': 'Neulewin'},
 '55115704':{'en': 'Itupeva - SP', 'pt': 'Itupeva - SP'},
 '4933458':{'de': 'Falkenberg Mark', 'en': 'Falkenberg Mark'},
 '496869':{'de': 'Merzig-Silwingen', 'en': 'Merzig-Silwingen'},
 '496868':{'de': u('Mettlach-T\u00fcnsdorf'), 'en': u('Mettlach-T\u00fcnsdorf')},
 '496648':{'de': 'Bad Salzschlirf', 'en': 'Bad Salzschlirf'},
 '496647':{'de': 'Herbstein-Stockhausen', 'en': 'Herbstein-Stockhausen'},
 '496646':{'de': 'Grebenau', 'en': 'Grebenau'},
 '496645':{'de': 'Ulrichstein', 'en': 'Ulrichstein'},
 '496644':{'de': 'Grebenhain', 'en': 'Grebenhain'},
 '496643':{'de': 'Herbstein', 'en': 'Herbstein'},
 '496642':{'de': 'Schlitz', 'en': 'Schlitz'},
 '496865':{'de': 'Mettlach-Orscholz', 'en': 'Mettlach-Orscholz'},
 '496864':{'de': 'Mettlach', 'en': 'Mettlach'},
 '496245':{'de': 'Biblis', 'en': 'Biblis'},
 '492528':{'de': 'Ennigerloh-Enniger', 'en': 'Ennigerloh-Enniger'},
 '492529':{'de': 'Oelde-Stromberg', 'en': 'Oelde-Stromberg'},
 '492522':{'de': 'Oelde', 'en': 'Oelde'},
 '492523':{'de': 'Wadersloh', 'en': 'Wadersloh'},
 '492520':{'de': 'Wadersloh-Diestedde', 'en': 'Wadersloh-Diestedde'},
 '492521':{'de': 'Beckum', 'en': 'Beckum'},
 '492526':{'de': 'Sendenhorst', 'en': 'Sendenhorst'},
 '492527':{'de': 'Lippetal-Lippborg', 'en': 'Lippetal-Lippborg'},
 '492524':{'de': 'Ennigerloh', 'en': 'Ennigerloh'},
 '492525':{'de': 'Beckum-Neubeckum', 'en': 'Beckum-Neubeckum'},
 '55114247':{'en': 'Barueri - SP', 'pt': 'Barueri - SP'},
 '55115818':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115819':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115548':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114243':{'en': 'Cotia - SP', 'pt': 'Cotia - SP'},
 '499748':{'de': 'Motten', 'en': 'Motten'},
 '55114816':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55133231':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133232':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133236':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133237':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133238':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133239':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '4933085':{'de': 'Seilershof', 'en': 'Seilershof'},
 '55115542':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115543':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115812':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112261':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115547':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115816':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115545':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112642':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '495195':{'de': 'Neuenkirchen bei Soltau', 'en': 'Neuenkirchen bei Soltau'},
 '55113135':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55113133':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113138':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115932':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112643':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52658':{'en': 'Baja California', 'es': 'Baja California'},
 '494252':{'de': 'Bruchhausen-Vilsen', 'en': 'Bruchhausen-Vilsen'},
 '494253':{'de': 'Asendorf Kreis Diepholz', 'en': 'Asendorf Kreis Diepholz'},
 '494251':{'de': 'Hoya', 'en': 'Hoya'},
 '494256':{'de': 'Hilgermissen', 'en': 'Hilgermissen'},
 '494257':{'de': 'Schweringen', 'en': 'Schweringen'},
 '494254':{'de': 'Eystrup', 'en': 'Eystrup'},
 '494255':{'de': 'Martfeld', 'en': 'Martfeld'},
 '494258':{'de': 'Schwarme', 'en': 'Schwarme'},
 '493946':{'de': 'Quedlinburg', 'en': 'Quedlinburg'},
 '46173':{'en': u('\u00d6regrund-\u00d6sthammar')},
 '55113210':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '46171':{'en': u('Enk\u00f6ping'), 'sv': u('Enk\u00f6ping')},
 '46176':{'en': u('Norrt\u00e4lje'), 'sv': u('Norrt\u00e4lje')},
 '46175':{'en': 'Hallstavik-Rimbo', 'sv': 'Hallstavik-Rimbo'},
 '46174':{'en': 'Alunda', 'sv': 'Alunda'},
 '498573':{'de': 'Ering', 'en': 'Ering'},
 '498572':{'de': 'Tann Niederbayern', 'en': 'Tann Niederbayern'},
 '498571':{'de': 'Simbach am Inn', 'en': 'Simbach am Inn'},
 '492948':{'de': 'Lippstadt-Rebbeke', 'en': 'Lippstadt-Rebbeke'},
 '498574':{'de': 'Wittibreut', 'en': 'Wittibreut'},
 '492944':{'de': 'Rietberg-Mastholte', 'en': 'Rietberg-Mastholte'},
 '492945':{'de': 'Lippstadt-Benninghausen', 'en': 'Lippstadt-Benninghausen'},
 '492947':{'de': u('Anr\u00f6chte'), 'en': u('Anr\u00f6chte')},
 '492941':{'de': 'Lippstadt', 'en': 'Lippstadt'},
 '492942':{'de': 'Geseke', 'en': 'Geseke'},
 '492943':{'de': 'Erwitte', 'en': 'Erwitte'},
 '4935053':{'de': u('Glash\u00fctte Sachsen'), 'en': u('Glash\u00fctte Sachsen')},
 '4935052':{'de': 'Kipsdorf Kurort', 'en': 'Kipsdorf Kurort'},
 '4935057':{'de': 'Hermsdorf Erzgebirge', 'en': 'Hermsdorf Erzgebirge'},
 '4935056':{'de': 'Altenberg Sachsen', 'en': 'Altenberg Sachsen'},
 '4935055':{'de': u('H\u00f6ckendorf bei Dippoldiswalde'), 'en': u('H\u00f6ckendorf bei Dippoldiswalde')},
 '4935054':{'de': 'Lauenstein Sachsen', 'en': 'Lauenstein Sachsen'},
 '4935058':{'de': 'Pretzschendorf', 'en': 'Pretzschendorf'},
 '46281':{'en': 'Vansbro', 'sv': 'Vansbro'},
 '4936966':{'de': 'Kaltennordheim', 'en': 'Kaltennordheim'},
 '4939929':{'de': 'Jabel bei Waren', 'en': 'Jabel bei Waren'},
 '4936967':{'de': 'Geisa', 'en': 'Geisa'},
 '4939927':{'de': u('Nossentiner H\u00fctte'), 'en': u('Nossentiner H\u00fctte')},
 '4939926':{'de': u('Grabowh\u00f6fe'), 'en': u('Grabowh\u00f6fe')},
 '4939925':{'de': 'Wredenhagen', 'en': 'Wredenhagen'},
 '4939924':{'de': 'Stuer', 'en': 'Stuer'},
 '4939923':{'de': 'Priborn', 'en': 'Priborn'},
 '4939922':{'de': u('Dambeck bei R\u00f6bel'), 'en': u('Dambeck bei R\u00f6bel')},
 '4939921':{'de': 'Ankershagen', 'en': 'Ankershagen'},
 '52424':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52425':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52426':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '4936965':{'de': 'Stadtlengsfeld', 'en': 'Stadtlengsfeld'},
 '52421':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '52422':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '52423':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '4936962':{'de': 'Vacha', 'en': 'Vacha'},
 '52428':{'en': 'Ocampo/San Felipe, GTO', 'es': 'Ocampo/San Felipe, GTO'},
 '52429':{'en': 'Guanajuato', 'es': 'Guanajuato'},
 '4936963':{'de': u('Dorndorf Rh\u00f6n'), 'en': u('Dorndorf Rh\u00f6n')},
 '495495':{'de': u('V\u00f6rden Kreis Vechta'), 'en': u('V\u00f6rden Kreis Vechta')},
 '4936961':{'de': 'Bad Liebenstein', 'en': 'Bad Liebenstein'},
 '495767':{'de': 'Warmsen', 'en': 'Warmsen'},
 '499196':{'de': 'Wiesenttal', 'en': 'Wiesenttal'},
 '499197':{'de': 'Egloffstein', 'en': 'Egloffstein'},
 '499194':{'de': 'Ebermannstadt', 'en': 'Ebermannstadt'},
 '499195':{'de': 'Adelsdorf Mittelfranken', 'en': 'Adelsdorf Mittelfranken'},
 '499192':{'de': u('Gr\u00e4fenberg'), 'en': u('Gr\u00e4fenberg')},
 '499193':{'de': u('H\u00f6chstadt an der Aisch'), 'en': u('H\u00f6chstadt an der Aisch')},
 '499190':{'de': 'Heroldsbach', 'en': 'Heroldsbach'},
 '499191':{'de': 'Forchheim Oberfranken', 'en': 'Forchheim Oberfranken'},
 '55113701':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499198':{'de': 'Heiligenstadt in Oberfranken', 'en': 'Heiligenstadt in Oberfranken'},
 '499199':{'de': 'Kunreuth', 'en': 'Kunreuth'},
 '441328':{'en': 'Fakenham'},
 '441329':{'en': 'Fareham'},
 '441320':{'en': 'Fort Augustus'},
 '441322':{'en': 'Dartford'},
 '441323':{'en': 'Eastbourne'},
 '441324':{'en': 'Falkirk'},
 '441325':{'en': 'Darlington'},
 '441326':{'en': 'Falmouth'},
 '441327':{'en': 'Daventry'},
 '55113399':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4936968':{'de': u('Rossdorf Rh\u00f6n'), 'en': u('Rossdorf Rh\u00f6n')},
 '55113393':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4419468':{'en': 'Whitehaven'},
 '55113395':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55112918':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112919':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '44281':{'en': 'Northern Ireland'},
 '55112442':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '495351':{'de': 'Helmstedt', 'en': 'Helmstedt'},
 '55112440':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112441':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112446':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112447':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112444':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '55112445':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '49345':{'de': 'Halle Saale', 'en': 'Halle Saale'},
 '499221':{'de': 'Kulmbach', 'en': 'Kulmbach'},
 '499222':{'de': 'Presseck', 'en': 'Presseck'},
 '499223':{'de': 'Rugendorf', 'en': 'Rugendorf'},
 '49341':{'de': 'Leipzig', 'en': 'Leipzig'},
 '49340':{'de': 'Dessau Anh', 'en': 'Dessau Anh'},
 '49831':{'de': u('Kempten Allg\u00e4u'), 'en': u('Kempten Allg\u00e4u')},
 '499227':{'de': 'Neuenmarkt', 'en': 'Neuenmarkt'},
 '499228':{'de': 'Thurnau', 'en': 'Thurnau'},
 '499229':{'de': 'Mainleus', 'en': 'Mainleus'},
 '499523':{'de': 'Hofheim in Unterfranken', 'en': 'Hofheim in Unterfranken'},
 '4939221':{'de': u('M\u00f6ckern bei Magdeburg'), 'en': u('M\u00f6ckern bei Magdeburg')},
 '543563':{'en': u('Balnearia, C\u00f3rdoba'), 'es': u('Balnearia, C\u00f3rdoba')},
 '543562':{'en': u('Morteros, C\u00f3rdoba'), 'es': u('Morteros, C\u00f3rdoba')},
 '4939222':{'de': u('M\u00f6ser'), 'en': u('M\u00f6ser')},
 '543564':{'en': u('San Francisco, C\u00f3rdoba'), 'es': u('San Francisco, C\u00f3rdoba')},
 '4939223':{'de': 'Theessen', 'en': 'Theessen'},
 '4939224':{'de': u('B\u00fcden'), 'en': u('B\u00fcden')},
 '499526':{'de': 'Riedbach', 'en': 'Riedbach'},
 '495353':{'de': u('K\u00f6nigslutter am Elm'), 'en': u('K\u00f6nigslutter am Elm')},
 '4933848':{'de': 'Raben', 'en': 'Raben'},
 '4933849':{'de': 'Wiesenburg Mark', 'en': 'Wiesenburg Mark'},
 '4933846':{'de': 'Dippmannsdorf', 'en': 'Dippmannsdorf'},
 '4933847':{'de': u('G\u00f6rzke'), 'en': u('G\u00f6rzke')},
 '4933844':{'de': u('Br\u00fcck Brandenburg'), 'en': u('Br\u00fcck Brandenburg')},
 '4933845':{'de': 'Borkheide', 'en': 'Borkheide'},
 '4933843':{'de': 'Niemegk', 'en': 'Niemegk'},
 '437675':{'de': 'Ampflwang im Hausruckwald', 'en': 'Ampflwang im Hausruckwald'},
 '4933841':{'de': 'Belzig', 'en': 'Belzig'},
 '4939749':{'de': 'Grambow bei Pasewalk', 'en': 'Grambow bei Pasewalk'},
 '4939748':{'de': 'Viereck', 'en': 'Viereck'},
 '54280':{'en': 'Trelew/Rawson, Chubut', 'es': 'Trelew/Rawson, Chubut'},
 '4939743':{'de': 'Zerrenthin', 'en': 'Zerrenthin'},
 '4939742':{'de': u('Br\u00fcssow bei Pasewalk'), 'en': u('Br\u00fcssow bei Pasewalk')},
 '4939741':{'de': 'Jatznick', 'en': 'Jatznick'},
 '4939740':{'de': 'Nechlin', 'en': 'Nechlin'},
 '4939747':{'de': u('Z\u00fcsedom'), 'en': u('Z\u00fcsedom')},
 '4939746':{'de': 'Krackow', 'en': 'Krackow'},
 '4939745':{'de': 'Hetzdorf bei Strasburg', 'en': 'Hetzdorf bei Strasburg'},
 '4939744':{'de': 'Rothenklempenow', 'en': 'Rothenklempenow'},
 '4938296':{'de': 'Rerik Ostseebad', 'en': 'Rerik Ostseebad'},
 '4938297':{'de': 'Moitin', 'en': 'Moitin'},
 '4938294':{'de': 'Neubukow', 'en': 'Neubukow'},
 '495354':{'de': 'Jerxheim', 'en': 'Jerxheim'},
 '4938292':{'de': u('Kr\u00f6pelin'), 'en': u('Kr\u00f6pelin')},
 '4938293':{'de': u('K\u00fchlungsborn Ostseebad'), 'en': u('K\u00fchlungsborn Ostseebad')},
 '495355':{'de': 'Frellstedt', 'en': 'Frellstedt'},
 '55112923':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55114729':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114728':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114725':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114727':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114726':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '55114723':{'en': 'Mogi das Cruzes - SP', 'pt': 'Mogi das Cruzes - SP'},
 '495356':{'de': 'Helmstedt-Barmke', 'en': 'Helmstedt-Barmke'},
 '497462':{'de': 'Immendingen', 'en': 'Immendingen'},
 '497463':{'de': u('M\u00fchlheim an der Donau'), 'en': u('M\u00fchlheim an der Donau')},
 '497464':{'de': 'Talheim Kreis Tuttlingen', 'en': 'Talheim Kreis Tuttlingen'},
 '495357':{'de': 'Grasleben', 'en': 'Grasleben'},
 '498592':{'de': 'Wegscheid Niederbayern', 'en': 'Wegscheid Niederbayern'},
 '497231':{'de': 'Pforzheim', 'en': 'Pforzheim'},
 '497233':{'de': u('Niefern-\u00d6schelbronn'), 'en': u('Niefern-\u00d6schelbronn')},
 '497232':{'de': u('K\u00f6nigsbach-Stein'), 'en': u('K\u00f6nigsbach-Stein')},
 '497235':{'de': 'Unterreichenbach Kreis Calw', 'en': 'Unterreichenbach Kreis Calw'},
 '497234':{'de': 'Tiefenbronn', 'en': 'Tiefenbronn'},
 '497237':{'de': 'Neulingen Enzkreis', 'en': 'Neulingen Enzkreis'},
 '497236':{'de': 'Keltern', 'en': 'Keltern'},
 '495853':{'de': 'Neu Darchau', 'en': 'Neu Darchau'},
 '495852':{'de': 'Bleckede', 'en': 'Bleckede'},
 '495851':{'de': 'Dahlenburg', 'en': 'Dahlenburg'},
 '495850':{'de': 'Neetze', 'en': 'Neetze'},
 '495857':{'de': 'Bleckede-Brackede', 'en': 'Bleckede-Brackede'},
 '495855':{'de': 'Nahrendorf', 'en': 'Nahrendorf'},
 '495854':{'de': 'Bleckede-Barskamp', 'en': 'Bleckede-Barskamp'},
 '495859':{'de': 'Thomasburg', 'en': 'Thomasburg'},
 '495858':{'de': 'Hitzacker-Wietzetze', 'en': 'Hitzacker-Wietzetze'},
 '495509':{'de': u('Rosdorf Kreis G\u00f6ttingen'), 'en': u('Rosdorf Kreis G\u00f6ttingen')},
 '495508':{'de': 'Gleichen-Rittmarshausen', 'en': 'Gleichen-Rittmarshausen'},
 '4935875':{'de': u('Obercunnersdorf bei L\u00f6bau'), 'en': u('Obercunnersdorf bei L\u00f6bau')},
 '4935874':{'de': 'Bernstadt an der Eigen', 'en': 'Bernstadt an der Eigen'},
 '4935877':{'de': 'Cunewalde', 'en': 'Cunewalde'},
 '4935876':{'de': 'Weissenberg Sachsen', 'en': 'Weissenberg Sachsen'},
 '4935873':{'de': 'Herrnhut', 'en': 'Herrnhut'},
 '4935872':{'de': 'Neusalza-Spremberg', 'en': 'Neusalza-Spremberg'},
 '437667':{'de': 'Sankt Georgen im Attergau', 'en': 'St. Georgen im Attergau'},
 '441528':{'en': 'Laggan'},
 '441529':{'en': 'Sleaford'},
 '441526':{'en': 'Martin'},
 '441527':{'en': 'Redditch'},
 '441525':{'en': 'Leighton Buzzard'},
 '441522':{'en': 'Lincoln'},
 '441520':{'en': 'Lochcarron'},
 '495255':{'de': 'Altenbeken', 'en': 'Altenbeken'},
 '499254':{'de': 'Gefrees', 'en': 'Gefrees'},
 '495254':{'de': 'Paderborn-Schloss Neuhaus', 'en': 'Paderborn-Schloss Neuhaus'},
 '498262':{'de': 'Mittelneufnach', 'en': 'Mittelneufnach'},
 '498261':{'de': 'Mindelheim', 'en': 'Mindelheim'},
 '495257':{'de': u('H\u00f6velhof'), 'en': u('H\u00f6velhof')},
 '436241':{'de': 'Sankt Koloman', 'en': 'St. Koloman'},
 '436240':{'de': 'Krispl', 'en': 'Krispl'},
 '436243':{'de': 'Abtenau', 'en': 'Abtenau'},
 '436242':{'de': u('Ru\u00dfbach am Pa\u00df Gsch\u00fctt'), 'en': u('Russbach am Pass Gsch\u00fctt')},
 '436245':{'de': 'Hallein', 'en': 'Hallein'},
 '436244':{'de': 'Golling an der Salzach', 'en': 'Golling an der Salzach'},
 '436247':{'de': u('Gro\u00dfgmain'), 'en': 'Grossgmain'},
 '436246':{'de': u('Gr\u00f6dig'), 'en': u('Gr\u00f6dig')},
 '499765':{'de': 'Trappstadt', 'en': 'Trappstadt'},
 '499764':{'de': u('H\u00f6chheim'), 'en': u('H\u00f6chheim')},
 '499766':{'de': 'Grosswenkheim', 'en': 'Grosswenkheim'},
 '499761':{'de': u('Bad K\u00f6nigshofen im Grabfeld'), 'en': u('Bad K\u00f6nigshofen im Grabfeld')},
 '499763':{'de': 'Sulzdorf an der Lederhecke', 'en': 'Sulzdorf an der Lederhecke'},
 '499762':{'de': 'Saal an der Saale', 'en': 'Saal an der Saale'},
 '4934652':{'de': 'Allstedt', 'en': 'Allstedt'},
 '4934653':{'de': 'Rottleberode', 'en': 'Rottleberode'},
 '4934651':{'de': 'Rossla', 'en': 'Rossla'},
 '4934656':{'de': 'Wallhausen Sachsen-Anhalt', 'en': 'Wallhausen Sachsen-Anhalt'},
 '4934654':{'de': 'Stolberg Harz', 'en': 'Stolberg Harz'},
 '497907':{'de': u('Schw\u00e4bisch Hall-Sulzdorf'), 'en': u('Schw\u00e4bisch Hall-Sulzdorf')},
 '497906':{'de': 'Braunsbach', 'en': 'Braunsbach'},
 '4934658':{'de': 'Hayn Harz', 'en': 'Hayn Harz'},
 '4934659':{'de': 'Blankenheim bei Sangerhausen', 'en': 'Blankenheim bei Sangerhausen'},
 '497903':{'de': 'Mainhardt', 'en': 'Mainhardt'},
 '55113892':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113891':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113896':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113897':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113895':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4935329':{'de': 'Dollenchen', 'en': 'Dollenchen'},
 '55113898':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113899':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '493591':{'de': 'Bautzen', 'en': 'Bautzen'},
 '493592':{'de': 'Kirschau', 'en': 'Kirschau'},
 '55133291':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '493594':{'de': 'Bischofswerda', 'en': 'Bischofswerda'},
 '493596':{'de': 'Neustadt in Sachsen', 'en': 'Neustadt in Sachsen'},
 '49641':{'de': 'Giessen', 'en': 'Giessen'},
 '46346':{'en': 'Falkenberg', 'sv': 'Falkenberg'},
 '499502':{'de': 'Frensdorf', 'en': 'Frensdorf'},
 '46340':{'en': 'Varberg', 'sv': 'Varberg'},
 '46613':{'en': u('Ull\u00e5nger'), 'sv': u('Ull\u00e5nger')},
 '46611':{'en': u('H\u00e4rn\u00f6sand'), 'sv': u('H\u00e4rn\u00f6sand')},
 '55113098':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113092':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113093':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113091':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113096':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113097':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113094':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113095':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4660':{'en': u('Sundsval-Timr\u00e5'), 'sv': u('Sundsval-Timr\u00e5')},
 '4663':{'en': u('\u00d6stersund'), 'sv': u('\u00d6stersund')},
 '55114264':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '55114265':{'en': 'Itapecerica da Serra - SP', 'pt': 'Itapecerica da Serra - SP'},
 '5173':{'en': 'Piura'},
 '5172':{'en': 'Tumbes'},
 '5176':{'en': 'Cajamarca'},
 '441974':{'en': 'Llanon'},
 '55113278':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52671':{'en': 'Durango', 'es': 'Durango'},
 '441971':{'en': 'Scourie'},
 '52673':{'en': 'Sinoloa', 'es': 'Sinoloa'},
 '52672':{'en': 'Sinoloa', 'es': 'Sinoloa'},
 '52675':{'en': 'Durango', 'es': 'Durango'},
 '52674':{'en': 'Durango', 'es': 'Durango'},
 '52677':{'en': 'Durango', 'es': 'Durango'},
 '441970':{'en': 'Aberystwyth'},
 '52223':{'en': 'Puebla', 'es': 'Puebla'},
 '441972':{'en': 'Glenborrodale'},
 '4939246':{'de': 'Lindau Anh', 'en': 'Lindau Anh'},
 '4939247':{'de': u('G\u00fctergl\u00fcck'), 'en': u('G\u00fctergl\u00fcck')},
 '4939244':{'de': 'Steutz', 'en': 'Steutz'},
 '4939245':{'de': 'Loburg', 'en': 'Loburg'},
 '4939242':{'de': u('Pr\u00f6del'), 'en': u('Pr\u00f6del')},
 '4939243':{'de': 'Nedlitz bei Zerbst', 'en': 'Nedlitz bei Zerbst'},
 '4939241':{'de': 'Leitzkau', 'en': 'Leitzkau'},
 '55133348':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '4939248':{'de': 'Dobritz', 'en': 'Dobritz'},
 '52225':{'en': 'Tlapacoyan, VER', 'es': 'Tlapacoyan, VER'},
 '55133347':{'en': u('Guaruj\u00e1 - SP'), 'pt': u('Guaruj\u00e1 - SP')},
 '5333':{'en': u('Ciego de \u00c1vila Province')},
 '4935268':{'de': 'Stauchitz', 'en': 'Stauchitz'},
 '5332':{'en': u('Camag\u00fcey Province')},
 '4935263':{'de': u('Gr\u00f6ditz bei Riesa'), 'en': u('Gr\u00f6ditz bei Riesa')},
 '4935264':{'de': 'Strehla', 'en': 'Strehla'},
 '4935265':{'de': 'Glaubitz', 'en': 'Glaubitz'},
 '4935266':{'de': 'Heyda bei Riesa', 'en': 'Heyda bei Riesa'},
 '4935267':{'de': 'Diesbar-Seusslitz', 'en': 'Diesbar-Seusslitz'},
 '4938371':{'de': 'Karlshagen', 'en': 'Karlshagen'},
 '4938370':{'de': u('Kr\u00f6slin'), 'en': u('Kr\u00f6slin')},
 '4938373':{'de': 'Katzow', 'en': 'Katzow'},
 '4938372':{'de': 'Usedom', 'en': 'Usedom'},
 '4938375':{'de': 'Koserow', 'en': 'Koserow'},
 '4938374':{'de': 'Lassan bei Wolgast', 'en': 'Lassan bei Wolgast'},
 '4938377':{'de': 'Zinnowitz', 'en': 'Zinnowitz'},
 '4938376':{'de': 'Zirchow', 'en': 'Zirchow'},
 '4938379':{'de': 'Benz Usedom', 'en': 'Benz Usedom'},
 '4938378':{'de': 'Heringsdorf Seebad', 'en': 'Heringsdorf Seebad'},
 '55112057':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112056':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112059':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112058':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123224':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '55123221':{'en': u('Ca\u00e7apava - SP'), 'pt': u('Ca\u00e7apava - SP')},
 '499421':{'de': 'Straubing', 'en': 'Straubing'},
 '4939362':{'de': u('Grieben bei Tangerh\u00fctte'), 'en': u('Grieben bei Tangerh\u00fctte')},
 '493860':{'de': 'Raben Steinfeld', 'en': 'Raben Steinfeld'},
 '493861':{'de': 'Plate', 'en': 'Plate'},
 '493863':{'de': 'Crivitz', 'en': 'Crivitz'},
 '493865':{'de': 'Holthusen', 'en': 'Holthusen'},
 '493866':{'de': 'Cambs', 'en': 'Cambs'},
 '493867':{'de': u('L\u00fcbstorf'), 'en': u('L\u00fcbstorf')},
 '493868':{'de': 'Rastow', 'en': 'Rastow'},
 '493869':{'de': u('D\u00fcmmer'), 'en': u('D\u00fcmmer')},
 '55113545':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113525':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115721':{'en': u('Mau\u00e1 - SP'), 'pt': u('Mau\u00e1 - SP')},
 '496337':{'de': 'Grossbundenbach', 'en': 'Grossbundenbach'},
 '496336':{'de': 'Dellfeld', 'en': 'Dellfeld'},
 '496335':{'de': 'Trulben', 'en': 'Trulben'},
 '496334':{'de': u('Thaleischweiler-Fr\u00f6schen'), 'en': u('Thaleischweiler-Fr\u00f6schen')},
 '496333':{'de': 'Waldfischbach-Burgalben', 'en': 'Waldfischbach-Burgalben'},
 '496332':{'de': u('Zweibr\u00fccken'), 'en': u('Zweibr\u00fccken')},
 '496331':{'de': 'Pirmasens', 'en': 'Pirmasens'},
 '496339':{'de': 'Grosssteinhausen', 'en': 'Grosssteinhausen'},
 '496338':{'de': 'Hornbach Pfalz', 'en': 'Hornbach Pfalz'},
 '496629':{'de': 'Schenklengsfeld', 'en': 'Schenklengsfeld'},
 '496628':{'de': 'Oberaula', 'en': 'Oberaula'},
 '496621':{'de': 'Bad Hersfeld', 'en': 'Bad Hersfeld'},
 '496620':{'de': 'Philippsthal Werra', 'en': 'Philippsthal Werra'},
 '496623':{'de': 'Rotenburg an der Fulda', 'en': 'Rotenburg an der Fulda'},
 '496622':{'de': 'Bebra', 'en': 'Bebra'},
 '496625':{'de': 'Niederaula', 'en': 'Niederaula'},
 '496624':{'de': 'Heringen Werra', 'en': 'Heringen Werra'},
 '496627':{'de': 'Nentershausen Hessen', 'en': 'Nentershausen Hessen'},
 '496626':{'de': 'Wildeck-Obersuhl', 'en': 'Wildeck-Obersuhl'},
 '4939409':{'de': 'Eilsleben', 'en': 'Eilsleben'},
 '55133216':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133212':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55133213':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '543467':{'en': u('Cruz Alta, C\u00f3rdoba/San Jos\u00e9 de la Esquina, Santa Fe'), 'es': u('Cruz Alta, C\u00f3rdoba/San Jos\u00e9 de la Esquina, Santa Fe')},
 '55133219':{'en': 'Santos - SP', 'pt': 'Santos - SP'},
 '55114456':{'en': 'Salto - SP', 'pt': 'Salto - SP'},
 '55114454':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '492504':{'de': 'Telgte', 'en': 'Telgte'},
 '492505':{'de': 'Altenberge Westfalen', 'en': 'Altenberge Westfalen'},
 '492506':{'de': u('M\u00fcnster-Wolbeck'), 'en': u('M\u00fcnster-Wolbeck')},
 '492507':{'de': 'Havixbeck', 'en': 'Havixbeck'},
 '492052':{'de': 'Velbert-Langenberg', 'en': 'Velbert-Langenberg'},
 '492501':{'de': u('M\u00fcnster-Hiltrup'), 'en': u('M\u00fcnster-Hiltrup')},
 '492502':{'de': 'Nottuln', 'en': 'Nottuln'},
 '492051':{'de': 'Velbert', 'en': 'Velbert'},
 '496658':{'de': 'Poppenhausen Wasserkuppe', 'en': 'Poppenhausen Wasserkuppe'},
 '492508':{'de': 'Drensteinfurt', 'en': 'Drensteinfurt'},
 '492509':{'de': u('Nottuln-Appelh\u00fclsen'), 'en': u('Nottuln-Appelh\u00fclsen')},
 '492058':{'de': u('W\u00fclfrath'), 'en': u('W\u00fclfrath')},
 '497579':{'de': 'Schwenningen Baden', 'en': 'Schwenningen Baden'},
 '493675':{'de': u('Sonneberg Th\u00fcringen'), 'en': u('Sonneberg Th\u00fcringen')},
 '493677':{'de': u('Ilmenau Th\u00fcringen'), 'en': u('Ilmenau Th\u00fcringen')},
 '493671':{'de': 'Saalfeld Saale', 'en': 'Saalfeld Saale'},
 '493672':{'de': 'Rudolstadt', 'en': 'Rudolstadt'},
 '493679':{'de': 'Neuhaus am Rennweg', 'en': 'Neuhaus am Rennweg'},
 '55113804':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114181':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55114183':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55114182':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55114185':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55113807':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114186':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '441754':{'en': 'Skegness'},
 '441757':{'en': 'Selby'},
 '441756':{'en': 'Skipton'},
 '441751':{'en': 'Pickering'},
 '441750':{'en': 'Selkirk'},
 '441753':{'en': 'Slough'},
 '441752':{'en': 'Plymouth'},
 '494274':{'de': 'Varrel bei Sulingen', 'en': 'Varrel bei Sulingen'},
 '494275':{'de': 'Ehrenburg', 'en': 'Ehrenburg'},
 '494276':{'de': 'Borstel bei Sulingen', 'en': 'Borstel bei Sulingen'},
 '494277':{'de': u('Schwaf\u00f6rden'), 'en': u('Schwaf\u00f6rden')},
 '494902':{'de': 'Jemgum-Ditzum', 'en': 'Jemgum-Ditzum'},
 '494271':{'de': 'Sulingen', 'en': 'Sulingen'},
 '494272':{'de': 'Siedenburg', 'en': 'Siedenburg'},
 '494273':{'de': 'Kirchdorf bei Sulingen', 'en': 'Kirchdorf bei Sulingen'},
 '55113803':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4939208':{'de': 'Loitsche', 'en': 'Loitsche'},
 '44147989':{'en': 'Grantown-on-Spey'},
 '44147988':{'en': 'Grantown-on-Spey'},
 '44147987':{'en': 'Grantown-on-Spey'},
 '44147986':{'en': 'Cairngorm'},
 '44147985':{'en': 'Dulnain Bridge'},
 '44147984':{'en': 'Carrbridge'},
 '44147983':{'en': 'Boat of Garten'},
 '44147982':{'en': 'Nethy Bridge'},
 '44147981':{'en': 'Aviemore'},
 '44147980':{'en': 'Grantown-on-Spey'},
 '4939209':{'de': 'Wanzleben', 'en': 'Wanzleben'},
 '52775':{'en': 'Tulancingo, HGO', 'es': 'Tulancingo, HGO'},
 '436588':{'de': 'Lofer', 'en': 'Lofer'},
 '436589':{'de': 'Unken', 'en': 'Unken'},
 '436582':{'de': 'Saalfelden am Steinernen Meer', 'en': 'Saalfelden am Steinernen Meer'},
 '436583':{'de': 'Leogang', 'en': 'Leogang'},
 '436584':{'de': 'Maria Alm am Steinernen Meer', 'en': 'Maria Alm am Steinernen Meer'},
 '52442':{'en': 'Queretaro', 'es': u('Quer\u00e9taro')},
 '52443':{'en': 'Morelia/Tarimbaro, MICH', 'es': u('Morelia/Tar\u00edmbaro, MICH')},
 '52441':{'en': 'Queretaro', 'es': u('Quer\u00e9taro')},
 '52447':{'en': 'Contepec/Maravatio, MICH', 'es': u('Contepec/Maravat\u00edo, MICH')},
 '52444':{'en': 'San Luis Potosi, SLP', 'es': u('San Luis Potos\u00ed, SLP')},
 '52445':{'en': 'Moroleon, GTO', 'es': 'Moroleon, GTO'},
 '52448':{'en': 'Queretaro', 'es': u('Quer\u00e9taro')},
 '52449':{'en': 'Aguascalientes/Jesus Maria, AGS', 'es': u('Aguascalientes/Jes\u00fas Mar\u00eda, AGS')},
 '55115928':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112609':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112604':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112605':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112606':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112607':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55115920':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112601':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112602':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112603':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '441342':{'en': 'East Grinstead'},
 '441343':{'en': 'Elgin'},
 '441340':{'en': 'Craigellachie (Aberlour)'},
 '441341':{'en': 'Barmouth'},
 '441346':{'en': 'Fraserburgh'},
 '441347':{'en': 'Easingwold'},
 '49581':{'de': 'Uelzen', 'en': 'Uelzen'},
 '441348':{'en': 'Fishguard'},
 '441349':{'en': 'Dingwall'},
 '55113376':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113371':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112934':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112933':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112931':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '49361':{'de': 'Erfurt', 'en': 'Erfurt'},
 '49365':{'de': 'Gera', 'en': 'Gera'},
 '499242':{'de': u('G\u00f6\u00dfweinstein'), 'en': u('G\u00f6ssweinstein')},
 '499243':{'de': 'Pottenstein', 'en': 'Pottenstein'},
 '55115587':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499241':{'de': 'Pegnitz', 'en': 'Pegnitz'},
 '499246':{'de': 'Pegnitz-Trockau', 'en': 'Pegnitz-Trockau'},
 '499244':{'de': 'Betzenstein', 'en': 'Betzenstein'},
 '499245':{'de': 'Obertrubach', 'en': 'Obertrubach'},
 '55123929':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55113378':{'en': u('Jundia\u00ed - SP'), 'pt': u('Jundia\u00ed - SP')},
 '55123928':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '441967':{'en': 'Strontian'},
 '441962':{'en': 'Winchester'},
 '441963':{'en': 'Wincanton'},
 '441968':{'en': 'Penicuik'},
 '441969':{'en': 'Leyburn'},
 '5324':{'en': u('Holgu\u00edn Province')},
 '496438':{'de': u('H\u00fcnfelden'), 'en': u('H\u00fcnfelden')},
 '496439':{'de': 'Holzappel', 'en': 'Holzappel'},
 '5321':{'en': u('Guant\u00e1namo Province')},
 '496434':{'de': 'Bad Camberg', 'en': 'Bad Camberg'},
 '496435':{'de': 'Wallmerod', 'en': 'Wallmerod'},
 '496436':{'de': 'Dornburg Hessen', 'en': 'Dornburg Hessen'},
 '496430':{'de': u('Hahnst\u00e4tten'), 'en': u('Hahnst\u00e4tten')},
 '496431':{'de': 'Limburg an der Lahn', 'en': 'Limburg an der Lahn'},
 '496432':{'de': 'Diez', 'en': 'Diez'},
 '496433':{'de': 'Hadamar', 'en': 'Hadamar'},
 '55113518':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113513':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113512':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113515':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113514':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55123862':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '497453':{'de': u('Altensteig W\u00fcrttemberg'), 'en': u('Altensteig W\u00fcrttemberg')},
 '499931':{'de': 'Plattling', 'en': 'Plattling'},
 '499932':{'de': 'Osterhofen', 'en': 'Osterhofen'},
 '499933':{'de': 'Wallersdorf', 'en': 'Wallersdorf'},
 '46223':{'en': 'Fagersta-Norberg'},
 '4939328':{'de': 'Rochau', 'en': 'Rochau'},
 '496291':{'de': 'Adelsheim', 'en': 'Adelsheim'},
 '496292':{'de': 'Seckach', 'en': 'Seckach'},
 '496293':{'de': 'Schefflenz', 'en': 'Schefflenz'},
 '496294':{'de': 'Krautheim Jagst', 'en': 'Krautheim Jagst'},
 '46221':{'en': u('K\u00f6ping'), 'sv': u('K\u00f6ping')},
 '496296':{'de': 'Ahorn Baden', 'en': 'Ahorn Baden'},
 '496297':{'de': 'Ravenstein Baden', 'en': 'Ravenstein Baden'},
 '496298':{'de': u('M\u00f6ckm\u00fchl'), 'en': u('M\u00f6ckm\u00fchl')},
 '46220':{'en': 'Hallstahammar-Surahammar', 'sv': 'Hallstahammar-Surahammar'},
 '441652':{'en': 'Brigg'},
 '497165':{'de': u('G\u00f6ppingen-Hohenstaufen'), 'en': u('G\u00f6ppingen-Hohenstaufen')},
 '4939325':{'de': 'Vinzelberg', 'en': 'Vinzelberg'},
 '4939324':{'de': u('Kl\u00e4den bei Stendal'), 'en': u('Kl\u00e4den bei Stendal')},
 '441654':{'en': 'Machynlleth'},
 '4939327':{'de': 'Klietz', 'en': 'Klietz'},
 '441655':{'en': 'Maybole'},
 '492339':{'de': u('Sprockh\u00f6vel-Ha\u00dflinghausen'), 'en': u('Sprockh\u00f6vel-Hasslinghausen')},
 '492338':{'de': 'Breckerfeld', 'en': 'Breckerfeld'},
 '497748':{'de': 'Grafenhausen Hochschwarzwald', 'en': 'Grafenhausen Hochschwarzwald'},
 '492333':{'de': 'Ennepetal', 'en': 'Ennepetal'},
 '492332':{'de': 'Gevelsberg', 'en': 'Gevelsberg'},
 '492331':{'de': 'Hagen Westfalen', 'en': 'Hagen Westfalen'},
 '492330':{'de': 'Herdecke', 'en': 'Herdecke'},
 '492337':{'de': 'Hagen-Dahl', 'en': 'Hagen-Dahl'},
 '492336':{'de': 'Schwelm', 'en': 'Schwelm'},
 '492335':{'de': 'Wetter Ruhr', 'en': 'Wetter Ruhr'},
 '4939320':{'de': 'Schinne', 'en': 'Schinne'},
 '494825':{'de': 'Burg Dithmarschen', 'en': 'Burg Dithmarschen'},
 '494180':{'de': u('K\u00f6nigsmoor'), 'en': u('K\u00f6nigsmoor')},
 '495529':{'de': 'Rhumspringe', 'en': 'Rhumspringe'},
 '441659':{'en': 'Sanquhar'},
 '495527':{'de': 'Duderstadt', 'en': 'Duderstadt'},
 '495525':{'de': 'Walkenried', 'en': 'Walkenried'},
 '495524':{'de': 'Bad Lauterberg im Harz', 'en': 'Bad Lauterberg im Harz'},
 '495523':{'de': 'Bad Sachsa', 'en': 'Bad Sachsa'},
 '495522':{'de': 'Osterode am Harz', 'en': 'Osterode am Harz'},
 '495521':{'de': 'Herzberg am Harz', 'en': 'Herzberg am Harz'},
 '495520':{'de': 'Braunlage', 'en': 'Braunlage'},
 '4939057':{'de': u('R\u00e4tzlingen Sachsen-Anhalt'), 'en': u('R\u00e4tzlingen Sachsen-Anhalt')},
 '4939056':{'de': u('Kl\u00fcden'), 'en': u('Kl\u00fcden')},
 '494537':{'de': u('S\u00fclfeld Holstein'), 'en': u('S\u00fclfeld Holstein')},
 '4935895':{'de': 'Klitten', 'en': 'Klitten'},
 '4935894':{'de': u('H\u00e4hnichen'), 'en': u('H\u00e4hnichen')},
 '4935893':{'de': u('M\u00fccka'), 'en': u('M\u00fccka')},
 '4939055':{'de': u('H\u00f6rsingen'), 'en': u('H\u00f6rsingen')},
 '4935891':{'de': 'Rothenburg OL', 'en': 'Rothenburg OL'},
 '441508':{'en': 'Brooke'},
 '492196':{'de': 'Wermelskirchen', 'en': 'Wermelskirchen'},
 '492195':{'de': 'Radevormwald', 'en': 'Radevormwald'},
 '4939054':{'de': 'Flechtingen', 'en': 'Flechtingen'},
 '492193':{'de': 'Dabringhausen', 'en': 'Dabringhausen'},
 '494535':{'de': 'Nahe', 'en': 'Nahe'},
 '492191':{'de': 'Remscheid', 'en': 'Remscheid'},
 '55123861':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '4939053':{'de': u('S\u00fcplingen'), 'en': u('S\u00fcplingen')},
 '441502':{'en': 'Lowestoft'},
 '494534':{'de': 'Steinburg Kreis Storman', 'en': 'Steinburg Kreis Storman'},
 '441505':{'en': 'Johnstone'},
 '441506':{'en': 'Bathgate'},
 '4939052':{'de': 'Erxleben bei Haldensleben', 'en': 'Erxleben bei Haldensleben'},
 '55123863':{'en': 'Maresias - SP', 'pt': 'Maresias - SP'},
 '4939051':{'de': u('Calv\u00f6rde'), 'en': u('Calv\u00f6rde')},
 '55123864':{'en': u('S\u00e3o Sebasti\u00e3o - SP'), 'pt': u('S\u00e3o Sebasti\u00e3o - SP')},
 '441758':{'en': 'Pwllheli'},
 '4415399':{'en': 'Kendal'},
 '55123867':{'en': 'Maresias - SP', 'pt': 'Maresias - SP'},
 '499954':{'de': 'Simbach Niederbayern', 'en': 'Simbach Niederbayern'},
 '55114888':{'en': u('Joan\u00f3polis - SP'), 'pt': u('Joan\u00f3polis - SP')},
 '55123923':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '4939059':{'de': 'Wegenstedt', 'en': 'Wegenstedt'},
 '543835':{'en': u('Andalgal\u00e1, Catamarca'), 'es': u('Andalgal\u00e1, Catamarca')},
 '543837':{'en': 'Tinogasta, Catamarca', 'es': 'Tinogasta, Catamarca'},
 '4939058':{'de': u('Uthm\u00f6den'), 'en': u('Uthm\u00f6den')},
 '498284':{'de': 'Ziemetshausen', 'en': 'Ziemetshausen'},
 '52878':{'en': 'Piedras Negras, COAH', 'es': 'Piedras Negras, COAH'},
 '52873':{'en': 'Nuevo Leon', 'es': u('Nuevo Le\u00f3n')},
 '52872':{'en': 'Coahuila/Durango', 'es': 'Coahuila/Durango'},
 '52871':{'en': 'Coahuila', 'es': 'Coahuila'},
 '55123922':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '52877':{'en': 'Ciudad Acuna, COAH', 'es': u('Ciudad Acu\u00f1a, COAH')},
 '55115112':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55114881':{'en': 'Francisco Morato - SP', 'pt': 'Francisco Morato - SP'},
 '55112246':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498368':{'de': 'Halblech', 'en': 'Halblech'},
 '497961':{'de': 'Ellwangen Jagst', 'en': 'Ellwangen Jagst'},
 '497963':{'de': 'Adelmannsfelden', 'en': 'Adelmannsfelden'},
 '497962':{'de': 'Fichtenau', 'en': 'Fichtenau'},
 '497965':{'de': u('Ellwangen-R\u00f6hlingen'), 'en': u('Ellwangen-R\u00f6hlingen')},
 '497964':{'de': u('St\u00f6dtlen'), 'en': u('St\u00f6dtlen')},
 '497967':{'de': 'Jagstzell', 'en': 'Jagstzell'},
 '497966':{'de': 'Unterschneidheim', 'en': 'Unterschneidheim'},
 '498292':{'de': 'Dinkelscherben', 'en': 'Dinkelscherben'},
 '498293':{'de': 'Welden bei Augsburg', 'en': 'Welden bei Augsburg'},
 '498291':{'de': 'Zusmarshausen', 'en': 'Zusmarshausen'},
 '498296':{'de': 'Villenbach', 'en': 'Villenbach'},
 '498294':{'de': 'Horgau', 'en': 'Horgau'},
 '498295':{'de': u('Altenm\u00fcnster Schwaben'), 'en': u('Altenm\u00fcnster Schwaben')},
 '54298242':{'en': 'Orense, Buenos Aires', 'es': 'Orense, Buenos Aires'},
 '54298240':{'en': 'Orense, Buenos Aires', 'es': 'Orense, Buenos Aires'},
 '498363':{'de': 'Pfronten', 'en': 'Pfronten'},
 '55112684':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498361':{'de': 'Nesselwang', 'en': 'Nesselwang'},
 '55123927':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '55112685':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '46322':{'en': u('Alings\u00e5s-V\u00e5rg\u00e5rda'), 'sv': u('Alings\u00e5s-V\u00e5rg\u00e5rda')},
 '46320':{'en': 'Kinna', 'sv': 'Kinna'},
 '46321':{'en': 'Ulricehamn', 'sv': 'Ulricehamn'},
 '46325':{'en': 'Svenljunga-Tranemo', 'sv': 'Svenljunga-Tranemo'},
 '52389':{'en': 'Nayarit', 'es': 'Nayarit'},
 '52388':{'en': 'Jalisco', 'es': 'Jalisco'},
 '55112687':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113074':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113075':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113076':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113077':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52381':{'en': 'Cojumatlan/San Jose de Gracia, MICH', 'es': 'Cojumatlan/San Jose de Gracia, MICH'},
 '55113079':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52383':{'en': 'Michoacan', 'es': u('Michoac\u00e1n')},
 '498365':{'de': 'Wertach', 'en': 'Wertach'},
 '52385':{'en': 'Jalisco', 'es': 'Jalisco'},
 '52384':{'en': 'Tala/Teuchitlan, JAL', 'es': 'Tala/Teuchitlan, JAL'},
 '52387':{'en': 'Jalisco', 'es': 'Jalisco'},
 '4939321':{'de': 'Arneburg', 'en': 'Arneburg'},
 '4414309':{'en': 'Market Weighton'},
 '4414308':{'en': 'Market Weighton'},
 '43662':{'de': 'Salzburg', 'en': 'Salzburg'},
 '495551':{'de': 'Northeim', 'en': 'Northeim'},
 '4935389':{'de': 'Holzdorf Elster', 'en': 'Holzdorf Elster'},
 '4642':{'en': u('Helsingborg-H\u00f6gan\u00e4s'), 'sv': u('Helsingborg-H\u00f6gan\u00e4s')},
 '4414300':{'en': 'North Cave/Market Weighton'},
 '4640':{'en': u('Malm\u00f6'), 'sv': u('Malm\u00f6')},
 '4935388':{'de': u('Kl\u00f6den'), 'en': u('Kl\u00f6den')},
 '4646':{'en': 'Lund', 'sv': 'Lund'},
 '4414304':{'en': 'North Cave'},
 '4644':{'en': 'Kristianstad', 'sv': 'Kristianstad'},
 '4414306':{'en': 'Market Weighton'},
 '499747':{'de': 'Geroda Bayern', 'en': 'Geroda Bayern'},
 '499746':{'de': 'Zeitlofs', 'en': 'Zeitlofs'},
 '499745':{'de': 'Wildflecken', 'en': 'Wildflecken'},
 '499744':{'de': 'Zeitlofs-Detter', 'en': 'Zeitlofs-Detter'},
 '499742':{'de': u('Kalbach Rh\u00f6n'), 'en': u('Kalbach Rh\u00f6n')},
 '499741':{'de': u('Bad Br\u00fcckenau'), 'en': u('Bad Br\u00fcckenau')},
 '55114246':{'en': 'Mairinque - SP', 'pt': 'Mairinque - SP'},
 '4939862':{'de': u('Schm\u00f6lln bei Prenzlau'), 'en': u('Schm\u00f6lln bei Prenzlau')},
 '4935385':{'de': 'Annaburg', 'en': 'Annaburg'},
 '499749':{'de': 'Oberbach Unterfranken', 'en': 'Oberbach Unterfranken'},
 '494792':{'de': 'Worpswede', 'en': 'Worpswede'},
 '495907':{'de': 'Geeste', 'en': 'Geeste'},
 '52656':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '4935384':{'de': 'Steinsdorf bei Jessen', 'en': 'Steinsdorf bei Jessen'},
 '52653':{'en': 'Luis B. Sanchez/San Luis Rio Colorado, SON', 'es': u('Luis B. S\u00e1nchez/San Luis R\u00edo Colorado, SON')},
 '52652':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '52651':{'en': 'Sonoita, SON', 'es': 'Sonoita, SON'},
 '5151':{'en': 'Puno'},
 '55112688':{'en': 'Guarulhos - SP', 'pt': 'Guarulhos - SP'},
 '5153':{'en': 'Moquegua'},
 '5152':{'en': 'Tacna'},
 '5154':{'en': 'Arequipa'},
 '52659':{'en': 'Chihuahua', 'es': 'Chihuahua'},
 '5156':{'en': 'Ica'},
 '55113214':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113215':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498434':{'de': 'Rennertshofen', 'en': 'Rennertshofen'},
 '498435':{'de': 'Ehekirchen', 'en': 'Ehekirchen'},
 '498432':{'de': 'Burgheim', 'en': 'Burgheim'},
 '498433':{'de': u('K\u00f6nigsmoos'), 'en': u('K\u00f6nigsmoos')},
 '55113212':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '498431':{'de': 'Neuburg an der Donau', 'en': 'Neuburg an der Donau'},
 '55113219':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '499926':{'de': 'Frauenau', 'en': 'Frauenau'},
 '442889':{'en': 'Fivemiletown'},
 '442880':{'en': 'Carrickmore'},
 '442881':{'en': 'Newtownstewart'},
 '442882':{'en': 'Omagh'},
 '442885':{'en': 'Ballygawley'},
 '442886':{'en': 'Cookstown'},
 '442887':{'en': 'Dungannon'},
 '494735':{'de': 'Butjadingen-Stollhamm', 'en': 'Butjadingen-Stollhamm'},
 '494734':{'de': 'Stadland-Seefeld', 'en': 'Stadland-Seefeld'},
 '494737':{'de': 'Stadland-Schwei', 'en': 'Stadland-Schwei'},
 '494736':{'de': 'Butjadingen-Tossens', 'en': 'Butjadingen-Tossens'},
 '494731':{'de': 'Nordenham', 'en': 'Nordenham'},
 '4939225':{'de': 'Altengrabow', 'en': 'Altengrabow'},
 '494733':{'de': 'Butjadingen-Burhave', 'en': 'Butjadingen-Burhave'},
 '494732':{'de': 'Stadland-Rodenkirchen', 'en': 'Stadland-Rodenkirchen'},
 '4939322':{'de': u('Tangerm\u00fcnde'), 'en': u('Tangerm\u00fcnde')},
 '4935792':{'de': 'Ossling', 'en': 'Ossling'},
 '4935793':{'de': 'Elstra', 'en': 'Elstra'},
 '4935795':{'de': u('K\u00f6nigsbr\u00fcck'), 'en': u('K\u00f6nigsbr\u00fcck')},
 '4935796':{'de': 'Panschwitz-Kuckau', 'en': 'Panschwitz-Kuckau'},
 '4935797':{'de': 'Schwepnitz', 'en': 'Schwepnitz'},
 '4935242':{'de': 'Nossen', 'en': 'Nossen'},
 '4935243':{'de': u('Weinb\u00f6hla'), 'en': u('Weinb\u00f6hla')},
 '4935240':{'de': u('Tauscha bei Gro\u00dfenhain'), 'en': 'Tauscha bei Grossenhain'},
 '4935241':{'de': 'Lommatzsch', 'en': 'Lommatzsch'},
 '4935246':{'de': 'Ziegenhain Sachsen', 'en': 'Ziegenhain Sachsen'},
 '4935247':{'de': 'Zehren Sachsen', 'en': 'Zehren Sachsen'},
 '4935244':{'de': u('Kr\u00f6gis'), 'en': u('Kr\u00f6gis')},
 '4935245':{'de': 'Burkhardswalde-Munzig', 'en': 'Burkhardswalde-Munzig'},
 '4935248':{'de': u('Sch\u00f6nfeld bei Gro\u00dfenhain'), 'en': u('Sch\u00f6nfeld bei Grossenhain')},
 '4935249':{'de': 'Basslitz', 'en': 'Basslitz'},
 '441289':{'en': 'Berwick-upon-Tweed'},
 '441288':{'en': 'Bude'},
 '441287':{'en': 'Guisborough'},
 '441286':{'en': 'Caernarfon'},
 '441285':{'en': 'Cirencester'},
 '441284':{'en': 'Bury St Edmunds'},
 '441283':{'en': 'Burton-on-Trent'},
 '441282':{'en': 'Burnley'},
 '441280':{'en': 'Buckingham'},
 '497457':{'de': 'Rottenburg-Ergenzingen', 'en': 'Rottenburg-Ergenzingen'},
 '4939349':{'de': 'Parey Elbe', 'en': 'Parey Elbe'},
 '55112037':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112036':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112033':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112032':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112031':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '52981':{'en': 'Campeche, CAMP', 'es': 'Campeche, CAMP'},
 '55112038':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '54388':{'en': 'San Salvador de Jujuy, Jujuy', 'es': 'San Salvador de Jujuy, Jujuy'},
 '54387':{'en': 'Salta, Salta', 'es': 'Salta, Salta'},
 '54385':{'en': 'Santiago del Estero, Santiago del Estero', 'es': 'Santiago del Estero, Santiago del Estero'},
 '54383':{'en': 'San Fernando del Valle de Catamarca, Catamarca', 'es': 'San Fernando del Valle de Catamarca, Catamarca'},
 '54381':{'en': u('San Miguel de Tucum\u00e1n, Tucum\u00e1n'), 'es': u('San Miguel de Tucum\u00e1n, Tucum\u00e1n')},
 '54380':{'en': 'La Rioja, La Rioja', 'es': 'La Rioja, La Rioja'},
 '437956':{'de': u('Unterwei\u00dfenbach'), 'en': 'Unterweissenbach'},
 '55123908':{'en': u('S\u00e3o Jos\u00e9 dos Campos - SP'), 'pt': u('S\u00e3o Jos\u00e9 dos Campos - SP')},
 '52985':{'en': 'Yucatan', 'es': u('Yucat\u00e1n')},
 '52984':{'en': 'Quintana Roo', 'es': 'Quintana Roo'},
 '437954':{'de': 'Sankt Georgen am Walde', 'en': 'St. Georgen am Walde'},
 '437955':{'de': u('K\u00f6nigswiesen'), 'en': u('K\u00f6nigswiesen')},
 '497451':{'de': 'Horb am Neckar', 'en': 'Horb am Neckar'},
 '437736':{'de': 'Pram', 'en': 'Pram'},
 '437952':{'de': 'Weitersfelden', 'en': 'Weitersfelden'},
 '437734':{'de': 'Hofkirchen an der Trattnach', 'en': 'Hofkirchen an der Trattnach'},
 '437735':{'de': 'Gaspoltshofen', 'en': 'Gaspoltshofen'},
 '437732':{'de': 'Haag am Hausruck', 'en': 'Haag am Hausruck'},
 '437733':{'de': 'Neumarkt im Hausruckkreis', 'en': 'Neumarkt im Hausruckkreis'},
 '437953':{'de': 'Liebenau', 'en': 'Liebenau'},
 '52988':{'en': 'Yucatan', 'es': u('Yucat\u00e1n')},
 '495956':{'de': 'Rastdorf', 'en': 'Rastdorf'},
 '495957':{'de': 'Lindern Oldenburg', 'en': 'Lindern Oldenburg'},
 '495954':{'de': 'Lorup', 'en': 'Lorup'},
 '495955':{'de': 'Esterwegen', 'en': 'Esterwegen'},
 '495952':{'de': u('S\u00f6gel'), 'en': u('S\u00f6gel')},
 '495953':{'de': u('B\u00f6rger'), 'en': u('B\u00f6rger')},
 '495951':{'de': 'Werlte', 'en': 'Werlte'},
 '4933369':{'de': 'Oderberg', 'en': 'Oderberg'},
 '4933368':{'de': 'Hohensaaten', 'en': 'Hohensaaten'},
 '55114895':{'en': u('Nazar\u00e9 Paulista - SP'), 'pt': u('Nazar\u00e9 Paulista - SP')},
 '4933363':{'de': 'Altenhof Kreis Barnim', 'en': 'Altenhof Kreis Barnim'},
 '4933362':{'de': 'Liepe Kreis Barnim', 'en': 'Liepe Kreis Barnim'},
 '4933361':{'de': 'Joachimsthal', 'en': 'Joachimsthal'},
 '55115695':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '4933367':{'de': 'Friedrichswalde Brandenburg', 'en': 'Friedrichswalde Brandenburg'},
 '4933366':{'de': 'Chorin', 'en': 'Chorin'},
 '4933365':{'de': u('L\u00fcdersdorf Kreis Barnim'), 'en': u('L\u00fcdersdorf Kreis Barnim')},
 '4933364':{'de': 'Gross Ziethen Kreis Barnim', 'en': 'Gross Ziethen Kreis Barnim'},
 '496351':{'de': 'Eisenberg Pfalz', 'en': 'Eisenberg Pfalz'},
 '496353':{'de': 'Freinsheim', 'en': 'Freinsheim'},
 '496352':{'de': 'Kirchheimbolanden', 'en': 'Kirchheimbolanden'},
 '496355':{'de': 'Albisheim Pfrimm', 'en': 'Albisheim Pfrimm'},
 '496357':{'de': u('Standenb\u00fchl'), 'en': u('Standenb\u00fchl')},
 '496356':{'de': 'Carlsberg Pfalz', 'en': 'Carlsberg Pfalz'},
 '496359':{'de': u('Gr\u00fcnstadt'), 'en': u('Gr\u00fcnstadt')},
 '496358':{'de': 'Kriegsfeld', 'en': 'Kriegsfeld'},
 '55114882':{'en': u('Carapicu\u00edba - SP'), 'pt': u('Carapicu\u00edba - SP')},
 '55114886':{'en': 'Itu - SP', 'pt': 'Itu - SP'},
 '55114887':{'en': 'Jarinu - SP', 'pt': 'Jarinu - SP'},
 '497452':{'de': 'Nagold', 'en': 'Nagold'},
 '55112894':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55112897':{'en': u('S\u00e3o Bernardo do Campo - SP'), 'pt': u('S\u00e3o Bernardo do Campo - SP')},
 '55112896':{'en': u('Santo Andr\u00e9 - SP'), 'pt': u('Santo Andr\u00e9 - SP')},
 '55112893':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113636':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '55113637':{'en': u('S\u00e3o Paulo - SP'), 'pt': u('S\u00e3o Paulo - SP')},
 '492294':{'de': 'Morsbach Sieg', 'en': 'Morsbach Sieg'},
 '492295':{'de': 'Ruppichteroth', 'en': 'Ruppichteroth'},
 '492296':{'de': u('Reichshof-Br\u00fccherm\u00fchle'), 'en': u('Reichshof-Br\u00fccherm\u00fchle')},
 '492297':{'de': u('Wildbergerh\u00fctte'), 'en': u('Wildbergerh\u00fctte')},
 '492291':{'de': u('Waldbr\u00f6l'), 'en': u('Waldbr\u00f6l')},
 '492292':{'de': 'Windeck Sieg', 'en': 'Windeck Sieg'},
 '492293':{'de': u('N\u00fcmbrecht'), 'en': u('N\u00fcmbrecht')},
}
